Index: libgomp/ChangeLog
===================================================================
--- libgomp/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ libgomp/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,26 @@
+2017-09-15  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-09-14  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/81314
+	* testsuite/libgomp.c++/pr81314.C: New test.
+
+2017-09-07  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-08-09  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/81687
+	* testsuite/libgomp.c/pr81687-1.c: New test.
+	* testsuite/libgomp.c/pr81687-2.c: New test.
+
+	2017-07-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/45784
+	* testsuite/libgomp.c/pr45784.c: New test.
+	* testsuite/libgomp.c++/pr45784.C: New test.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: libgomp/testsuite/libgomp.c++/pr81314.C
===================================================================
--- libgomp/testsuite/libgomp.c++/pr81314.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libgomp/testsuite/libgomp.c++/pr81314.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,38 @@
+// PR c++/81314
+// { dg-do link }
+
+template <int N>
+struct S {
+  S () { s = 0; }
+  S (const S &x) { s = x.s; }
+  ~S () {}
+  int s;
+};
+
+void
+foo (S<2> &x)
+{
+  #pragma omp taskloop
+  for (int i = 0; i < 100; ++i)
+    x.s++;
+}
+
+void
+bar (S<3> &x)
+{
+  #pragma omp task
+  x.s++;
+}
+
+int
+main ()
+{
+  S<2> s;
+  S<3> t;
+  #pragma omp parallel
+  #pragma omp master
+  {
+    foo (s);
+    bar (t);
+  }
+}
Index: libgomp/testsuite/libgomp.c++/pr45784.C
===================================================================
--- libgomp/testsuite/libgomp.c++/pr45784.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libgomp/testsuite/libgomp.c++/pr45784.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,5 @@
+// PR c/45784
+// { dg-do run }
+
+#include "../libgomp.c/pr45784.c"
+
Index: libgomp/testsuite/libgomp.c/pr81687-2.c
===================================================================
--- libgomp/testsuite/libgomp.c/pr81687-2.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libgomp/testsuite/libgomp.c/pr81687-2.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,27 @@
+/* PR c/81687 */
+/* { dg-do link } */
+/* { dg-additional-options "-O2" } */
+
+int
+main ()
+{
+  __label__ lab4, lab5, lab6;
+  volatile int l = 0;
+  int m = l;
+  void foo (int x) { if (x == 1) goto lab4; }
+  void bar (int x) { if (x == 2) goto lab5; }
+  void baz (int x) { if (x == 3) goto lab6; }
+  #pragma omp parallel
+  {
+    foo (m + 1);
+   lab4:;
+  }
+  #pragma omp task
+  {
+    bar (m + 2);
+   lab5:;
+  }
+  baz (m + 3);
+ lab6:;
+  return 0;
+}
Index: libgomp/testsuite/libgomp.c/pr45784.c
===================================================================
--- libgomp/testsuite/libgomp.c/pr45784.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libgomp/testsuite/libgomp.c/pr45784.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,41 @@
+/* PR c/45784 */
+/* { dg-do run } */
+
+void
+foo (int n)
+{
+  char *p, vla[2 * n];
+  int i;
+  #pragma omp parallel for
+  for (p = vla; p < vla + (sizeof (vla) / sizeof (vla[0])); p++)
+    *p = ' ';
+  #pragma omp parallel for
+  for (i = 0; i < 2 * n; i++)
+    if (vla[i] != ' ')
+      __builtin_abort ();
+}
+
+void
+bar (int n)
+{
+  char *p, vla1[n], vla2[n * 2], vla3[n * 3], vla4[n * 4];
+  int i;
+  __builtin_memset (vla4, ' ', n * 4);
+  #pragma omp parallel for
+  for (p = vla4 + sizeof (vla1); p < vla4 + sizeof (vla3) - sizeof (vla2) + sizeof (vla1); p += sizeof (vla4) / sizeof (vla4))
+    p[0] = '!';
+  #pragma omp parallel for
+  for (i = 0; i < n * 4; i++)
+    if (vla4[i] != ((i >= n && i < 2 * n) ? '!' : ' '))
+      __builtin_abort ();
+}
+
+int
+main ()
+{
+  volatile int n;
+  n = 128;
+  foo (n);
+  bar (n);
+  return 0;
+}
Index: libgomp/testsuite/libgomp.c/pr81687-1.c
===================================================================
--- libgomp/testsuite/libgomp.c/pr81687-1.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libgomp/testsuite/libgomp.c/pr81687-1.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,23 @@
+/* PR c/81687 */
+/* { dg-do link } */
+/* { dg-additional-options "-O2" } */
+
+extern int printf (const char *, ...);
+
+int
+main ()
+{
+  #pragma omp parallel
+  {
+   lab1:
+    printf ("lab1=%p\n", (void *)(&&lab1));
+  }
+ lab2:
+  #pragma omp parallel
+  {
+   lab3:
+    printf ("lab2=%p\n", (void *)(&&lab2));
+  }
+  printf ("lab3=%p\n", (void *)(&&lab3));
+  return 0;
+}
Index: libsanitizer/include/system/sys/ptrace.h
===================================================================
--- libsanitizer/include/system/sys/ptrace.h	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libsanitizer/include/system/sys/ptrace.h	(.../branches/gcc-7-branch)
@@ -0,0 +1,7 @@
+#include_next <sys/ptrace.h>
+#ifndef PTRACE_GETREGSET
+/* glibc before
+   https://sourceware.org/git/?p=glibc.git;a=commitdiff;h=cbff0d9689c4d68578b6a4f0a17807232506ea27
+   doesn't define PTRACE_GETREGSET.  */
+#define PTRACE_GETREGSET 0x4204
+#endif
Index: libsanitizer/ChangeLog
===================================================================
--- libsanitizer/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ libsanitizer/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,25 @@
+2017-10-20  Jakub Jelinek  <jakub@redhat.com>
+
+	PR sanitizer/82595
+	* lsan/Makefile.am (lsan_files): Remove lsan_preinit.cc.
+	* lsan/Makefile.in: Regenerated.
+
+2017-10-05  H.J. Lu  <hongjiu.lu@intel.com>
+
+	Backported from mainline
+	2017-10-05  H.J. Lu  <hongjiu.lu@intel.com>
+
+	PR sanitizer/82379
+	* configure.tgt (SANITIZER_COMMON_TARGET_DEPENDENT_OBJECTS): Set
+	to sanitizer_linux_x86_64.lo if __x86_64__ is defined by $CC.
+
+2017-09-07  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-08-07  Jakub Jelinek  <jakub@redhat.com>
+
+	* include/system/sys/ptrace.h: New file.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: libsanitizer/lsan/Makefile.in
===================================================================
--- libsanitizer/lsan/Makefile.in	(.../tags/gcc_7_2_0_release)
+++ libsanitizer/lsan/Makefile.in	(.../branches/gcc-7-branch)
@@ -109,7 +109,7 @@
 	$(am__append_1) $(am__DEPENDENCIES_1)
 am__objects_1 = lsan_common.lo lsan_common_linux.lo
 am__objects_2 = $(am__objects_1) lsan.lo lsan_allocator.lo \
-	lsan_interceptors.lo lsan_preinit.lo lsan_thread.lo
+	lsan_interceptors.lo lsan_thread.lo
 am_liblsan_la_OBJECTS = $(am__objects_2)
 liblsan_la_OBJECTS = $(am_liblsan_la_OBJECTS)
 liblsan_la_LINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) \
@@ -306,7 +306,6 @@
 	lsan.cc \
 	lsan_allocator.cc \
 	lsan_interceptors.cc \
-	lsan_preinit.cc \
 	lsan_thread.cc
 
 libsanitizer_lsan_la_SOURCES = $(sanitizer_lsan_files)
@@ -447,7 +446,6 @@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lsan_common.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lsan_common_linux.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lsan_interceptors.Plo@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lsan_preinit.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lsan_thread.Plo@am__quote@
 
 .cc.o:
Index: libsanitizer/lsan/Makefile.am
===================================================================
--- libsanitizer/lsan/Makefile.am	(.../tags/gcc_7_2_0_release)
+++ libsanitizer/lsan/Makefile.am	(.../branches/gcc-7-branch)
@@ -23,7 +23,6 @@
 	lsan.cc \
 	lsan_allocator.cc \
 	lsan_interceptors.cc \
-	lsan_preinit.cc \
 	lsan_thread.cc
 
 libsanitizer_lsan_la_SOURCES = $(sanitizer_lsan_files)
Index: libsanitizer/configure.tgt
===================================================================
--- libsanitizer/configure.tgt	(.../tags/gcc_7_2_0_release)
+++ libsanitizer/configure.tgt	(.../branches/gcc-7-branch)
@@ -27,6 +27,8 @@
 		TSAN_SUPPORTED=yes
 		LSAN_SUPPORTED=yes
 		TSAN_TARGET_DEPENDENT_OBJECTS=tsan_rtl_amd64.lo
+	fi
+	if echo "int x = __x86_64__;" | $CC -c -x c -o /dev/null - > /dev/null 2>&1; then
 		SANITIZER_COMMON_TARGET_DEPENDENT_OBJECTS=sanitizer_linux_x86_64.lo
 	fi
 	;;
Index: libstdc++-v3/doc/xml/manual/status_cxxtr1.xml
===================================================================
--- libstdc++-v3/doc/xml/manual/status_cxxtr1.xml	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/xml/manual/status_cxxtr1.xml	(.../branches/gcc-7-branch)
@@ -22,8 +22,7 @@
 </para>
 
 <para>
-This page describes the TR1 support in mainline GCC SVN, not in any particular
-release.
+This page describes the TR1 support in the GCC 7 series.
 </para>
 
 <!-- Status is Yes or No, Broken/Partial-->
Index: libstdc++-v3/doc/xml/manual/status_cxx1998.xml
===================================================================
--- libstdc++-v3/doc/xml/manual/status_cxx1998.xml	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/xml/manual/status_cxx1998.xml	(.../branches/gcc-7-branch)
@@ -18,8 +18,7 @@
 </para>
 
 <para>
-This page describes the C++ support in mainline GCC SVN, not in any
-particular release.
+This page describes the C++ support in the GCC 7 series.
 </para>
 
 <!-- Status is Yes or No, Broken/Partial-->
Index: libstdc++-v3/doc/xml/manual/status_cxx2011.xml
===================================================================
--- libstdc++-v3/doc/xml/manual/status_cxx2011.xml	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/xml/manual/status_cxx2011.xml	(.../branches/gcc-7-branch)
@@ -27,8 +27,7 @@
 </para>
 
 <para>
-This page describes the C++11 support in mainline GCC SVN, not in any
-particular release.
+This page describes the C++11 support in the GCC 7 series.
 </para>
 
 <!-- Status is Yes or No, Broken/Partial-->
Index: libstdc++-v3/doc/xml/manual/status_cxx2014.xml
===================================================================
--- libstdc++-v3/doc/xml/manual/status_cxx2014.xml	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/xml/manual/status_cxx2014.xml	(.../branches/gcc-7-branch)
@@ -20,8 +20,7 @@
 </para>
 
 <para>
-This page describes the C++14 and library TS support in mainline GCC SVN,
-not in any particular release.
+This page describes the C++14 and library TS support in the GCC 7 series.
 </para>
 
 <table frame="all" xml:id="table.cxx14_status">
Index: libstdc++-v3/doc/xml/manual/status_cxx2017.xml
===================================================================
--- libstdc++-v3/doc/xml/manual/status_cxx2017.xml	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/xml/manual/status_cxx2017.xml	(.../branches/gcc-7-branch)
@@ -1,17 +1,17 @@
 <section xmlns="http://docbook.org/ns/docbook" version="5.0" 
-	 xml:id="status.iso.201z" xreflabel="Status C++ 201z">
-<?dbhtml filename="status_iso_cxx201z.html"?>
+	 xml:id="status.iso.2017" xreflabel="Status C++ 2017">
+<?dbhtml filename="status_iso_cxx2017.html"?>
 
-<info><title>C++ 201z</title>
+<info><title>C++ 2017</title>
   <keywordset>
     <keyword>ISO C++</keyword>
-    <keyword>201z</keyword>
+    <keyword>2017</keyword>
   </keywordset>
 </info>
 
 <para>
-In this implementation the <literal>-std=gnu++1z</literal> or
-<literal>-std=c++1z</literal> flag must be used to enable language
+In this implementation the <literal>-std=gnu++17</literal> or
+<literal>-std=c++17</literal> flag must be used to enable language
 and library
 features. See <link linkend="manual.intro.using.flags">dialect</link>
 options. The pre-defined symbol
@@ -20,13 +20,12 @@
 </para>
 
 <para>
-This section describes the C++1z and library TS support in mainline GCC SVN,
-not in any particular release.
+This section describes the C++17 and library TS support in the GCC 7 series.
 </para>
 
 <para>
 The following table lists new library features that have been accepted into
-the C++1z working draft. The "Proposal" column provides a link to the
+the C++17 working draft. The "Proposal" column provides a link to the
 ISO C++ committee proposal that describes the feature, while the "Status"
 column indicates the first version of GCC that contains an implementation of
 this feature (if it has been implemented).
@@ -35,8 +34,8 @@
 Feature-testing recommendations for C++</link>.
 </para>
 
-<table frame="all" xml:id="table.cxx1z_status">
-<title>C++ 201z Implementation Status</title>
+<table frame="all" xml:id="table.cxx17_status">
+<title>C++ 2017 Implementation Status</title>
 
 <tgroup cols="4" align="left" colsep="0" rowsep="1">
 <colspec colname="c1"/>
@@ -75,7 +74,7 @@
 	P0137R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry> <code>__cpp_lib_launder >= 201606</code> </entry>
     </row>
 
@@ -97,8 +96,11 @@
 	P0088R3
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
-      <entry> <code>__has_include(&lt;variant&gt;)</code> </entry>
+      <entry align="center"> 7.1 </entry>
+      <entry> <code>__has_include(&lt;variant&gt;)</code>,
+              <code>__cpp_lib_variant >= 201603</code>
+              (since 7.3, see Note 1)
+      </entry>
     </row>
 
     <row>
@@ -108,8 +110,11 @@
 	P0220R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
-      <entry> <code>__has_include(&lt;optional&gt;)</code> </entry>
+      <entry align="center"> 7.1 </entry>
+      <entry> <code>__has_include(&lt;optional&gt;)</code>,
+              <code>__cpp_lib_optional >= 201603</code>
+              (since 7.3, see Note 1)
+      </entry>
     </row>
 
     <row>
@@ -119,8 +124,11 @@
 	P0220R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
-      <entry> <code>__has_include(&lt;any&gt;)</code> </entry>
+      <entry align="center"> 7.1 </entry>
+      <entry> <code>__has_include(&lt;any&gt;)</code>,
+              <code>__cpp_lib_any >= 201603</code>
+              (since 7.3, see Note 1)
+      </entry>
     </row>
 
     <row>
@@ -130,8 +138,11 @@
 	P0220R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
-      <entry> <code>__has_include(&lt;string_view&gt;)</code> </entry>
+      <entry align="center"> 7.1 </entry>
+      <entry> <code>__has_include(&lt;string_view&gt;)</code>,
+              <code>__cpp_lib_string_view >= 201603</code>
+              (since 7.3, see Note 1)
+      </entry>
     </row>
 
     <row>
@@ -143,7 +154,9 @@
 	</link>
       </entry>
       <entry align="center"> No </entry>
-      <entry> <code>__has_include(&lt;memory_resource&gt;)</code> </entry>
+      <entry> <code>__has_include(&lt;memory_resource&gt;)</code>,
+              <code>__cpp_lib_memory_resource >= 201603</code>
+      </entry>
     </row>
 
     <row>
@@ -153,7 +166,7 @@
 	P0220R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry> <code>__cpp_lib_apply >= 201603</code> </entry>
     </row>
 
@@ -164,7 +177,7 @@
 	P0220R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry> <code>__cpp_lib_shared_ptr_arrays >= 201603</code> </entry>
     </row>
 
@@ -175,7 +188,7 @@
 	P0220R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry> <code>__cpp_lib_boyer_moore_searcher >= 201603</code> </entry>
     </row>
 
@@ -186,7 +199,7 @@
 	P0220R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry> <code>__cpp_lib_sample >= 201603</code> </entry>
     </row>
 
@@ -197,7 +210,7 @@
 	P0007R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_as_const >= 201510 </code></entry>
     </row>
 
@@ -219,7 +232,7 @@
 	P0209R2
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_make_from_tuple >= 201606 </code></entry>
     </row>
 
@@ -257,7 +270,7 @@
 	P0074R0
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_transparent_operators >= 201510 </code></entry>
     </row>
 
@@ -268,7 +281,7 @@
 	LWG2296
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_addressof_constexpr >= 201603 </code></entry>
     </row>
 
@@ -301,7 +314,7 @@
 	P0033R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code>__cpp_lib_enable_shared_from_this >= 201603</code></entry>
     </row>
 
@@ -334,7 +347,7 @@
 	P0005R4
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code>__cpp_lib_not_fn >= 201603</code></entry>
     </row>
 
@@ -345,7 +358,7 @@
 	P0358R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry/>
     </row>
 
@@ -356,7 +369,7 @@
 	P0253R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry/>
     </row>
 
@@ -367,7 +380,7 @@
 	P0040R3
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> </code></entry>
     </row>
 
@@ -378,7 +391,7 @@
 	P0163R0
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_shared_ptr_weak_type >= 201606</code></entry>
     </row>
 
@@ -411,7 +424,7 @@
 	P0006R0
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_type_trait_variable_templates >= 201510 </code></entry>
     </row>
 
@@ -444,7 +457,7 @@
 	P0077R2
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_is_callable >= 201603 </code></entry>
     </row>
 
@@ -455,7 +468,7 @@
 	P0258R2
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_has_unique_object_representations >= 201606 </code></entry>
     </row>
 
@@ -466,7 +479,7 @@
 	P0092R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_chrono >= 201510 </code></entry>
     </row>
 
@@ -477,12 +490,13 @@
 	P0505R0
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
-      <entry><code> ??? </code></entry>
+      <entry align="center"> 7.1 </entry>
+      <entry><code> __cpp_lib_chrono >= 201611 </code>
+             (since 7.3, see Note 2)
+      </entry>
     </row>
 
     <row>
-      <?dbhtml bgcolor="#B0B0B0" ?>
       <entry> Constexpr for <code>std::char_traits</code> </entry>
       <entry>
 	<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0426r1.html">
@@ -489,8 +503,8 @@
 	P0426R1
 	</link>
       </entry>
-      <entry align="center"> 7 (partial) </entry>
-      <entry><code> ??? </code></entry>
+      <entry align="center"> 7.3 </entry>
+      <entry><code> __cpp_lib_constexpr_char_traits >= 201611 </code></entry>
     </row>
 
     <row>
@@ -500,7 +514,7 @@
 	P0254R2
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> </code></entry>
     </row>
 
@@ -511,7 +525,7 @@
 	P0272R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> </code></entry>
     </row>
 
@@ -544,9 +558,9 @@
 	N4510
 	</link>
       </entry>
-      <entry align="center"> 6.2 (3.0)</entry>
+      <entry align="center"> 3.0 </entry>
       <entry><code> __cpp_lib_incomplete_container_elements >= 201505 </code>
-	     (the feature was always supported, but the macro was not defined until GCC 6.2)
+	     (since 6.2, see Note 2)
       </entry>
     </row>
 
@@ -557,8 +571,8 @@
 	P0084R2
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
-      <entry><code> ??? </code></entry>
+      <entry align="center"> 7.1 </entry>
+      <entry/>
     </row>
 
     <row>
@@ -581,7 +595,7 @@
 	P0083R3
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_node_extract >= 201606 </code></entry>
     </row>
 
@@ -603,7 +617,7 @@
 	P0031R0
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_array_constexpr >= 201603 </code></entry>
     </row>
 
@@ -617,7 +631,9 @@
       </entry>
       <entry align="center"> No </entry>
       <entry><code> __has_include(&lt;execution&gt;) </code>,
-	     <code> __cpp_lib_parallel_algorithm >= 201603 </code></entry>
+	     <code> __cpp_lib_execution >= 201603 </code>,
+	     <code> __cpp_lib_parallel_algorithm >= 201603 </code>
+      </entry>
     </row>
 
     <row>
@@ -627,7 +643,7 @@
 	P0025R0
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_clamp >= 201603 </code></entry>
     </row>
 
@@ -638,10 +654,8 @@
 	P0295R0
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
-      <entry><code> __cpp_lib_gcd >= 201606 </code>,
-	     <code> __cpp_lib_lcm >= 201606 </code>
-      </entry>
+      <entry align="center"> 7.1 </entry>
+      <entry><code> __cpp_lib_gcd_lcm >= 201606 </code></entry>
     </row>
 
     <row>
@@ -651,7 +665,7 @@
 	P0030R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_hypot >= 201603 </code></entry>
     </row>
 
@@ -662,11 +676,9 @@
 	P0226R1
 	</link>
       </entry>
-      <entry align="center"> 7 (6.1) </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_math_special_functions >= 201603 </code>
-	     (for GCC 6 or pre-C++17 define
-	     <code>__STDCPP_WANT_MATH_SPEC_FUNCS__</code> to a non-zero value
-	     and test for <code>__STDCPP_MATH_SPEC_FUNCS__ >= 201003L</code>)
+	     (see Note 3)
       </entry>
     </row>
 
@@ -692,7 +704,7 @@
 	</link>
       </entry>
       <entry align="center"> No </entry>
-      <entry/>
+      <entry><code> __cpp_lib_filesystem >= 201606 </code></entry>
     </row>
 
     <row>
@@ -704,10 +716,22 @@
 	</link>
       </entry>
       <entry align="center"> No </entry>
-      <entry/>
+      <entry><code> __cpp_lib_filesystem >= 201606 </code></entry>
     </row>
 
     <row>
+      <?dbhtml bgcolor="#C8B0B0" ?>
+      <entry> Directory Entry Caching for Filesystem </entry>
+      <entry>
+       <link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0317r1.html">
+       P0317R1
+       </link>
+      </entry>
+      <entry align="center"> No </entry>
+      <entry><code> __cpp_lib_filesystem >= 201703 </code></entry>
+     </row>
+
+    <row>
       <entry> constexpr <code>atomic&lt;T&gt;::is_always_lock_free</code>	 </entry>
       <entry>
 	<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0152r1.html">
@@ -714,7 +738,7 @@
 	P0152R1
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_atomic_is_always_lock_free >= 201603 </code></entry>
     </row>
 
@@ -730,29 +754,30 @@
     </row>
 
     <row>
-      <entry> Variadic <code>lock_guard</code> </entry>
+      <entry> Variadic <code>lock_guard</code> (Rev. 5) </entry>
       <entry>
 	<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2017/p0156r2.html">
 	P0156R2
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
+      <entry align="center"> 7.1 </entry>
       <entry><code> __cpp_lib_scoped_lock >= 201703 </code></entry>
     </row>
 
     <row>
-      <entry> byte type definition </entry>
+      <entry> A byte type definition </entry>
       <entry>
 	<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2017/p0298r3.pdf">
 	P0298R3
 	</link>
       </entry>
-      <entry align="center"> 7 </entry>
-      <entry><code> ??? </code></entry>
+      <entry align="center"> 7.1 </entry>
+      <entry><code> __cpp_lib_byte >= 201603 </code> (since 7.3, see Note 2)
+      </entry>
     </row>
 
     <row>
-      <?dbhtml bgcolor="#C8B0B0" ?>
+      <?dbhtml bgcolor="#B0B0B0" ?>
       <entry> Elementary string conversions </entry>
       <entry>
 	<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0067r5.html">
@@ -759,8 +784,9 @@
 	P0067R5
 	</link>
       </entry>
-      <entry align="center"> No </entry>
-      <entry><code> ??? </code></entry>
+      <entry align="center"> 8 (only integral types supported) </entry>
+      <entry><code> __has_include(&lt;charconv&gt;) </code>
+             <code> __cpp_lib_to_chars >= 201611 </code></entry>
     </row>
 
 
@@ -768,8 +794,26 @@
 </tgroup>
 </table>
 
+<para>
+Note 1: This feature is supported in GCC 7.1 and 7.2 but before GCC 7.3 the
+<code>__cpp_lib</code> macro is not defined, and compilation will fail if the
+header is included without using <option>-std</option> to enable C++17 support.
+</para>
 
-<table frame="all" xml:id="table.cxx1z_ts_status">
+<para>
+Note 2: This feature is supported in older releases but the
+<code>__cpp_lib</code> macro is not defined to the right value
+(or not defined at all) until the version shown in parentheses.
+</para>
+
+<para>
+Note 3: The mathematical special functions are enabled in C++17 mode from
+GCC 7.1 onwards. For GCC 6.x or for C++11/C++14 define
+<code>__STDCPP_WANT_MATH_SPEC_FUNCS__</code> to a non-zero value
+and test for <code>__STDCPP_MATH_SPEC_FUNCS__ >= 201003L</code>.
+</para>
+
+<table frame="all" xml:id="table.cxx17_ts_status">
 <title>C++ Technical Specifications Implementation Status</title>
 
 <tgroup cols="4" align="left" colsep="0" rowsep="1">
Index: libstdc++-v3/doc/xml/manual/extensions.xml
===================================================================
--- libstdc++-v3/doc/xml/manual/extensions.xml	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/xml/manual/extensions.xml	(.../branches/gcc-7-branch)
@@ -502,7 +502,7 @@
     <quote>demangling.</quote>
   </para>
   <para>
-    If you have read the <link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:href="http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a01115.html">source
+    If you have read the <link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:href="http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/namespaces.html">source
     documentation for <code>namespace abi</code></link> then you are
     aware of the cross-vendor C++ ABI in use by GCC.  One of the
     exposed functions is used for demangling,
Index: libstdc++-v3/doc/xml/manual/status_cxxtr24733.xml
===================================================================
--- libstdc++-v3/doc/xml/manual/status_cxxtr24733.xml	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/xml/manual/status_cxxtr24733.xml	(.../branches/gcc-7-branch)
@@ -16,8 +16,7 @@
 </para>
 
 <para>
-This page describes the TR 24733 support in mainline GCC SVN, not in any
-particular release.
+This page describes the TR 24733 support in the GCC 7 series.
 </para>
 
 <!-- Status is Yes or No, Broken/Partial-->
Index: libstdc++-v3/doc/html/bk02.html
===================================================================
--- libstdc++-v3/doc/html/bk02.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/bk02.html	(.../branches/gcc-7-branch)
@@ -1,2 +1,2 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title></title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library" /><link rel="prev" href="manual/backwards.html" title="Backwards Compatibility" /><link rel="next" href="api.html" title="The GNU C++ Library API Reference" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center"></th></tr><tr><td width="20%" align="left"><a accesskey="p" href="manual/backwards.html">Prev</a> </td><th width="60%" align="center"> </th><td width="20%" align="right"> <a accesskey="n" href="api.html">Next</a></td></tr></table><hr /></div><div class="book"><div class="titlepage"><hr /></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="article"><a href="api.html">The GNU C++ Library API Reference</a></span></dt></dl></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="manual/backwards.html">Prev</a> </td><td width="20%" align="center"> </td><td width="40%" align="right"> <a accesskey="n" href="api.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">Backwards Compatibility </td><td width="20%" align="center"><a accesskey="h" href="index.html">Home</a></td><td width="40%" align="right" valign="top"> The GNU C++ Library API Reference</td></tr></table></div></body></html>
\ No newline at end of file
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title></title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library" /><link rel="prev" href="manual/backwards.html" title="Backwards Compatibility" /><link rel="next" href="api.html" title="The GNU C++ Library API Reference" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center"></th></tr><tr><td width="20%" align="left"><a accesskey="p" href="manual/backwards.html">Prev</a> </td><th width="60%" align="center"> </th><td width="20%" align="right"> <a accesskey="n" href="api.html">Next</a></td></tr></table><hr /></div><div class="book"><div class="titlepage"><hr /></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="article"><a href="api.html">The GNU C++ Library API Reference</a></span></dt></dl></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="manual/backwards.html">Prev</a> </td><td width="20%" align="center"> </td><td width="40%" align="right"> <a accesskey="n" href="api.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">Backwards Compatibility </td><td width="20%" align="center"><a accesskey="h" href="index.html">Home</a></td><td width="40%" align="right" valign="top"> The GNU C++ Library API Reference</td></tr></table></div></body></html>
\ No newline at end of file
Index: libstdc++-v3/doc/html/bk03.html
===================================================================
--- libstdc++-v3/doc/html/bk03.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/bk03.html	(.../branches/gcc-7-branch)
@@ -1,2 +1,2 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title></title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library" /><link rel="prev" href="api.html" title="The GNU C++ Library API Reference" /><link rel="next" href="faq.html" title="Frequently Asked Questions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center"></th></tr><tr><td width="20%" align="left"><a accesskey="p" href="api.html">Prev</a> </td><th width="60%" align="center"> </th><td width="20%" align="right"> <a accesskey="n" href="faq.html">Next</a></td></tr></table><hr /></div><div class="book"><div class="titlepage"><hr /></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="article"><a href="faq.html">Frequently Asked Questions</a></span></dt></dl></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="api.html">Prev</a> </td><td width="20%" align="center"> </td><td width="40%" align="right"> <a accesskey="n" href="faq.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">The GNU C++ Library API Reference </td><td width="20%" align="center"><a accesskey="h" href="index.html">Home</a></td><td width="40%" align="right" valign="top"> Frequently Asked Questions</td></tr></table></div></body></html>
\ No newline at end of file
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title></title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library" /><link rel="prev" href="api.html" title="The GNU C++ Library API Reference" /><link rel="next" href="faq.html" title="Frequently Asked Questions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center"></th></tr><tr><td width="20%" align="left"><a accesskey="p" href="api.html">Prev</a> </td><th width="60%" align="center"> </th><td width="20%" align="right"> <a accesskey="n" href="faq.html">Next</a></td></tr></table><hr /></div><div class="book"><div class="titlepage"><hr /></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="article"><a href="faq.html">Frequently Asked Questions</a></span></dt></dl></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="api.html">Prev</a> </td><td width="20%" align="center"> </td><td width="40%" align="right"> <a accesskey="n" href="faq.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">The GNU C++ Library API Reference </td><td width="20%" align="center"><a accesskey="h" href="index.html">Home</a></td><td width="40%" align="right" valign="top"> Frequently Asked Questions</td></tr></table></div></body></html>
\ No newline at end of file
Index: libstdc++-v3/doc/html/faq.html
===================================================================
--- libstdc++-v3/doc/html/faq.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/faq.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Frequently Asked Questions</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="up" href="bk03.html" title="" /><link rel="prev" href="bk03.html" title="" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Frequently Asked Questions</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bk03.html">Prev</a> </td><th width="60%" align="center"></th><td width="20%" align="right"> </td></tr></table><hr /></div><div class="article"><div class="titlepage"><div><div><h1 class="title"><a id="faq"></a>Frequently Asked Questions</h1></div><div><p class="copyright">Copyright © 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Frequently Asked Questions</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="up" href="bk03.html" title="" /><link rel="prev" href="bk03.html" title="" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Frequently Asked Questions</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bk03.html">Prev</a> </td><th width="60%" align="center"></th><td width="20%" align="right"> </td></tr></table><hr /></div><div class="article"><div class="titlepage"><div><div><h1 class="title"><a id="faq"></a>Frequently Asked Questions</h1></div><div><p class="copyright">Copyright © 
       2008-2014
      
       <a class="link" href="http://www.fsf.org" target="_top">FSF</a>
Index: libstdc++-v3/doc/html/index.html
===================================================================
--- libstdc++-v3/doc/html/index.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/index.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>The GNU C++ Library</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="description" content="Short Contents Copyright (C) 2008-2017 FSF Permission is granted to copy, distribute and/or modify this document under the terms of the GNU Free Documentation License, Version 1.2 or any later version published by the Free Software Foundation; with no Invariant Sections, with no Front-Cover Texts, and with no Back-Cover Texts. This is the top level of the libstdc++ documentation set. The documentation is divided into the following three sections. Manual Frequently Asked Questions API and Source Documentation" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="next" href="manual/index.html" title="The GNU C++ Library Manual" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">The GNU C++ Library</th></tr><tr><td width="20%" align="left"> </td><th width="60%" align="center"> </th><td width="20%" align="right"> <a accesskey="n" href="manual/index.html">Next</a></td></tr></table><hr /></div><div class="set" lang="en" xml:lang="en"><div class="titlepage"><div><div><h1 class="title"><a id="set-index"></a>The GNU C++ Library</h1></div><div><div class="abstract"><a id="contents"></a><p class="title"><strong>Short Contents</strong></p><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>The GNU C++ Library</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="description" content="Short Contents Copyright (C) 2008-2017 FSF Permission is granted to copy, distribute and/or modify this document under the terms of the GNU Free Documentation License, Version 1.2 or any later version published by the Free Software Foundation; with no Invariant Sections, with no Front-Cover Texts, and with no Back-Cover Texts. This is the top level of the libstdc++ documentation set. The documentation is divided into the following three sections. Manual Frequently Asked Questions API and Source Documentation" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="next" href="manual/index.html" title="The GNU C++ Library Manual" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">The GNU C++ Library</th></tr><tr><td width="20%" align="left"> </td><th width="60%" align="center"> </th><td width="20%" align="right"> <a accesskey="n" href="manual/index.html">Next</a></td></tr></table><hr /></div><div class="set" lang="en" xml:lang="en"><div class="titlepage"><div><div><h1 class="title"><a id="set-index"></a>The GNU C++ Library</h1></div><div><div class="abstract"><a id="contents"></a><p class="title"><strong>Short Contents</strong></p><p>
       Copyright (C) 2008-2017
       <a class="link" href="http://www.fsf.org/" target="_top">FSF
       </a>
@@ -23,7 +23,7 @@
     </p></div></div></div><hr /></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="book"><a href="manual/index.html">The GNU C++ Library Manual</a></span></dt><dd><dl><dt><span class="part"><a href="manual/intro.html">I. 
   Introduction
   
-</a></span></dt><dd><dl><dt><span class="chapter"><a href="manual/status.html">1. Status</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#manual.intro.status.iso">Implementation Status</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#status.iso.1998">C++ 1998/2003</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#iso.1998.status">Implementation Status</a></span></dt><dt><span class="section"><a href="manual/status.html#iso.1998.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="manual/status.html#status.iso.2011">C++ 2011</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#iso.2011.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="manual/status.html#status.iso.2014">C++ 2014</a></span></dt><dt><span class="section"><a href="manual/status.html#status.iso.201z">C++ 201z</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#iso.2017.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="manual/status.html#status.iso.tr1">C++ TR1</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#iso.tr1.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="manual/status.html#status.iso.tr24733">C++ TR 24733</a></span></dt></dl></dd><dt><span class="section"><a href="manual/license.html">License</a></span></dt><dd><dl><dt><span class="section"><a href="manual/license.html#manual.intro.status.license.gpl">The Code: GPL</a></span></dt><dt><span class="section"><a href="manual/license.html#manual.intro.status.license.fdl">The Documentation: GPL, FDL</a></span></dt></dl></dd><dt><span class="section"><a href="manual/bugs.html">Bugs</a></span></dt><dd><dl><dt><span class="section"><a href="manual/bugs.html#manual.intro.status.bugs.impl">Implementation Bugs</a></span></dt><dt><span class="section"><a href="manual/bugs.html#manual.intro.status.bugs.iso">Standard Bugs</a></span></dt></dl></dd></dl></dd><dt><span class="chapter"><a href="manual/setup.html">2. Setup</a></span></dt><dd><dl><dt><span class="section"><a href="manual/setup.html#manual.intro.setup.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="manual/configure.html">Configure</a></span></dt><dt><span class="section"><a href="manual/make.html">Make</a></span></dt></dl></dd><dt><span class="chapter"><a href="manual/using.html">3. Using</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using.html#manual.intro.using.flags">Command Options</a></span></dt><dt><span class="section"><a href="manual/using_headers.html">Headers</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_headers.html#manual.intro.using.headers.all">Header Files</a></span></dt><dt><span class="section"><a href="manual/using_headers.html#manual.intro.using.headers.mixing">Mixing Headers</a></span></dt><dt><span class="section"><a href="manual/using_headers.html#manual.intro.using.headers.cheaders">The C Headers and <code class="code">namespace std</code></a></span></dt><dt><span class="section"><a href="manual/using_headers.html#manual.intro.using.headers.pre">Precompiled Headers</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_macros.html">Macros</a></span></dt><dt><span class="section"><a href="manual/using_dual_abi.html">Dual ABI</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_dual_abi.html#manual.intro.using.abi.trouble">Troubleshooting</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_namespaces.html">Namespaces</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_namespaces.html#manual.intro.using.namespaces.all">Available Namespaces</a></span></dt><dt><span class="section"><a href="manual/using_namespaces.html#manual.intro.using.namespaces.std">namespace std</a></span></dt><dt><span class="section"><a href="manual/using_namespaces.html#manual.intro.using.namespaces.comp">Using Namespace Composition</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_dynamic_or_shared.html">Linking</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_dynamic_or_shared.html#manual.intro.using.linkage.freestanding">Almost Nothing</a></span></dt><dt><span class="section"><a href="manual/using_dynamic_or_shared.html#manual.intro.using.linkage.dynamic">Finding Dynamic or Shared Libraries</a></span></dt><dt><span class="section"><a href="manual/using_dynamic_or_shared.html#manual.intro.using.linkage.experimental">Experimental Library Extensions</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_concurrency.html">Concurrency</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.thread_safety">Thread Safety</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.atomics">Atomics</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.io">IO</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_concurrency.html#concurrency.io.structure">Structure</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#concurrency.io.defaults">Defaults</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#concurrency.io.future">Future</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#concurrency.io.alt">Alternatives</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.containers">Containers</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_exceptions.html">Exceptions</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_exceptions.html#intro.using.exception.safety">Exception Safety</a></span></dt><dt><span class="section"><a href="manual/using_exceptions.html#intro.using.exception.propagating">Exception Neutrality</a></span></dt><dt><span class="section"><a href="manual/using_exceptions.html#intro.using.exception.no">Doing without</a></span></dt><dt><span class="section"><a href="manual/using_exceptions.html#intro.using.exception.compat">Compatibility</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_exceptions.html#using.exception.compat.c">With <code class="literal">C</code></a></span></dt><dt><span class="section"><a href="manual/using_exceptions.html#using.exception.compat.posix">With <code class="literal">POSIX</code> thread cancellation</a></span></dt></dl></dd></dl></dd><dt><span class="section"><a href="manual/debug.html">Debugging Support</a></span></dt><dd><dl><dt><span class="section"><a href="manual/debug.html#debug.compiler">Using <span class="command"><strong>g++</strong></span></a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.req">Debug Versions of Library Binary Files</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.memory">Memory Leak Hunting</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.races">Data Race Hunting</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.gdb">Using <span class="command"><strong>gdb</strong></span></a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.exceptions">Tracking uncaught exceptions</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.debug_mode">Debug Mode</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.compile_time_checks">Compile Time Checking</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.profile_mode">Profile-based Performance Analysis</a></span></dt></dl></dd></dl></dd></dl></dd><dt><span class="part"><a href="manual/std_contents.html">II. 
+</a></span></dt><dd><dl><dt><span class="chapter"><a href="manual/status.html">1. Status</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#manual.intro.status.iso">Implementation Status</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#status.iso.1998">C++ 1998/2003</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#iso.1998.status">Implementation Status</a></span></dt><dt><span class="section"><a href="manual/status.html#iso.1998.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="manual/status.html#status.iso.2011">C++ 2011</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#iso.2011.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="manual/status.html#status.iso.2014">C++ 2014</a></span></dt><dt><span class="section"><a href="manual/status.html#status.iso.2017">C++ 2017</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#iso.2017.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="manual/status.html#status.iso.tr1">C++ TR1</a></span></dt><dd><dl><dt><span class="section"><a href="manual/status.html#iso.tr1.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="manual/status.html#status.iso.tr24733">C++ TR 24733</a></span></dt></dl></dd><dt><span class="section"><a href="manual/license.html">License</a></span></dt><dd><dl><dt><span class="section"><a href="manual/license.html#manual.intro.status.license.gpl">The Code: GPL</a></span></dt><dt><span class="section"><a href="manual/license.html#manual.intro.status.license.fdl">The Documentation: GPL, FDL</a></span></dt></dl></dd><dt><span class="section"><a href="manual/bugs.html">Bugs</a></span></dt><dd><dl><dt><span class="section"><a href="manual/bugs.html#manual.intro.status.bugs.impl">Implementation Bugs</a></span></dt><dt><span class="section"><a href="manual/bugs.html#manual.intro.status.bugs.iso">Standard Bugs</a></span></dt></dl></dd></dl></dd><dt><span class="chapter"><a href="manual/setup.html">2. Setup</a></span></dt><dd><dl><dt><span class="section"><a href="manual/setup.html#manual.intro.setup.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="manual/configure.html">Configure</a></span></dt><dt><span class="section"><a href="manual/make.html">Make</a></span></dt></dl></dd><dt><span class="chapter"><a href="manual/using.html">3. Using</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using.html#manual.intro.using.flags">Command Options</a></span></dt><dt><span class="section"><a href="manual/using_headers.html">Headers</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_headers.html#manual.intro.using.headers.all">Header Files</a></span></dt><dt><span class="section"><a href="manual/using_headers.html#manual.intro.using.headers.mixing">Mixing Headers</a></span></dt><dt><span class="section"><a href="manual/using_headers.html#manual.intro.using.headers.cheaders">The C Headers and <code class="code">namespace std</code></a></span></dt><dt><span class="section"><a href="manual/using_headers.html#manual.intro.using.headers.pre">Precompiled Headers</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_macros.html">Macros</a></span></dt><dt><span class="section"><a href="manual/using_dual_abi.html">Dual ABI</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_dual_abi.html#manual.intro.using.abi.trouble">Troubleshooting</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_namespaces.html">Namespaces</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_namespaces.html#manual.intro.using.namespaces.all">Available Namespaces</a></span></dt><dt><span class="section"><a href="manual/using_namespaces.html#manual.intro.using.namespaces.std">namespace std</a></span></dt><dt><span class="section"><a href="manual/using_namespaces.html#manual.intro.using.namespaces.comp">Using Namespace Composition</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_dynamic_or_shared.html">Linking</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_dynamic_or_shared.html#manual.intro.using.linkage.freestanding">Almost Nothing</a></span></dt><dt><span class="section"><a href="manual/using_dynamic_or_shared.html#manual.intro.using.linkage.dynamic">Finding Dynamic or Shared Libraries</a></span></dt><dt><span class="section"><a href="manual/using_dynamic_or_shared.html#manual.intro.using.linkage.experimental">Experimental Library Extensions</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_concurrency.html">Concurrency</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.thread_safety">Thread Safety</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.atomics">Atomics</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.io">IO</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_concurrency.html#concurrency.io.structure">Structure</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#concurrency.io.defaults">Defaults</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#concurrency.io.future">Future</a></span></dt><dt><span class="section"><a href="manual/using_concurrency.html#concurrency.io.alt">Alternatives</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_concurrency.html#manual.intro.using.concurrency.containers">Containers</a></span></dt></dl></dd><dt><span class="section"><a href="manual/using_exceptions.html">Exceptions</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_exceptions.html#intro.using.exception.safety">Exception Safety</a></span></dt><dt><span class="section"><a href="manual/using_exceptions.html#intro.using.exception.propagating">Exception Neutrality</a></span></dt><dt><span class="section"><a href="manual/using_exceptions.html#intro.using.exception.no">Doing without</a></span></dt><dt><span class="section"><a href="manual/using_exceptions.html#intro.using.exception.compat">Compatibility</a></span></dt><dd><dl><dt><span class="section"><a href="manual/using_exceptions.html#using.exception.compat.c">With <code class="literal">C</code></a></span></dt><dt><span class="section"><a href="manual/using_exceptions.html#using.exception.compat.posix">With <code class="literal">POSIX</code> thread cancellation</a></span></dt></dl></dd></dl></dd><dt><span class="section"><a href="manual/debug.html">Debugging Support</a></span></dt><dd><dl><dt><span class="section"><a href="manual/debug.html#debug.compiler">Using <span class="command"><strong>g++</strong></span></a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.req">Debug Versions of Library Binary Files</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.memory">Memory Leak Hunting</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.races">Data Race Hunting</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.gdb">Using <span class="command"><strong>gdb</strong></span></a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.exceptions">Tracking uncaught exceptions</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.debug_mode">Debug Mode</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.compile_time_checks">Compile Time Checking</a></span></dt><dt><span class="section"><a href="manual/debug.html#debug.profile_mode">Profile-based Performance Analysis</a></span></dt></dl></dd></dl></dd></dl></dd><dt><span class="part"><a href="manual/std_contents.html">II. 
     Standard Contents
   </a></span></dt><dd><dl><dt><span class="chapter"><a href="manual/support.html">4. 
   Support
Index: libstdc++-v3/doc/html/api.html
===================================================================
--- libstdc++-v3/doc/html/api.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/api.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>The GNU C++ Library API Reference</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="up" href="bk02.html" title="" /><link rel="prev" href="bk02.html" title="" /><link rel="next" href="bk03.html" title="" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">The GNU C++ Library API Reference</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bk02.html">Prev</a> </td><th width="60%" align="center"></th><td width="20%" align="right"> <a accesskey="n" href="bk03.html">Next</a></td></tr></table><hr /></div><div class="article"><div class="titlepage"><div><div><h1 class="title"><a id="api"></a>The GNU C++ Library API Reference</h1></div><div><p class="copyright">Copyright © 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>The GNU C++ Library API Reference</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="index.html" title="The GNU C++ Library" /><link rel="up" href="bk02.html" title="" /><link rel="prev" href="bk02.html" title="" /><link rel="next" href="bk03.html" title="" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">The GNU C++ Library API Reference</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bk02.html">Prev</a> </td><th width="60%" align="center"></th><td width="20%" align="right"> <a accesskey="n" href="bk03.html">Next</a></td></tr></table><hr /></div><div class="article"><div class="titlepage"><div><div><h1 class="title"><a id="api"></a>The GNU C++ Library API Reference</h1></div><div><p class="copyright">Copyright © 
       2008
     , 
       2010
Index: libstdc++-v3/doc/html/manual/dynamic_memory.html
===================================================================
--- libstdc++-v3/doc/html/manual/dynamic_memory.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/dynamic_memory.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Dynamic Memory</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="support.html" title="Chapter 4.  Support" /><link rel="prev" href="support.html" title="Chapter 4.  Support" /><link rel="next" href="termination.html" title="Termination" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Dynamic Memory</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="support.html">Prev</a> </td><th width="60%" align="center">Chapter 4. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Dynamic Memory</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="support.html" title="Chapter 4.  Support" /><link rel="prev" href="support.html" title="Chapter 4.  Support" /><link rel="next" href="termination.html" title="Termination" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Dynamic Memory</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="support.html">Prev</a> </td><th width="60%" align="center">Chapter 4. 
   Support
   
 </th><td width="20%" align="right"> <a accesskey="n" href="termination.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.support.memory"></a>Dynamic Memory</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/iterators.html
===================================================================
--- libstdc++-v3/doc/html/manual/iterators.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/iterators.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 10.  Iterators</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="containers_and_c.html" title="Interacting with C" /><link rel="next" href="algorithms.html" title="Chapter 11.  Algorithms" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 10. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 10.  Iterators</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="containers_and_c.html" title="Interacting with C" /><link rel="next" href="algorithms.html" title="Chapter 11.  Algorithms" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 10. 
   Iterators
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="containers_and_c.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/mt_allocator_ex_single.html
===================================================================
--- libstdc++-v3/doc/html/manual/mt_allocator_ex_single.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/mt_allocator_ex_single.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Single Thread Example</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="prev" href="mt_allocator_impl.html" title="Implementation" /><link rel="next" href="mt_allocator_ex_multi.html" title="Multiple Thread Example" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Single Thread Example</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator_impl.html">Prev</a> </td><th width="60%" align="center">Chapter 20. The mt_allocator</th><td width="20%" align="right"> <a accesskey="n" href="mt_allocator_ex_multi.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.mt.example_single"></a>Single Thread Example</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Single Thread Example</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="prev" href="mt_allocator_impl.html" title="Implementation" /><link rel="next" href="mt_allocator_ex_multi.html" title="Multiple Thread Example" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Single Thread Example</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator_impl.html">Prev</a> </td><th width="60%" align="center">Chapter 20. The mt_allocator</th><td width="20%" align="right"> <a accesskey="n" href="mt_allocator_ex_multi.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.mt.example_single"></a>Single Thread Example</h2></div></div></div><p>
 Let's start by describing how the data on a freelist is laid out in memory.
 This is the first two blocks in freelist for thread id 3 in bin 3 (8 bytes):
 </p><pre class="programlisting">
Index: libstdc++-v3/doc/html/manual/generalized_numeric_operations.html
===================================================================
--- libstdc++-v3/doc/html/manual/generalized_numeric_operations.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/generalized_numeric_operations.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Generalized Operations</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="numerics.html" title="Chapter 12.  Numerics" /><link rel="prev" href="numerics.html" title="Chapter 12.  Numerics" /><link rel="next" href="numerics_and_c.html" title="Interacting with C" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Generalized Operations</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="numerics.html">Prev</a> </td><th width="60%" align="center">Chapter 12. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Generalized Operations</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="numerics.html" title="Chapter 12.  Numerics" /><link rel="prev" href="numerics.html" title="Chapter 12.  Numerics" /><link rel="next" href="numerics_and_c.html" title="Interacting with C" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Generalized Operations</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="numerics.html">Prev</a> </td><th width="60%" align="center">Chapter 12. 
   Numerics
   
 </th><td width="20%" align="right"> <a accesskey="n" href="numerics_and_c.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.numerics.generalized_ops"></a>Generalized Operations</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/mt_allocator.html
===================================================================
--- libstdc++-v3/doc/html/manual/mt_allocator.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/mt_allocator.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 20. The mt_allocator</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="profile_mode_diagnostics.html" title="Diagnostics" /><link rel="next" href="mt_allocator_design.html" title="Design Issues" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 20. The mt_allocator</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_diagnostics.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 20. The mt_allocator</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="profile_mode_diagnostics.html" title="Diagnostics" /><link rel="next" href="mt_allocator_design.html" title="Design Issues" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 20. The mt_allocator</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_diagnostics.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="mt_allocator_design.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.allocator.mt"></a>Chapter 20. The mt_allocator</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="mt_allocator.html#allocator.mt.intro">Intro</a></span></dt><dt><span class="section"><a href="mt_allocator_design.html">Design Issues</a></span></dt><dd><dl><dt><span class="section"><a href="mt_allocator_design.html#allocator.mt.overview">Overview</a></span></dt></dl></dd><dt><span class="section"><a href="mt_allocator_impl.html">Implementation</a></span></dt><dd><dl><dt><span class="section"><a href="mt_allocator_impl.html#allocator.mt.tune">Tunable Parameters</a></span></dt><dt><span class="section"><a href="mt_allocator_impl.html#allocator.mt.init">Initialization</a></span></dt><dt><span class="section"><a href="mt_allocator_impl.html#allocator.mt.deallocation">Deallocation Notes</a></span></dt></dl></dd><dt><span class="section"><a href="mt_allocator_ex_single.html">Single Thread Example</a></span></dt><dt><span class="section"><a href="mt_allocator_ex_multi.html">Multiple Thread Example</a></span></dt></dl></div><p>
Index: libstdc++-v3/doc/html/manual/unordered_associative.html
===================================================================
--- libstdc++-v3/doc/html/manual/unordered_associative.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/unordered_associative.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Unordered Associative</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="containers.html" title="Chapter 9.  Containers" /><link rel="prev" href="associative.html" title="Associative" /><link rel="next" href="containers_and_c.html" title="Interacting with C" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Unordered Associative</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="associative.html">Prev</a> </td><th width="60%" align="center">Chapter 9. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Unordered Associative</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="containers.html" title="Chapter 9.  Containers" /><link rel="prev" href="associative.html" title="Associative" /><link rel="next" href="containers_and_c.html" title="Interacting with C" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Unordered Associative</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="associative.html">Prev</a> </td><th width="60%" align="center">Chapter 9. 
   Containers
   
 </th><td width="20%" align="right"> <a accesskey="n" href="containers_and_c.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.containers.unordered"></a>Unordered Associative</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="containers.unordered.insert_hints"></a>Insertion Hints</h3></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/configure.html
===================================================================
--- libstdc++-v3/doc/html/manual/configure.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/configure.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Configure</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, configure, options" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="setup.html" title="Chapter 2. Setup" /><link rel="prev" href="setup.html" title="Chapter 2. Setup" /><link rel="next" href="make.html" title="Make" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Configure</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="setup.html">Prev</a> </td><th width="60%" align="center">Chapter 2. Setup</th><td width="20%" align="right"> <a accesskey="n" href="make.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.setup.configure"></a>Configure</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Configure</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, configure, options" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="setup.html" title="Chapter 2. Setup" /><link rel="prev" href="setup.html" title="Chapter 2. Setup" /><link rel="next" href="make.html" title="Make" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Configure</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="setup.html">Prev</a> </td><th width="60%" align="center">Chapter 2. Setup</th><td width="20%" align="right"> <a accesskey="n" href="make.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.setup.configure"></a>Configure</h2></div></div></div><p>
   When configuring libstdc++, you'll have to configure the entire
   <span class="emphasis"><em>gccsrcdir</em></span> directory. Consider using the
   toplevel gcc configuration option
Index: libstdc++-v3/doc/html/manual/status.html
===================================================================
--- libstdc++-v3/doc/html/manual/status.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/status.html	(.../branches/gcc-7-branch)
@@ -1,13 +1,12 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 1. Status</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="intro.html" title="Part I.  Introduction" /><link rel="prev" href="intro.html" title="Part I.  Introduction" /><link rel="next" href="license.html" title="License" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 1. Status</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="intro.html">Prev</a> </td><th width="60%" align="center">Part I. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 1. Status</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="intro.html" title="Part I.  Introduction" /><link rel="prev" href="intro.html" title="Part I.  Introduction" /><link rel="next" href="license.html" title="License" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 1. Status</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="intro.html">Prev</a> </td><th width="60%" align="center">Part I. 
   Introduction
   
-</th><td width="20%" align="right"> <a accesskey="n" href="license.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.intro.status"></a>Chapter 1. Status</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="status.html#manual.intro.status.iso">Implementation Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#status.iso.1998">C++ 1998/2003</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.1998.status">Implementation Status</a></span></dt><dt><span class="section"><a href="status.html#iso.1998.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2011">C++ 2011</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2011.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2014">C++ 2014</a></span></dt><dt><span class="section"><a href="status.html#status.iso.201z">C++ 201z</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2017.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr1">C++ TR1</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.tr1.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr24733">C++ TR 24733</a></span></dt></dl></dd><dt><span class="section"><a href="license.html">License</a></span></dt><dd><dl><dt><span class="section"><a href="license.html#manual.intro.status.license.gpl">The Code: GPL</a></span></dt><dt><span class="section"><a href="license.html#manual.intro.status.license.fdl">The Documentation: GPL, FDL</a></span></dt></dl></dd><dt><span class="section"><a href="bugs.html">Bugs</a></span></dt><dd><dl><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.impl">Implementation Bugs</a></span></dt><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.iso">Standard Bugs</a></span></dt></dl></dd></dl></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.status.iso"></a>Implementation Status</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="status.iso.1998"></a>C++ 1998/2003</h3></div></div></div><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="iso.1998.status"></a>Implementation Status</h4></div></div></div><p>
+</th><td width="20%" align="right"> <a accesskey="n" href="license.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.intro.status"></a>Chapter 1. Status</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="status.html#manual.intro.status.iso">Implementation Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#status.iso.1998">C++ 1998/2003</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.1998.status">Implementation Status</a></span></dt><dt><span class="section"><a href="status.html#iso.1998.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2011">C++ 2011</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2011.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2014">C++ 2014</a></span></dt><dt><span class="section"><a href="status.html#status.iso.2017">C++ 2017</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2017.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr1">C++ TR1</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.tr1.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr24733">C++ TR 24733</a></span></dt></dl></dd><dt><span class="section"><a href="license.html">License</a></span></dt><dd><dl><dt><span class="section"><a href="license.html#manual.intro.status.license.gpl">The Code: GPL</a></span></dt><dt><span class="section"><a href="license.html#manual.intro.status.license.fdl">The Documentation: GPL, FDL</a></span></dt></dl></dd><dt><span class="section"><a href="bugs.html">Bugs</a></span></dt><dd><dl><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.impl">Implementation Bugs</a></span></dt><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.iso">Standard Bugs</a></span></dt></dl></dd></dl></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.status.iso"></a>Implementation Status</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="status.iso.1998"></a>C++ 1998/2003</h3></div></div></div><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="iso.1998.status"></a>Implementation Status</h4></div></div></div><p>
 This status table is based on the table of contents of ISO/IEC 14882:2003.
 </p><p>
-This page describes the C++ support in mainline GCC SVN, not in any
-particular release.
-</p><div class="table"><a id="table.cxx98_status"></a><p class="title"><strong>Table 1.1. C++ 1998/2003 Implementation Status</strong></p><div class="table-contents"><table summary="C++ 1998/2003 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Section</th><th align="left">Description</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
+This page describes the C++ support in the GCC 7 series.
+</p><div class="table"><a id="table.cxx98_status"></a><p class="title"><strong>Table 1.1. C++ 1998/2003 Implementation Status</strong></p><div class="table-contents"><table class="table" summary="C++ 1998/2003 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Section</th><th align="left">Description</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
 	<span class="emphasis"><em>18</em></span>
       </td><td colspan="3" align="left">
 	<span class="emphasis"><em>Language support</em></span>
@@ -152,9 +151,8 @@
 <code class="constant">__cplusplus</code> is used to check for the
 presence of the required flag.
 </p><p>
-This page describes the C++11 support in mainline GCC SVN, not in any
-particular release.
-</p><div class="table"><a id="table.cxx11_status"></a><p class="title"><strong>Table 1.2. C++ 2011 Implementation Status</strong></p><div class="table-contents"><table summary="C++ 2011 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Section</th><th align="left">Description</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
+This page describes the C++11 support in the GCC 7 series.
+</p><div class="table"><a id="table.cxx11_status"></a><p class="title"><strong>Table 1.2. C++ 2011 Implementation Status</strong></p><div class="table-contents"><table class="table" summary="C++ 2011 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Section</th><th align="left">Description</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
 	<span class="emphasis"><em>18</em></span>
       </td><td colspan="3" align="left">
 	<span class="emphasis"><em>Language support</em></span>
@@ -381,9 +379,8 @@
 <code class="constant">__cplusplus</code> is used to check for the
 presence of the required flag.
 </p><p>
-This page describes the C++14 and library TS support in mainline GCC SVN,
-not in any particular release.
-</p><div class="table"><a id="table.cxx14_status"></a><p class="title"><strong>Table 1.3. C++ 2014 Implementation Status</strong></p><div class="table-contents"><table summary="C++ 2014 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Paper</th><th align="left">Title</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
+This page describes the C++14 and library TS support in the GCC 7 series.
+</p><div class="table"><a id="table.cxx14_status"></a><p class="title"><strong>Table 1.3. C++ 2014 Implementation Status</strong></p><div class="table-contents"><table class="table" summary="C++ 2014 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Paper</th><th align="left">Title</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
 	<a class="link" href="http://www.open-std.org/JTC1/sc22/WG21/docs/papers/2013/n3669.pdf" target="_top">
 	  N3669
 	</a>
@@ -455,7 +452,7 @@
 	<a class="link" href="http://www.open-std.org/JTC1/sc22/WG21/docs/papers/2013/n3644.pdf" target="_top">
 	  N3644
 	</a>
-      </td><td align="left">Null Forward Iterators</td><td align="left">Partial</td><td align="left">Only affects Debug Mode</td></tr></tbody></table></div></div><br class="table-break" /><div class="table"><a id="table.ts_status"></a><p class="title"><strong>Table 1.4. C++ Technical Specifications Implementation Status</strong></p><div class="table-contents"><table summary="C++ Technical Specifications Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Paper</th><th align="left">Title</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr bgcolor="#C8B0B0"><td align="left">
+      </td><td align="left">Null Forward Iterators</td><td align="left">Partial</td><td align="left">Only affects Debug Mode</td></tr></tbody></table></div></div><br class="table-break" /><div class="table"><a id="table.ts_status"></a><p class="title"><strong>Table 1.4. C++ Technical Specifications Implementation Status</strong></p><div class="table-contents"><table class="table" summary="C++ Technical Specifications Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Paper</th><th align="left">Title</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr bgcolor="#C8B0B0"><td align="left">
 	<a class="link" href="http://www.open-std.org/JTC1/sc22/WG21/docs/papers/2013/n3662.html" target="_top">
 	  N3662
 	</a>
@@ -507,9 +504,9 @@
 	Link with
 	<a class="link" href="using_dynamic_or_shared.html#manual.intro.using.linkage.experimental" title="Experimental Library Extensions">
 	<code class="option">-lstdc++fs</code></a>
-      </td></tr></tbody></table></div></div><br class="table-break" /></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="status.iso.201z"></a>C++ 201z</h3></div></div></div><p>
-In this implementation the <code class="literal">-std=gnu++1z</code> or
-<code class="literal">-std=c++1z</code> flag must be used to enable language
+      </td></tr></tbody></table></div></div><br class="table-break" /></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="status.iso.2017"></a>C++ 2017</h3></div></div></div><p>
+In this implementation the <code class="literal">-std=gnu++17</code> or
+<code class="literal">-std=c++17</code> flag must be used to enable language
 and library
 features. See <a class="link" href="using.html#manual.intro.using.flags" title="Command Options">dialect</a>
 options. The pre-defined symbol
@@ -516,11 +513,10 @@
 <code class="constant">__cplusplus</code> is used to check for the
 presence of the required flag.
 </p><p>
-This section describes the C++1z and library TS support in mainline GCC SVN,
-not in any particular release.
+This section describes the C++17 and library TS support in the GCC 7 series.
 </p><p>
 The following table lists new library features that have been accepted into
-the C++1z working draft. The "Proposal" column provides a link to the
+the C++17 working draft. The "Proposal" column provides a link to the
 ISO C++ committee proposal that describes the feature, while the "Status"
 column indicates the first version of GCC that contains an implementation of
 this feature (if it has been implemented).
@@ -527,7 +523,7 @@
 The "SD-6 Feature Test" column shows the corresponding macro or header from
 <a class="link" href="https://isocpp.org/std/standing-documents/sd-6-sg10-feature-test-recommendations" target="_top">SD-6:
 Feature-testing recommendations for C++</a>.
-</p><div class="table"><a id="table.cxx1z_status"></a><p class="title"><strong>Table 1.5. C++ 201z Implementation Status</strong></p><div class="table-contents"><table summary="C++ 201z Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Library Feature</th><th align="left">Proposal</th><th align="left">Status</th><th align="left">SD-6 Feature Test</th></tr></thead><tbody><tr bgcolor="#C8B0B0"><td align="left">
+</p><div class="table"><a id="table.cxx17_status"></a><p class="title"><strong>Table 1.5. C++ 2017 Implementation Status</strong></p><div class="table-contents"><table class="table" summary="C++ 2017 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Library Feature</th><th align="left">Proposal</th><th align="left">Status</th><th align="left">SD-6 Feature Test</th></tr></thead><tbody><tr bgcolor="#C8B0B0"><td align="left">
 	<code class="code">constexpr std::hardware_{constructive,destructive}_interference_size</code>
       </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0154r1.html" target="_top">
@@ -537,7 +533,7 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0137r1.html" target="_top">
 	P0137R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> <code class="code">__cpp_lib_launder &gt;= 201606</code> </td></tr><tr><td align="left">Wording for <code class="code">std::uncaught_exceptions</code></td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> <code class="code">__cpp_lib_launder &gt;= 201606</code> </td></tr><tr><td align="left">Wording for <code class="code">std::uncaught_exceptions</code></td><td align="left">
 	<a class="link" href="http://www.open-std.org/JTC1/sc22/WG21/docs/papers/2014/n4259.pdf" target="_top">
 	  N4259
 	</a>
@@ -545,43 +541,57 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0088r3.html" target="_top">
 	P0088R3
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> <code class="code">__has_include(&lt;variant&gt;)</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">optional</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> <code class="code">__has_include(&lt;variant&gt;)</code>,
+              <code class="code">__cpp_lib_variant &gt;= 201603</code>
+              (since 7.3, see Note 1)
+      </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">optional</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0220r1.html" target="_top">
 	P0220R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> <code class="code">__has_include(&lt;optional&gt;)</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">any</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> <code class="code">__has_include(&lt;optional&gt;)</code>,
+              <code class="code">__cpp_lib_optional &gt;= 201603</code>
+              (since 7.3, see Note 1)
+      </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">any</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0220r1.html" target="_top">
 	P0220R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> <code class="code">__has_include(&lt;any&gt;)</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">string_view</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> <code class="code">__has_include(&lt;any&gt;)</code>,
+              <code class="code">__cpp_lib_any &gt;= 201603</code>
+              (since 7.3, see Note 1)
+      </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">string_view</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0220r1.html" target="_top">
 	P0220R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> <code class="code">__has_include(&lt;string_view&gt;)</code> </td></tr><tr bgcolor="#C8B0B0"><td align="left"> Library Fundamentals V1 TS Components: <code class="code">memory_resource</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> <code class="code">__has_include(&lt;string_view&gt;)</code>,
+              <code class="code">__cpp_lib_string_view &gt;= 201603</code>
+              (since 7.3, see Note 1)
+      </td></tr><tr bgcolor="#C8B0B0"><td align="left"> Library Fundamentals V1 TS Components: <code class="code">memory_resource</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0220r1.html" target="_top">
 	P0220R1
 	</a>
-      </td><td align="center"> No </td><td align="left"> <code class="code">__has_include(&lt;memory_resource&gt;)</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">apply</code> </td><td align="left">
+      </td><td align="center"> No </td><td align="left"> <code class="code">__has_include(&lt;memory_resource&gt;)</code>,
+              <code class="code">__cpp_lib_memory_resource &gt;= 201603</code>
+      </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">apply</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0220r1.html" target="_top">
 	P0220R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> <code class="code">__cpp_lib_apply &gt;= 201603</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">shared_ptr&lt;T[]&gt;</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> <code class="code">__cpp_lib_apply &gt;= 201603</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: <code class="code">shared_ptr&lt;T[]&gt;</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0220r1.html" target="_top">
 	P0220R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> <code class="code">__cpp_lib_shared_ptr_arrays &gt;= 201603</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: Searchers </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> <code class="code">__cpp_lib_shared_ptr_arrays &gt;= 201603</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: Searchers </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0220r1.html" target="_top">
 	P0220R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> <code class="code">__cpp_lib_boyer_moore_searcher &gt;= 201603</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: Sampling </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> <code class="code">__cpp_lib_boyer_moore_searcher &gt;= 201603</code> </td></tr><tr><td align="left"> Library Fundamentals V1 TS Components: Sampling </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0220r1.html" target="_top">
 	P0220R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> <code class="code">__cpp_lib_sample &gt;= 201603</code> </td></tr><tr><td align="left"> Constant View: A proposal for a <code class="code">std::as_const</code> helper function template	</td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> <code class="code">__cpp_lib_sample &gt;= 201603</code> </td></tr><tr><td align="left"> Constant View: A proposal for a <code class="code">std::as_const</code> helper function template	</td><td align="left">
 	<a class="link" href="" target="_top">
 	P0007R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_as_const &gt;= 201510 </code></td></tr><tr><td align="left"> Improving pair and tuple </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_as_const &gt;= 201510 </code></td></tr><tr><td align="left"> Improving pair and tuple </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/n4387" target="_top">
 	N4387
 	</a>
@@ -589,7 +599,7 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0209r2.pdf" target="_top">
 	P0209R2
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_make_from_tuple &gt;= 201606 </code></td></tr><tr bgcolor="#C8B0B0"><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_make_from_tuple &gt;= 201606 </code></td></tr><tr bgcolor="#C8B0B0"><td align="left">
         Removing <code class="code">auto_ptr</code>, <code class="code">random_shuffle()</code>,
         And Old <code class="code">&lt;functional&gt;</code> Stuff
       </td><td align="left">
@@ -604,11 +614,11 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/p0074r0.html" target="_top">
 	P0074R0
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_transparent_operators &gt;= 201510 </code></td></tr><tr><td align="left"> <code class="code">std::addressof</code> should be constexpr </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_transparent_operators &gt;= 201510 </code></td></tr><tr><td align="left"> <code class="code">std::addressof</code> should be constexpr </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0304r0.html#2296" target="_top">
 	LWG2296
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_addressof_constexpr &gt;= 201603 </code></td></tr><tr><td align="left"> Safe conversions in <code class="code">unique_ptr&lt;T[]&gt;</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_addressof_constexpr &gt;= 201603 </code></td></tr><tr><td align="left"> Safe conversions in <code class="code">unique_ptr&lt;T[]&gt;</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2014/n4089.pdf" target="_top">
 	N4089
 	</a>
@@ -620,7 +630,7 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0033r1.html" target="_top">
 	P0033R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code">__cpp_lib_enable_shared_from_this &gt;= 201603</code></td></tr><tr><td align="left"> A proposal to add <code class="code">invoke</code> function template </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code">__cpp_lib_enable_shared_from_this &gt;= 201603</code></td></tr><tr><td align="left"> A proposal to add <code class="code">invoke</code> function template </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2014/n4169.html" target="_top">
 	N4169
 	</a>
@@ -632,23 +642,23 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0005r4.html" target="_top">
 	P0005R4
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code">__cpp_lib_not_fn &gt;= 201603</code></td></tr><tr><td align="left"> Fixes for <code class="code">not_fn</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code">__cpp_lib_not_fn &gt;= 201603</code></td></tr><tr><td align="left"> Fixes for <code class="code">not_fn</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0358r1.html" target="_top">
 	P0358R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> </td></tr><tr><td align="left"> Fixing a design mistake in the searchers interface in Library Fundamentals </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> </td></tr><tr><td align="left"> Fixing a design mistake in the searchers interface in Library Fundamentals </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0253r1.pdf" target="_top">
 	P0253R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"> </td></tr><tr><td align="left"> Extending memory management tools </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> </td></tr><tr><td align="left"> Extending memory management tools </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0040r3.html" target="_top">
 	P0040R3
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> </code></td></tr><tr><td align="left"> <code class="code">shared_ptr::weak_type</code></td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> </code></td></tr><tr><td align="left"> <code class="code">shared_ptr::weak_type</code></td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/p0163r0.html" target="_top">
 	P0163R0
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_shared_ptr_weak_type &gt;= 201606</code></td></tr><tr><td align="left">Transformation Trait Alias <code class="code">void_t</code></td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_shared_ptr_weak_type &gt;= 201606</code></td></tr><tr><td align="left">Transformation Trait Alias <code class="code">void_t</code></td><td align="left">
 	<a class="link" href="http://www.open-std.org/JTC1/sc22/WG21/docs/papers/2014/n3911.pdf" target="_top">
 	  N3911
 	</a>
@@ -660,7 +670,7 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/p0006r0.html" target="_top">
 	P0006R0
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_type_trait_variable_templates &gt;= 201510 </code></td></tr><tr><td align="left"> Logical Operator Type Traits</td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_type_trait_variable_templates &gt;= 201510 </code></td></tr><tr><td align="left"> Logical Operator Type Traits</td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/p0013r1.html" target="_top">
 	P0013R1
 	</a>
@@ -672,31 +682,33 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0077r2.html" target="_top">
 	P0077R2
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_is_callable &gt;= 201603 </code></td></tr><tr><td align="left"> has_unique_object_representations </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_is_callable &gt;= 201603 </code></td></tr><tr><td align="left"> has_unique_object_representations </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0258r2.html" target="_top">
 	P0258R2
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_has_unique_object_representations &gt;= 201606 </code></td></tr><tr><td align="left"> Polishing <code class="code">&lt;chrono&gt;</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_has_unique_object_representations &gt;= 201606 </code></td></tr><tr><td align="left"> Polishing <code class="code">&lt;chrono&gt;</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/p0092r1.html" target="_top">
 	P0092R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_chrono &gt;= 201510 </code></td></tr><tr><td align="left"> Adding more constexpr to <code class="code">&lt;chrono&gt;</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_chrono &gt;= 201510 </code></td></tr><tr><td align="left"> Adding more constexpr to <code class="code">&lt;chrono&gt;</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0505r0.html" target="_top">
 	P0505R0
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> ??? </code></td></tr><tr bgcolor="#B0B0B0"><td align="left"> Constexpr for <code class="code">std::char_traits</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_chrono &gt;= 201611 </code>
+             (since 7.3, see Note 2)
+      </td></tr><tr><td align="left"> Constexpr for <code class="code">std::char_traits</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0426r1.html" target="_top">
 	P0426R1
 	</a>
-      </td><td align="center"> 7 (partial) </td><td align="left"><code class="code"> ??? </code></td></tr><tr><td align="left"> Integrating <code class="code">std::string_view</code> and <code class="code">std::string</code> </td><td align="left">
+      </td><td align="center"> 7.3 </td><td align="left"><code class="code"> __cpp_lib_constexpr_char_traits &gt;= 201611 </code></td></tr><tr><td align="left"> Integrating <code class="code">std::string_view</code> and <code class="code">std::string</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0254r2.pdf" target="_top">
 	P0254R2
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> </code></td></tr><tr><td align="left"> Give 'std::string' a non-const '.data()' member function </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> </code></td></tr><tr><td align="left"> Give 'std::string' a non-const '.data()' member function </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0272r1.html" target="_top">
 	P0272R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> </code></td></tr><tr><td align="left">Cleaning-up noexcept in the Library</td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> </code></td></tr><tr><td align="left">Cleaning-up noexcept in the Library</td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2014/n4258.pdf" target="_top">
 	  N4258
 	</a>
@@ -708,13 +720,13 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/n4510.html" target="_top">
 	N4510
 	</a>
-      </td><td align="center"> 6.2 (3.0)</td><td align="left"><code class="code"> __cpp_lib_incomplete_container_elements &gt;= 201505 </code>
-	     (the feature was always supported, but the macro was not defined until GCC 6.2)
+      </td><td align="center"> 3.0 </td><td align="left"><code class="code"> __cpp_lib_incomplete_container_elements &gt;= 201505 </code>
+	     (since 6.2, see Note 2)
       </td></tr><tr><td align="left"> Emplace return type </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0084r2.pdf" target="_top">
 	P0084R2
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> ??? </code></td></tr><tr><td align="left">Improved insertion interface for unique-key maps</td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"> </td></tr><tr><td align="left">Improved insertion interface for unique-key maps</td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2014/n4279.html" target="_top">
 	  N4279
 	</a>
@@ -724,7 +736,7 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0083r3.pdf" target="_top">
 	P0083R3
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_node_extract &gt;= 201606 </code></td></tr><tr><td align="left">Non-member <code class="code">size()</code> and more</td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_node_extract &gt;= 201606 </code></td></tr><tr><td align="left">Non-member <code class="code">size()</code> and more</td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2014/n4280.pdf" target="_top">
 	  N4280
 	</a>
@@ -732,33 +744,31 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/p0031r0.html" target="_top">
 	P0031R0
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_array_constexpr &gt;= 201603 </code></td></tr><tr bgcolor="#C8B0B0"><td align="left"> The Parallelism TS Should be Standardized	 </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_array_constexpr &gt;= 201603 </code></td></tr><tr bgcolor="#C8B0B0"><td align="left"> The Parallelism TS Should be Standardized	 </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0024r2.html" target="_top">
 	P0024R2
 	</a>
       </td><td align="center"> No </td><td align="left"><code class="code"> __has_include(&lt;execution&gt;) </code>,
-	     <code class="code"> __cpp_lib_parallel_algorithm &gt;= 201603 </code></td></tr><tr><td align="left"> An algorithm to "clamp" a value between a pair of boundary values </td><td align="left">
+	     <code class="code"> __cpp_lib_execution &gt;= 201603 </code>,
+	     <code class="code"> __cpp_lib_parallel_algorithm &gt;= 201603 </code>
+      </td></tr><tr><td align="left"> An algorithm to "clamp" a value between a pair of boundary values </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/p0025r0.html" target="_top">
 	P0025R0
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_clamp &gt;= 201603 </code></td></tr><tr><td align="left"> Adopt Selected Library Fundamentals V2 Components for C++17 </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_clamp &gt;= 201603 </code></td></tr><tr><td align="left"> Adopt Selected Library Fundamentals V2 Components for C++17 </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0295r0.pdf" target="_top">
 	P0295R0
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_gcd &gt;= 201606 </code>,
-	     <code class="code"> __cpp_lib_lcm &gt;= 201606 </code>
-      </td></tr><tr><td align="left"> Proposal to Introduce a 3-Argument Overload to <code class="code">std::hypot</code> </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_gcd_lcm &gt;= 201606 </code></td></tr><tr><td align="left"> Proposal to Introduce a 3-Argument Overload to <code class="code">std::hypot</code> </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/p0030r1.pdf" target="_top">
 	P0030R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_hypot &gt;= 201603 </code></td></tr><tr><td align="left"> Mathematical Special Functions for C++17 </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_hypot &gt;= 201603 </code></td></tr><tr><td align="left"> Mathematical Special Functions for C++17 </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0226r1.pdf" target="_top">
 	P0226R1
 	</a>
-      </td><td align="center"> 7 (6.1) </td><td align="left"><code class="code"> __cpp_lib_math_special_functions &gt;= 201603 </code>
-	     (for GCC 6 or pre-C++17 define
-	     <code class="code">__STDCPP_WANT_MATH_SPEC_FUNCS__</code> to a non-zero value
-	     and test for <code class="code">__STDCPP_MATH_SPEC_FUNCS__ &gt;= 201003L</code>)
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_math_special_functions &gt;= 201603 </code>
+	     (see Note 3)
       </td></tr><tr bgcolor="#C8B0B0"><td align="left">Adopt the File System TS for C++17	 </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0218r1.html" target="_top">
 	P0218R1
@@ -768,31 +778,50 @@
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0219r1.html" target="_top">
 	P0219R1
 	</a>
-      </td><td align="center"> No </td><td align="left"> </td></tr><tr bgcolor="#C8B0B0"><td align="left"> Adapting string_view by filesystem paths </td><td align="left">
+      </td><td align="center"> No </td><td align="left"><code class="code"> __cpp_lib_filesystem &gt;= 201606 </code></td></tr><tr bgcolor="#C8B0B0"><td align="left"> Adapting string_view by filesystem paths </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0392r0.pdf" target="_top">
 	P0392R0
 	</a>
-      </td><td align="center"> No </td><td align="left"> </td></tr><tr><td align="left"> constexpr <code class="code">atomic&lt;T&gt;::is_always_lock_free</code>	 </td><td align="left">
+      </td><td align="center"> No </td><td align="left"><code class="code"> __cpp_lib_filesystem &gt;= 201606 </code></td></tr><tr bgcolor="#C8B0B0"><td align="left"> Directory Entry Caching for Filesystem </td><td align="left">
+       <a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0317r1.html" target="_top">
+       P0317R1
+       </a>
+      </td><td align="center"> No </td><td align="left"><code class="code"> __cpp_lib_filesystem &gt;= 201703 </code></td></tr><tr><td align="left"> constexpr <code class="code">atomic&lt;T&gt;::is_always_lock_free</code>	 </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0152r1.html" target="_top">
 	P0152R1
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_atomic_is_always_lock_free &gt;= 201603 </code></td></tr><tr><td align="left">A proposal to add <code class="code">shared_mutex</code> (untimed) (Revision 4)</td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_atomic_is_always_lock_free &gt;= 201603 </code></td></tr><tr><td align="left">A proposal to add <code class="code">shared_mutex</code> (untimed) (Revision 4)</td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2015/n4508.html" target="_top">
 	  N4508
 	</a>
-      </td><td align="center"> 6.1 </td><td align="left"><code class="code"> __cpp_lib_shared_mutex &gt;= 201505 </code></td></tr><tr><td align="left"> Variadic <code class="code">lock_guard</code> </td><td align="left">
+      </td><td align="center"> 6.1 </td><td align="left"><code class="code"> __cpp_lib_shared_mutex &gt;= 201505 </code></td></tr><tr><td align="left"> Variadic <code class="code">lock_guard</code> (Rev. 5) </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2017/p0156r2.html" target="_top">
 	P0156R2
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> __cpp_lib_scoped_lock &gt;= 201703 </code></td></tr><tr><td align="left"> byte type definition </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_scoped_lock &gt;= 201703 </code></td></tr><tr><td align="left"> A byte type definition </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2017/p0298r3.pdf" target="_top">
 	P0298R3
 	</a>
-      </td><td align="center"> 7 </td><td align="left"><code class="code"> ??? </code></td></tr><tr bgcolor="#C8B0B0"><td align="left"> Elementary string conversions </td><td align="left">
+      </td><td align="center"> 7.1 </td><td align="left"><code class="code"> __cpp_lib_byte &gt;= 201603 </code> (since 7.3, see Note 2)
+      </td></tr><tr bgcolor="#B0B0B0"><td align="left"> Elementary string conversions </td><td align="left">
 	<a class="link" href="http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2016/p0067r5.html" target="_top">
 	P0067R5
 	</a>
-      </td><td align="center"> No </td><td align="left"><code class="code"> ??? </code></td></tr></tbody></table></div></div><br class="table-break" /><div class="table"><a id="table.cxx1z_ts_status"></a><p class="title"><strong>Table 1.6. C++ Technical Specifications Implementation Status</strong></p><div class="table-contents"><table summary="C++ Technical Specifications Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Paper</th><th align="left">Title</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
+      </td><td align="center"> 8 (only integral types supported) </td><td align="left"><code class="code"> __has_include(&lt;charconv&gt;) </code>
+             <code class="code"> __cpp_lib_to_chars &gt;= 201611 </code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+Note 1: This feature is supported in GCC 7.1 and 7.2 but before GCC 7.3 the
+<code class="code">__cpp_lib</code> macro is not defined, and compilation will fail if the
+header is included without using <code class="option">-std</code> to enable C++17 support.
+</p><p>
+Note 2: This feature is supported in older releases but the
+<code class="code">__cpp_lib</code> macro is not defined to the right value
+(or not defined at all) until the version shown in parentheses.
+</p><p>
+Note 3: The mathematical special functions are enabled in C++17 mode from
+GCC 7.1 onwards. For GCC 6.x or for C++11/C++14 define
+<code class="code">__STDCPP_WANT_MATH_SPEC_FUNCS__</code> to a non-zero value
+and test for <code class="code">__STDCPP_MATH_SPEC_FUNCS__ &gt;= 201003L</code>.
+</p><div class="table"><a id="table.cxx17_ts_status"></a><p class="title"><strong>Table 1.6. C++ Technical Specifications Implementation Status</strong></p><div class="table-contents"><table class="table" summary="C++ Technical Specifications Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Paper</th><th align="left">Title</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
 	<a class="link" href="http://www.open-std.org/JTC1/SC22/WG21/docs/papers/2014/n4076.html" target="_top">
 	  N4076
 	</a>
@@ -915,9 +944,8 @@
 <code class="code">tr1/</code>, for instance <code class="code">&lt;tr1/functional&gt;</code>,
 <code class="code">&lt;tr1/memory&gt;</code>, and so on.
 </p><p>
-This page describes the TR1 support in mainline GCC SVN, not in any particular
-release.
-</p><div class="table"><a id="table.tr1_status"></a><p class="title"><strong>Table 1.7. C++ TR1 Implementation Status</strong></p><div class="table-contents"><table summary="C++ TR1 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Section</th><th align="left">Description</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left"><span class="emphasis"><em>2</em></span></td><td colspan="3" align="left"><span class="emphasis"><em>General Utilities</em></span></td></tr><tr><td align="left">2.1</td><td align="left">Reference wrappers</td><td align="left"> </td><td align="left"> </td></tr><tr><td align="left">2.1.1</td><td align="left">Additions to header <code class="code">&lt;functional&gt;</code> synopsis</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2</td><td align="left">Class template <code class="code">reference_wrapper</code></td><td align="left"> </td><td align="left"> </td></tr><tr><td align="left">2.1.2.1</td><td align="left"><code class="code">reference_wrapper</code> construct/copy/destroy</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2.2</td><td align="left"><code class="code">reference_wrapper</code> assignment</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2.3</td><td align="left"><code class="code">reference_wrapper</code> access</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2.4</td><td align="left"><code class="code">reference_wrapper</code> invocation</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2.5</td><td align="left"><code class="code">reference_wrapper</code> helper functions</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.2</td><td align="left">Smart pointers</td><td align="left"> </td><td align="left"> </td></tr><tr><td align="left">2.2.1</td><td align="left">Additions to header <code class="code">&lt;memory&gt;</code> synopsis</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.2.2</td><td align="left">Class <code class="code">bad_weak_ptr</code></td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.2.3</td><td align="left">Class template <code class="code">shared_ptr</code></td><td align="left"> </td><td align="left">
+This page describes the TR1 support in the GCC 7 series.
+</p><div class="table"><a id="table.tr1_status"></a><p class="title"><strong>Table 1.7. C++ TR1 Implementation Status</strong></p><div class="table-contents"><table class="table" summary="C++ TR1 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Section</th><th align="left">Description</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left"><span class="emphasis"><em>2</em></span></td><td colspan="3" align="left"><span class="emphasis"><em>General Utilities</em></span></td></tr><tr><td align="left">2.1</td><td align="left">Reference wrappers</td><td align="left"> </td><td align="left"> </td></tr><tr><td align="left">2.1.1</td><td align="left">Additions to header <code class="code">&lt;functional&gt;</code> synopsis</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2</td><td align="left">Class template <code class="code">reference_wrapper</code></td><td align="left"> </td><td align="left"> </td></tr><tr><td align="left">2.1.2.1</td><td align="left"><code class="code">reference_wrapper</code> construct/copy/destroy</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2.2</td><td align="left"><code class="code">reference_wrapper</code> assignment</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2.3</td><td align="left"><code class="code">reference_wrapper</code> access</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2.4</td><td align="left"><code class="code">reference_wrapper</code> invocation</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.1.2.5</td><td align="left"><code class="code">reference_wrapper</code> helper functions</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.2</td><td align="left">Smart pointers</td><td align="left"> </td><td align="left"> </td></tr><tr><td align="left">2.2.1</td><td align="left">Additions to header <code class="code">&lt;memory&gt;</code> synopsis</td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.2.2</td><td align="left">Class <code class="code">bad_weak_ptr</code></td><td align="left">Y</td><td align="left"> </td></tr><tr><td align="left">2.2.3</td><td align="left">Class template <code class="code">shared_ptr</code></td><td align="left"> </td><td align="left">
 	<p>
 	  Uses code from
 	  <a class="link" href="http://www.boost.org/libs/smart_ptr/shared_ptr.htm" target="_top">boost::shared_ptr</a>.
@@ -936,9 +964,8 @@
 Extension for the programming language C++ to support
 decimal floating-point arithmetic
 </p><p>
-This page describes the TR 24733 support in mainline GCC SVN, not in any
-particular release.
-</p><div class="table"><a id="table.decfp_status"></a><p class="title"><strong>Table 1.8. C++ TR 24733 Implementation Status</strong></p><div class="table-contents"><table summary="C++ TR 24733 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Section</th><th align="left">Description</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
+This page describes the TR 24733 support in the GCC 7 series.
+</p><div class="table"><a id="table.decfp_status"></a><p class="title"><strong>Table 1.8. C++ TR 24733 Implementation Status</strong></p><div class="table-contents"><table class="table" summary="C++ TR 24733 Implementation Status" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Section</th><th align="left">Description</th><th align="left">Status</th><th align="left">Comments</th></tr></thead><tbody><tr><td align="left">
 	<span class="emphasis"><em>0</em></span>
       </td><td colspan="3" align="left">
 	<span class="emphasis"><em>Introduction</em></span>
Index: libstdc++-v3/doc/html/manual/profile_mode_devel.html
===================================================================
--- libstdc++-v3/doc/html/manual/profile_mode_devel.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/profile_mode_devel.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Developer Information</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_impl.html" title="Implementation Issues" /><link rel="next" href="profile_mode_diagnostics.html" title="Diagnostics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Developer Information</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_impl.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_diagnostics.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.developer"></a>Developer Information</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.ext.profile_mode.developer.bigpic"></a>Big Picture</h3></div></div></div><p>The profile mode headers are included with
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Developer Information</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_impl.html" title="Implementation Issues" /><link rel="next" href="profile_mode_diagnostics.html" title="Diagnostics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Developer Information</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_impl.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_diagnostics.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.developer"></a>Developer Information</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.ext.profile_mode.developer.bigpic"></a>Big Picture</h3></div></div></div><p>The profile mode headers are included with
    <code class="code">-D_GLIBCXX_PROFILE</code> through preprocessor directives in
    <code class="code">include/std/*</code>.
   </p><p>Instrumented implementations are provided in
Index: libstdc++-v3/doc/html/manual/debug_mode_design.html
===================================================================
--- libstdc++-v3/doc/html/manual/debug_mode_design.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/debug_mode_design.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="debug_mode.html" title="Chapter 17. Debug Mode" /><link rel="prev" href="debug_mode_using.html" title="Using" /><link rel="next" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="debug_mode_using.html">Prev</a> </td><th width="60%" align="center">Chapter 17. Debug Mode</th><td width="20%" align="right"> <a accesskey="n" href="parallel_mode.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.debug_mode.design"></a>Design</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="debug_mode.html" title="Chapter 17. Debug Mode" /><link rel="prev" href="debug_mode_using.html" title="Using" /><link rel="next" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="debug_mode_using.html">Prev</a> </td><th width="60%" align="center">Chapter 17. Debug Mode</th><td width="20%" align="right"> <a accesskey="n" href="parallel_mode.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.debug_mode.design"></a>Design</h2></div></div></div><p>
   </p><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="debug_mode.design.goals"></a>Goals</h3></div></div></div><p>
     </p><p> The libstdc++ debug mode replaces unsafe (but efficient) standard
   containers and iterators with semantically equivalent safe standard
Index: libstdc++-v3/doc/html/manual/policy_data_structures_design.html
===================================================================
--- libstdc++-v3/doc/html/manual/policy_data_structures_design.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/policy_data_structures_design.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="prev" href="policy_data_structures_using.html" title="Using" /><link rel="next" href="policy_based_data_structures_test.html" title="Testing" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_data_structures_using.html">Prev</a> </td><th width="60%" align="center">Chapter 22. Policy-Based Data Structures</th><td width="20%" align="right"> <a accesskey="n" href="policy_based_data_structures_test.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="containers.pbds.design"></a>Design</h2></div></div></div><p></p><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="pbds.design.concepts"></a>Concepts</h3></div></div></div><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="pbds.design.concepts.null_type"></a>Null Policy Classes</h4></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="prev" href="policy_data_structures_using.html" title="Using" /><link rel="next" href="policy_based_data_structures_test.html" title="Testing" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_data_structures_using.html">Prev</a> </td><th width="60%" align="center">Chapter 22. Policy-Based Data Structures</th><td width="20%" align="right"> <a accesskey="n" href="policy_based_data_structures_test.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="containers.pbds.design"></a>Design</h2></div></div></div><p></p><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="pbds.design.concepts"></a>Concepts</h3></div></div></div><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="pbds.design.concepts.null_type"></a>Null Policy Classes</h4></div></div></div><p>
 	Associative containers are typically parametrized by various
 	policies. For example, a hash-based associative container is
 	parametrized by a hash-functor, transforming each key into an
Index: libstdc++-v3/doc/html/manual/using.html
===================================================================
--- libstdc++-v3/doc/html/manual/using.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/using.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 3. Using</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="intro.html" title="Part I.  Introduction" /><link rel="prev" href="make.html" title="Make" /><link rel="next" href="using_headers.html" title="Headers" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 3. Using</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="make.html">Prev</a> </td><th width="60%" align="center">Part I. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 3. Using</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="intro.html" title="Part I.  Introduction" /><link rel="prev" href="make.html" title="Make" /><link rel="next" href="using_headers.html" title="Headers" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 3. Using</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="make.html">Prev</a> </td><th width="60%" align="center">Part I. 
   Introduction
   
 </th><td width="20%" align="right"> <a accesskey="n" href="using_headers.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.intro.using"></a>Chapter 3. Using</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="using.html#manual.intro.using.flags">Command Options</a></span></dt><dt><span class="section"><a href="using_headers.html">Headers</a></span></dt><dd><dl><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.all">Header Files</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.mixing">Mixing Headers</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.cheaders">The C Headers and <code class="code">namespace std</code></a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.pre">Precompiled Headers</a></span></dt></dl></dd><dt><span class="section"><a href="using_macros.html">Macros</a></span></dt><dt><span class="section"><a href="using_dual_abi.html">Dual ABI</a></span></dt><dd><dl><dt><span class="section"><a href="using_dual_abi.html#manual.intro.using.abi.trouble">Troubleshooting</a></span></dt></dl></dd><dt><span class="section"><a href="using_namespaces.html">Namespaces</a></span></dt><dd><dl><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.all">Available Namespaces</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.std">namespace std</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.comp">Using Namespace Composition</a></span></dt></dl></dd><dt><span class="section"><a href="using_dynamic_or_shared.html">Linking</a></span></dt><dd><dl><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.freestanding">Almost Nothing</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.dynamic">Finding Dynamic or Shared Libraries</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.experimental">Experimental Library Extensions</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html">Concurrency</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.thread_safety">Thread Safety</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.atomics">Atomics</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.io">IO</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#concurrency.io.structure">Structure</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.defaults">Defaults</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.future">Future</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.alt">Alternatives</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.containers">Containers</a></span></dt></dl></dd><dt><span class="section"><a href="using_exceptions.html">Exceptions</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.safety">Exception Safety</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.propagating">Exception Neutrality</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.no">Doing without</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.compat">Compatibility</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.c">With <code class="literal">C</code></a></span></dt><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.posix">With <code class="literal">POSIX</code> thread cancellation</a></span></dt></dl></dd></dl></dd><dt><span class="section"><a href="debug.html">Debugging Support</a></span></dt><dd><dl><dt><span class="section"><a href="debug.html#debug.compiler">Using <span class="command"><strong>g++</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.req">Debug Versions of Library Binary Files</a></span></dt><dt><span class="section"><a href="debug.html#debug.memory">Memory Leak Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.races">Data Race Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.gdb">Using <span class="command"><strong>gdb</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.exceptions">Tracking uncaught exceptions</a></span></dt><dt><span class="section"><a href="debug.html#debug.debug_mode">Debug Mode</a></span></dt><dt><span class="section"><a href="debug.html#debug.compile_time_checks">Compile Time Checking</a></span></dt><dt><span class="section"><a href="debug.html#debug.profile_mode">Profile-based Performance Analysis</a></span></dt></dl></dd></dl></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.flags"></a>Command Options</h2></div></div></div><p>
@@ -13,7 +13,7 @@
       By default, <span class="command"><strong>g++</strong></span> is equivalent to
       <span class="command"><strong>g++ -std=gnu++14</strong></span> since GCC 6, and
       <span class="command"><strong>g++ -std=gnu++98</strong></span> for older releases.
-    </p><div class="table"><a id="table.cmd_options"></a><p class="title"><strong>Table 3.1. C++ Command Options</strong></p><div class="table-contents"><table summary="C++ Command Options" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">Option Flags</th><th align="left">Description</th></tr></thead><tbody><tr><td align="left"><code class="literal">-std=c++98</code> or <code class="literal">-std=c++03</code>
+    </p><div class="table"><a id="table.cmd_options"></a><p class="title"><strong>Table 3.1. C++ Command Options</strong></p><div class="table-contents"><table class="table" summary="C++ Command Options" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">Option Flags</th><th align="left">Description</th></tr></thead><tbody><tr><td align="left"><code class="literal">-std=c++98</code> or <code class="literal">-std=c++03</code>
       </td><td align="left">Use the 1998 ISO C++ standard plus amendments.</td></tr><tr><td align="left"><code class="literal">-std=gnu++98</code> or <code class="literal">-std=gnu++03</code>
       </td><td align="left">As directly above, with GNU extensions.</td></tr><tr><td align="left"><code class="literal">-std=c++11</code></td><td align="left">Use the 2011 ISO C++ standard.</td></tr><tr><td align="left"><code class="literal">-std=gnu++11</code></td><td align="left">As directly above, with GNU extensions.</td></tr><tr><td align="left"><code class="literal">-std=c++14</code></td><td align="left">Use the 2014 ISO C++ standard.</td></tr><tr><td align="left"><code class="literal">-std=gnu++14</code></td><td align="left">As directly above, with GNU extensions.</td></tr><tr><td align="left"><code class="literal">-fexceptions</code></td><td align="left">See <a class="link" href="using_exceptions.html#intro.using.exception.no" title="Doing without">exception-free dialect</a></td></tr><tr><td align="left"><code class="literal">-frtti</code></td><td align="left">As above, but RTTI-free dialect.</td></tr><tr><td align="left"><code class="literal">-pthread</code></td><td align="left">For ISO C++11
         <code class="filename">&lt;thread&gt;</code>,
Index: libstdc++-v3/doc/html/manual/profile_mode_impl.html
===================================================================
--- libstdc++-v3/doc/html/manual/profile_mode_impl.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/profile_mode_impl.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Implementation Issues</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_cost_model.html" title="Empirical Cost Model" /><link rel="next" href="profile_mode_devel.html" title="Developer Information" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Implementation Issues</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_cost_model.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_devel.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.implementation"></a>Implementation Issues</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.ext.profile_mode.implementation.stack"></a>Stack Traces</h3></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Implementation Issues</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_cost_model.html" title="Empirical Cost Model" /><link rel="next" href="profile_mode_devel.html" title="Developer Information" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Implementation Issues</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_cost_model.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_devel.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.implementation"></a>Implementation Issues</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.ext.profile_mode.implementation.stack"></a>Stack Traces</h3></div></div></div><p>
   Accurate stack traces are needed during profiling since we group events by
   call context and dynamic instance.  Without accurate traces, diagnostics
   may be hard to interpret.  For instance, when giving advice to the user
Index: libstdc++-v3/doc/html/manual/ext_containers.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_containers.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_containers.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 23. HP/SGI Extensions</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="policy_data_structures_ack.html" title="Acknowledgments" /><link rel="next" href="ext_sgi.html" title="Deprecated" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 23. HP/SGI Extensions</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_data_structures_ack.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 23. HP/SGI Extensions</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="policy_data_structures_ack.html" title="Acknowledgments" /><link rel="next" href="ext_sgi.html" title="Deprecated" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 23. HP/SGI Extensions</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_data_structures_ack.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="ext_sgi.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.containers"></a>Chapter 23. HP/SGI Extensions</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="ext_containers.html#manual.ext.containers.sgi">Backwards Compatibility</a></span></dt><dt><span class="section"><a href="ext_sgi.html">Deprecated</a></span></dt></dl></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.containers.sgi"></a>Backwards Compatibility</h2></div></div></div><p>A few extensions and nods to backwards-compatibility have
Index: libstdc++-v3/doc/html/manual/ext_concurrency_use.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_concurrency_use.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_concurrency_use.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Use</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="ext_concurrency.html" title="Chapter 30. Concurrency" /><link rel="prev" href="ext_concurrency_impl.html" title="Implementation" /><link rel="next" href="appendix.html" title="Part IV.  Appendices" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Use</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_concurrency_impl.html">Prev</a> </td><th width="60%" align="center">Chapter 30. Concurrency</th><td width="20%" align="right"> <a accesskey="n" href="appendix.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.concurrency.use"></a>Use</h2></div></div></div><p>Typical usage of the last two constructs is demonstrated as follows:
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Use</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="ext_concurrency.html" title="Chapter 30. Concurrency" /><link rel="prev" href="ext_concurrency_impl.html" title="Implementation" /><link rel="next" href="appendix.html" title="Part IV.  Appendices" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Use</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_concurrency_impl.html">Prev</a> </td><th width="60%" align="center">Chapter 30. Concurrency</th><td width="20%" align="right"> <a accesskey="n" href="appendix.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.concurrency.use"></a>Use</h2></div></div></div><p>Typical usage of the last two constructs is demonstrated as follows:
 </p><pre class="programlisting">
 #include &lt;ext/concurrence.h&gt;
 
Index: libstdc++-v3/doc/html/manual/ext_io.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_io.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_io.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 28. Input and Output</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_iterators.html" title="Chapter 27. Iterators" /><link rel="next" href="ext_demangling.html" title="Chapter 29. Demangling" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 28. Input and Output</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_iterators.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 28. Input and Output</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_iterators.html" title="Chapter 27. Iterators" /><link rel="next" href="ext_demangling.html" title="Chapter 29. Demangling" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 28. Input and Output</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_iterators.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="ext_demangling.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.io"></a>Chapter 28. Input and Output</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="ext_io.html#manual.ext.io.filebuf_derived">Derived filebufs</a></span></dt></dl></div><p>
Index: libstdc++-v3/doc/html/manual/termination.html
===================================================================
--- libstdc++-v3/doc/html/manual/termination.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/termination.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Termination</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="support.html" title="Chapter 4.  Support" /><link rel="prev" href="dynamic_memory.html" title="Dynamic Memory" /><link rel="next" href="diagnostics.html" title="Chapter 5.  Diagnostics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Termination</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="dynamic_memory.html">Prev</a> </td><th width="60%" align="center">Chapter 4. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Termination</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="support.html" title="Chapter 4.  Support" /><link rel="prev" href="dynamic_memory.html" title="Dynamic Memory" /><link rel="next" href="diagnostics.html" title="Chapter 5.  Diagnostics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Termination</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="dynamic_memory.html">Prev</a> </td><th width="60%" align="center">Chapter 4. 
   Support
   
 </th><td width="20%" align="right"> <a accesskey="n" href="diagnostics.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.support.termination"></a>Termination</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="support.termination.handlers"></a>Termination Handlers</h3></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/using_macros.html
===================================================================
--- libstdc++-v3/doc/html/manual/using_macros.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/using_macros.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Macros</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_headers.html" title="Headers" /><link rel="next" href="using_dual_abi.html" title="Dual ABI" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Macros</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_headers.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_dual_abi.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.macros"></a>Macros</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Macros</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_headers.html" title="Headers" /><link rel="next" href="using_dual_abi.html" title="Dual ABI" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Macros</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_headers.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_dual_abi.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.macros"></a>Macros</h2></div></div></div><p>
      All library macros begin with <code class="code">_GLIBCXX_</code>.
    </p><p>
      Furthermore, all pre-processor macros, switches, and
Index: libstdc++-v3/doc/html/manual/concurrency.html
===================================================================
--- libstdc++-v3/doc/html/manual/concurrency.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/concurrency.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 15.  Concurrency</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library, mutex, thread, future, condition_variable" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="atomics.html" title="Chapter 14.  Atomics" /><link rel="next" href="extensions.html" title="Part III.  Extensions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 15. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 15.  Concurrency</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library, mutex, thread, future, condition_variable" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="atomics.html" title="Chapter 14.  Atomics" /><link rel="next" href="extensions.html" title="Part III.  Extensions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 15. 
   Concurrency
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="atomics.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/ext_utilities.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_utilities.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_utilities.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 24. Utilities</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_sgi.html" title="Deprecated" /><link rel="next" href="ext_algorithms.html" title="Chapter 25. Algorithms" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 24. Utilities</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_sgi.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 24. Utilities</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_sgi.html" title="Deprecated" /><link rel="next" href="ext_algorithms.html" title="Chapter 25. Algorithms" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 24. Utilities</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_sgi.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="ext_algorithms.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.util"></a>Chapter 24. Utilities</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/policy_data_structures.html
===================================================================
--- libstdc++-v3/doc/html/manual/policy_data_structures.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/policy_data_structures.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 22. Policy-Based Data Structures</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="bitmap_allocator_impl.html" title="Implementation" /><link rel="next" href="policy_data_structures_using.html" title="Using" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 22. Policy-Based Data Structures</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bitmap_allocator_impl.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 22. Policy-Based Data Structures</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="bitmap_allocator_impl.html" title="Implementation" /><link rel="next" href="policy_data_structures_using.html" title="Using" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 22. Policy-Based Data Structures</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bitmap_allocator_impl.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="policy_data_structures_using.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.containers.pbds"></a>Chapter 22. Policy-Based Data Structures</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="policy_data_structures.html#pbds.intro">Intro</a></span></dt><dd><dl><dt><span class="section"><a href="policy_data_structures.html#pbds.intro.issues">Performance Issues</a></span></dt><dd><dl><dt><span class="section"><a href="policy_data_structures.html#pbds.intro.issues.associative">Associative</a></span></dt><dt><span class="section"><a href="policy_data_structures.html#pbds.intro.issues.priority_queue">Priority Que</a></span></dt></dl></dd><dt><span class="section"><a href="policy_data_structures.html#pbds.intro.motivation">Goals</a></span></dt><dd><dl><dt><span class="section"><a href="policy_data_structures.html#pbds.intro.motivation.associative">Associative</a></span></dt><dd><dl><dt><span class="section"><a href="policy_data_structures.html#motivation.associative.policy">Policy Choices</a></span></dt><dt><span class="section"><a href="policy_data_structures.html#motivation.associative.underlying">Underlying Data Structures</a></span></dt><dt><span class="section"><a href="policy_data_structures.html#motivation.associative.iterators">Iterators</a></span></dt><dt><span class="section"><a href="policy_data_structures.html#motivation.associative.functions">Functional</a></span></dt></dl></dd><dt><span class="section"><a href="policy_data_structures.html#pbds.intro.motivation.priority_queue">Priority Queues</a></span></dt><dd><dl><dt><span class="section"><a href="policy_data_structures.html#motivation.priority_queue.policy">Policy Choices</a></span></dt><dt><span class="section"><a href="policy_data_structures.html#motivation.priority_queue.underlying">Underlying Data Structures</a></span></dt><dt><span class="section"><a href="policy_data_structures.html#motivation.priority_queue.binary_heap">Binary Heaps</a></span></dt></dl></dd></dl></dd></dl></dd><dt><span class="section"><a href="policy_data_structures_using.html">Using</a></span></dt><dd><dl><dt><span class="section"><a href="policy_data_structures_using.html#pbds.using.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="policy_data_structures_using.html#pbds.using.organization">Organization</a></span></dt><dt><span class="section"><a href="policy_data_structures_using.html#pbds.using.tutorial">Tutorial</a></span></dt><dd><dl><dt><span class="section"><a href="policy_data_structures_using.html#pbds.using.tutorial.basic">Basic Use</a></span></dt><dt><span class="section"><a href="policy_data_structures_using.html#pbds.using.tutorial.configuring">
Index: libstdc++-v3/doc/html/manual/ext_iterators.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_iterators.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_iterators.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 27. Iterators</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_numerics.html" title="Chapter 26. Numerics" /><link rel="next" href="ext_io.html" title="Chapter 28. Input and Output" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 27. Iterators</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_numerics.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 27. Iterators</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_numerics.html" title="Chapter 26. Numerics" /><link rel="next" href="ext_io.html" title="Chapter 28. Input and Output" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 27. Iterators</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_numerics.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="ext_io.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.iterators"></a>Chapter 27. Iterators</h2></div></div></div><p>24.3.2 describes <code class="code">struct iterator</code>, which didn't exist in the
Index: libstdc++-v3/doc/html/manual/bitmap_allocator_impl.html
===================================================================
--- libstdc++-v3/doc/html/manual/bitmap_allocator_impl.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/bitmap_allocator_impl.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Implementation</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="bitmap_allocator.html" title="Chapter 21. The bitmap_allocator" /><link rel="prev" href="bitmap_allocator.html" title="Chapter 21. The bitmap_allocator" /><link rel="next" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Implementation</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bitmap_allocator.html">Prev</a> </td><th width="60%" align="center">Chapter 21. The bitmap_allocator</th><td width="20%" align="right"> <a accesskey="n" href="policy_data_structures.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.bitmap.impl"></a>Implementation</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="bitmap.impl.free_list_store"></a>Free List Store</h3></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Implementation</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="bitmap_allocator.html" title="Chapter 21. The bitmap_allocator" /><link rel="prev" href="bitmap_allocator.html" title="Chapter 21. The bitmap_allocator" /><link rel="next" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Implementation</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bitmap_allocator.html">Prev</a> </td><th width="60%" align="center">Chapter 21. The bitmap_allocator</th><td width="20%" align="right"> <a accesskey="n" href="policy_data_structures.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.bitmap.impl"></a>Implementation</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="bitmap.impl.free_list_store"></a>Free List Store</h3></div></div></div><p>
     The Free List Store (referred to as FLS for the remaining part of this
     document) is the Global memory pool that is shared by all instances of
     the bitmapped allocator instantiated for any type. This maintains a
@@ -75,7 +75,7 @@
   </p><p>
     Consider a block of size 64 ints. In memory, it would look like this:
     (assume a 32-bit system where, size_t is a 32-bit entity).
-  </p><div class="table"><a id="table.bitmap_alloc"></a><p class="title"><strong>Table 21.1. Bitmap Allocator Memory Map</strong></p><div class="table-contents"><table summary="Bitmap Allocator Memory Map" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left">268</td><td align="left">0</td><td align="left">4294967295</td><td align="left">4294967295</td><td align="left">Data -&gt; Space for 64 ints</td></tr></tbody></table></div></div><br class="table-break" /><p>
+  </p><div class="table"><a id="table.bitmap_alloc"></a><p class="title"><strong>Table 21.1. Bitmap Allocator Memory Map</strong></p><div class="table-contents"><table class="table" summary="Bitmap Allocator Memory Map" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left">268</td><td align="left">0</td><td align="left">4294967295</td><td align="left">4294967295</td><td align="left">Data -&gt; Space for 64 ints</td></tr></tbody></table></div></div><br class="table-break" /><p>
     The first Column(268) represents the size of the Block in bytes as
     seen by the Bitmap Allocator. Internally, a global free list is
     used to keep track of the free blocks used and given back by the
Index: libstdc++-v3/doc/html/manual/appendix_contributing.html
===================================================================
--- libstdc++-v3/doc/html/manual/appendix_contributing.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/appendix_contributing.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix A.  Contributing</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="appendix.html" title="Part IV.  Appendices" /><link rel="next" href="source_organization.html" title="Directory Layout and Source Conventions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix A. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix A.  Contributing</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="appendix.html" title="Part IV.  Appendices" /><link rel="next" href="source_organization.html" title="Directory Layout and Source Conventions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix A. 
   Contributing
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="appendix.html">Prev</a> </td><th width="60%" align="center">Part IV. 
Index: libstdc++-v3/doc/html/manual/parallel_mode_test.html
===================================================================
--- libstdc++-v3/doc/html/manual/parallel_mode_test.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/parallel_mode_test.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Testing</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="prev" href="parallel_mode_design.html" title="Design" /><link rel="next" href="profile_mode.html" title="Chapter 19. Profile Mode" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Testing</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode_design.html">Prev</a> </td><th width="60%" align="center">Chapter 18. Parallel Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.parallel_mode.test"></a>Testing</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Testing</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="prev" href="parallel_mode_design.html" title="Design" /><link rel="next" href="profile_mode.html" title="Chapter 19. Profile Mode" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Testing</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode_design.html">Prev</a> </td><th width="60%" align="center">Chapter 18. Parallel Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.parallel_mode.test"></a>Testing</h2></div></div></div><p>
     Both the normal conformance and regression tests and the
     supplemental performance tests work.
   </p><p>
Index: libstdc++-v3/doc/html/manual/profile_mode.html
===================================================================
--- libstdc++-v3/doc/html/manual/profile_mode.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/profile_mode.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 19. Profile Mode</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="parallel_mode_test.html" title="Testing" /><link rel="next" href="profile_mode_design.html" title="Design" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 19. Profile Mode</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode_test.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 19. Profile Mode</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="parallel_mode_test.html" title="Testing" /><link rel="next" href="profile_mode_design.html" title="Design" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 19. Profile Mode</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode_test.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_design.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.profile_mode"></a>Chapter 19. Profile Mode</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="profile_mode.html#manual.ext.profile_mode.intro">Intro</a></span></dt><dd><dl><dt><span class="section"><a href="profile_mode.html#manual.ext.profile_mode.using">Using the Profile Mode</a></span></dt><dt><span class="section"><a href="profile_mode.html#manual.ext.profile_mode.tuning">Tuning the Profile Mode</a></span></dt></dl></dd><dt><span class="section"><a href="profile_mode_design.html">Design</a></span></dt><dd><dl><dt><span class="section"><a href="profile_mode_design.html#manual.ext.profile_mode.design.wrapper">Wrapper Model</a></span></dt><dt><span class="section"><a href="profile_mode_design.html#manual.ext.profile_mode.design.instrumentation">Instrumentation</a></span></dt><dt><span class="section"><a href="profile_mode_design.html#manual.ext.profile_mode.design.rtlib">Run Time Behavior</a></span></dt><dt><span class="section"><a href="profile_mode_design.html#manual.ext.profile_mode.design.analysis">Analysis and Diagnostics</a></span></dt><dt><span class="section"><a href="profile_mode_design.html#manual.ext.profile_mode.design.cost-model">Cost Model</a></span></dt><dt><span class="section"><a href="profile_mode_design.html#manual.ext.profile_mode.design.reports">Reports</a></span></dt><dt><span class="section"><a href="profile_mode_design.html#manual.ext.profile_mode.design.testing">Testing</a></span></dt></dl></dd><dt><span class="section"><a href="profile_mode_api.html">Extensions for Custom Containers</a></span></dt><dt><span class="section"><a href="profile_mode_cost_model.html">Empirical Cost Model</a></span></dt><dt><span class="section"><a href="profile_mode_impl.html">Implementation Issues</a></span></dt><dd><dl><dt><span class="section"><a href="profile_mode_impl.html#manual.ext.profile_mode.implementation.stack">Stack Traces</a></span></dt><dt><span class="section"><a href="profile_mode_impl.html#manual.ext.profile_mode.implementation.symbols">Symbolization of Instruction Addresses</a></span></dt><dt><span class="section"><a href="profile_mode_impl.html#manual.ext.profile_mode.implementation.concurrency">Concurrency</a></span></dt><dt><span class="section"><a href="profile_mode_impl.html#manual.ext.profile_mode.implementation.stdlib-in-proflib">Using the Standard Library in the Instrumentation Implementation</a></span></dt><dt><span class="section"><a href="profile_mode_impl.html#manual.ext.profile_mode.implementation.malloc-hooks">Malloc Hooks</a></span></dt><dt><span class="section"><a href="profile_mode_impl.html#manual.ext.profile_mode.implementation.construction-destruction">Construction and Destruction of Global Objects</a></span></dt></dl></dd><dt><span class="section"><a href="profile_mode_devel.html">Developer Information</a></span></dt><dd><dl><dt><span class="section"><a href="profile_mode_devel.html#manual.ext.profile_mode.developer.bigpic">Big Picture</a></span></dt><dt><span class="section"><a href="profile_mode_devel.html#manual.ext.profile_mode.developer.howto">How To Add A Diagnostic</a></span></dt></dl></dd><dt><span class="section"><a href="profile_mode_diagnostics.html">Diagnostics</a></span></dt><dd><dl><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.template">Diagnostic Template</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.containers">Containers</a></span></dt><dd><dl><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.hashtable_too_small">Hashtable Too Small</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.hashtable_too_large">Hashtable Too Large</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.inefficient_hash">Inefficient Hash</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.vector_too_small">Vector Too Small</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.vector_too_large">Vector Too Large</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.vector_to_hashtable">Vector to Hashtable</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.hashtable_to_vector">Hashtable to Vector</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.vector_to_list">Vector to List</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.list_to_vector">List to Vector</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.list_to_slist">List to Forward List (Slist)</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.assoc_ord_to_unord">Ordered to Unordered Associative Container</a></span></dt></dl></dd><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.algorithms">Algorithms</a></span></dt><dd><dl><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.algorithms.sort">Sort Algorithm Performance</a></span></dt></dl></dd><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.locality">Data Locality</a></span></dt><dd><dl><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.locality.sw_prefetch">Need Software Prefetch</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.locality.linked">Linked Structure Locality</a></span></dt></dl></dd><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.mthread">Multithreaded Data Access</a></span></dt><dd><dl><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.mthread.ddtest">Data Dependence Violations at Container Level</a></span></dt><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.mthread.false_share">False Sharing</a></span></dt></dl></dd><dt><span class="section"><a href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.statistics">Statistics</a></span></dt></dl></dd><dt><span class="bibliography"><a href="profile_mode.html#profile_mode.biblio">Bibliography</a></span></dt></dl></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.intro"></a>Intro</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/stringstreams.html
===================================================================
--- libstdc++-v3/doc/html/manual/stringstreams.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/stringstreams.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Memory Based Streams</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="io.html" title="Chapter 13.  Input and Output" /><link rel="prev" href="streambufs.html" title="Stream Buffers" /><link rel="next" href="fstreams.html" title="File Based Streams" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Memory Based Streams</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="streambufs.html">Prev</a> </td><th width="60%" align="center">Chapter 13. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Memory Based Streams</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="io.html" title="Chapter 13.  Input and Output" /><link rel="prev" href="streambufs.html" title="Stream Buffers" /><link rel="next" href="fstreams.html" title="File Based Streams" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Memory Based Streams</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="streambufs.html">Prev</a> </td><th width="60%" align="center">Chapter 13. 
   Input and Output
   
 </th><td width="20%" align="right"> <a accesskey="n" href="fstreams.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.io.memstreams"></a>Memory Based Streams</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="std.io.memstreams.compat"></a>Compatibility With strstream</h3></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/traits.html
===================================================================
--- libstdc++-v3/doc/html/manual/traits.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/traits.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Traits</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="utilities.html" title="Chapter 6.  Utilities" /><link rel="prev" href="memory.html" title="Memory" /><link rel="next" href="strings.html" title="Chapter 7.  Strings" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Traits</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="memory.html">Prev</a> </td><th width="60%" align="center">Chapter 6. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Traits</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="utilities.html" title="Chapter 6.  Utilities" /><link rel="prev" href="memory.html" title="Memory" /><link rel="next" href="strings.html" title="Chapter 7.  Strings" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Traits</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="memory.html">Prev</a> </td><th width="60%" align="center">Chapter 6. 
   Utilities
   
 </th><td width="20%" align="right"> <a accesskey="n" href="strings.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.util.traits"></a>Traits</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/policy_data_structures_ack.html
===================================================================
--- libstdc++-v3/doc/html/manual/policy_data_structures_ack.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/policy_data_structures_ack.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Acknowledgments</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="prev" href="policy_based_data_structures_test.html" title="Testing" /><link rel="next" href="ext_containers.html" title="Chapter 23. HP/SGI Extensions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Acknowledgments</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_based_data_structures_test.html">Prev</a> </td><th width="60%" align="center">Chapter 22. Policy-Based Data Structures</th><td width="20%" align="right"> <a accesskey="n" href="ext_containers.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="pbds.ack"></a>Acknowledgments</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Acknowledgments</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="prev" href="policy_based_data_structures_test.html" title="Testing" /><link rel="next" href="ext_containers.html" title="Chapter 23. HP/SGI Extensions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Acknowledgments</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_based_data_structures_test.html">Prev</a> </td><th width="60%" align="center">Chapter 22. Policy-Based Data Structures</th><td width="20%" align="right"> <a accesskey="n" href="ext_containers.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="pbds.ack"></a>Acknowledgments</h2></div></div></div><p>
       Written by Ami Tavory and Vladimir Dreizin (IBM Haifa Research
       Laboratories), and Benjamin Kosnik (Red Hat).
     </p><p>
Index: libstdc++-v3/doc/html/manual/associative.html
===================================================================
--- libstdc++-v3/doc/html/manual/associative.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/associative.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Associative</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="containers.html" title="Chapter 9.  Containers" /><link rel="prev" href="containers.html" title="Chapter 9.  Containers" /><link rel="next" href="unordered_associative.html" title="Unordered Associative" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Associative</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="containers.html">Prev</a> </td><th width="60%" align="center">Chapter 9. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Associative</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="containers.html" title="Chapter 9.  Containers" /><link rel="prev" href="containers.html" title="Chapter 9.  Containers" /><link rel="next" href="unordered_associative.html" title="Unordered Associative" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Associative</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="containers.html">Prev</a> </td><th width="60%" align="center">Chapter 9. 
   Containers
   
 </th><td width="20%" align="right"> <a accesskey="n" href="unordered_associative.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.containers.associative"></a>Associative</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="containers.associative.insert_hints"></a>Insertion Hints</h3></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/ext_concurrency.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_concurrency.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_concurrency.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 30. Concurrency</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_demangling.html" title="Chapter 29. Demangling" /><link rel="next" href="ext_concurrency_impl.html" title="Implementation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 30. Concurrency</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_demangling.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 30. Concurrency</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_demangling.html" title="Chapter 29. Demangling" /><link rel="next" href="ext_concurrency_impl.html" title="Implementation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 30. Concurrency</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_demangling.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="ext_concurrency_impl.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.concurrency"></a>Chapter 30. Concurrency</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="ext_concurrency.html#manual.ext.concurrency.design">Design</a></span></dt><dd><dl><dt><span class="section"><a href="ext_concurrency.html#manual.ext.concurrency.design.threads">Interface to Locks and Mutexes</a></span></dt><dt><span class="section"><a href="ext_concurrency.html#manual.ext.concurrency.design.atomics">Interface to Atomic Functions</a></span></dt></dl></dd><dt><span class="section"><a href="ext_concurrency_impl.html">Implementation</a></span></dt><dd><dl><dt><span class="section"><a href="ext_concurrency_impl.html#manual.ext.concurrency.impl.atomic_fallbacks">Using Built-in Atomic Functions</a></span></dt><dt><span class="section"><a href="ext_concurrency_impl.html#manual.ext.concurrency.impl.thread">Thread Abstraction</a></span></dt></dl></dd><dt><span class="section"><a href="ext_concurrency_use.html">Use</a></span></dt></dl></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.concurrency.design"></a>Design</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.ext.concurrency.design.threads"></a>Interface to Locks and Mutexes</h3></div></div></div><p>The file <code class="filename">&lt;ext/concurrence.h&gt;</code>
Index: libstdc++-v3/doc/html/manual/support.html
===================================================================
--- libstdc++-v3/doc/html/manual/support.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/support.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 4.  Support</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="next" href="dynamic_memory.html" title="Dynamic Memory" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 4. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 4.  Support</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="next" href="dynamic_memory.html" title="Dynamic Memory" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 4. 
   Support
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="std_contents.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/bitmap_allocator.html
===================================================================
--- libstdc++-v3/doc/html/manual/bitmap_allocator.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/bitmap_allocator.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 21. The bitmap_allocator</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="mt_allocator_ex_multi.html" title="Multiple Thread Example" /><link rel="next" href="bitmap_allocator_impl.html" title="Implementation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 21. The bitmap_allocator</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator_ex_multi.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 21. The bitmap_allocator</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="mt_allocator_ex_multi.html" title="Multiple Thread Example" /><link rel="next" href="bitmap_allocator_impl.html" title="Implementation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 21. The bitmap_allocator</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator_ex_multi.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="bitmap_allocator_impl.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.allocator.bitmap"></a>Chapter 21. The bitmap_allocator</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="bitmap_allocator.html#allocator.bitmap.design">Design</a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html">Implementation</a></span></dt><dd><dl><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.free_list_store">Free List Store</a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.super_block">Super Block</a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.super_block_data">Super Block Data Layout</a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.max_wasted">Maximum Wasted Percentage</a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.allocate"><code class="function">allocate</code></a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.deallocate"><code class="function">deallocate</code></a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.questions">Questions</a></span></dt><dd><dl><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.question.1">1</a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.question.2">2</a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.question.3">3</a></span></dt></dl></dd><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.locality">Locality</a></span></dt><dt><span class="section"><a href="bitmap_allocator_impl.html#bitmap.impl.grow_policy">Overhead and Grow Policy</a></span></dt></dl></dd></dl></div><p>
Index: libstdc++-v3/doc/html/manual/license.html
===================================================================
--- libstdc++-v3/doc/html/manual/license.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/license.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>License</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="status.html" title="Chapter 1. Status" /><link rel="prev" href="status.html" title="Chapter 1. Status" /><link rel="next" href="bugs.html" title="Bugs" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">License</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="status.html">Prev</a> </td><th width="60%" align="center">Chapter 1. Status</th><td width="20%" align="right"> <a accesskey="n" href="bugs.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.status.license"></a>License</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>License</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="status.html" title="Chapter 1. Status" /><link rel="prev" href="status.html" title="Chapter 1. Status" /><link rel="next" href="bugs.html" title="Bugs" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">License</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="status.html">Prev</a> </td><th width="60%" align="center">Chapter 1. Status</th><td width="20%" align="right"> <a accesskey="n" href="bugs.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.status.license"></a>License</h2></div></div></div><p>
     There are two licenses affecting GNU libstdc++: one for the code,
     and one for the documentation.
     </p><p>
Index: libstdc++-v3/doc/html/manual/numerics.html
===================================================================
--- libstdc++-v3/doc/html/manual/numerics.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/numerics.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 12.  Numerics</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="algorithms.html" title="Chapter 11.  Algorithms" /><link rel="next" href="generalized_numeric_operations.html" title="Generalized Operations" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 12. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 12.  Numerics</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="algorithms.html" title="Chapter 11.  Algorithms" /><link rel="next" href="generalized_numeric_operations.html" title="Generalized Operations" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 12. 
   Numerics
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="algorithms.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/using_exceptions.html
===================================================================
--- libstdc++-v3/doc/html/manual/using_exceptions.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/using_exceptions.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Exceptions</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, exception, error, exception neutrality, exception safety, exception propagation, -fno-exceptions" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_concurrency.html" title="Concurrency" /><link rel="next" href="debug.html" title="Debugging Support" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Exceptions</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_concurrency.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="debug.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.exceptions"></a>Exceptions</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Exceptions</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, exception, error, exception neutrality, exception safety, exception propagation, -fno-exceptions" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_concurrency.html" title="Concurrency" /><link rel="next" href="debug.html" title="Debugging Support" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Exceptions</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_concurrency.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="debug.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.exceptions"></a>Exceptions</h2></div></div></div><p>
 The C++ language provides language support for stack unwinding
 with <code class="literal">try</code> and <code class="literal">catch</code> blocks and
 the <code class="literal">throw</code> keyword.
Index: libstdc++-v3/doc/html/manual/policy_based_data_structures_test.html
===================================================================
--- libstdc++-v3/doc/html/manual/policy_based_data_structures_test.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/policy_based_data_structures_test.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Testing</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="prev" href="policy_data_structures_design.html" title="Design" /><link rel="next" href="policy_data_structures_ack.html" title="Acknowledgments" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Testing</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_data_structures_design.html">Prev</a> </td><th width="60%" align="center">Chapter 22. Policy-Based Data Structures</th><td width="20%" align="right"> <a accesskey="n" href="policy_data_structures_ack.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="pbds.test"></a>Testing</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="pbds.test.regression"></a>Regression</h3></div></div></div><p>The library contains a single comprehensive regression test.
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Testing</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="prev" href="policy_data_structures_design.html" title="Design" /><link rel="next" href="policy_data_structures_ack.html" title="Acknowledgments" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Testing</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_data_structures_design.html">Prev</a> </td><th width="60%" align="center">Chapter 22. Policy-Based Data Structures</th><td width="20%" align="right"> <a accesskey="n" href="policy_data_structures_ack.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="pbds.test"></a>Testing</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="pbds.test.regression"></a>Regression</h3></div></div></div><p>The library contains a single comprehensive regression test.
     For a given container type in this library, the test creates
     an object of the container type and an object of the
     corresponding standard type (e.g., <code class="classname">std::set</code>). It
@@ -49,7 +49,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_hash_text_find.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
 		    n_hash_map_ncah
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_map</code>
@@ -182,7 +182,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_cc_hash_int_find.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
 		    n_hash_map_ncah
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_map</code>
@@ -284,7 +284,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_gp_hash_int_find.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
 		    n_hash_map_ncah
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_map</code>
@@ -384,7 +384,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_cc_hash_int_subscript_find.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
 		    n_hash_map_ncah
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_map</code>
@@ -484,7 +484,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_gp_hash_int_subscript_find.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
 		    n_hash_map_ncah
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_map</code>
@@ -571,7 +571,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_cc_hash_int_subscript_insert.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
 		    n_hash_map_ncah
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_map</code>
@@ -671,7 +671,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_gp_hash_int_subscript_insert.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
 		    n_hash_map_ncah
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_map</code>
@@ -779,7 +779,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_hash_zlob_int_find.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
 		    n_hash_map_ncah
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_map</code>
@@ -899,7 +899,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_hash_int_erase_mem.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="5" align="left">
 		    n_hash_map_ncah
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_map</code>
@@ -1007,7 +1007,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_tree_text_insert_node.png" align="middle" /></div><p>
 	      The abbreviated names in the legend of the graphic above are
 	      instantiated with the types in the following table.
-	    </p></div><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	    </p></div><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_map
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::map</code>
@@ -1040,7 +1040,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_tree_text_insert_vector.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_map
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::map</code>
@@ -1061,7 +1061,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_tree_text_insert_trie.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_map
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::map</code>
@@ -1117,7 +1117,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_tree_text_find.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_map
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::map</code>
@@ -1225,7 +1225,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_tree_text_lor_find.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_map
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::map</code>
@@ -1313,7 +1313,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_tree_split_join.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_set
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::set</code>
@@ -1416,7 +1416,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_tree_order_statistics.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_set
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::set</code>
@@ -1489,7 +1489,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_find_small_s2p_tree.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::multimap</code>
@@ -1551,7 +1551,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_find_small_s2p_hash.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_hash_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_multimap</code>
@@ -1660,7 +1660,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_find_large_s2p_tree.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::multimap</code>
@@ -1722,7 +1722,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_find_large_s2p_hash.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_hash_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_multimap</code>
@@ -1834,7 +1834,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_insert_small_s2p_tree.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::multimap</code>
@@ -1896,7 +1896,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_find_small_s2p_hash.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_hash_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_multimap</code>
@@ -2008,7 +2008,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_insert_large_s2p_tree.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::multimap</code>
@@ -2070,7 +2070,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_find_large_s2p_hash.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_hash_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_multimap</code>
@@ -2177,7 +2177,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_insert_mem_small_s2p_tree.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::multimap</code>
@@ -2239,7 +2239,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_find_large_s2p_hash.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_hash_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_multimap</code>
@@ -2346,7 +2346,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_insert_mem_large_s2p_tree.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::multimap</code>
@@ -2408,7 +2408,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_multimap_text_find_large_s2p_hash.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="7" align="left">
 		    n_hash_mmap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::tr1::unordered_multimap</code>
@@ -2514,7 +2514,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_priority_queue_text_push.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
@@ -2576,7 +2576,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_pairing_priority_queue_text_push.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
@@ -2650,7 +2650,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_priority_queue_text_push_pop.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
@@ -2712,7 +2712,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_pairing_priority_queue_text_push_pop.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code> adapting <code class="classname">std::vector</code>
@@ -2779,7 +2779,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_priority_queue_int_push.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
@@ -2841,7 +2841,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_binary_priority_queue_int_push.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code> adapting <code class="classname">std::vector</code>
@@ -2896,7 +2896,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_priority_queue_int_push_pop.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
@@ -2996,7 +2996,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_priority_queue_text_pop_mem.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
@@ -3089,7 +3089,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_priority_queue_text_join.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
@@ -3188,7 +3188,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_priority_queue_text_modify_up.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
@@ -3250,7 +3250,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_pairing_priority_queue_text_modify_up_thin.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    thin_heap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">priority_queue</code>
@@ -3321,7 +3321,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_priority_queue_text_modify_down.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    n_pq_vector
 		  </td></tr><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
@@ -3383,7 +3383,7 @@
 	  </p><div class="informalfigure"><div class="mediaobject" align="center"><img src="../images/pbds_pairing_priority_queue_text_modify_down_thin.png" align="middle" /></div></div><p>
 	    The abbreviated names in the legend of the graphic above are
 	    instantiated with the types in the following table.
-	  </p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
+	  </p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left"><span class="emphasis"><em>Name/Instantiating Type</em></span></th><th align="left"><span class="emphasis"><em>Parameter</em></span></th><th align="left"><span class="emphasis"><em>Details</em></span></th></tr></thead><tbody><tr bgcolor="#B0B0B0"><td colspan="3" align="left">
 		    thin_heap
 		  </td></tr><tr><td align="left">
 		    <code class="classname">priority_queue</code>
@@ -3588,7 +3588,7 @@
 	  underlying data structures in terms of orders of growth. It is
 	  interesting to note that this table implies something about the
 	  constants of the operations as well (see Amortized <code class="function">push</code>
-	  and <code class="function">pop</code> operations).</p><div class="informaltable"><table border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /></colgroup><thead><tr><th align="left"> </th><th align="left"><span class="emphasis"><em><code class="function">push</code></em></span></th><th align="left"><span class="emphasis"><em><code class="function">pop</code></em></span></th><th align="left"><span class="emphasis"><em><code class="function">modify</code></em></span></th><th align="left"><span class="emphasis"><em><code class="function">erase</code></em></span></th><th align="left"><span class="emphasis"><em><code class="function">join</code></em></span></th></tr></thead><tbody><tr><td align="left">
+	  and <code class="function">pop</code> operations).</p><div class="informaltable"><table class="informaltable" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /></colgroup><thead><tr><th align="left"> </th><th align="left"><span class="emphasis"><em><code class="function">push</code></em></span></th><th align="left"><span class="emphasis"><em><code class="function">pop</code></em></span></th><th align="left"><span class="emphasis"><em><code class="function">modify</code></em></span></th><th align="left"><span class="emphasis"><em><code class="function">erase</code></em></span></th><th align="left"><span class="emphasis"><em><code class="function">join</code></em></span></th></tr></thead><tbody><tr><td align="left">
 		    <code class="classname">std::priority_queue</code>
 		  </td><td align="left">
 		    Θ(n) worst
Index: libstdc++-v3/doc/html/manual/parallel_mode_design.html
===================================================================
--- libstdc++-v3/doc/html/manual/parallel_mode_design.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/parallel_mode_design.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="prev" href="parallel_mode_using.html" title="Using" /><link rel="next" href="parallel_mode_test.html" title="Testing" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode_using.html">Prev</a> </td><th width="60%" align="center">Chapter 18. Parallel Mode</th><td width="20%" align="right"> <a accesskey="n" href="parallel_mode_test.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.parallel_mode.design"></a>Design</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="prev" href="parallel_mode_using.html" title="Using" /><link rel="next" href="parallel_mode_test.html" title="Testing" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode_using.html">Prev</a> </td><th width="60%" align="center">Chapter 18. Parallel Mode</th><td width="20%" align="right"> <a accesskey="n" href="parallel_mode_test.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.parallel_mode.design"></a>Design</h2></div></div></div><p>
   </p><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="parallel_mode.design.intro"></a>Interface Basics</h3></div></div></div><p>
 All parallel algorithms are intended to have signatures that are
 equivalent to the ISO C++ algorithms replaced. For instance, the
Index: libstdc++-v3/doc/html/manual/abi.html
===================================================================
--- libstdc++-v3/doc/html/manual/abi.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/abi.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>ABI Policy and Guidelines</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, ABI, version, dynamic, shared, compatibility" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="test.html" title="Testing" /><link rel="next" href="api.html" title="API Evolution and Deprecation History" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">ABI Policy and Guidelines</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="test.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>ABI Policy and Guidelines</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, ABI, version, dynamic, shared, compatibility" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="test.html" title="Testing" /><link rel="next" href="api.html" title="API Evolution and Deprecation History" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">ABI Policy and Guidelines</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="test.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
   Porting and Maintenance
   
 </th><td width="20%" align="right"> <a accesskey="n" href="api.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="appendix.porting.abi"></a>ABI Policy and Guidelines</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/intro.html
===================================================================
--- libstdc++-v3/doc/html/manual/intro.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/intro.html	(.../branches/gcc-7-branch)
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Part I.  Introduction</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library Manual" /><link rel="prev" href="index.html" title="The GNU C++ Library Manual" /><link rel="next" href="status.html" title="Chapter 1. Status" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Part I. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Part I.  Introduction</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library Manual" /><link rel="prev" href="index.html" title="The GNU C++ Library Manual" /><link rel="next" href="status.html" title="Chapter 1. Status" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Part I. 
   Introduction
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="index.html">Prev</a> </td><th width="60%" align="center">The GNU C++ Library Manual</th><td width="20%" align="right"> <a accesskey="n" href="status.html">Next</a></td></tr></table><hr /></div><div class="part"><div class="titlepage"><div><div><h1 class="title"><a id="manual.intro"></a>Part I. 
   Introduction
   <a id="id-1.3.3.1.1.1" class="indexterm"></a>
-</h1></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="chapter"><a href="status.html">1. Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#manual.intro.status.iso">Implementation Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#status.iso.1998">C++ 1998/2003</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.1998.status">Implementation Status</a></span></dt><dt><span class="section"><a href="status.html#iso.1998.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2011">C++ 2011</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2011.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2014">C++ 2014</a></span></dt><dt><span class="section"><a href="status.html#status.iso.201z">C++ 201z</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2017.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr1">C++ TR1</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.tr1.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr24733">C++ TR 24733</a></span></dt></dl></dd><dt><span class="section"><a href="license.html">License</a></span></dt><dd><dl><dt><span class="section"><a href="license.html#manual.intro.status.license.gpl">The Code: GPL</a></span></dt><dt><span class="section"><a href="license.html#manual.intro.status.license.fdl">The Documentation: GPL, FDL</a></span></dt></dl></dd><dt><span class="section"><a href="bugs.html">Bugs</a></span></dt><dd><dl><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.impl">Implementation Bugs</a></span></dt><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.iso">Standard Bugs</a></span></dt></dl></dd></dl></dd><dt><span class="chapter"><a href="setup.html">2. Setup</a></span></dt><dd><dl><dt><span class="section"><a href="setup.html#manual.intro.setup.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="configure.html">Configure</a></span></dt><dt><span class="section"><a href="make.html">Make</a></span></dt></dl></dd><dt><span class="chapter"><a href="using.html">3. Using</a></span></dt><dd><dl><dt><span class="section"><a href="using.html#manual.intro.using.flags">Command Options</a></span></dt><dt><span class="section"><a href="using_headers.html">Headers</a></span></dt><dd><dl><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.all">Header Files</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.mixing">Mixing Headers</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.cheaders">The C Headers and <code class="code">namespace std</code></a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.pre">Precompiled Headers</a></span></dt></dl></dd><dt><span class="section"><a href="using_macros.html">Macros</a></span></dt><dt><span class="section"><a href="using_dual_abi.html">Dual ABI</a></span></dt><dd><dl><dt><span class="section"><a href="using_dual_abi.html#manual.intro.using.abi.trouble">Troubleshooting</a></span></dt></dl></dd><dt><span class="section"><a href="using_namespaces.html">Namespaces</a></span></dt><dd><dl><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.all">Available Namespaces</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.std">namespace std</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.comp">Using Namespace Composition</a></span></dt></dl></dd><dt><span class="section"><a href="using_dynamic_or_shared.html">Linking</a></span></dt><dd><dl><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.freestanding">Almost Nothing</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.dynamic">Finding Dynamic or Shared Libraries</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.experimental">Experimental Library Extensions</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html">Concurrency</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.thread_safety">Thread Safety</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.atomics">Atomics</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.io">IO</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#concurrency.io.structure">Structure</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.defaults">Defaults</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.future">Future</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.alt">Alternatives</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.containers">Containers</a></span></dt></dl></dd><dt><span class="section"><a href="using_exceptions.html">Exceptions</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.safety">Exception Safety</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.propagating">Exception Neutrality</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.no">Doing without</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.compat">Compatibility</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.c">With <code class="literal">C</code></a></span></dt><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.posix">With <code class="literal">POSIX</code> thread cancellation</a></span></dt></dl></dd></dl></dd><dt><span class="section"><a href="debug.html">Debugging Support</a></span></dt><dd><dl><dt><span class="section"><a href="debug.html#debug.compiler">Using <span class="command"><strong>g++</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.req">Debug Versions of Library Binary Files</a></span></dt><dt><span class="section"><a href="debug.html#debug.memory">Memory Leak Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.races">Data Race Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.gdb">Using <span class="command"><strong>gdb</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.exceptions">Tracking uncaught exceptions</a></span></dt><dt><span class="section"><a href="debug.html#debug.debug_mode">Debug Mode</a></span></dt><dt><span class="section"><a href="debug.html#debug.compile_time_checks">Compile Time Checking</a></span></dt><dt><span class="section"><a href="debug.html#debug.profile_mode">Profile-based Performance Analysis</a></span></dt></dl></dd></dl></dd></dl></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="index.html">Prev</a> </td><td width="20%" align="center"><a accesskey="u" href="index.html">Up</a></td><td width="40%" align="right"> <a accesskey="n" href="status.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">The GNU C++ Library Manual </td><td width="20%" align="center"><a accesskey="h" href="../index.html">Home</a></td><td width="40%" align="right" valign="top"> Chapter 1. Status</td></tr></table></div></body></html>
\ No newline at end of file
+</h1></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="chapter"><a href="status.html">1. Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#manual.intro.status.iso">Implementation Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#status.iso.1998">C++ 1998/2003</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.1998.status">Implementation Status</a></span></dt><dt><span class="section"><a href="status.html#iso.1998.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2011">C++ 2011</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2011.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2014">C++ 2014</a></span></dt><dt><span class="section"><a href="status.html#status.iso.2017">C++ 2017</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2017.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr1">C++ TR1</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.tr1.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr24733">C++ TR 24733</a></span></dt></dl></dd><dt><span class="section"><a href="license.html">License</a></span></dt><dd><dl><dt><span class="section"><a href="license.html#manual.intro.status.license.gpl">The Code: GPL</a></span></dt><dt><span class="section"><a href="license.html#manual.intro.status.license.fdl">The Documentation: GPL, FDL</a></span></dt></dl></dd><dt><span class="section"><a href="bugs.html">Bugs</a></span></dt><dd><dl><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.impl">Implementation Bugs</a></span></dt><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.iso">Standard Bugs</a></span></dt></dl></dd></dl></dd><dt><span class="chapter"><a href="setup.html">2. Setup</a></span></dt><dd><dl><dt><span class="section"><a href="setup.html#manual.intro.setup.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="configure.html">Configure</a></span></dt><dt><span class="section"><a href="make.html">Make</a></span></dt></dl></dd><dt><span class="chapter"><a href="using.html">3. Using</a></span></dt><dd><dl><dt><span class="section"><a href="using.html#manual.intro.using.flags">Command Options</a></span></dt><dt><span class="section"><a href="using_headers.html">Headers</a></span></dt><dd><dl><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.all">Header Files</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.mixing">Mixing Headers</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.cheaders">The C Headers and <code class="code">namespace std</code></a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.pre">Precompiled Headers</a></span></dt></dl></dd><dt><span class="section"><a href="using_macros.html">Macros</a></span></dt><dt><span class="section"><a href="using_dual_abi.html">Dual ABI</a></span></dt><dd><dl><dt><span class="section"><a href="using_dual_abi.html#manual.intro.using.abi.trouble">Troubleshooting</a></span></dt></dl></dd><dt><span class="section"><a href="using_namespaces.html">Namespaces</a></span></dt><dd><dl><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.all">Available Namespaces</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.std">namespace std</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.comp">Using Namespace Composition</a></span></dt></dl></dd><dt><span class="section"><a href="using_dynamic_or_shared.html">Linking</a></span></dt><dd><dl><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.freestanding">Almost Nothing</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.dynamic">Finding Dynamic or Shared Libraries</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.experimental">Experimental Library Extensions</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html">Concurrency</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.thread_safety">Thread Safety</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.atomics">Atomics</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.io">IO</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#concurrency.io.structure">Structure</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.defaults">Defaults</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.future">Future</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.alt">Alternatives</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.containers">Containers</a></span></dt></dl></dd><dt><span class="section"><a href="using_exceptions.html">Exceptions</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.safety">Exception Safety</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.propagating">Exception Neutrality</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.no">Doing without</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.compat">Compatibility</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.c">With <code class="literal">C</code></a></span></dt><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.posix">With <code class="literal">POSIX</code> thread cancellation</a></span></dt></dl></dd></dl></dd><dt><span class="section"><a href="debug.html">Debugging Support</a></span></dt><dd><dl><dt><span class="section"><a href="debug.html#debug.compiler">Using <span class="command"><strong>g++</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.req">Debug Versions of Library Binary Files</a></span></dt><dt><span class="section"><a href="debug.html#debug.memory">Memory Leak Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.races">Data Race Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.gdb">Using <span class="command"><strong>gdb</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.exceptions">Tracking uncaught exceptions</a></span></dt><dt><span class="section"><a href="debug.html#debug.debug_mode">Debug Mode</a></span></dt><dt><span class="section"><a href="debug.html#debug.compile_time_checks">Compile Time Checking</a></span></dt><dt><span class="section"><a href="debug.html#debug.profile_mode">Profile-based Performance Analysis</a></span></dt></dl></dd></dl></dd></dl></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="index.html">Prev</a> </td><td width="20%" align="center"><a accesskey="u" href="index.html">Up</a></td><td width="40%" align="right"> <a accesskey="n" href="status.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">The GNU C++ Library Manual </td><td width="20%" align="center"><a accesskey="h" href="../index.html">Home</a></td><td width="40%" align="right" valign="top"> Chapter 1. Status</td></tr></table></div></body></html>
\ No newline at end of file
Index: libstdc++-v3/doc/html/manual/profile_mode_api.html
===================================================================
--- libstdc++-v3/doc/html/manual/profile_mode_api.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/profile_mode_api.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Extensions for Custom Containers</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_design.html" title="Design" /><link rel="next" href="profile_mode_cost_model.html" title="Empirical Cost Model" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Extensions for Custom Containers</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_design.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_cost_model.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.api"></a>Extensions for Custom Containers</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Extensions for Custom Containers</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_design.html" title="Design" /><link rel="next" href="profile_mode_cost_model.html" title="Empirical Cost Model" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Extensions for Custom Containers</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_design.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_cost_model.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.api"></a>Extensions for Custom Containers</h2></div></div></div><p>
   Many large projects use their own data structures instead of the ones in the
   standard library.  If these data structures are similar in functionality
   to the standard library, they can be instrumented with the same hooks
Index: libstdc++-v3/doc/html/manual/atomics.html
===================================================================
--- libstdc++-v3/doc/html/manual/atomics.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/atomics.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 14.  Atomics</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library, atomic" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="io_and_c.html" title="Interacting with C" /><link rel="next" href="concurrency.html" title="Chapter 15.  Concurrency" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 14. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 14.  Atomics</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library, atomic" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="io_and_c.html" title="Interacting with C" /><link rel="next" href="concurrency.html" title="Chapter 15.  Concurrency" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 14. 
   Atomics
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="io_and_c.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/internals.html
===================================================================
--- libstdc++-v3/doc/html/manual/internals.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/internals.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Porting to New Hardware or Operating Systems</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, internals" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="documentation_hacking.html" title="Writing and Generating Documentation" /><link rel="next" href="test.html" title="Testing" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Porting to New Hardware or Operating Systems</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="documentation_hacking.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Porting to New Hardware or Operating Systems</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, internals" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="documentation_hacking.html" title="Writing and Generating Documentation" /><link rel="next" href="test.html" title="Testing" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Porting to New Hardware or Operating Systems</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="documentation_hacking.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
   Porting and Maintenance
   
 </th><td width="20%" align="right"> <a accesskey="n" href="test.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="appendix.porting.internals"></a>Porting to New Hardware or Operating Systems</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/policy_data_structures_using.html
===================================================================
--- libstdc++-v3/doc/html/manual/policy_data_structures_using.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/policy_data_structures_using.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Using</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="prev" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="next" href="policy_data_structures_design.html" title="Design" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Using</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_data_structures.html">Prev</a> </td><th width="60%" align="center">Chapter 22. Policy-Based Data Structures</th><td width="20%" align="right"> <a accesskey="n" href="policy_data_structures_design.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="containers.pbds.using"></a>Using</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="pbds.using.prereq"></a>Prerequisites</h3></div></div></div><p>The library contains only header files, and does not require any
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Using</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, policy, container, data, structure, associated, tree, trie, hash, metaprogramming" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="prev" href="policy_data_structures.html" title="Chapter 22. Policy-Based Data Structures" /><link rel="next" href="policy_data_structures_design.html" title="Design" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Using</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="policy_data_structures.html">Prev</a> </td><th width="60%" align="center">Chapter 22. Policy-Based Data Structures</th><td width="20%" align="right"> <a accesskey="n" href="policy_data_structures_design.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="containers.pbds.using"></a>Using</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="pbds.using.prereq"></a>Prerequisites</h3></div></div></div><p>The library contains only header files, and does not require any
       other libraries except the standard C++ library . All classes are
       defined in namespace <code class="code">__gnu_pbds</code>. The library internally
       uses macros beginning with <code class="code">PB_DS</code>, but
Index: libstdc++-v3/doc/html/manual/bugs.html
===================================================================
--- libstdc++-v3/doc/html/manual/bugs.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/bugs.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Bugs</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="status.html" title="Chapter 1. Status" /><link rel="prev" href="license.html" title="License" /><link rel="next" href="setup.html" title="Chapter 2. Setup" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Bugs</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="license.html">Prev</a> </td><th width="60%" align="center">Chapter 1. Status</th><td width="20%" align="right"> <a accesskey="n" href="setup.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.status.bugs"></a>Bugs</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.status.bugs.impl"></a>Implementation Bugs</h3></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Bugs</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="status.html" title="Chapter 1. Status" /><link rel="prev" href="license.html" title="License" /><link rel="next" href="setup.html" title="Chapter 2. Setup" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Bugs</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="license.html">Prev</a> </td><th width="60%" align="center">Chapter 1. Status</th><td width="20%" align="right"> <a accesskey="n" href="setup.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.status.bugs"></a>Bugs</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.status.bugs.impl"></a>Implementation Bugs</h3></div></div></div><p>
       Information on known bugs, details on efforts to fix them, and
       fixed bugs are all available as part of the <a class="link" href="http://gcc.gnu.org/bugs/" target="_top">GCC bug tracking system</a>,
       with the category set to <code class="literal">libstdc++</code>.
Index: libstdc++-v3/doc/html/manual/parallel_mode_using.html
===================================================================
--- libstdc++-v3/doc/html/manual/parallel_mode_using.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/parallel_mode_using.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Using</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="prev" href="parallel_mode_semantics.html" title="Semantics" /><link rel="next" href="parallel_mode_design.html" title="Design" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Using</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode_semantics.html">Prev</a> </td><th width="60%" align="center">Chapter 18. Parallel Mode</th><td width="20%" align="right"> <a accesskey="n" href="parallel_mode_design.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.parallel_mode.using"></a>Using</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="parallel_mode.using.prereq_flags"></a>Prerequisite Compiler Flags</h3></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Using</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="prev" href="parallel_mode_semantics.html" title="Semantics" /><link rel="next" href="parallel_mode_design.html" title="Design" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Using</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode_semantics.html">Prev</a> </td><th width="60%" align="center">Chapter 18. Parallel Mode</th><td width="20%" align="right"> <a accesskey="n" href="parallel_mode_design.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.parallel_mode.using"></a>Using</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="parallel_mode.using.prereq_flags"></a>Prerequisite Compiler Flags</h3></div></div></div><p>
   Any use of parallel functionality requires additional compiler
   and runtime support, in particular support for OpenMP. Adding this support is
   not difficult: just compile your application with the compiler
@@ -63,4 +63,4 @@
 flags for atomic operations.)
 </p><p> The following table provides the names and headers of all the
   parallel algorithms that can be used in a similar manner:
-</p><div class="table"><a id="table.parallel_algos"></a><p class="title"><strong>Table 18.1. Parallel Algorithms</strong></p><div class="table-contents"><table summary="Parallel Algorithms" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Algorithm</th><th align="left">Header</th><th align="left">Parallel algorithm</th><th align="left">Parallel header</th></tr></thead><tbody><tr><td align="left"><code class="function">std::accumulate</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="function">__gnu_parallel::accumulate</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr><tr><td align="left"><code class="function">std::adjacent_difference</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="function">__gnu_parallel::adjacent_difference</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr><tr><td align="left"><code class="function">std::inner_product</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="function">__gnu_parallel::inner_product</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr><tr><td align="left"><code class="function">std::partial_sum</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="function">__gnu_parallel::partial_sum</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr><tr><td align="left"><code class="function">std::adjacent_find</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::adjacent_find</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::count</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::count</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::count_if</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::count_if</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::equal</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::equal</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::find</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::find</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::find_if</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::find_if</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::find_first_of</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::find_first_of</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::for_each</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::for_each</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::generate</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::generate</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::generate_n</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::generate_n</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::lexicographical_compare</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::lexicographical_compare</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::mismatch</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::mismatch</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::search</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::search</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::search_n</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::search_n</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::transform</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::transform</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::replace</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::replace</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::replace_if</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::replace_if</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::max_element</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::max_element</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::merge</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::merge</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::min_element</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::min_element</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::nth_element</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::nth_element</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::partial_sort</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::partial_sort</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::partition</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::partition</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::random_shuffle</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::random_shuffle</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::set_union</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::set_union</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::set_intersection</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::set_intersection</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::set_symmetric_difference</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::set_symmetric_difference</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::set_difference</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::set_difference</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::sort</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::sort</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::stable_sort</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::stable_sort</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::unique_copy</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::unique_copy</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr></tbody></table></div></div><br class="table-break" /></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="parallel_mode_semantics.html">Prev</a> </td><td width="20%" align="center"><a accesskey="u" href="parallel_mode.html">Up</a></td><td width="40%" align="right"> <a accesskey="n" href="parallel_mode_design.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">Semantics </td><td width="20%" align="center"><a accesskey="h" href="../index.html">Home</a></td><td width="40%" align="right" valign="top"> Design</td></tr></table></div></body></html>
\ No newline at end of file
+</p><div class="table"><a id="table.parallel_algos"></a><p class="title"><strong>Table 18.1. Parallel Algorithms</strong></p><div class="table-contents"><table class="table" summary="Parallel Algorithms" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Algorithm</th><th align="left">Header</th><th align="left">Parallel algorithm</th><th align="left">Parallel header</th></tr></thead><tbody><tr><td align="left"><code class="function">std::accumulate</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="function">__gnu_parallel::accumulate</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr><tr><td align="left"><code class="function">std::adjacent_difference</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="function">__gnu_parallel::adjacent_difference</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr><tr><td align="left"><code class="function">std::inner_product</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="function">__gnu_parallel::inner_product</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr><tr><td align="left"><code class="function">std::partial_sum</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="function">__gnu_parallel::partial_sum</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr><tr><td align="left"><code class="function">std::adjacent_find</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::adjacent_find</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::count</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::count</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::count_if</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::count_if</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::equal</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::equal</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::find</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::find</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::find_if</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::find_if</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::find_first_of</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::find_first_of</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::for_each</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::for_each</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::generate</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::generate</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::generate_n</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::generate_n</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::lexicographical_compare</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::lexicographical_compare</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::mismatch</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::mismatch</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::search</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::search</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::search_n</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::search_n</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::transform</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::transform</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::replace</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::replace</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::replace_if</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::replace_if</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::max_element</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::max_element</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::merge</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::merge</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::min_element</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::min_element</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::nth_element</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::nth_element</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::partial_sort</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::partial_sort</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::partition</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::partition</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::random_shuffle</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::random_shuffle</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::set_union</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::set_union</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::set_intersection</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::set_intersection</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::set_symmetric_difference</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::set_symmetric_difference</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::set_difference</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::set_difference</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::sort</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::sort</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::stable_sort</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::stable_sort</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr><tr><td align="left"><code class="function">std::unique_copy</code></td><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="function">__gnu_parallel::unique_copy</code></td><td align="left"><code class="filename">parallel/algorithm</code></td></tr></tbody></table></div></div><br class="table-break" /></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="parallel_mode_semantics.html">Prev</a> </td><td width="20%" align="center"><a accesskey="u" href="parallel_mode.html">Up</a></td><td width="40%" align="right"> <a accesskey="n" href="parallel_mode_design.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">Semantics </td><td width="20%" align="center"><a accesskey="h" href="../index.html">Home</a></td><td width="40%" align="right" valign="top"> Design</td></tr></table></div></body></html>
\ No newline at end of file
Index: libstdc++-v3/doc/html/manual/ext_numerics.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_numerics.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_numerics.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 26. Numerics</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_algorithms.html" title="Chapter 25. Algorithms" /><link rel="next" href="ext_iterators.html" title="Chapter 27. Iterators" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 26. Numerics</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_algorithms.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 26. Numerics</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_algorithms.html" title="Chapter 25. Algorithms" /><link rel="next" href="ext_iterators.html" title="Chapter 27. Iterators" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 26. Numerics</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_algorithms.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="ext_iterators.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.numerics"></a>Chapter 26. Numerics</h2></div></div></div><p>26.4, the generalized numeric operations such as <code class="code">accumulate</code>,
Index: libstdc++-v3/doc/html/manual/parallel_mode_semantics.html
===================================================================
--- libstdc++-v3/doc/html/manual/parallel_mode_semantics.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/parallel_mode_semantics.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Semantics</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="prev" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="next" href="parallel_mode_using.html" title="Using" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Semantics</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode.html">Prev</a> </td><th width="60%" align="center">Chapter 18. Parallel Mode</th><td width="20%" align="right"> <a accesskey="n" href="parallel_mode_using.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.parallel_mode.semantics"></a>Semantics</h2></div></div></div><p> The parallel mode STL algorithms are currently not exception-safe,
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Semantics</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="prev" href="parallel_mode.html" title="Chapter 18. Parallel Mode" /><link rel="next" href="parallel_mode_using.html" title="Using" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Semantics</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="parallel_mode.html">Prev</a> </td><th width="60%" align="center">Chapter 18. Parallel Mode</th><td width="20%" align="right"> <a accesskey="n" href="parallel_mode_using.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.parallel_mode.semantics"></a>Semantics</h2></div></div></div><p> The parallel mode STL algorithms are currently not exception-safe,
 i.e. user-defined functors must not throw exceptions.
 Also, the order of execution is not guaranteed for some functions, of course.
 Therefore, user-defined functors should not have any concurrent side effects.
Index: libstdc++-v3/doc/html/manual/std_contents.html
===================================================================
--- libstdc++-v3/doc/html/manual/std_contents.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/std_contents.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Part II.  Standard Contents</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library Manual" /><link rel="prev" href="debug.html" title="Debugging Support" /><link rel="next" href="support.html" title="Chapter 4.  Support" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Part II. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Part II.  Standard Contents</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library Manual" /><link rel="prev" href="debug.html" title="Debugging Support" /><link rel="next" href="support.html" title="Chapter 4.  Support" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Part II. 
     Standard Contents
   </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="debug.html">Prev</a> </td><th width="60%" align="center">The GNU C++ Library Manual</th><td width="20%" align="right"> <a accesskey="n" href="support.html">Next</a></td></tr></table><hr /></div><div class="part"><div class="titlepage"><div><div><h1 class="title"><a id="manual.std"></a>Part II. 
     Standard Contents
Index: libstdc++-v3/doc/html/manual/appendix.html
===================================================================
--- libstdc++-v3/doc/html/manual/appendix.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/appendix.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Part IV.  Appendices</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library Manual" /><link rel="prev" href="ext_concurrency_use.html" title="Use" /><link rel="next" href="appendix_contributing.html" title="Appendix A.  Contributing" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Part IV. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Part IV.  Appendices</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library Manual" /><link rel="prev" href="ext_concurrency_use.html" title="Use" /><link rel="next" href="appendix_contributing.html" title="Appendix A.  Contributing" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Part IV. 
   Appendices
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_concurrency_use.html">Prev</a> </td><th width="60%" align="center">The GNU C++ Library Manual</th><td width="20%" align="right"> <a accesskey="n" href="appendix_contributing.html">Next</a></td></tr></table><hr /></div><div class="part"><div class="titlepage"><div><div><h1 class="title"><a id="appendix"></a>Part IV. 
   Appendices
Index: libstdc++-v3/doc/html/manual/memory.html
===================================================================
--- libstdc++-v3/doc/html/manual/memory.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/memory.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Memory</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="utilities.html" title="Chapter 6.  Utilities" /><link rel="prev" href="pairs.html" title="Pairs" /><link rel="next" href="traits.html" title="Traits" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Memory</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="pairs.html">Prev</a> </td><th width="60%" align="center">Chapter 6. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Memory</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="utilities.html" title="Chapter 6.  Utilities" /><link rel="prev" href="pairs.html" title="Pairs" /><link rel="next" href="traits.html" title="Traits" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Memory</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="pairs.html">Prev</a> </td><th width="60%" align="center">Chapter 6. 
   Utilities
   
 </th><td width="20%" align="right"> <a accesskey="n" href="traits.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.util.memory"></a>Memory</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/api.html
===================================================================
--- libstdc++-v3/doc/html/manual/api.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/api.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>API Evolution and Deprecation History</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, api, evolution, deprecation, history" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="abi.html" title="ABI Policy and Guidelines" /><link rel="next" href="backwards.html" title="Backwards Compatibility" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">API Evolution and Deprecation History</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="abi.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>API Evolution and Deprecation History</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, api, evolution, deprecation, history" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="abi.html" title="ABI Policy and Guidelines" /><link rel="next" href="backwards.html" title="Backwards Compatibility" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">API Evolution and Deprecation History</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="abi.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
   Porting and Maintenance
   
 </th><td width="20%" align="right"> <a accesskey="n" href="backwards.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="appendix.porting.api"></a>API Evolution and Deprecation History</h2></div></div></div><p>
@@ -77,11 +77,11 @@
    <span class="type">__alloc</span> to select an underlying allocator that
    satisfied memory allocation requests. The selection of this
    underlying allocator was not user-configurable.
-   </p><div class="table"><a id="table.extension_allocators"></a><p class="title"><strong>Table B.6. Extension Allocators</strong></p><div class="table-contents"><table summary="Extension Allocators" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Allocator (3.4)</th><th align="left">Header (3.4)</th><th align="left">Allocator (3.[0-3])</th><th align="left">Header (3.[0-3])</th></tr></thead><tbody><tr><td align="left"><code class="classname">__gnu_cxx::new_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/new_allocator.h</code></td><td align="left"><code class="classname">std::__new_alloc</code></td><td align="left"><code class="filename">memory</code></td></tr><tr><td align="left"><code class="classname">__gnu_cxx::malloc_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/malloc_allocator.h</code></td><td align="left"><code class="classname">std::__malloc_alloc_template&lt;int&gt;</code></td><td align="left"><code class="filename">memory</code></td></tr><tr><td align="left"><code class="classname">__gnu_cxx::debug_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/debug_allocator.h</code></td><td align="left"><code class="classname">std::debug_alloc&lt;T&gt;</code></td><td align="left"><code class="filename">memory</code></td></tr><tr><td align="left"><code class="classname">__gnu_cxx::__pool_alloc&lt;T&gt;</code></td><td align="left"><code class="filename">ext/pool_allocator.h</code></td><td align="left"><code class="classname">std::__default_alloc_template&lt;bool,int&gt;</code></td><td align="left"><code class="filename">memory</code></td></tr><tr><td align="left"><code class="classname">__gnu_cxx::__mt_alloc&lt;T&gt;</code></td><td align="left"><code class="filename">ext/mt_allocator.h</code></td><td align="left"> </td><td align="left"> </td></tr><tr><td align="left"><code class="classname">__gnu_cxx::bitmap_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/bitmap_allocator.h</code></td><td align="left"> </td><td align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p> Releases after gcc-3.4 have continued to add to the collection
+   </p><div class="table"><a id="table.extension_allocators"></a><p class="title"><strong>Table B.6. Extension Allocators</strong></p><div class="table-contents"><table class="table" summary="Extension Allocators" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Allocator (3.4)</th><th align="left">Header (3.4)</th><th align="left">Allocator (3.[0-3])</th><th align="left">Header (3.[0-3])</th></tr></thead><tbody><tr><td align="left"><code class="classname">__gnu_cxx::new_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/new_allocator.h</code></td><td align="left"><code class="classname">std::__new_alloc</code></td><td align="left"><code class="filename">memory</code></td></tr><tr><td align="left"><code class="classname">__gnu_cxx::malloc_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/malloc_allocator.h</code></td><td align="left"><code class="classname">std::__malloc_alloc_template&lt;int&gt;</code></td><td align="left"><code class="filename">memory</code></td></tr><tr><td align="left"><code class="classname">__gnu_cxx::debug_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/debug_allocator.h</code></td><td align="left"><code class="classname">std::debug_alloc&lt;T&gt;</code></td><td align="left"><code class="filename">memory</code></td></tr><tr><td align="left"><code class="classname">__gnu_cxx::__pool_alloc&lt;T&gt;</code></td><td align="left"><code class="filename">ext/pool_allocator.h</code></td><td align="left"><code class="classname">std::__default_alloc_template&lt;bool,int&gt;</code></td><td align="left"><code class="filename">memory</code></td></tr><tr><td align="left"><code class="classname">__gnu_cxx::__mt_alloc&lt;T&gt;</code></td><td align="left"><code class="filename">ext/mt_allocator.h</code></td><td align="left"> </td><td align="left"> </td></tr><tr><td align="left"><code class="classname">__gnu_cxx::bitmap_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/bitmap_allocator.h</code></td><td align="left"> </td><td align="left"> </td></tr></tbody></table></div></div><br class="table-break" /><p> Releases after gcc-3.4 have continued to add to the collection
    of available allocators. All of these new allocators are
    standard-style. The following table includes details, along with
    the first released version of GCC that included the extension allocator.
-   </p><div class="table"><a id="table.extension_allocators2"></a><p class="title"><strong>Table B.7. Extension Allocators Continued</strong></p><div class="table-contents"><table summary="Extension Allocators Continued" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left">Allocator</th><th align="left">Include</th><th align="left">Version</th></tr></thead><tbody><tr><td align="left"><code class="classname">__gnu_cxx::array_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/array_allocator.h</code></td><td align="left">4.0.0</td></tr><tr><td align="left"><code class="classname">__gnu_cxx::throw_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/throw_allocator.h</code></td><td align="left">4.2.0</td></tr></tbody></table></div></div><br class="table-break" /><p>
+   </p><div class="table"><a id="table.extension_allocators2"></a><p class="title"><strong>Table B.7. Extension Allocators Continued</strong></p><div class="table-contents"><table class="table" summary="Extension Allocators Continued" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /></colgroup><thead><tr><th align="left">Allocator</th><th align="left">Include</th><th align="left">Version</th></tr></thead><tbody><tr><td align="left"><code class="classname">__gnu_cxx::array_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/array_allocator.h</code></td><td align="left">4.0.0</td></tr><tr><td align="left"><code class="classname">__gnu_cxx::throw_allocator&lt;T&gt;</code></td><td align="left"><code class="filename">ext/throw_allocator.h</code></td><td align="left">4.2.0</td></tr></tbody></table></div></div><br class="table-break" /><p>
 Debug mode first appears.
 </p><p>
 Precompiled header support <acronym class="acronym">PCH</acronym> support.
Index: libstdc++-v3/doc/html/manual/source_organization.html
===================================================================
--- libstdc++-v3/doc/html/manual/source_organization.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/source_organization.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Directory Layout and Source Conventions</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_contributing.html" title="Appendix A.  Contributing" /><link rel="prev" href="appendix_contributing.html" title="Appendix A.  Contributing" /><link rel="next" href="source_code_style.html" title="Coding Style" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Directory Layout and Source Conventions</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="appendix_contributing.html">Prev</a> </td><th width="60%" align="center">Appendix A. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Directory Layout and Source Conventions</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_contributing.html" title="Appendix A.  Contributing" /><link rel="prev" href="appendix_contributing.html" title="Appendix A.  Contributing" /><link rel="next" href="source_code_style.html" title="Coding Style" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Directory Layout and Source Conventions</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="appendix_contributing.html">Prev</a> </td><th width="60%" align="center">Appendix A. 
   Contributing
   
 </th><td width="20%" align="right"> <a accesskey="n" href="source_code_style.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="contrib.organization"></a>Directory Layout and Source Conventions</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/fstreams.html
===================================================================
--- libstdc++-v3/doc/html/manual/fstreams.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/fstreams.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>File Based Streams</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="io.html" title="Chapter 13.  Input and Output" /><link rel="prev" href="stringstreams.html" title="Memory Based Streams" /><link rel="next" href="io_and_c.html" title="Interacting with C" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">File Based Streams</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="stringstreams.html">Prev</a> </td><th width="60%" align="center">Chapter 13. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>File Based Streams</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="io.html" title="Chapter 13.  Input and Output" /><link rel="prev" href="stringstreams.html" title="Memory Based Streams" /><link rel="next" href="io_and_c.html" title="Interacting with C" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">File Based Streams</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="stringstreams.html">Prev</a> </td><th width="60%" align="center">Chapter 13. 
   Input and Output
   
 </th><td width="20%" align="right"> <a accesskey="n" href="io_and_c.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.io.filestreams"></a>File Based Streams</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="std.io.filestreams.copying_a_file"></a>Copying a File</h3></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/ext_demangling.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_demangling.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_demangling.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 29. Demangling</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_io.html" title="Chapter 28. Input and Output" /><link rel="next" href="ext_concurrency.html" title="Chapter 30. Concurrency" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 29. Demangling</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_io.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 29. Demangling</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_io.html" title="Chapter 28. Input and Output" /><link rel="next" href="ext_concurrency.html" title="Chapter 30. Concurrency" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 29. Demangling</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_io.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="ext_concurrency.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.demangle"></a>Chapter 29. Demangling</h2></div></div></div><p>
@@ -7,7 +7,7 @@
     original C++ source identifiers is called
     <span class="quote">“<span class="quote">demangling.</span>”</span>
   </p><p>
-    If you have read the <a class="link" href="http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/a01115.html" target="_top">source
+    If you have read the <a class="link" href="http://gcc.gnu.org/onlinedocs/libstdc++/latest-doxygen/namespaces.html" target="_top">source
     documentation for <code class="code">namespace abi</code></a> then you are
     aware of the cross-vendor C++ ABI in use by GCC.  One of the
     exposed functions is used for demangling,
Index: libstdc++-v3/doc/html/manual/ext_preface.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_preface.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_preface.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title></title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="extensions.html" title="Part III.  Extensions" /><link rel="next" href="ext_compile_checks.html" title="Chapter 16. Compile Time Checks" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center"></th></tr><tr><td width="20%" align="left"><a accesskey="p" href="extensions.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title></title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="extensions.html" title="Part III.  Extensions" /><link rel="next" href="ext_compile_checks.html" title="Chapter 16. Compile Time Checks" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center"></th></tr><tr><td width="20%" align="left"><a accesskey="p" href="extensions.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="ext_compile_checks.html">Next</a></td></tr></table><hr /></div><div class="preface"><div class="titlepage"><div><div><h1 class="title"><a id="manual.ext.preface"></a></h1></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/concept_checking.html
===================================================================
--- libstdc++-v3/doc/html/manual/concept_checking.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/concept_checking.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Concept Checking</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="diagnostics.html" title="Chapter 5.  Diagnostics" /><link rel="prev" href="errno.html" title="Use of errno by the library" /><link rel="next" href="utilities.html" title="Chapter 6.  Utilities" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Concept Checking</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="errno.html">Prev</a> </td><th width="60%" align="center">Chapter 5. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Concept Checking</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="diagnostics.html" title="Chapter 5.  Diagnostics" /><link rel="prev" href="errno.html" title="Use of errno by the library" /><link rel="next" href="utilities.html" title="Chapter 6.  Utilities" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Concept Checking</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="errno.html">Prev</a> </td><th width="60%" align="center">Chapter 5. 
   Diagnostics
   
 </th><td width="20%" align="right"> <a accesskey="n" href="utilities.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.diagnostics.concept_checking"></a>Concept Checking</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/mt_allocator_ex_multi.html
===================================================================
--- libstdc++-v3/doc/html/manual/mt_allocator_ex_multi.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/mt_allocator_ex_multi.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Multiple Thread Example</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="prev" href="mt_allocator_ex_single.html" title="Single Thread Example" /><link rel="next" href="bitmap_allocator.html" title="Chapter 21. The bitmap_allocator" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Multiple Thread Example</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator_ex_single.html">Prev</a> </td><th width="60%" align="center">Chapter 20. The mt_allocator</th><td width="20%" align="right"> <a accesskey="n" href="bitmap_allocator.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.mt.example_multi"></a>Multiple Thread Example</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Multiple Thread Example</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="prev" href="mt_allocator_ex_single.html" title="Single Thread Example" /><link rel="next" href="bitmap_allocator.html" title="Chapter 21. The bitmap_allocator" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Multiple Thread Example</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator_ex_single.html">Prev</a> </td><th width="60%" align="center">Chapter 20. The mt_allocator</th><td width="20%" align="right"> <a accesskey="n" href="bitmap_allocator.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.mt.example_multi"></a>Multiple Thread Example</h2></div></div></div><p>
 In the ST example we never used the thread_id variable present in each block.
 Let's start by explaining the purpose of this in a MT application.
 </p><p>
Index: libstdc++-v3/doc/html/manual/ext_compile_checks.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_compile_checks.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_compile_checks.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 16. Compile Time Checks</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_preface.html" title="" /><link rel="next" href="debug_mode.html" title="Chapter 17. Debug Mode" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 16. Compile Time Checks</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_preface.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 16. Compile Time Checks</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_preface.html" title="" /><link rel="next" href="debug_mode.html" title="Chapter 17. Debug Mode" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 16. Compile Time Checks</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_preface.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="debug_mode.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.compile_checks"></a>Chapter 16. Compile Time Checks</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/strings.html
===================================================================
--- libstdc++-v3/doc/html/manual/strings.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/strings.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 7.  Strings</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="traits.html" title="Traits" /><link rel="next" href="localization.html" title="Chapter 8.  Localization" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 7. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 7.  Strings</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="traits.html" title="Traits" /><link rel="next" href="localization.html" title="Chapter 8.  Localization" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 7. 
   Strings
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="traits.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/containers_and_c.html
===================================================================
--- libstdc++-v3/doc/html/manual/containers_and_c.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/containers_and_c.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Interacting with C</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="containers.html" title="Chapter 9.  Containers" /><link rel="prev" href="unordered_associative.html" title="Unordered Associative" /><link rel="next" href="iterators.html" title="Chapter 10.  Iterators" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Interacting with C</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="unordered_associative.html">Prev</a> </td><th width="60%" align="center">Chapter 9. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Interacting with C</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="containers.html" title="Chapter 9.  Containers" /><link rel="prev" href="unordered_associative.html" title="Unordered Associative" /><link rel="next" href="iterators.html" title="Chapter 10.  Iterators" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Interacting with C</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="unordered_associative.html">Prev</a> </td><th width="60%" align="center">Chapter 9. 
   Containers
   
 </th><td width="20%" align="right"> <a accesskey="n" href="iterators.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.containers.c"></a>Interacting with C</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="containers.c.vs_array"></a>Containers vs. Arrays</h3></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/profile_mode_diagnostics.html
===================================================================
--- libstdc++-v3/doc/html/manual/profile_mode_diagnostics.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/profile_mode_diagnostics.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Diagnostics</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_devel.html" title="Developer Information" /><link rel="next" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Diagnostics</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_devel.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="mt_allocator.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.diagnostics"></a>Diagnostics</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Diagnostics</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_devel.html" title="Developer Information" /><link rel="next" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Diagnostics</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_devel.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="mt_allocator.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.diagnostics"></a>Diagnostics</h2></div></div></div><p>
   The table below presents all the diagnostics we intend to implement.
   Each diagnostic has a corresponding compile time switch
   <code class="code">-D_GLIBCXX_PROFILE_&lt;diagnostic&gt;</code>.
@@ -17,7 +17,7 @@
   A high accuracy means that the diagnostic is unlikely to be wrong.
   These grades are not perfect.  They are just meant to guide users with
   specific needs or time budgets.
-  </p><div class="table"><a id="table.profile_diagnostics"></a><p class="title"><strong>Table 19.2. Profile Diagnostics</strong></p><div class="table-contents"><table summary="Profile Diagnostics" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left">Group</th><th align="left">Flag</th><th align="left">Benefit</th><th align="left">Cost</th><th align="left">Freq.</th><th align="left">Implemented</th><td class="auto-generated"> </td></tr></thead><tbody><tr><td align="left"><a class="link" href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.containers" title="Containers">
+  </p><div class="table"><a id="table.profile_diagnostics"></a><p class="title"><strong>Table 19.2. Profile Diagnostics</strong></p><div class="table-contents"><table class="table" summary="Profile Diagnostics" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /><col align="left" class="c6" /><col align="left" class="c7" /></colgroup><thead><tr><th align="left">Group</th><th align="left">Flag</th><th align="left">Benefit</th><th align="left">Cost</th><th align="left">Freq.</th><th align="left">Implemented</th><td class="auto-generated"> </td></tr></thead><tbody><tr><td align="left"><a class="link" href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.containers" title="Containers">
     CONTAINERS</a></td><td align="left"><a class="link" href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.hashtable_too_small" title="Hashtable Too Small">
     HASHTABLE_TOO_SMALL</a></td><td align="left">10</td><td align="left">1</td><td align="left"> </td><td align="left">10</td><td align="left">yes</td></tr><tr><td align="left"> </td><td align="left"><a class="link" href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.hashtable_too_large" title="Hashtable Too Large">
     HASHTABLE_TOO_LARGE</a></td><td align="left">5</td><td align="left">1</td><td align="left"> </td><td align="left">10</td><td align="left">yes</td></tr><tr><td align="left"> </td><td align="left"><a class="link" href="profile_mode_diagnostics.html#manual.ext.profile_mode.analysis.inefficient_hash" title="Inefficient Hash">
Index: libstdc++-v3/doc/html/manual/ext_concurrency_impl.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_concurrency_impl.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_concurrency_impl.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Implementation</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="ext_concurrency.html" title="Chapter 30. Concurrency" /><link rel="prev" href="ext_concurrency.html" title="Chapter 30. Concurrency" /><link rel="next" href="ext_concurrency_use.html" title="Use" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Implementation</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_concurrency.html">Prev</a> </td><th width="60%" align="center">Chapter 30. Concurrency</th><td width="20%" align="right"> <a accesskey="n" href="ext_concurrency_use.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.concurrency.impl"></a>Implementation</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.ext.concurrency.impl.atomic_fallbacks"></a>Using Built-in Atomic Functions</h3></div></div></div><p>The functions for atomic operations described above are either
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Implementation</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="ext_concurrency.html" title="Chapter 30. Concurrency" /><link rel="prev" href="ext_concurrency.html" title="Chapter 30. Concurrency" /><link rel="next" href="ext_concurrency_use.html" title="Use" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Implementation</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_concurrency.html">Prev</a> </td><th width="60%" align="center">Chapter 30. Concurrency</th><td width="20%" align="right"> <a accesskey="n" href="ext_concurrency_use.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.concurrency.impl"></a>Implementation</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.ext.concurrency.impl.atomic_fallbacks"></a>Using Built-in Atomic Functions</h3></div></div></div><p>The functions for atomic operations described above are either
 implemented via compiler intrinsics (if the underlying host is
 capable) or by library fallbacks.</p><p>Compiler intrinsics (builtins) are always preferred.  However, as
 the compiler builtins for atomics are not universally implemented,
Index: libstdc++-v3/doc/html/manual/io_and_c.html
===================================================================
--- libstdc++-v3/doc/html/manual/io_and_c.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/io_and_c.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Interacting with C</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="io.html" title="Chapter 13.  Input and Output" /><link rel="prev" href="fstreams.html" title="File Based Streams" /><link rel="next" href="atomics.html" title="Chapter 14.  Atomics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Interacting with C</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="fstreams.html">Prev</a> </td><th width="60%" align="center">Chapter 13. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Interacting with C</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="io.html" title="Chapter 13.  Input and Output" /><link rel="prev" href="fstreams.html" title="File Based Streams" /><link rel="next" href="atomics.html" title="Chapter 14.  Atomics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Interacting with C</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="fstreams.html">Prev</a> </td><th width="60%" align="center">Chapter 13. 
   Input and Output
   
 </th><td width="20%" align="right"> <a accesskey="n" href="atomics.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.io.c"></a>Interacting with C</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="std.io.c.FILE"></a>Using FILE* and file descriptors</h3></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/documentation_hacking.html
===================================================================
--- libstdc++-v3/doc/html/manual/documentation_hacking.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/documentation_hacking.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Writing and Generating Documentation</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, documentation, style, docbook, doxygen" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="next" href="internals.html" title="Porting to New Hardware or Operating Systems" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Writing and Generating Documentation</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="appendix_porting.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Writing and Generating Documentation</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, documentation, style, docbook, doxygen" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="next" href="internals.html" title="Porting to New Hardware or Operating Systems" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Writing and Generating Documentation</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="appendix_porting.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
   Porting and Maintenance
   
 </th><td width="20%" align="right"> <a accesskey="n" href="internals.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="appendix.porting.doc"></a>Writing and Generating Documentation</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="doc.intro"></a>Introduction</h3></div></div></div><p>
@@ -112,7 +112,7 @@
       supported, and are always aliased to dummy rules. These
       unsupported formats are: <span class="emphasis"><em>info</em></span>,
       <span class="emphasis"><em>ps</em></span>, and <span class="emphasis"><em>dvi</em></span>.
-    </p></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="doc.doxygen"></a>Doxygen</h3></div></div></div><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="doxygen.prereq"></a>Prerequisites</h4></div></div></div><div class="table"><a id="table.doxygen_prereq"></a><p class="title"><strong>Table B.1. Doxygen Prerequisites</strong></p><div class="table-contents"><table summary="Doxygen Prerequisites" border="1"><colgroup><col align="center" class="c1" /><col align="center" class="c2" /><col align="center" class="c3" /></colgroup><thead><tr><th align="center">Tool</th><th align="center">Version</th><th align="center">Required By</th></tr></thead><tbody><tr><td align="center">coreutils</td><td align="center">8.5</td><td align="center">all</td></tr><tr><td align="center">bash</td><td align="center">4.1</td><td align="center">all</td></tr><tr><td align="center">doxygen</td><td align="center">1.7.6.1</td><td align="center">all</td></tr><tr><td align="center">graphviz</td><td align="center">2.26</td><td align="center">graphical hierarchies</td></tr><tr><td align="center">pdflatex</td><td align="center">2007-59</td><td align="center">pdf output</td></tr></tbody></table></div></div><br class="table-break" /><p>
+    </p></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="doc.doxygen"></a>Doxygen</h3></div></div></div><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="doxygen.prereq"></a>Prerequisites</h4></div></div></div><div class="table"><a id="table.doxygen_prereq"></a><p class="title"><strong>Table B.1. Doxygen Prerequisites</strong></p><div class="table-contents"><table class="table" summary="Doxygen Prerequisites" border="1"><colgroup><col align="center" class="c1" /><col align="center" class="c2" /><col align="center" class="c3" /></colgroup><thead><tr><th align="center">Tool</th><th align="center">Version</th><th align="center">Required By</th></tr></thead><tbody><tr><td align="center">coreutils</td><td align="center">8.5</td><td align="center">all</td></tr><tr><td align="center">bash</td><td align="center">4.1</td><td align="center">all</td></tr><tr><td align="center">doxygen</td><td align="center">1.7.6.1</td><td align="center">all</td></tr><tr><td align="center">graphviz</td><td align="center">2.26</td><td align="center">graphical hierarchies</td></tr><tr><td align="center">pdflatex</td><td align="center">2007-59</td><td align="center">pdf output</td></tr></tbody></table></div></div><br class="table-break" /><p>
 	Prerequisite tools are Bash 2.0 or later,
 	<a class="link" href="http://www.doxygen.org" target="_top">Doxygen</a>, and
 	the <a class="link" href="http://www.gnu.org/software/coreutils/" target="_top">GNU
@@ -322,7 +322,7 @@
 	writing Doxygen comments. Single and double quotes, and
 	separators in filenames are two common trouble spots. When in
 	doubt, consult the following table.
-      </p><div class="table"><a id="table.doxygen_cmp"></a><p class="title"><strong>Table B.2. HTML to Doxygen Markup Comparison</strong></p><div class="table-contents"><table summary="HTML to Doxygen Markup Comparison" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">HTML</th><th align="left">Doxygen</th></tr></thead><tbody><tr><td align="left">\</td><td align="left">\\</td></tr><tr><td align="left">"</td><td align="left">\"</td></tr><tr><td align="left">'</td><td align="left">\'</td></tr><tr><td align="left">&lt;i&gt;</td><td align="left">@a word</td></tr><tr><td align="left">&lt;b&gt;</td><td align="left">@b word</td></tr><tr><td align="left">&lt;code&gt;</td><td align="left">@c word</td></tr><tr><td align="left">&lt;em&gt;</td><td align="left">@a word</td></tr><tr><td align="left">&lt;em&gt;</td><td align="left">&lt;em&gt;two words or more&lt;/em&gt;</td></tr></tbody></table></div></div><br class="table-break" /></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="doc.docbook"></a>Docbook</h3></div></div></div><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="docbook.prereq"></a>Prerequisites</h4></div></div></div><div class="table"><a id="table.docbook_prereq"></a><p class="title"><strong>Table B.3. Docbook Prerequisites</strong></p><div class="table-contents"><table summary="Docbook Prerequisites" border="1"><colgroup><col align="center" class="c1" /><col align="center" class="c2" /><col align="center" class="c3" /></colgroup><thead><tr><th align="center">Tool</th><th align="center">Version</th><th align="center">Required By</th></tr></thead><tbody><tr><td align="center">docbook5-style-xsl</td><td align="center">1.76.1</td><td align="center">all</td></tr><tr><td align="center">xsltproc</td><td align="center">1.1.26</td><td align="center">all</td></tr><tr><td align="center">xmllint</td><td align="center">2.7.7</td><td align="center">validation</td></tr><tr><td align="center">dblatex</td><td align="center">0.3</td><td align="center">pdf output</td></tr><tr><td align="center">pdflatex</td><td align="center">2007-59</td><td align="center">pdf output</td></tr><tr><td align="center">docbook2X</td><td align="center">0.8.8</td><td align="center">info output</td></tr><tr><td align="center">epub3 stylesheets</td><td align="center">b3</td><td align="center">epub output</td></tr></tbody></table></div></div><br class="table-break" /><p>
+      </p><div class="table"><a id="table.doxygen_cmp"></a><p class="title"><strong>Table B.2. HTML to Doxygen Markup Comparison</strong></p><div class="table-contents"><table class="table" summary="HTML to Doxygen Markup Comparison" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">HTML</th><th align="left">Doxygen</th></tr></thead><tbody><tr><td align="left">\</td><td align="left">\\</td></tr><tr><td align="left">"</td><td align="left">\"</td></tr><tr><td align="left">'</td><td align="left">\'</td></tr><tr><td align="left">&lt;i&gt;</td><td align="left">@a word</td></tr><tr><td align="left">&lt;b&gt;</td><td align="left">@b word</td></tr><tr><td align="left">&lt;code&gt;</td><td align="left">@c word</td></tr><tr><td align="left">&lt;em&gt;</td><td align="left">@a word</td></tr><tr><td align="left">&lt;em&gt;</td><td align="left">&lt;em&gt;two words or more&lt;/em&gt;</td></tr></tbody></table></div></div><br class="table-break" /></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="doc.docbook"></a>Docbook</h3></div></div></div><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="docbook.prereq"></a>Prerequisites</h4></div></div></div><div class="table"><a id="table.docbook_prereq"></a><p class="title"><strong>Table B.3. Docbook Prerequisites</strong></p><div class="table-contents"><table class="table" summary="Docbook Prerequisites" border="1"><colgroup><col align="center" class="c1" /><col align="center" class="c2" /><col align="center" class="c3" /></colgroup><thead><tr><th align="center">Tool</th><th align="center">Version</th><th align="center">Required By</th></tr></thead><tbody><tr><td align="center">docbook5-style-xsl</td><td align="center">1.76.1</td><td align="center">all</td></tr><tr><td align="center">xsltproc</td><td align="center">1.1.26</td><td align="center">all</td></tr><tr><td align="center">xmllint</td><td align="center">2.7.7</td><td align="center">validation</td></tr><tr><td align="center">dblatex</td><td align="center">0.3</td><td align="center">pdf output</td></tr><tr><td align="center">pdflatex</td><td align="center">2007-59</td><td align="center">pdf output</td></tr><tr><td align="center">docbook2X</td><td align="center">0.8.8</td><td align="center">info output</td></tr><tr><td align="center">epub3 stylesheets</td><td align="center">b3</td><td align="center">epub output</td></tr></tbody></table></div></div><br class="table-break" /><p>
 	Editing the DocBook sources requires an XML editor. Many
 	exist: some notable options
 	include <span class="command"><strong>emacs</strong></span>, <span class="application">Kate</span>,
@@ -530,11 +530,11 @@
 	<a class="link" href="http://tdg.docbook.org/tdg/5.0/ref-elements.html" target="_top">DocBook Element Reference</a>.
 	An incomplete reference for HTML to Docbook conversion is
 	detailed in the table below.
-      </p><div class="table"><a id="table.docbook_cmp"></a><p class="title"><strong>Table B.4. HTML to Docbook XML Markup Comparison</strong></p><div class="table-contents"><table summary="HTML to Docbook XML Markup Comparison" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">HTML</th><th align="left">Docbook</th></tr></thead><tbody><tr><td align="left">&lt;p&gt;</td><td align="left">&lt;para&gt;</td></tr><tr><td align="left">&lt;pre&gt;</td><td align="left">&lt;computeroutput&gt;, &lt;programlisting&gt;,
+      </p><div class="table"><a id="table.docbook_cmp"></a><p class="title"><strong>Table B.4. HTML to Docbook XML Markup Comparison</strong></p><div class="table-contents"><table class="table" summary="HTML to Docbook XML Markup Comparison" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">HTML</th><th align="left">Docbook</th></tr></thead><tbody><tr><td align="left">&lt;p&gt;</td><td align="left">&lt;para&gt;</td></tr><tr><td align="left">&lt;pre&gt;</td><td align="left">&lt;computeroutput&gt;, &lt;programlisting&gt;,
 	&lt;literallayout&gt;</td></tr><tr><td align="left">&lt;ul&gt;</td><td align="left">&lt;itemizedlist&gt;</td></tr><tr><td align="left">&lt;ol&gt;</td><td align="left">&lt;orderedlist&gt;</td></tr><tr><td align="left">&lt;il&gt;</td><td align="left">&lt;listitem&gt;</td></tr><tr><td align="left">&lt;dl&gt;</td><td align="left">&lt;variablelist&gt;</td></tr><tr><td align="left">&lt;dt&gt;</td><td align="left">&lt;term&gt;</td></tr><tr><td align="left">&lt;dd&gt;</td><td align="left">&lt;listitem&gt;</td></tr><tr><td align="left">&lt;a href=""&gt;</td><td align="left">&lt;ulink url=""&gt;</td></tr><tr><td align="left">&lt;code&gt;</td><td align="left">&lt;literal&gt;, &lt;programlisting&gt;</td></tr><tr><td align="left">&lt;strong&gt;</td><td align="left">&lt;emphasis&gt;</td></tr><tr><td align="left">&lt;em&gt;</td><td align="left">&lt;emphasis&gt;</td></tr><tr><td align="left">"</td><td align="left">&lt;quote&gt;</td></tr></tbody></table></div></div><br class="table-break" /><p>
   And examples of detailed markup for which there are no real HTML
   equivalents are listed in the table below.
-</p><div class="table"><a id="table.docbook_elem"></a><p class="title"><strong>Table B.5. Docbook XML Element Use</strong></p><div class="table-contents"><table summary="Docbook XML Element Use" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">Element</th><th align="left">Use</th></tr></thead><tbody><tr><td align="left">&lt;structname&gt;</td><td align="left">&lt;structname&gt;char_traits&lt;/structname&gt;</td></tr><tr><td align="left">&lt;classname&gt;</td><td align="left">&lt;classname&gt;string&lt;/classname&gt;</td></tr><tr><td align="left">&lt;function&gt;</td><td align="left">
+</p><div class="table"><a id="table.docbook_elem"></a><p class="title"><strong>Table B.5. Docbook XML Element Use</strong></p><div class="table-contents"><table class="table" summary="Docbook XML Element Use" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">Element</th><th align="left">Use</th></tr></thead><tbody><tr><td align="left">&lt;structname&gt;</td><td align="left">&lt;structname&gt;char_traits&lt;/structname&gt;</td></tr><tr><td align="left">&lt;classname&gt;</td><td align="left">&lt;classname&gt;string&lt;/classname&gt;</td></tr><tr><td align="left">&lt;function&gt;</td><td align="left">
 	<p>&lt;function&gt;clear()&lt;/function&gt;</p>
 	<p>&lt;function&gt;fs.clear()&lt;/function&gt;</p>
       </td></tr><tr><td align="left">&lt;type&gt;</td><td align="left">&lt;type&gt;long long&lt;/type&gt;</td></tr><tr><td align="left">&lt;varname&gt;</td><td align="left">&lt;varname&gt;fs&lt;/varname&gt;</td></tr><tr><td align="left">&lt;literal&gt;</td><td align="left">
Index: libstdc++-v3/doc/html/manual/extensions.html
===================================================================
--- libstdc++-v3/doc/html/manual/extensions.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/extensions.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Part III.  Extensions</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library Manual" /><link rel="prev" href="io_and_c.html" title="Interacting with C" /><link rel="next" href="ext_preface.html" title="" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Part III.  Extensions</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="index.html" title="The GNU C++ Library Manual" /><link rel="prev" href="io_and_c.html" title="Interacting with C" /><link rel="next" href="ext_preface.html" title="" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Part III. 
   Extensions
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="io_and_c.html">Prev</a> </td><th width="60%" align="center">The GNU C++ Library Manual</th><td width="20%" align="right"> <a accesskey="n" href="ext_preface.html">Next</a></td></tr></table><hr /></div><div class="part"><div class="titlepage"><div><div><h1 class="title"><a id="manual.ext"></a>Part III. 
Index: libstdc++-v3/doc/html/manual/debug_mode_using.html
===================================================================
--- libstdc++-v3/doc/html/manual/debug_mode_using.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/debug_mode_using.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Using</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="debug_mode.html" title="Chapter 17. Debug Mode" /><link rel="prev" href="debug_mode_semantics.html" title="Semantics" /><link rel="next" href="debug_mode_design.html" title="Design" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Using</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="debug_mode_semantics.html">Prev</a> </td><th width="60%" align="center">Chapter 17. Debug Mode</th><td width="20%" align="right"> <a accesskey="n" href="debug_mode_design.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.debug_mode.using"></a>Using</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Using</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="debug_mode.html" title="Chapter 17. Debug Mode" /><link rel="prev" href="debug_mode_semantics.html" title="Semantics" /><link rel="next" href="debug_mode_design.html" title="Design" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Using</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="debug_mode_semantics.html">Prev</a> </td><th width="60%" align="center">Chapter 17. Debug Mode</th><td width="20%" align="right"> <a accesskey="n" href="debug_mode_design.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.debug_mode.using"></a>Using</h2></div></div></div><p>
   </p><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="debug_mode.using.mode"></a>Using the Debug Mode</h3></div></div></div><p>To use the libstdc++ debug mode, compile your application with the
   compiler flag <code class="code">-D_GLIBCXX_DEBUG</code>. Note that this flag
   changes the sizes and behavior of standard class templates such
@@ -18,6 +18,6 @@
   mode or with debug mode. The
   following table provides the names and headers of the debugging
   containers:
-</p><div class="table"><a id="table.debug_mode_containers"></a><p class="title"><strong>Table 17.1. Debugging Containers</strong></p><div class="table-contents"><table summary="Debugging Containers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Container</th><th align="left">Header</th><th align="left">Debug container</th><th align="left">Debug header</th></tr></thead><tbody><tr><td align="left"><code class="classname">std::bitset</code></td><td align="left"><code class="filename">bitset</code></td><td align="left"><code class="classname">__gnu_debug::bitset</code></td><td align="left"><code class="filename">&lt;debug/bitset&gt;</code></td></tr><tr><td align="left"><code class="classname">std::deque</code></td><td align="left"><code class="filename">deque</code></td><td align="left"><code class="classname">__gnu_debug::deque</code></td><td align="left"><code class="filename">&lt;debug/deque&gt;</code></td></tr><tr><td align="left"><code class="classname">std::list</code></td><td align="left"><code class="filename">list</code></td><td align="left"><code class="classname">__gnu_debug::list</code></td><td align="left"><code class="filename">&lt;debug/list&gt;</code></td></tr><tr><td align="left"><code class="classname">std::map</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="classname">__gnu_debug::map</code></td><td align="left"><code class="filename">&lt;debug/map&gt;</code></td></tr><tr><td align="left"><code class="classname">std::multimap</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="classname">__gnu_debug::multimap</code></td><td align="left"><code class="filename">&lt;debug/map&gt;</code></td></tr><tr><td align="left"><code class="classname">std::multiset</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="classname">__gnu_debug::multiset</code></td><td align="left"><code class="filename">&lt;debug/set&gt;</code></td></tr><tr><td align="left"><code class="classname">std::set</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="classname">__gnu_debug::set</code></td><td align="left"><code class="filename">&lt;debug/set&gt;</code></td></tr><tr><td align="left"><code class="classname">std::string</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="classname">__gnu_debug::string</code></td><td align="left"><code class="filename">&lt;debug/string&gt;</code></td></tr><tr><td align="left"><code class="classname">std::wstring</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="classname">__gnu_debug::wstring</code></td><td align="left"><code class="filename">&lt;debug/string&gt;</code></td></tr><tr><td align="left"><code class="classname">std::basic_string</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="classname">__gnu_debug::basic_string</code></td><td align="left"><code class="filename">&lt;debug/string&gt;</code></td></tr><tr><td align="left"><code class="classname">std::vector</code></td><td align="left"><code class="filename">vector</code></td><td align="left"><code class="classname">__gnu_debug::vector</code></td><td align="left"><code class="filename">&lt;debug/vector&gt;</code></td></tr></tbody></table></div></div><br class="table-break" /><p>In addition, when compiling in C++11 mode, these additional
+</p><div class="table"><a id="table.debug_mode_containers"></a><p class="title"><strong>Table 17.1. Debugging Containers</strong></p><div class="table-contents"><table class="table" summary="Debugging Containers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Container</th><th align="left">Header</th><th align="left">Debug container</th><th align="left">Debug header</th></tr></thead><tbody><tr><td align="left"><code class="classname">std::bitset</code></td><td align="left"><code class="filename">bitset</code></td><td align="left"><code class="classname">__gnu_debug::bitset</code></td><td align="left"><code class="filename">&lt;debug/bitset&gt;</code></td></tr><tr><td align="left"><code class="classname">std::deque</code></td><td align="left"><code class="filename">deque</code></td><td align="left"><code class="classname">__gnu_debug::deque</code></td><td align="left"><code class="filename">&lt;debug/deque&gt;</code></td></tr><tr><td align="left"><code class="classname">std::list</code></td><td align="left"><code class="filename">list</code></td><td align="left"><code class="classname">__gnu_debug::list</code></td><td align="left"><code class="filename">&lt;debug/list&gt;</code></td></tr><tr><td align="left"><code class="classname">std::map</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="classname">__gnu_debug::map</code></td><td align="left"><code class="filename">&lt;debug/map&gt;</code></td></tr><tr><td align="left"><code class="classname">std::multimap</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="classname">__gnu_debug::multimap</code></td><td align="left"><code class="filename">&lt;debug/map&gt;</code></td></tr><tr><td align="left"><code class="classname">std::multiset</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="classname">__gnu_debug::multiset</code></td><td align="left"><code class="filename">&lt;debug/set&gt;</code></td></tr><tr><td align="left"><code class="classname">std::set</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="classname">__gnu_debug::set</code></td><td align="left"><code class="filename">&lt;debug/set&gt;</code></td></tr><tr><td align="left"><code class="classname">std::string</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="classname">__gnu_debug::string</code></td><td align="left"><code class="filename">&lt;debug/string&gt;</code></td></tr><tr><td align="left"><code class="classname">std::wstring</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="classname">__gnu_debug::wstring</code></td><td align="left"><code class="filename">&lt;debug/string&gt;</code></td></tr><tr><td align="left"><code class="classname">std::basic_string</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="classname">__gnu_debug::basic_string</code></td><td align="left"><code class="filename">&lt;debug/string&gt;</code></td></tr><tr><td align="left"><code class="classname">std::vector</code></td><td align="left"><code class="filename">vector</code></td><td align="left"><code class="classname">__gnu_debug::vector</code></td><td align="left"><code class="filename">&lt;debug/vector&gt;</code></td></tr></tbody></table></div></div><br class="table-break" /><p>In addition, when compiling in C++11 mode, these additional
 containers have additional debug capability.
-</p><div class="table"><a id="table.debug_mode_containers_cxx11"></a><p class="title"><strong>Table 17.2. Debugging Containers C++11</strong></p><div class="table-contents"><table summary="Debugging Containers C++11" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Container</th><th align="left">Header</th><th align="left">Debug container</th><th align="left">Debug header</th></tr></thead><tbody><tr><td align="left"><code class="classname">std::unordered_map</code></td><td align="left"><code class="filename">unordered_map</code></td><td align="left"><code class="classname">__gnu_debug::unordered_map</code></td><td align="left"><code class="filename">&lt;debug/unordered_map&gt;</code></td></tr><tr><td align="left"><code class="classname">std::unordered_multimap</code></td><td align="left"><code class="filename">unordered_map</code></td><td align="left"><code class="classname">__gnu_debug::unordered_multimap</code></td><td align="left"><code class="filename">&lt;debug/unordered_map&gt;</code></td></tr><tr><td align="left"><code class="classname">std::unordered_set</code></td><td align="left"><code class="filename">unordered_set</code></td><td align="left"><code class="classname">__gnu_debug::unordered_set</code></td><td align="left"><code class="filename">&lt;debug/unordered_set&gt;</code></td></tr><tr><td align="left"><code class="classname">std::unordered_multiset</code></td><td align="left"><code class="filename">unordered_set</code></td><td align="left"><code class="classname">__gnu_debug::unordered_multiset</code></td><td align="left"><code class="filename">&lt;debug/unordered_set&gt;</code></td></tr></tbody></table></div></div><br class="table-break" /></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="debug_mode_semantics.html">Prev</a> </td><td width="20%" align="center"><a accesskey="u" href="debug_mode.html">Up</a></td><td width="40%" align="right"> <a accesskey="n" href="debug_mode_design.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">Semantics </td><td width="20%" align="center"><a accesskey="h" href="../index.html">Home</a></td><td width="40%" align="right" valign="top"> Design</td></tr></table></div></body></html>
\ No newline at end of file
+</p><div class="table"><a id="table.debug_mode_containers_cxx11"></a><p class="title"><strong>Table 17.2. Debugging Containers C++11</strong></p><div class="table-contents"><table class="table" summary="Debugging Containers C++11" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><thead><tr><th align="left">Container</th><th align="left">Header</th><th align="left">Debug container</th><th align="left">Debug header</th></tr></thead><tbody><tr><td align="left"><code class="classname">std::unordered_map</code></td><td align="left"><code class="filename">unordered_map</code></td><td align="left"><code class="classname">__gnu_debug::unordered_map</code></td><td align="left"><code class="filename">&lt;debug/unordered_map&gt;</code></td></tr><tr><td align="left"><code class="classname">std::unordered_multimap</code></td><td align="left"><code class="filename">unordered_map</code></td><td align="left"><code class="classname">__gnu_debug::unordered_multimap</code></td><td align="left"><code class="filename">&lt;debug/unordered_map&gt;</code></td></tr><tr><td align="left"><code class="classname">std::unordered_set</code></td><td align="left"><code class="filename">unordered_set</code></td><td align="left"><code class="classname">__gnu_debug::unordered_set</code></td><td align="left"><code class="filename">&lt;debug/unordered_set&gt;</code></td></tr><tr><td align="left"><code class="classname">std::unordered_multiset</code></td><td align="left"><code class="filename">unordered_set</code></td><td align="left"><code class="classname">__gnu_debug::unordered_multiset</code></td><td align="left"><code class="filename">&lt;debug/unordered_set&gt;</code></td></tr></tbody></table></div></div><br class="table-break" /></div></div><div class="navfooter"><hr /><table width="100%" summary="Navigation footer"><tr><td width="40%" align="left"><a accesskey="p" href="debug_mode_semantics.html">Prev</a> </td><td width="20%" align="center"><a accesskey="u" href="debug_mode.html">Up</a></td><td width="40%" align="right"> <a accesskey="n" href="debug_mode_design.html">Next</a></td></tr><tr><td width="40%" align="left" valign="top">Semantics </td><td width="20%" align="center"><a accesskey="h" href="../index.html">Home</a></td><td width="40%" align="right" valign="top"> Design</td></tr></table></div></body></html>
\ No newline at end of file
Index: libstdc++-v3/doc/html/manual/debug_mode_semantics.html
===================================================================
--- libstdc++-v3/doc/html/manual/debug_mode_semantics.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/debug_mode_semantics.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Semantics</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="debug_mode.html" title="Chapter 17. Debug Mode" /><link rel="prev" href="debug_mode.html" title="Chapter 17. Debug Mode" /><link rel="next" href="debug_mode_using.html" title="Using" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Semantics</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="debug_mode.html">Prev</a> </td><th width="60%" align="center">Chapter 17. Debug Mode</th><td width="20%" align="right"> <a accesskey="n" href="debug_mode_using.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.debug_mode.semantics"></a>Semantics</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Semantics</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="debug_mode.html" title="Chapter 17. Debug Mode" /><link rel="prev" href="debug_mode.html" title="Chapter 17. Debug Mode" /><link rel="next" href="debug_mode_using.html" title="Using" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Semantics</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="debug_mode.html">Prev</a> </td><th width="60%" align="center">Chapter 17. Debug Mode</th><td width="20%" align="right"> <a accesskey="n" href="debug_mode_using.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.debug_mode.semantics"></a>Semantics</h2></div></div></div><p>
   </p><p>A program that uses the C++ standard library correctly
   will maintain the same semantics under debug mode as it had with
   the normal (release) library. All functional and exception-handling
Index: libstdc++-v3/doc/html/manual/parallel_mode.html
===================================================================
--- libstdc++-v3/doc/html/manual/parallel_mode.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/parallel_mode.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 18. Parallel Mode</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="debug_mode_design.html" title="Design" /><link rel="next" href="parallel_mode_semantics.html" title="Semantics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 18. Parallel Mode</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="debug_mode_design.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 18. Parallel Mode</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, parallel" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="debug_mode_design.html" title="Design" /><link rel="next" href="parallel_mode_semantics.html" title="Semantics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 18. Parallel Mode</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="debug_mode_design.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="parallel_mode_semantics.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.parallel_mode"></a>Chapter 18. Parallel Mode</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="parallel_mode.html#manual.ext.parallel_mode.intro">Intro</a></span></dt><dt><span class="section"><a href="parallel_mode_semantics.html">Semantics</a></span></dt><dt><span class="section"><a href="parallel_mode_using.html">Using</a></span></dt><dd><dl><dt><span class="section"><a href="parallel_mode_using.html#parallel_mode.using.prereq_flags">Prerequisite Compiler Flags</a></span></dt><dt><span class="section"><a href="parallel_mode_using.html#parallel_mode.using.parallel_mode">Using Parallel Mode</a></span></dt><dt><span class="section"><a href="parallel_mode_using.html#parallel_mode.using.specific">Using Specific Parallel Components</a></span></dt></dl></dd><dt><span class="section"><a href="parallel_mode_design.html">Design</a></span></dt><dd><dl><dt><span class="section"><a href="parallel_mode_design.html#parallel_mode.design.intro">Interface Basics</a></span></dt><dt><span class="section"><a href="parallel_mode_design.html#parallel_mode.design.tuning">Configuration and Tuning</a></span></dt><dd><dl><dt><span class="section"><a href="parallel_mode_design.html#parallel_mode.design.tuning.omp">Setting up the OpenMP Environment</a></span></dt><dt><span class="section"><a href="parallel_mode_design.html#parallel_mode.design.tuning.compile">Compile Time Switches</a></span></dt><dt><span class="section"><a href="parallel_mode_design.html#parallel_mode.design.tuning.settings">Run Time Settings and Defaults</a></span></dt></dl></dd><dt><span class="section"><a href="parallel_mode_design.html#parallel_mode.design.impl">Implementation Namespaces</a></span></dt></dl></dd><dt><span class="section"><a href="parallel_mode_test.html">Testing</a></span></dt><dt><span class="bibliography"><a href="parallel_mode.html#parallel_mode.biblio">Bibliography</a></span></dt></dl></div><p> The libstdc++ parallel mode is an experimental parallel
Index: libstdc++-v3/doc/html/manual/setup.html
===================================================================
--- libstdc++-v3/doc/html/manual/setup.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/setup.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 2. Setup</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="intro.html" title="Part I.  Introduction" /><link rel="prev" href="bugs.html" title="Bugs" /><link rel="next" href="configure.html" title="Configure" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 2. Setup</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bugs.html">Prev</a> </td><th width="60%" align="center">Part I. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 2. Setup</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="intro.html" title="Part I.  Introduction" /><link rel="prev" href="bugs.html" title="Bugs" /><link rel="next" href="configure.html" title="Configure" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 2. Setup</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="bugs.html">Prev</a> </td><th width="60%" align="center">Part I. 
   Introduction
   
 </th><td width="20%" align="right"> <a accesskey="n" href="configure.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.intro.setup"></a>Chapter 2. Setup</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="setup.html#manual.intro.setup.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="configure.html">Configure</a></span></dt><dt><span class="section"><a href="make.html">Make</a></span></dt></dl></div><p>To transform libstdc++ sources into installed include files
Index: libstdc++-v3/doc/html/manual/backwards.html
===================================================================
--- libstdc++-v3/doc/html/manual/backwards.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/backwards.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Backwards Compatibility</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, backwards" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="api.html" title="API Evolution and Deprecation History" /><link rel="next" href="appendix_free.html" title="Appendix C.  Free Software Needs Free Documentation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Backwards Compatibility</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="api.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Backwards Compatibility</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, backwards" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="api.html" title="API Evolution and Deprecation History" /><link rel="next" href="appendix_free.html" title="Appendix C.  Free Software Needs Free Documentation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Backwards Compatibility</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="api.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
   Porting and Maintenance
   
 </th><td width="20%" align="right"> <a accesskey="n" href="appendix_free.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.appendix.porting.backwards"></a>Backwards Compatibility</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="backwards.first"></a>First</h3></div></div></div><p>The first generation GNU C++ library was called libg++.  It was a
Index: libstdc++-v3/doc/html/manual/source_design_notes.html
===================================================================
--- libstdc++-v3/doc/html/manual/source_design_notes.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/source_design_notes.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design Notes</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_contributing.html" title="Appendix A.  Contributing" /><link rel="prev" href="source_code_style.html" title="Coding Style" /><link rel="next" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design Notes</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="source_code_style.html">Prev</a> </td><th width="60%" align="center">Appendix A. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design Notes</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_contributing.html" title="Appendix A.  Contributing" /><link rel="prev" href="source_code_style.html" title="Coding Style" /><link rel="next" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design Notes</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="source_code_style.html">Prev</a> </td><th width="60%" align="center">Appendix A. 
   Contributing
   
 </th><td width="20%" align="right"> <a accesskey="n" href="appendix_porting.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="contrib.design_notes"></a>Design Notes</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/ext_sgi.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_sgi.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_sgi.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Deprecated</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="ext_containers.html" title="Chapter 23. HP/SGI Extensions" /><link rel="prev" href="ext_containers.html" title="Chapter 23. HP/SGI Extensions" /><link rel="next" href="ext_utilities.html" title="Chapter 24. Utilities" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Deprecated</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_containers.html">Prev</a> </td><th width="60%" align="center">Chapter 23. HP/SGI Extensions</th><td width="20%" align="right"> <a accesskey="n" href="ext_utilities.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.containers.deprecated_sgi"></a>Deprecated</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Deprecated</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="ext_containers.html" title="Chapter 23. HP/SGI Extensions" /><link rel="prev" href="ext_containers.html" title="Chapter 23. HP/SGI Extensions" /><link rel="next" href="ext_utilities.html" title="Chapter 24. Utilities" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Deprecated</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_containers.html">Prev</a> </td><th width="60%" align="center">Chapter 23. HP/SGI Extensions</th><td width="20%" align="right"> <a accesskey="n" href="ext_utilities.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.containers.deprecated_sgi"></a>Deprecated</h2></div></div></div><p>
      The SGI hashing classes <code class="classname">hash_set</code> and
      <code class="classname">hash_set</code> have been deprecated by the
      unordered_set, unordered_multiset, unordered_map,
Index: libstdc++-v3/doc/html/manual/facets.html
===================================================================
--- libstdc++-v3/doc/html/manual/facets.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/facets.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Facets</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="localization.html" title="Chapter 8.  Localization" /><link rel="prev" href="localization.html" title="Chapter 8.  Localization" /><link rel="next" href="containers.html" title="Chapter 9.  Containers" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Facets</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="localization.html">Prev</a> </td><th width="60%" align="center">Chapter 8. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Facets</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="localization.html" title="Chapter 8.  Localization" /><link rel="prev" href="localization.html" title="Chapter 8.  Localization" /><link rel="next" href="containers.html" title="Chapter 9.  Containers" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Facets</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="localization.html">Prev</a> </td><th width="60%" align="center">Chapter 8. 
   Localization
   
 </th><td width="20%" align="right"> <a accesskey="n" href="containers.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.localization.facet"></a>Facets</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="std.localization.facet.ctype"></a>ctype</h3></div></div></div><div class="section"><div class="titlepage"><div><div><h4 class="title"><a id="facet.ctype.impl"></a>Implementation</h4></div></div></div><div class="section"><div class="titlepage"><div><div><h5 class="title"><a id="facet.ctype.impl.spec"></a>Specializations</h5></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/using_dual_abi.html
===================================================================
--- libstdc++-v3/doc/html/manual/using_dual_abi.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/using_dual_abi.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Dual ABI</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_macros.html" title="Macros" /><link rel="next" href="using_namespaces.html" title="Namespaces" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Dual ABI</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_macros.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_namespaces.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.abi"></a>Dual ABI</h2></div></div></div><p> In the GCC 5.1 release libstdc++ introduced a new library ABI that
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Dual ABI</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_macros.html" title="Macros" /><link rel="next" href="using_namespaces.html" title="Namespaces" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Dual ABI</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_macros.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_namespaces.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.abi"></a>Dual ABI</h2></div></div></div><p> In the GCC 5.1 release libstdc++ introduced a new library ABI that
   includes new implementations of <code class="classname">std::string</code> and
   <code class="classname">std::list</code>. These changes were necessary to conform
   to the 2011 C++ standard which forbids Copy-On-Write strings and requires
Index: libstdc++-v3/doc/html/manual/diagnostics.html
===================================================================
--- libstdc++-v3/doc/html/manual/diagnostics.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/diagnostics.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 5.  Diagnostics</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="termination.html" title="Termination" /><link rel="next" href="errno.html" title="Use of errno by the library" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 5. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 5.  Diagnostics</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="termination.html" title="Termination" /><link rel="next" href="errno.html" title="Use of errno by the library" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 5. 
   Diagnostics
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="termination.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/mt_allocator_design.html
===================================================================
--- libstdc++-v3/doc/html/manual/mt_allocator_design.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/mt_allocator_design.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design Issues</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="prev" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="next" href="mt_allocator_impl.html" title="Implementation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design Issues</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator.html">Prev</a> </td><th width="60%" align="center">Chapter 20. The mt_allocator</th><td width="20%" align="right"> <a accesskey="n" href="mt_allocator_impl.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.mt.design_issues"></a>Design Issues</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="allocator.mt.overview"></a>Overview</h3></div></div></div><p> There are three general components to the allocator: a datum
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design Issues</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="prev" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="next" href="mt_allocator_impl.html" title="Implementation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design Issues</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator.html">Prev</a> </td><th width="60%" align="center">Chapter 20. The mt_allocator</th><td width="20%" align="right"> <a accesskey="n" href="mt_allocator_impl.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.mt.design_issues"></a>Design Issues</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="allocator.mt.overview"></a>Overview</h3></div></div></div><p> There are three general components to the allocator: a datum
 describing the characteristics of the memory pool, a policy class
 containing this pool that links instantiation types to common or
 individual pools, and a class inheriting from the policy class that is
Index: libstdc++-v3/doc/html/manual/appendix_free.html
===================================================================
--- libstdc++-v3/doc/html/manual/appendix_free.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/appendix_free.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix C.  Free Software Needs Free Documentation</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="backwards.html" title="Backwards Compatibility" /><link rel="next" href="appendix_gpl.html" title="Appendix D.  GNU General Public License version 3" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix C. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix C.  Free Software Needs Free Documentation</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="backwards.html" title="Backwards Compatibility" /><link rel="next" href="appendix_gpl.html" title="Appendix D.  GNU General Public License version 3" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix C. 
   Free Software Needs Free Documentation
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="backwards.html">Prev</a> </td><th width="60%" align="center">Part IV. 
Index: libstdc++-v3/doc/html/manual/algorithms.html
===================================================================
--- libstdc++-v3/doc/html/manual/algorithms.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/algorithms.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 11.  Algorithms</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library, algorithm" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="iterators.html" title="Chapter 10.  Iterators" /><link rel="next" href="numerics.html" title="Chapter 12.  Numerics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 11. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 11.  Algorithms</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library, algorithm" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="iterators.html" title="Chapter 10.  Iterators" /><link rel="next" href="numerics.html" title="Chapter 12.  Numerics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 11. 
   Algorithms
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="iterators.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/appendix_porting.html
===================================================================
--- libstdc++-v3/doc/html/manual/appendix_porting.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/appendix_porting.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix B.  Porting and Maintenance</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="source_design_notes.html" title="Design Notes" /><link rel="next" href="documentation_hacking.html" title="Writing and Generating Documentation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix B. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix B.  Porting and Maintenance</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="source_design_notes.html" title="Design Notes" /><link rel="next" href="documentation_hacking.html" title="Writing and Generating Documentation" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix B. 
   Porting and Maintenance
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="source_design_notes.html">Prev</a> </td><th width="60%" align="center">Part IV. 
Index: libstdc++-v3/doc/html/manual/profile_mode_cost_model.html
===================================================================
--- libstdc++-v3/doc/html/manual/profile_mode_cost_model.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/profile_mode_cost_model.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Empirical Cost Model</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_api.html" title="Extensions for Custom Containers" /><link rel="next" href="profile_mode_impl.html" title="Implementation Issues" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Empirical Cost Model</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_api.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_impl.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.cost_model"></a>Empirical Cost Model</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Empirical Cost Model</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode_api.html" title="Extensions for Custom Containers" /><link rel="next" href="profile_mode_impl.html" title="Implementation Issues" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Empirical Cost Model</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode_api.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_impl.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.cost_model"></a>Empirical Cost Model</h2></div></div></div><p>
   Currently, the cost model uses formulas with predefined relative weights
   for alternative containers or container implementations.  For instance,
   iterating through a vector is X times faster than iterating through a list.
Index: libstdc++-v3/doc/html/manual/make.html
===================================================================
--- libstdc++-v3/doc/html/manual/make.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/make.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Make</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="setup.html" title="Chapter 2. Setup" /><link rel="prev" href="configure.html" title="Configure" /><link rel="next" href="using.html" title="Chapter 3. Using" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Make</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="configure.html">Prev</a> </td><th width="60%" align="center">Chapter 2. Setup</th><td width="20%" align="right"> <a accesskey="n" href="using.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.setup.make"></a>Make</h2></div></div></div><p>If you have never done this before, you should read the basic
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Make</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="setup.html" title="Chapter 2. Setup" /><link rel="prev" href="configure.html" title="Configure" /><link rel="next" href="using.html" title="Chapter 3. Using" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Make</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="configure.html">Prev</a> </td><th width="60%" align="center">Chapter 2. Setup</th><td width="20%" align="right"> <a accesskey="n" href="using.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.setup.make"></a>Make</h2></div></div></div><p>If you have never done this before, you should read the basic
       <a class="link" href="http://gcc.gnu.org/install/" target="_top">GCC Installation
       Instructions</a> first.  Read <span class="emphasis"><em>all of them</em></span>.
       <span class="emphasis"><em>Twice.</em></span>
Index: libstdc++-v3/doc/html/manual/pairs.html
===================================================================
--- libstdc++-v3/doc/html/manual/pairs.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/pairs.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Pairs</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="utilities.html" title="Chapter 6.  Utilities" /><link rel="prev" href="utilities.html" title="Chapter 6.  Utilities" /><link rel="next" href="memory.html" title="Memory" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Pairs</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="utilities.html">Prev</a> </td><th width="60%" align="center">Chapter 6. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Pairs</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="utilities.html" title="Chapter 6.  Utilities" /><link rel="prev" href="utilities.html" title="Chapter 6.  Utilities" /><link rel="next" href="memory.html" title="Memory" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Pairs</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="utilities.html">Prev</a> </td><th width="60%" align="center">Chapter 6. 
   Utilities
   
 </th><td width="20%" align="right"> <a accesskey="n" href="memory.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.util.pairs"></a>Pairs</h2></div></div></div><p>The <code class="code">pair&lt;T1,T2&gt;</code> is a simple and handy way to
Index: libstdc++-v3/doc/html/manual/test.html
===================================================================
--- libstdc++-v3/doc/html/manual/test.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/test.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Testing</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, test, testsuite, performance, conformance, ABI, exception safety" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="internals.html" title="Porting to New Hardware or Operating Systems" /><link rel="next" href="abi.html" title="ABI Policy and Guidelines" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Testing</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="internals.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Testing</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, test, testsuite, performance, conformance, ABI, exception safety" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_porting.html" title="Appendix B.  Porting and Maintenance" /><link rel="prev" href="internals.html" title="Porting to New Hardware or Operating Systems" /><link rel="next" href="abi.html" title="ABI Policy and Guidelines" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Testing</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="internals.html">Prev</a> </td><th width="60%" align="center">Appendix B. 
   Porting and Maintenance
   
 </th><td width="20%" align="right"> <a accesskey="n" href="abi.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.setup.test"></a>Testing</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/using_dynamic_or_shared.html
===================================================================
--- libstdc++-v3/doc/html/manual/using_dynamic_or_shared.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/using_dynamic_or_shared.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Linking</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_namespaces.html" title="Namespaces" /><link rel="next" href="using_concurrency.html" title="Concurrency" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Linking</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_namespaces.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_concurrency.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.linkage"></a>Linking</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.linkage.freestanding"></a>Almost Nothing</h3></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Linking</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_namespaces.html" title="Namespaces" /><link rel="next" href="using_concurrency.html" title="Concurrency" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Linking</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_namespaces.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_concurrency.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.linkage"></a>Linking</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.linkage.freestanding"></a>Almost Nothing</h3></div></div></div><p>
 	Or as close as it gets: freestanding. This is a minimal
 	configuration, with only partial support for the standard
 	library. Assume only the following header files can be used:
Index: libstdc++-v3/doc/html/manual/using_headers.html
===================================================================
--- libstdc++-v3/doc/html/manual/using_headers.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/using_headers.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Headers</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using.html" title="Chapter 3. Using" /><link rel="next" href="using_macros.html" title="Macros" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Headers</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_macros.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.headers"></a>Headers</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.headers.all"></a>Header Files</h3></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Headers</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using.html" title="Chapter 3. Using" /><link rel="next" href="using_macros.html" title="Macros" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Headers</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_macros.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.headers"></a>Headers</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.headers.all"></a>Header Files</h3></div></div></div><p>
      The C++ standard specifies the entire set of header files that
      must be available to all hosted implementations.  Actually, the
      word "files" is a misnomer, since the contents of the
@@ -18,19 +18,19 @@
      the 1998 standard as updated for 2003, and the current 2011 standard.
    </p><p>
      C++98/03 include files. These are available in the default compilation mode, i.e. <code class="code">-std=c++98</code> or <code class="code">-std=gnu++98</code>.
-   </p><div class="table"><a id="table.cxx98_headers"></a><p class="title"><strong>Table 3.2. C++ 1998 Library Headers</strong></p><div class="table-contents"><table summary="C++ 1998 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="filename">bitset</code></td><td align="left"><code class="filename">complex</code></td><td align="left"><code class="filename">deque</code></td><td align="left"><code class="filename">exception</code></td></tr><tr><td align="left"><code class="filename">fstream</code></td><td align="left"><code class="filename">functional</code></td><td align="left"><code class="filename">iomanip</code></td><td align="left"><code class="filename">ios</code></td><td align="left"><code class="filename">iosfwd</code></td></tr><tr><td align="left"><code class="filename">iostream</code></td><td align="left"><code class="filename">istream</code></td><td align="left"><code class="filename">iterator</code></td><td align="left"><code class="filename">limits</code></td><td align="left"><code class="filename">list</code></td></tr><tr><td align="left"><code class="filename">locale</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="filename">memory</code></td><td align="left"><code class="filename">new</code></td><td align="left"><code class="filename">numeric</code></td></tr><tr><td align="left"><code class="filename">ostream</code></td><td align="left"><code class="filename">queue</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="filename">sstream</code></td><td align="left"><code class="filename">stack</code></td></tr><tr><td align="left"><code class="filename">stdexcept</code></td><td align="left"><code class="filename">streambuf</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="filename">utility</code></td><td align="left"><code class="filename">typeinfo</code></td></tr><tr><td align="left"><code class="filename">valarray</code></td><td align="left"><code class="filename">vector</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.cxx98_cheaders"></a><p class="title"><strong>Table 3.3. C++ 1998 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table summary="C++ 1998 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">cassert</code></td><td align="left"><code class="filename">cerrno</code></td><td align="left"><code class="filename">cctype</code></td><td align="left"><code class="filename">cfloat</code></td><td align="left"><code class="filename">ciso646</code></td></tr><tr><td align="left"><code class="filename">climits</code></td><td align="left"><code class="filename">clocale</code></td><td align="left"><code class="filename">cmath</code></td><td align="left"><code class="filename">csetjmp</code></td><td align="left"><code class="filename">csignal</code></td></tr><tr><td align="left"><code class="filename">cstdarg</code></td><td align="left"><code class="filename">cstddef</code></td><td align="left"><code class="filename">cstdio</code></td><td align="left"><code class="filename">cstdlib</code></td><td align="left"><code class="filename">cstring</code></td></tr><tr><td align="left"><code class="filename">ctime</code></td><td align="left"><code class="filename">cwchar</code></td><td align="left"><code class="filename">cwctype</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p>
+   </p><div class="table"><a id="table.cxx98_headers"></a><p class="title"><strong>Table 3.2. C++ 1998 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ 1998 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="filename">bitset</code></td><td align="left"><code class="filename">complex</code></td><td align="left"><code class="filename">deque</code></td><td align="left"><code class="filename">exception</code></td></tr><tr><td align="left"><code class="filename">fstream</code></td><td align="left"><code class="filename">functional</code></td><td align="left"><code class="filename">iomanip</code></td><td align="left"><code class="filename">ios</code></td><td align="left"><code class="filename">iosfwd</code></td></tr><tr><td align="left"><code class="filename">iostream</code></td><td align="left"><code class="filename">istream</code></td><td align="left"><code class="filename">iterator</code></td><td align="left"><code class="filename">limits</code></td><td align="left"><code class="filename">list</code></td></tr><tr><td align="left"><code class="filename">locale</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="filename">memory</code></td><td align="left"><code class="filename">new</code></td><td align="left"><code class="filename">numeric</code></td></tr><tr><td align="left"><code class="filename">ostream</code></td><td align="left"><code class="filename">queue</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="filename">sstream</code></td><td align="left"><code class="filename">stack</code></td></tr><tr><td align="left"><code class="filename">stdexcept</code></td><td align="left"><code class="filename">streambuf</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="filename">utility</code></td><td align="left"><code class="filename">typeinfo</code></td></tr><tr><td align="left"><code class="filename">valarray</code></td><td align="left"><code class="filename">vector</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.cxx98_cheaders"></a><p class="title"><strong>Table 3.3. C++ 1998 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table class="table" summary="C++ 1998 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">cassert</code></td><td align="left"><code class="filename">cerrno</code></td><td align="left"><code class="filename">cctype</code></td><td align="left"><code class="filename">cfloat</code></td><td align="left"><code class="filename">ciso646</code></td></tr><tr><td align="left"><code class="filename">climits</code></td><td align="left"><code class="filename">clocale</code></td><td align="left"><code class="filename">cmath</code></td><td align="left"><code class="filename">csetjmp</code></td><td align="left"><code class="filename">csignal</code></td></tr><tr><td align="left"><code class="filename">cstdarg</code></td><td align="left"><code class="filename">cstddef</code></td><td align="left"><code class="filename">cstdio</code></td><td align="left"><code class="filename">cstdlib</code></td><td align="left"><code class="filename">cstring</code></td></tr><tr><td align="left"><code class="filename">ctime</code></td><td align="left"><code class="filename">cwchar</code></td><td align="left"><code class="filename">cwctype</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p>
 C++11 include files. These are only available in C++11 compilation
 mode, i.e. <code class="literal">-std=c++11</code> or <code class="literal">-std=gnu++11</code>.
-</p><p></p><div class="table"><a id="table.cxx11_headers"></a><p class="title"><strong>Table 3.4. C++ 2011 Library Headers</strong></p><div class="table-contents"><table summary="C++ 2011 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="filename">array</code></td><td align="left"><code class="filename">bitset</code></td><td align="left"><code class="filename">chrono</code></td><td align="left"><code class="filename">complex</code></td></tr><tr><td align="left"><code class="filename">condition_variable</code></td><td align="left"><code class="filename">deque</code></td><td align="left"><code class="filename">exception</code></td><td align="left"><code class="filename">forward_list</code></td><td align="left"><code class="filename">fstream</code></td></tr><tr><td align="left"><code class="filename">functional</code></td><td align="left"><code class="filename">future</code></td><td align="left"><code class="filename">initalizer_list</code></td><td align="left"><code class="filename">iomanip</code></td><td align="left"><code class="filename">ios</code></td></tr><tr><td align="left"><code class="filename">iosfwd</code></td><td align="left"><code class="filename">iostream</code></td><td align="left"><code class="filename">istream</code></td><td align="left"><code class="filename">iterator</code></td><td align="left"><code class="filename">limits</code></td></tr><tr><td align="left"><code class="filename">list</code></td><td align="left"><code class="filename">locale</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="filename">memory</code></td><td align="left"><code class="filename">mutex</code></td></tr><tr><td align="left"><code class="filename">new</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="filename">ostream</code></td><td align="left"><code class="filename">queue</code></td><td align="left"><code class="filename">random</code></td></tr><tr><td align="left"><code class="filename">ratio</code></td><td align="left"><code class="filename">regex</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="filename">sstream</code></td><td align="left"><code class="filename">stack</code></td></tr><tr><td align="left"><code class="filename">stdexcept</code></td><td align="left"><code class="filename">streambuf</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="filename">system_error</code></td><td align="left"><code class="filename">thread</code></td></tr><tr><td align="left"><code class="filename">tuple</code></td><td align="left"><code class="filename">type_traits</code></td><td align="left"><code class="filename">typeinfo</code></td><td align="left"><code class="filename">unordered_map</code></td><td align="left"><code class="filename">unordered_set</code></td></tr><tr><td align="left"><code class="filename">utility</code></td><td align="left"><code class="filename">valarray</code></td><td align="left"><code class="filename">vector</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.cxx11_cheaders"></a><p class="title"><strong>Table 3.5. C++ 2011 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table summary="C++ 2011 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">cassert</code></td><td align="left"><code class="filename">ccomplex</code></td><td align="left"><code class="filename">cctype</code></td><td align="left"><code class="filename">cerrno</code></td><td align="left"><code class="filename">cfenv</code></td></tr><tr><td align="left"><code class="filename">cfloat</code></td><td align="left"><code class="filename">cinttypes</code></td><td align="left"><code class="filename">ciso646</code></td><td align="left"><code class="filename">climits</code></td><td align="left"><code class="filename">clocale</code></td></tr><tr><td align="left"><code class="filename">cmath</code></td><td align="left"><code class="filename">csetjmp</code></td><td align="left"><code class="filename">csignal</code></td><td align="left"><code class="filename">cstdarg</code></td><td align="left"><code class="filename">cstdbool</code></td></tr><tr><td align="left"><code class="filename">cstddef</code></td><td align="left"><code class="filename">cstdint</code></td><td align="left"><code class="filename">cstdlib</code></td><td align="left"><code class="filename">cstdio</code></td><td align="left"><code class="filename">cstring</code></td></tr><tr><td align="left"><code class="filename">ctgmath</code></td><td align="left"><code class="filename">ctime</code></td><td align="left"><code class="filename">cuchar</code></td><td align="left"><code class="filename">cwchar</code></td><td align="left"><code class="filename">cwctype</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+</p><p></p><div class="table"><a id="table.cxx11_headers"></a><p class="title"><strong>Table 3.4. C++ 2011 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ 2011 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">algorithm</code></td><td align="left"><code class="filename">array</code></td><td align="left"><code class="filename">bitset</code></td><td align="left"><code class="filename">chrono</code></td><td align="left"><code class="filename">complex</code></td></tr><tr><td align="left"><code class="filename">condition_variable</code></td><td align="left"><code class="filename">deque</code></td><td align="left"><code class="filename">exception</code></td><td align="left"><code class="filename">forward_list</code></td><td align="left"><code class="filename">fstream</code></td></tr><tr><td align="left"><code class="filename">functional</code></td><td align="left"><code class="filename">future</code></td><td align="left"><code class="filename">initalizer_list</code></td><td align="left"><code class="filename">iomanip</code></td><td align="left"><code class="filename">ios</code></td></tr><tr><td align="left"><code class="filename">iosfwd</code></td><td align="left"><code class="filename">iostream</code></td><td align="left"><code class="filename">istream</code></td><td align="left"><code class="filename">iterator</code></td><td align="left"><code class="filename">limits</code></td></tr><tr><td align="left"><code class="filename">list</code></td><td align="left"><code class="filename">locale</code></td><td align="left"><code class="filename">map</code></td><td align="left"><code class="filename">memory</code></td><td align="left"><code class="filename">mutex</code></td></tr><tr><td align="left"><code class="filename">new</code></td><td align="left"><code class="filename">numeric</code></td><td align="left"><code class="filename">ostream</code></td><td align="left"><code class="filename">queue</code></td><td align="left"><code class="filename">random</code></td></tr><tr><td align="left"><code class="filename">ratio</code></td><td align="left"><code class="filename">regex</code></td><td align="left"><code class="filename">set</code></td><td align="left"><code class="filename">sstream</code></td><td align="left"><code class="filename">stack</code></td></tr><tr><td align="left"><code class="filename">stdexcept</code></td><td align="left"><code class="filename">streambuf</code></td><td align="left"><code class="filename">string</code></td><td align="left"><code class="filename">system_error</code></td><td align="left"><code class="filename">thread</code></td></tr><tr><td align="left"><code class="filename">tuple</code></td><td align="left"><code class="filename">type_traits</code></td><td align="left"><code class="filename">typeinfo</code></td><td align="left"><code class="filename">unordered_map</code></td><td align="left"><code class="filename">unordered_set</code></td></tr><tr><td align="left"><code class="filename">utility</code></td><td align="left"><code class="filename">valarray</code></td><td align="left"><code class="filename">vector</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.cxx11_cheaders"></a><p class="title"><strong>Table 3.5. C++ 2011 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table class="table" summary="C++ 2011 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">cassert</code></td><td align="left"><code class="filename">ccomplex</code></td><td align="left"><code class="filename">cctype</code></td><td align="left"><code class="filename">cerrno</code></td><td align="left"><code class="filename">cfenv</code></td></tr><tr><td align="left"><code class="filename">cfloat</code></td><td align="left"><code class="filename">cinttypes</code></td><td align="left"><code class="filename">ciso646</code></td><td align="left"><code class="filename">climits</code></td><td align="left"><code class="filename">clocale</code></td></tr><tr><td align="left"><code class="filename">cmath</code></td><td align="left"><code class="filename">csetjmp</code></td><td align="left"><code class="filename">csignal</code></td><td align="left"><code class="filename">cstdarg</code></td><td align="left"><code class="filename">cstdbool</code></td></tr><tr><td align="left"><code class="filename">cstddef</code></td><td align="left"><code class="filename">cstdint</code></td><td align="left"><code class="filename">cstdlib</code></td><td align="left"><code class="filename">cstdio</code></td><td align="left"><code class="filename">cstring</code></td></tr><tr><td align="left"><code class="filename">ctgmath</code></td><td align="left"><code class="filename">ctime</code></td><td align="left"><code class="filename">cuchar</code></td><td align="left"><code class="filename">cwchar</code></td><td align="left"><code class="filename">cwctype</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
   In addition, TR1 includes as:
-</p><div class="table"><a id="table.tr1_headers"></a><p class="title"><strong>Table 3.6. C++ TR 1 Library Headers</strong></p><div class="table-contents"><table summary="C++ TR 1 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">tr1/array</code></td><td align="left"><code class="filename">tr1/complex</code></td><td align="left"><code class="filename">tr1/memory</code></td><td align="left"><code class="filename">tr1/functional</code></td><td align="left"><code class="filename">tr1/random</code></td></tr><tr><td align="left"><code class="filename">tr1/regex</code></td><td align="left"><code class="filename">tr1/tuple</code></td><td align="left"><code class="filename">tr1/type_traits</code></td><td align="left"><code class="filename">tr1/unordered_map</code></td><td align="left"><code class="filename">tr1/unordered_set</code></td></tr><tr><td align="left"><code class="filename">tr1/utility</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.tr1_cheaders"></a><p class="title"><strong>Table 3.7. C++ TR 1 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table summary="C++ TR 1 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">tr1/ccomplex</code></td><td align="left"><code class="filename">tr1/cfenv</code></td><td align="left"><code class="filename">tr1/cfloat</code></td><td align="left"><code class="filename">tr1/cmath</code></td><td align="left"><code class="filename">tr1/cinttypes</code></td></tr><tr><td align="left"><code class="filename">tr1/climits</code></td><td align="left"><code class="filename">tr1/cstdarg</code></td><td align="left"><code class="filename">tr1/cstdbool</code></td><td align="left"><code class="filename">tr1/cstdint</code></td><td align="left"><code class="filename">tr1/cstdio</code></td></tr><tr><td align="left"><code class="filename">tr1/cstdlib</code></td><td align="left"><code class="filename">tr1/ctgmath</code></td><td align="left"><code class="filename">tr1/ctime</code></td><td align="left"><code class="filename">tr1/cwchar</code></td><td align="left"><code class="filename">tr1/cwctype</code></td></tr></tbody></table></div></div><br class="table-break" /><p>Decimal floating-point arithmetic is available if the C++
+</p><div class="table"><a id="table.tr1_headers"></a><p class="title"><strong>Table 3.6. C++ TR 1 Library Headers</strong></p><div class="table-contents"><table class="table" summary="C++ TR 1 Library Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">tr1/array</code></td><td align="left"><code class="filename">tr1/complex</code></td><td align="left"><code class="filename">tr1/memory</code></td><td align="left"><code class="filename">tr1/functional</code></td><td align="left"><code class="filename">tr1/random</code></td></tr><tr><td align="left"><code class="filename">tr1/regex</code></td><td align="left"><code class="filename">tr1/tuple</code></td><td align="left"><code class="filename">tr1/type_traits</code></td><td align="left"><code class="filename">tr1/unordered_map</code></td><td align="left"><code class="filename">tr1/unordered_set</code></td></tr><tr><td align="left"><code class="filename">tr1/utility</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.tr1_cheaders"></a><p class="title"><strong>Table 3.7. C++ TR 1 Library Headers for C Library Facilities</strong></p><div class="table-contents"><table class="table" summary="C++ TR 1 Library Headers for C Library Facilities" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">tr1/ccomplex</code></td><td align="left"><code class="filename">tr1/cfenv</code></td><td align="left"><code class="filename">tr1/cfloat</code></td><td align="left"><code class="filename">tr1/cmath</code></td><td align="left"><code class="filename">tr1/cinttypes</code></td></tr><tr><td align="left"><code class="filename">tr1/climits</code></td><td align="left"><code class="filename">tr1/cstdarg</code></td><td align="left"><code class="filename">tr1/cstdbool</code></td><td align="left"><code class="filename">tr1/cstdint</code></td><td align="left"><code class="filename">tr1/cstdio</code></td></tr><tr><td align="left"><code class="filename">tr1/cstdlib</code></td><td align="left"><code class="filename">tr1/ctgmath</code></td><td align="left"><code class="filename">tr1/ctime</code></td><td align="left"><code class="filename">tr1/cwchar</code></td><td align="left"><code class="filename">tr1/cwctype</code></td></tr></tbody></table></div></div><br class="table-break" /><p>Decimal floating-point arithmetic is available if the C++
 compiler supports scalar decimal floating-point types defined via
 <code class="code">__attribute__((mode(SD|DD|LD)))</code>.
-</p><div class="table"><a id="table.decfp_headers"></a><p class="title"><strong>Table 3.8. C++ TR 24733 Decimal Floating-Point Header</strong></p><div class="table-contents"><table summary="C++ TR 24733 Decimal Floating-Point Header" border="1"><colgroup><col align="left" class="c1" /></colgroup><tbody><tr><td align="left"><code class="filename">decimal/decimal</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+</p><div class="table"><a id="table.decfp_headers"></a><p class="title"><strong>Table 3.8. C++ TR 24733 Decimal Floating-Point Header</strong></p><div class="table-contents"><table class="table" summary="C++ TR 24733 Decimal Floating-Point Header" border="1"><colgroup><col align="left" class="c1" /></colgroup><tbody><tr><td align="left"><code class="filename">decimal/decimal</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
   Also included are files for the C++ ABI interface:
-</p><div class="table"><a id="table.abi_headers"></a><p class="title"><strong>Table 3.9. C++ ABI Headers</strong></p><div class="table-contents"><table summary="C++ ABI Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><tbody><tr><td align="left"><code class="filename">cxxabi.h</code></td><td align="left"><code class="filename">cxxabi_forced.h</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
+</p><div class="table"><a id="table.abi_headers"></a><p class="title"><strong>Table 3.9. C++ ABI Headers</strong></p><div class="table-contents"><table class="table" summary="C++ ABI Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><tbody><tr><td align="left"><code class="filename">cxxabi.h</code></td><td align="left"><code class="filename">cxxabi_forced.h</code></td></tr></tbody></table></div></div><br class="table-break" /><p>
   And a large variety of extensions.
-</p><div class="table"><a id="table.ext_headers"></a><p class="title"><strong>Table 3.10. Extension Headers</strong></p><div class="table-contents"><table summary="Extension Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">ext/algorithm</code></td><td align="left"><code class="filename">ext/atomicity.h</code></td><td align="left"><code class="filename">ext/array_allocator.h</code></td><td align="left"><code class="filename">ext/bitmap_allocator.h</code></td><td align="left"><code class="filename">ext/cast.h</code></td></tr><tr><td align="left"><code class="filename">ext/codecvt_specializations.h</code></td><td align="left"><code class="filename">ext/concurrence.h</code></td><td align="left"><code class="filename">ext/debug_allocator.h</code></td><td align="left"><code class="filename">ext/enc_filebuf.h</code></td><td align="left"><code class="filename">ext/extptr_allocator.h</code></td></tr><tr><td align="left"><code class="filename">ext/functional</code></td><td align="left"><code class="filename">ext/iterator</code></td><td align="left"><code class="filename">ext/malloc_allocator.h</code></td><td align="left"><code class="filename">ext/memory</code></td><td align="left"><code class="filename">ext/mt_allocator.h</code></td></tr><tr><td align="left"><code class="filename">ext/new_allocator.h</code></td><td align="left"><code class="filename">ext/numeric</code></td><td align="left"><code class="filename">ext/numeric_traits.h</code></td><td align="left"><code class="filename">ext/pb_ds/assoc_container.h</code></td><td align="left"><code class="filename">ext/pb_ds/priority_queue.h</code></td></tr><tr><td align="left"><code class="filename">ext/pod_char_traits.h</code></td><td align="left"><code class="filename">ext/pool_allocator.h</code></td><td align="left"><code class="filename">ext/rb_tree</code></td><td align="left"><code class="filename">ext/rope</code></td><td align="left"><code class="filename">ext/slist</code></td></tr><tr><td align="left"><code class="filename">ext/stdio_filebuf.h</code></td><td align="left"><code class="filename">ext/stdio_sync_filebuf.h</code></td><td align="left"><code class="filename">ext/throw_allocator.h</code></td><td align="left"><code class="filename">ext/typelist.h</code></td><td align="left"><code class="filename">ext/type_traits.h</code></td></tr><tr><td align="left"><code class="filename">ext/vstring.h</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.debug_headers"></a><p class="title"><strong>Table 3.11. Extension Debug Headers</strong></p><div class="table-contents"><table summary="Extension Debug Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">debug/bitset</code></td><td align="left"><code class="filename">debug/deque</code></td><td align="left"><code class="filename">debug/list</code></td><td align="left"><code class="filename">debug/map</code></td><td align="left"><code class="filename">debug/set</code></td></tr><tr><td align="left"><code class="filename">debug/string</code></td><td align="left"><code class="filename">debug/unordered_map</code></td><td align="left"><code class="filename">debug/unordered_set</code></td><td align="left"><code class="filename">debug/vector</code></td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.profile_headers"></a><p class="title"><strong>Table 3.12. Extension Profile Headers</strong></p><div class="table-contents"><table summary="Extension Profile Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><tbody><tr><td align="left"><code class="filename">profile/bitset</code></td><td align="left"><code class="filename">profile/deque</code></td><td align="left"><code class="filename">profile/list</code></td><td align="left"><code class="filename">profile/map</code></td></tr><tr><td align="left"><code class="filename">profile/set</code></td><td align="left"><code class="filename">profile/unordered_map</code></td><td align="left"><code class="filename">profile/unordered_set</code></td><td align="left"><code class="filename">profile/vector</code></td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.parallel_headers"></a><p class="title"><strong>Table 3.13. Extension Parallel Headers</strong></p><div class="table-contents"><table summary="Extension Parallel Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><tbody><tr><td align="left"><code class="filename">parallel/algorithm</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr></tbody></table></div></div><br class="table-break" /></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.headers.mixing"></a>Mixing Headers</h3></div></div></div><p> A few simple rules.
+</p><div class="table"><a id="table.ext_headers"></a><p class="title"><strong>Table 3.10. Extension Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">ext/algorithm</code></td><td align="left"><code class="filename">ext/atomicity.h</code></td><td align="left"><code class="filename">ext/array_allocator.h</code></td><td align="left"><code class="filename">ext/bitmap_allocator.h</code></td><td align="left"><code class="filename">ext/cast.h</code></td></tr><tr><td align="left"><code class="filename">ext/codecvt_specializations.h</code></td><td align="left"><code class="filename">ext/concurrence.h</code></td><td align="left"><code class="filename">ext/debug_allocator.h</code></td><td align="left"><code class="filename">ext/enc_filebuf.h</code></td><td align="left"><code class="filename">ext/extptr_allocator.h</code></td></tr><tr><td align="left"><code class="filename">ext/functional</code></td><td align="left"><code class="filename">ext/iterator</code></td><td align="left"><code class="filename">ext/malloc_allocator.h</code></td><td align="left"><code class="filename">ext/memory</code></td><td align="left"><code class="filename">ext/mt_allocator.h</code></td></tr><tr><td align="left"><code class="filename">ext/new_allocator.h</code></td><td align="left"><code class="filename">ext/numeric</code></td><td align="left"><code class="filename">ext/numeric_traits.h</code></td><td align="left"><code class="filename">ext/pb_ds/assoc_container.h</code></td><td align="left"><code class="filename">ext/pb_ds/priority_queue.h</code></td></tr><tr><td align="left"><code class="filename">ext/pod_char_traits.h</code></td><td align="left"><code class="filename">ext/pool_allocator.h</code></td><td align="left"><code class="filename">ext/rb_tree</code></td><td align="left"><code class="filename">ext/rope</code></td><td align="left"><code class="filename">ext/slist</code></td></tr><tr><td align="left"><code class="filename">ext/stdio_filebuf.h</code></td><td align="left"><code class="filename">ext/stdio_sync_filebuf.h</code></td><td align="left"><code class="filename">ext/throw_allocator.h</code></td><td align="left"><code class="filename">ext/typelist.h</code></td><td align="left"><code class="filename">ext/type_traits.h</code></td></tr><tr><td align="left"><code class="filename">ext/vstring.h</code></td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.debug_headers"></a><p class="title"><strong>Table 3.11. Extension Debug Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Debug Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /><col align="left" class="c5" /></colgroup><tbody><tr><td align="left"><code class="filename">debug/bitset</code></td><td align="left"><code class="filename">debug/deque</code></td><td align="left"><code class="filename">debug/list</code></td><td align="left"><code class="filename">debug/map</code></td><td align="left"><code class="filename">debug/set</code></td></tr><tr><td align="left"><code class="filename">debug/string</code></td><td align="left"><code class="filename">debug/unordered_map</code></td><td align="left"><code class="filename">debug/unordered_set</code></td><td align="left"><code class="filename">debug/vector</code></td><td class="auto-generated"> </td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.profile_headers"></a><p class="title"><strong>Table 3.12. Extension Profile Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Profile Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /><col align="left" class="c3" /><col align="left" class="c4" /></colgroup><tbody><tr><td align="left"><code class="filename">profile/bitset</code></td><td align="left"><code class="filename">profile/deque</code></td><td align="left"><code class="filename">profile/list</code></td><td align="left"><code class="filename">profile/map</code></td></tr><tr><td align="left"><code class="filename">profile/set</code></td><td align="left"><code class="filename">profile/unordered_map</code></td><td align="left"><code class="filename">profile/unordered_set</code></td><td align="left"><code class="filename">profile/vector</code></td></tr></tbody></table></div></div><br class="table-break" /><p></p><div class="table"><a id="table.parallel_headers"></a><p class="title"><strong>Table 3.13. Extension Parallel Headers</strong></p><div class="table-contents"><table class="table" summary="Extension Parallel Headers" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><tbody><tr><td align="left"><code class="filename">parallel/algorithm</code></td><td align="left"><code class="filename">parallel/numeric</code></td></tr></tbody></table></div></div><br class="table-break" /></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.headers.mixing"></a>Mixing Headers</h3></div></div></div><p> A few simple rules.
 </p><p>First, mixing different dialects of the standard headers is not
 possible. It's an all-or-nothing affair. Thus, code like
 </p><pre class="programlisting">
Index: libstdc++-v3/doc/html/manual/using_namespaces.html
===================================================================
--- libstdc++-v3/doc/html/manual/using_namespaces.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/using_namespaces.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Namespaces</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_dual_abi.html" title="Dual ABI" /><link rel="next" href="using_dynamic_or_shared.html" title="Linking" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Namespaces</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_dual_abi.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_dynamic_or_shared.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.namespaces"></a>Namespaces</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.namespaces.all"></a>Available Namespaces</h3></div></div></div><p> There are three main namespaces.
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Namespaces</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_dual_abi.html" title="Dual ABI" /><link rel="next" href="using_dynamic_or_shared.html" title="Linking" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Namespaces</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_dual_abi.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_dynamic_or_shared.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.namespaces"></a>Namespaces</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.intro.using.namespaces.all"></a>Available Namespaces</h3></div></div></div><p> There are three main namespaces.
 </p><div class="itemizedlist"><ul class="itemizedlist" style="list-style-type: disc; "><li class="listitem"><p>std</p><p>The ISO C++ standards specify that "all library entities are defined
 within namespace std." This includes namespaces nested
 within namespace <code class="code">std</code>, such as namespace
Index: libstdc++-v3/doc/html/manual/errno.html
===================================================================
--- libstdc++-v3/doc/html/manual/errno.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/errno.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Use of errno by the library</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="diagnostics.html" title="Chapter 5.  Diagnostics" /><link rel="prev" href="diagnostics.html" title="Chapter 5.  Diagnostics" /><link rel="next" href="concept_checking.html" title="Concept Checking" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Use of errno by the library</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="diagnostics.html">Prev</a> </td><th width="60%" align="center">Chapter 5. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Use of errno by the library</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="diagnostics.html" title="Chapter 5.  Diagnostics" /><link rel="prev" href="diagnostics.html" title="Chapter 5.  Diagnostics" /><link rel="next" href="concept_checking.html" title="Concept Checking" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Use of errno by the library</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="diagnostics.html">Prev</a> </td><th width="60%" align="center">Chapter 5. 
   Diagnostics
   
 </th><td width="20%" align="right"> <a accesskey="n" href="concept_checking.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.diagnostics.errno"></a>Use of errno by the library</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/debug.html
===================================================================
--- libstdc++-v3/doc/html/manual/debug.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/debug.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Debugging Support</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_exceptions.html" title="Exceptions" /><link rel="next" href="std_contents.html" title="Part II.  Standard Contents" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Debugging Support</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_exceptions.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="std_contents.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.debug"></a>Debugging Support</h2></div></div></div><p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Debugging Support</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_exceptions.html" title="Exceptions" /><link rel="next" href="std_contents.html" title="Part II.  Standard Contents" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Debugging Support</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_exceptions.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="std_contents.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.debug"></a>Debugging Support</h2></div></div></div><p>
   There are numerous things that can be done to improve the ease with
   which C++ binaries are debugged when using the GNU tool chain. Here
   are some of them.
Index: libstdc++-v3/doc/html/manual/localization.html
===================================================================
--- libstdc++-v3/doc/html/manual/localization.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/localization.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 8.  Localization</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="strings.html" title="Chapter 7.  Strings" /><link rel="next" href="facets.html" title="Facets" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 8. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 8.  Localization</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="strings.html" title="Chapter 7.  Strings" /><link rel="next" href="facets.html" title="Facets" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 8. 
   Localization
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="strings.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/ext_algorithms.html
===================================================================
--- libstdc++-v3/doc/html/manual/ext_algorithms.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/ext_algorithms.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 25. Algorithms</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_utilities.html" title="Chapter 24. Utilities" /><link rel="next" href="ext_numerics.html" title="Chapter 26. Numerics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 25. Algorithms</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_utilities.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 25. Algorithms</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_utilities.html" title="Chapter 24. Utilities" /><link rel="next" href="ext_numerics.html" title="Chapter 26. Numerics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 25. Algorithms</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_utilities.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="ext_numerics.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.algorithms"></a>Chapter 25. Algorithms</h2></div></div></div><p>25.1.6 (count, count_if) is extended with two more versions of count
Index: libstdc++-v3/doc/html/manual/debug_mode.html
===================================================================
--- libstdc++-v3/doc/html/manual/debug_mode.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/debug_mode.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 17. Debug Mode</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_compile_checks.html" title="Chapter 16. Compile Time Checks" /><link rel="next" href="debug_mode_semantics.html" title="Semantics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 17. Debug Mode</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_compile_checks.html">Prev</a> </td><th width="60%" align="center">Part III. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 17. Debug Mode</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, debug" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="extensions.html" title="Part III.  Extensions" /><link rel="prev" href="ext_compile_checks.html" title="Chapter 16. Compile Time Checks" /><link rel="next" href="debug_mode_semantics.html" title="Semantics" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 17. Debug Mode</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="ext_compile_checks.html">Prev</a> </td><th width="60%" align="center">Part III. 
   Extensions
   
 </th><td width="20%" align="right"> <a accesskey="n" href="debug_mode_semantics.html">Next</a></td></tr></table><hr /></div><div class="chapter"><div class="titlepage"><div><div><h2 class="title"><a id="manual.ext.debug_mode"></a>Chapter 17. Debug Mode</h2></div></div></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="section"><a href="debug_mode.html#manual.ext.debug_mode.intro">Intro</a></span></dt><dt><span class="section"><a href="debug_mode_semantics.html">Semantics</a></span></dt><dt><span class="section"><a href="debug_mode_using.html">Using</a></span></dt><dd><dl><dt><span class="section"><a href="debug_mode_using.html#debug_mode.using.mode">Using the Debug Mode</a></span></dt><dt><span class="section"><a href="debug_mode_using.html#debug_mode.using.specific">Using a Specific Debug Container</a></span></dt></dl></dd><dt><span class="section"><a href="debug_mode_design.html">Design</a></span></dt><dd><dl><dt><span class="section"><a href="debug_mode_design.html#debug_mode.design.goals">Goals</a></span></dt><dt><span class="section"><a href="debug_mode_design.html#debug_mode.design.methods">Methods</a></span></dt><dd><dl><dt><span class="section"><a href="debug_mode_design.html#debug_mode.design.methods.wrappers">The Wrapper Model</a></span></dt><dd><dl><dt><span class="section"><a href="debug_mode_design.html#debug_mode.design.methods.safe_iter">Safe Iterators</a></span></dt><dt><span class="section"><a href="debug_mode_design.html#debug_mode.design.methods.safe_seq">Safe Sequences (Containers)</a></span></dt></dl></dd><dt><span class="section"><a href="debug_mode_design.html#debug_mode.design.methods.precond">Precondition Checking</a></span></dt><dt><span class="section"><a href="debug_mode_design.html#debug_mode.design.methods.coexistence">Release- and debug-mode coexistence</a></span></dt><dd><dl><dt><span class="section"><a href="debug_mode_design.html#methods.coexistence.compile">Compile-time coexistence of release- and debug-mode components</a></span></dt><dt><span class="section"><a href="debug_mode_design.html#methods.coexistence.link">Link- and run-time coexistence of release- and
Index: libstdc++-v3/doc/html/manual/profile_mode_design.html
===================================================================
--- libstdc++-v3/doc/html/manual/profile_mode_design.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/profile_mode_design.html	(.../branches/gcc-7-branch)
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="next" href="profile_mode_api.html" title="Extensions for Custom Containers" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_api.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.design"></a>Design</h2></div></div></div><p>
-</p><div class="table"><a id="table.profile_code_loc"></a><p class="title"><strong>Table 19.1. Profile Code Location</strong></p><div class="table-contents"><table summary="Profile Code Location" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">Code Location</th><th align="left">Use</th></tr></thead><tbody><tr><td align="left"><code class="code">libstdc++-v3/include/std/*</code></td><td align="left">Preprocessor code to redirect to profile extension headers.</td></tr><tr><td align="left"><code class="code">libstdc++-v3/include/profile/*</code></td><td align="left">Profile extension public headers (map, vector, ...).</td></tr><tr><td align="left"><code class="code">libstdc++-v3/include/profile/impl/*</code></td><td align="left">Profile extension internals.  Implementation files are
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Design</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="C++, library, profile" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="prev" href="profile_mode.html" title="Chapter 19. Profile Mode" /><link rel="next" href="profile_mode_api.html" title="Extensions for Custom Containers" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Design</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="profile_mode.html">Prev</a> </td><th width="60%" align="center">Chapter 19. Profile Mode</th><td width="20%" align="right"> <a accesskey="n" href="profile_mode_api.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.ext.profile_mode.design"></a>Design</h2></div></div></div><p>
+</p><div class="table"><a id="table.profile_code_loc"></a><p class="title"><strong>Table 19.1. Profile Code Location</strong></p><div class="table-contents"><table class="table" summary="Profile Code Location" border="1"><colgroup><col align="left" class="c1" /><col align="left" class="c2" /></colgroup><thead><tr><th align="left">Code Location</th><th align="left">Use</th></tr></thead><tbody><tr><td align="left"><code class="code">libstdc++-v3/include/std/*</code></td><td align="left">Preprocessor code to redirect to profile extension headers.</td></tr><tr><td align="left"><code class="code">libstdc++-v3/include/profile/*</code></td><td align="left">Profile extension public headers (map, vector, ...).</td></tr><tr><td align="left"><code class="code">libstdc++-v3/include/profile/impl/*</code></td><td align="left">Profile extension internals.  Implementation files are
      only included from <code class="code">impl/profiler.h</code>, which is the only
      file included from the public headers.</td></tr></tbody></table></div></div><br class="table-break" /><p>
 </p><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="manual.ext.profile_mode.design.wrapper"></a>Wrapper Model</h3></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/using_concurrency.html
===================================================================
--- libstdc++-v3/doc/html/manual/using_concurrency.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/using_concurrency.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Concurrency</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_dynamic_or_shared.html" title="Linking" /><link rel="next" href="using_exceptions.html" title="Exceptions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Concurrency</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_dynamic_or_shared.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_exceptions.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.concurrency"></a>Concurrency</h2></div></div></div><p>This section discusses issues surrounding the proper compilation
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Concurrency</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="using.html" title="Chapter 3. Using" /><link rel="prev" href="using_dynamic_or_shared.html" title="Linking" /><link rel="next" href="using_exceptions.html" title="Exceptions" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Concurrency</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="using_dynamic_or_shared.html">Prev</a> </td><th width="60%" align="center">Chapter 3. Using</th><td width="20%" align="right"> <a accesskey="n" href="using_exceptions.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="manual.intro.using.concurrency"></a>Concurrency</h2></div></div></div><p>This section discusses issues surrounding the proper compilation
       of multithreaded applications which use the Standard C++
       library.  This information is GCC-specific since the C++
       standard does not address matters of multithreaded applications.
Index: libstdc++-v3/doc/html/manual/mt_allocator_impl.html
===================================================================
--- libstdc++-v3/doc/html/manual/mt_allocator_impl.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/mt_allocator_impl.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Implementation</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="prev" href="mt_allocator_design.html" title="Design Issues" /><link rel="next" href="mt_allocator_ex_single.html" title="Single Thread Example" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Implementation</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator_design.html">Prev</a> </td><th width="60%" align="center">Chapter 20. The mt_allocator</th><td width="20%" align="right"> <a accesskey="n" href="mt_allocator_ex_single.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.mt.impl"></a>Implementation</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="allocator.mt.tune"></a>Tunable Parameters</h3></div></div></div><p>Certain allocation parameters can be modified, or tuned. There
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Implementation</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, allocator" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="mt_allocator.html" title="Chapter 20. The mt_allocator" /><link rel="prev" href="mt_allocator_design.html" title="Design Issues" /><link rel="next" href="mt_allocator_ex_single.html" title="Single Thread Example" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Implementation</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="mt_allocator_design.html">Prev</a> </td><th width="60%" align="center">Chapter 20. The mt_allocator</th><td width="20%" align="right"> <a accesskey="n" href="mt_allocator_ex_single.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="allocator.mt.impl"></a>Implementation</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="allocator.mt.tune"></a>Tunable Parameters</h3></div></div></div><p>Certain allocation parameters can be modified, or tuned. There
 exists a nested <code class="code">struct __pool_base::_Tune</code> that contains all
 these parameters, which include settings for
 </p><div class="itemizedlist"><ul class="itemizedlist" style="list-style-type: disc; "><li class="listitem"><p>Alignment</p></li><li class="listitem"><p>Maximum bytes before calling <code class="code">::operator new</code> directly</p></li><li class="listitem"><p>Minimum bytes</p></li><li class="listitem"><p>Size of underlying global allocations</p></li><li class="listitem"><p>Maximum number of supported threads</p></li><li class="listitem"><p>Migration of deallocations to the global free list</p></li><li class="listitem"><p>Shunt for global <code class="code">new</code> and <code class="code">delete</code></p></li></ul></div><p>Adjusting parameters for a given instance of an allocator can only
Index: libstdc++-v3/doc/html/manual/appendix_gfdl.html
===================================================================
--- libstdc++-v3/doc/html/manual/appendix_gfdl.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/appendix_gfdl.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix E. GNU Free Documentation License</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="appendix_gpl.html" title="Appendix D.  GNU General Public License version 3" /><link rel="next" href="../bk02.html" title="" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix E. GNU Free Documentation License</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="appendix_gpl.html">Prev</a> </td><th width="60%" align="center">Part IV. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix E. GNU Free Documentation License</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="appendix_gpl.html" title="Appendix D.  GNU General Public License version 3" /><link rel="next" href="../bk02.html" title="" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix E. GNU Free Documentation License</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="appendix_gpl.html">Prev</a> </td><th width="60%" align="center">Part IV. 
   Appendices
 </th><td width="20%" align="right"> <a accesskey="n" href="../bk02.html">Next</a></td></tr></table><hr /></div><div class="appendix"><div class="titlepage"><div><div><h1 class="title"><a id="appendix.gfdl-1.3"></a>GNU Free Documentation License</h1></div></div></div><p>Version 1.3, 3 November 2008</p><p>
     Copyright © 2000, 2001, 2002, 2007, 2008
Index: libstdc++-v3/doc/html/manual/containers.html
===================================================================
--- libstdc++-v3/doc/html/manual/containers.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/containers.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 9.  Containers</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="facets.html" title="Facets" /><link rel="next" href="associative.html" title="Associative" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 9. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 9.  Containers</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="facets.html" title="Facets" /><link rel="next" href="associative.html" title="Associative" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 9. 
   Containers
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="facets.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/io.html
===================================================================
--- libstdc++-v3/doc/html/manual/io.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/io.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 13.  Input and Output</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="numerics_and_c.html" title="Interacting with C" /><link rel="next" href="streambufs.html" title="Stream Buffers" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 13. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 13.  Input and Output</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="numerics_and_c.html" title="Interacting with C" /><link rel="next" href="streambufs.html" title="Stream Buffers" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 13. 
   Input and Output
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="numerics_and_c.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/html/manual/index.html
===================================================================
--- libstdc++-v3/doc/html/manual/index.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/index.html	(.../branches/gcc-7-branch)
@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>The GNU C++ Library Manual</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="../index.html" title="The GNU C++ Library" /><link rel="prev" href="../index.html" title="The GNU C++ Library" /><link rel="next" href="intro.html" title="Part I.  Introduction" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">The GNU C++ Library Manual</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="../index.html">Prev</a> </td><th width="60%" align="center"> </th><td width="20%" align="right"> <a accesskey="n" href="intro.html">Next</a></td></tr></table><hr /></div><div class="book"><div class="titlepage"><div><div><h1 class="title"><a id="manual"></a>The GNU C++ Library Manual</h1></div><div><div class="authorgroup"><div class="author"><h3 class="author"><span class="firstname"></span> <span class="surname"></span></h3></div><div class="author"><h3 class="author"><span class="firstname">Paolo</span> <span class="surname">Carlini</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Phil</span> <span class="surname">Edwards</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Doug</span> <span class="surname">Gregor</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Benjamin</span> <span class="surname">Kosnik</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Dhruv</span> <span class="surname">Matani</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Jason</span> <span class="surname">Merrill</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Mark</span> <span class="surname">Mitchell</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Nathan</span> <span class="surname">Myers</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Felix</span> <span class="surname">Natter</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Stefan</span> <span class="surname">Olsson</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Silvius</span> <span class="surname">Rus</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Johannes</span> <span class="surname">Singler</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Ami</span> <span class="surname">Tavory</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Jonathan</span> <span class="surname">Wakely</span></h3></div></div></div><div><p class="copyright">Copyright © 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>The GNU C++ Library Manual</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="../index.html" title="The GNU C++ Library" /><link rel="prev" href="../index.html" title="The GNU C++ Library" /><link rel="next" href="intro.html" title="Part I.  Introduction" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">The GNU C++ Library Manual</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="../index.html">Prev</a> </td><th width="60%" align="center"> </th><td width="20%" align="right"> <a accesskey="n" href="intro.html">Next</a></td></tr></table><hr /></div><div class="book"><div class="titlepage"><div><div><h1 class="title"><a id="manual"></a>The GNU C++ Library Manual</h1></div><div><div class="authorgroup"><div class="author"><h3 class="author"><span class="firstname"></span> <span class="surname"></span></h3></div><div class="author"><h3 class="author"><span class="firstname">Paolo</span> <span class="surname">Carlini</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Phil</span> <span class="surname">Edwards</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Doug</span> <span class="surname">Gregor</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Benjamin</span> <span class="surname">Kosnik</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Dhruv</span> <span class="surname">Matani</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Jason</span> <span class="surname">Merrill</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Mark</span> <span class="surname">Mitchell</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Nathan</span> <span class="surname">Myers</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Felix</span> <span class="surname">Natter</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Stefan</span> <span class="surname">Olsson</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Silvius</span> <span class="surname">Rus</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Johannes</span> <span class="surname">Singler</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Ami</span> <span class="surname">Tavory</span></h3></div><div class="author"><h3 class="author"><span class="firstname">Jonathan</span> <span class="surname">Wakely</span></h3></div></div></div><div><p class="copyright">Copyright © 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
       <a class="link" href="http://www.fsf.org" target="_top">FSF</a>
     </p></div></div><hr /></div><div class="toc"><p><strong>Table of Contents</strong></p><dl class="toc"><dt><span class="part"><a href="intro.html">I. 
   Introduction
   
-</a></span></dt><dd><dl><dt><span class="chapter"><a href="status.html">1. Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#manual.intro.status.iso">Implementation Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#status.iso.1998">C++ 1998/2003</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.1998.status">Implementation Status</a></span></dt><dt><span class="section"><a href="status.html#iso.1998.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2011">C++ 2011</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2011.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2014">C++ 2014</a></span></dt><dt><span class="section"><a href="status.html#status.iso.201z">C++ 201z</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2017.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr1">C++ TR1</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.tr1.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr24733">C++ TR 24733</a></span></dt></dl></dd><dt><span class="section"><a href="license.html">License</a></span></dt><dd><dl><dt><span class="section"><a href="license.html#manual.intro.status.license.gpl">The Code: GPL</a></span></dt><dt><span class="section"><a href="license.html#manual.intro.status.license.fdl">The Documentation: GPL, FDL</a></span></dt></dl></dd><dt><span class="section"><a href="bugs.html">Bugs</a></span></dt><dd><dl><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.impl">Implementation Bugs</a></span></dt><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.iso">Standard Bugs</a></span></dt></dl></dd></dl></dd><dt><span class="chapter"><a href="setup.html">2. Setup</a></span></dt><dd><dl><dt><span class="section"><a href="setup.html#manual.intro.setup.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="configure.html">Configure</a></span></dt><dt><span class="section"><a href="make.html">Make</a></span></dt></dl></dd><dt><span class="chapter"><a href="using.html">3. Using</a></span></dt><dd><dl><dt><span class="section"><a href="using.html#manual.intro.using.flags">Command Options</a></span></dt><dt><span class="section"><a href="using_headers.html">Headers</a></span></dt><dd><dl><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.all">Header Files</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.mixing">Mixing Headers</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.cheaders">The C Headers and <code class="code">namespace std</code></a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.pre">Precompiled Headers</a></span></dt></dl></dd><dt><span class="section"><a href="using_macros.html">Macros</a></span></dt><dt><span class="section"><a href="using_dual_abi.html">Dual ABI</a></span></dt><dd><dl><dt><span class="section"><a href="using_dual_abi.html#manual.intro.using.abi.trouble">Troubleshooting</a></span></dt></dl></dd><dt><span class="section"><a href="using_namespaces.html">Namespaces</a></span></dt><dd><dl><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.all">Available Namespaces</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.std">namespace std</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.comp">Using Namespace Composition</a></span></dt></dl></dd><dt><span class="section"><a href="using_dynamic_or_shared.html">Linking</a></span></dt><dd><dl><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.freestanding">Almost Nothing</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.dynamic">Finding Dynamic or Shared Libraries</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.experimental">Experimental Library Extensions</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html">Concurrency</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.thread_safety">Thread Safety</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.atomics">Atomics</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.io">IO</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#concurrency.io.structure">Structure</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.defaults">Defaults</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.future">Future</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.alt">Alternatives</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.containers">Containers</a></span></dt></dl></dd><dt><span class="section"><a href="using_exceptions.html">Exceptions</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.safety">Exception Safety</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.propagating">Exception Neutrality</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.no">Doing without</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.compat">Compatibility</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.c">With <code class="literal">C</code></a></span></dt><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.posix">With <code class="literal">POSIX</code> thread cancellation</a></span></dt></dl></dd></dl></dd><dt><span class="section"><a href="debug.html">Debugging Support</a></span></dt><dd><dl><dt><span class="section"><a href="debug.html#debug.compiler">Using <span class="command"><strong>g++</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.req">Debug Versions of Library Binary Files</a></span></dt><dt><span class="section"><a href="debug.html#debug.memory">Memory Leak Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.races">Data Race Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.gdb">Using <span class="command"><strong>gdb</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.exceptions">Tracking uncaught exceptions</a></span></dt><dt><span class="section"><a href="debug.html#debug.debug_mode">Debug Mode</a></span></dt><dt><span class="section"><a href="debug.html#debug.compile_time_checks">Compile Time Checking</a></span></dt><dt><span class="section"><a href="debug.html#debug.profile_mode">Profile-based Performance Analysis</a></span></dt></dl></dd></dl></dd></dl></dd><dt><span class="part"><a href="std_contents.html">II. 
+</a></span></dt><dd><dl><dt><span class="chapter"><a href="status.html">1. Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#manual.intro.status.iso">Implementation Status</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#status.iso.1998">C++ 1998/2003</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.1998.status">Implementation Status</a></span></dt><dt><span class="section"><a href="status.html#iso.1998.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2011">C++ 2011</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2011.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.2014">C++ 2014</a></span></dt><dt><span class="section"><a href="status.html#status.iso.2017">C++ 2017</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.2017.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr1">C++ TR1</a></span></dt><dd><dl><dt><span class="section"><a href="status.html#iso.tr1.specific">Implementation Specific Behavior</a></span></dt></dl></dd><dt><span class="section"><a href="status.html#status.iso.tr24733">C++ TR 24733</a></span></dt></dl></dd><dt><span class="section"><a href="license.html">License</a></span></dt><dd><dl><dt><span class="section"><a href="license.html#manual.intro.status.license.gpl">The Code: GPL</a></span></dt><dt><span class="section"><a href="license.html#manual.intro.status.license.fdl">The Documentation: GPL, FDL</a></span></dt></dl></dd><dt><span class="section"><a href="bugs.html">Bugs</a></span></dt><dd><dl><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.impl">Implementation Bugs</a></span></dt><dt><span class="section"><a href="bugs.html#manual.intro.status.bugs.iso">Standard Bugs</a></span></dt></dl></dd></dl></dd><dt><span class="chapter"><a href="setup.html">2. Setup</a></span></dt><dd><dl><dt><span class="section"><a href="setup.html#manual.intro.setup.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="configure.html">Configure</a></span></dt><dt><span class="section"><a href="make.html">Make</a></span></dt></dl></dd><dt><span class="chapter"><a href="using.html">3. Using</a></span></dt><dd><dl><dt><span class="section"><a href="using.html#manual.intro.using.flags">Command Options</a></span></dt><dt><span class="section"><a href="using_headers.html">Headers</a></span></dt><dd><dl><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.all">Header Files</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.mixing">Mixing Headers</a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.cheaders">The C Headers and <code class="code">namespace std</code></a></span></dt><dt><span class="section"><a href="using_headers.html#manual.intro.using.headers.pre">Precompiled Headers</a></span></dt></dl></dd><dt><span class="section"><a href="using_macros.html">Macros</a></span></dt><dt><span class="section"><a href="using_dual_abi.html">Dual ABI</a></span></dt><dd><dl><dt><span class="section"><a href="using_dual_abi.html#manual.intro.using.abi.trouble">Troubleshooting</a></span></dt></dl></dd><dt><span class="section"><a href="using_namespaces.html">Namespaces</a></span></dt><dd><dl><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.all">Available Namespaces</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.std">namespace std</a></span></dt><dt><span class="section"><a href="using_namespaces.html#manual.intro.using.namespaces.comp">Using Namespace Composition</a></span></dt></dl></dd><dt><span class="section"><a href="using_dynamic_or_shared.html">Linking</a></span></dt><dd><dl><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.freestanding">Almost Nothing</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.dynamic">Finding Dynamic or Shared Libraries</a></span></dt><dt><span class="section"><a href="using_dynamic_or_shared.html#manual.intro.using.linkage.experimental">Experimental Library Extensions</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html">Concurrency</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.prereq">Prerequisites</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.thread_safety">Thread Safety</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.atomics">Atomics</a></span></dt><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.io">IO</a></span></dt><dd><dl><dt><span class="section"><a href="using_concurrency.html#concurrency.io.structure">Structure</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.defaults">Defaults</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.future">Future</a></span></dt><dt><span class="section"><a href="using_concurrency.html#concurrency.io.alt">Alternatives</a></span></dt></dl></dd><dt><span class="section"><a href="using_concurrency.html#manual.intro.using.concurrency.containers">Containers</a></span></dt></dl></dd><dt><span class="section"><a href="using_exceptions.html">Exceptions</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.safety">Exception Safety</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.propagating">Exception Neutrality</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.no">Doing without</a></span></dt><dt><span class="section"><a href="using_exceptions.html#intro.using.exception.compat">Compatibility</a></span></dt><dd><dl><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.c">With <code class="literal">C</code></a></span></dt><dt><span class="section"><a href="using_exceptions.html#using.exception.compat.posix">With <code class="literal">POSIX</code> thread cancellation</a></span></dt></dl></dd></dl></dd><dt><span class="section"><a href="debug.html">Debugging Support</a></span></dt><dd><dl><dt><span class="section"><a href="debug.html#debug.compiler">Using <span class="command"><strong>g++</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.req">Debug Versions of Library Binary Files</a></span></dt><dt><span class="section"><a href="debug.html#debug.memory">Memory Leak Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.races">Data Race Hunting</a></span></dt><dt><span class="section"><a href="debug.html#debug.gdb">Using <span class="command"><strong>gdb</strong></span></a></span></dt><dt><span class="section"><a href="debug.html#debug.exceptions">Tracking uncaught exceptions</a></span></dt><dt><span class="section"><a href="debug.html#debug.debug_mode">Debug Mode</a></span></dt><dt><span class="section"><a href="debug.html#debug.compile_time_checks">Compile Time Checking</a></span></dt><dt><span class="section"><a href="debug.html#debug.profile_mode">Profile-based Performance Analysis</a></span></dt></dl></dd></dl></dd></dl></dd><dt><span class="part"><a href="std_contents.html">II. 
     Standard Contents
   </a></span></dt><dd><dl><dt><span class="chapter"><a href="support.html">4. 
   Support
@@ -149,7 +149,7 @@
 	  </a></dt><dt>22.10. <a href="policy_data_structures_design.html#id-1.3.5.9.4.3.3.3.23">Non-unique Mapping Containers</a></dt><dt>22.11. <a href="policy_data_structures_design.html#id-1.3.5.9.4.3.4.3.5">Point Iterator Hierarchy</a></dt><dt>22.12. <a href="policy_data_structures_design.html#id-1.3.5.9.4.3.4.4.5">Invalidation Guarantee Tags Hierarchy</a></dt><dt>22.13. <a href="policy_data_structures_design.html#id-1.3.5.9.4.3.5.7.4">Container Tag Hierarchy</a></dt><dt>22.14. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.2.3">Hash functions, ranged-hash functions, and
 	      range-hashing functions</a></dt><dt>22.15. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.5.3.4">Insert hash sequence diagram</a></dt><dt>22.16. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.5.3.6">Insert hash sequence diagram with a null policy</a></dt><dt>22.17. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.5.5.5">Hash policy class diagram</a></dt><dt>22.18. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.3.4.7">Balls and bins</a></dt><dt>22.19. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.3.5.3.6">Insert resize sequence diagram</a></dt><dt>22.20. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.3.5.3.9">Standard resize policy trigger sequence
 		diagram</a></dt><dt>22.21. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.3.5.3.10">Standard resize policy size sequence
-		diagram</a></dt><dt>22.22. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.5">Tree node invariants</a></dt><dt>22.23. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.8">Tree node invalidation</a></dt><dt>22.24. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.3">A tree and its update policy</a></dt><dt>22.25. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.8">Restoring node invariants</a></dt><dt>22.26. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.10">Insert update sequence</a></dt><dt>22.27. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.20">Useless update path</a></dt><dt>22.28. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.4.3.2.10">A PATRICIA trie</a></dt><dt>22.29. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.4.3.3.5">A trie and its update policy</a></dt><dt>22.30. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.5.3.3.3">A simple list</a></dt><dt>22.31. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.5.3.3.6">The counter algorithm</a></dt><dt>22.32. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.6.3.3.3">Underlying Priority-Queue Data-Structures.</a></dt><dt>22.33. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.6.3.4.4">Priority-Queue Data-Structure Tags.</a></dt><dt>B.1. <a href="appendix_porting.html#fig.build_hacking.deps">Configure and Build File Dependencies</a></dt></dl></div><div class="list-of-tables"><p><strong>List of Tables</strong></p><dl><dt>1.1. <a href="status.html#table.cxx98_status">C++ 1998/2003 Implementation Status</a></dt><dt>1.2. <a href="status.html#table.cxx11_status">C++ 2011 Implementation Status</a></dt><dt>1.3. <a href="status.html#table.cxx14_status">C++ 2014 Implementation Status</a></dt><dt>1.4. <a href="status.html#table.ts_status">C++ Technical Specifications Implementation Status</a></dt><dt>1.5. <a href="status.html#table.cxx1z_status">C++ 201z Implementation Status</a></dt><dt>1.6. <a href="status.html#table.cxx1z_ts_status">C++ Technical Specifications Implementation Status</a></dt><dt>1.7. <a href="status.html#table.tr1_status">C++ TR1 Implementation Status</a></dt><dt>1.8. <a href="status.html#table.decfp_status">C++ TR 24733 Implementation Status</a></dt><dt>3.1. <a href="using.html#table.cmd_options">C++ Command Options</a></dt><dt>3.2. <a href="using_headers.html#table.cxx98_headers">C++ 1998 Library Headers</a></dt><dt>3.3. <a href="using_headers.html#table.cxx98_cheaders">C++ 1998 Library Headers for C Library Facilities</a></dt><dt>3.4. <a href="using_headers.html#table.cxx11_headers">C++ 2011 Library Headers</a></dt><dt>3.5. <a href="using_headers.html#table.cxx11_cheaders">C++ 2011 Library Headers for C Library Facilities</a></dt><dt>3.6. <a href="using_headers.html#table.tr1_headers">C++ TR 1 Library Headers</a></dt><dt>3.7. <a href="using_headers.html#table.tr1_cheaders">C++ TR 1 Library Headers for C Library Facilities</a></dt><dt>3.8. <a href="using_headers.html#table.decfp_headers">C++ TR 24733 Decimal Floating-Point Header</a></dt><dt>3.9. <a href="using_headers.html#table.abi_headers">C++ ABI Headers</a></dt><dt>3.10. <a href="using_headers.html#table.ext_headers">Extension Headers</a></dt><dt>3.11. <a href="using_headers.html#table.debug_headers">Extension Debug Headers</a></dt><dt>3.12. <a href="using_headers.html#table.profile_headers">Extension Profile Headers</a></dt><dt>3.13. <a href="using_headers.html#table.parallel_headers">Extension Parallel Headers</a></dt><dt>17.1. <a href="debug_mode_using.html#table.debug_mode_containers">Debugging Containers</a></dt><dt>17.2. <a href="debug_mode_using.html#table.debug_mode_containers_cxx11">Debugging Containers C++11</a></dt><dt>18.1. <a href="parallel_mode_using.html#table.parallel_algos">Parallel Algorithms</a></dt><dt>19.1. <a href="profile_mode_design.html#table.profile_code_loc">Profile Code Location</a></dt><dt>19.2. <a href="profile_mode_diagnostics.html#table.profile_diagnostics">Profile Diagnostics</a></dt><dt>21.1. <a href="bitmap_allocator_impl.html#table.bitmap_alloc">Bitmap Allocator Memory Map</a></dt><dt>B.1. <a href="documentation_hacking.html#table.doxygen_prereq">Doxygen Prerequisites</a></dt><dt>B.2. <a href="documentation_hacking.html#table.doxygen_cmp">HTML to Doxygen Markup Comparison</a></dt><dt>B.3. <a href="documentation_hacking.html#table.docbook_prereq">Docbook Prerequisites</a></dt><dt>B.4. <a href="documentation_hacking.html#table.docbook_cmp">HTML to Docbook XML Markup Comparison</a></dt><dt>B.5. <a href="documentation_hacking.html#table.docbook_elem">Docbook XML Element Use</a></dt><dt>B.6. <a href="api.html#table.extension_allocators">Extension Allocators</a></dt><dt>B.7. <a href="api.html#table.extension_allocators2">Extension Allocators Continued</a></dt></dl></div><div class="list-of-equations"><p><strong>List of Equations</strong></p><dl><dt>22.1. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.2.15">Ranged Hash Function</a></dt><dt>22.2. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.3">Range-Hashing, Division Method</a></dt><dt>22.3. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.9">Division via Prime Modulo</a></dt><dt>22.4. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.11">Division via Bit Mask</a></dt><dt>22.5. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.4.7">
+		diagram</a></dt><dt>22.22. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.5">Tree node invariants</a></dt><dt>22.23. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.8">Tree node invalidation</a></dt><dt>22.24. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.3">A tree and its update policy</a></dt><dt>22.25. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.8">Restoring node invariants</a></dt><dt>22.26. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.10">Insert update sequence</a></dt><dt>22.27. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.3.3.2.11.20">Useless update path</a></dt><dt>22.28. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.4.3.2.10">A PATRICIA trie</a></dt><dt>22.29. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.4.3.3.5">A trie and its update policy</a></dt><dt>22.30. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.5.3.3.3">A simple list</a></dt><dt>22.31. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.5.3.3.6">The counter algorithm</a></dt><dt>22.32. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.6.3.3.3">Underlying Priority-Queue Data-Structures.</a></dt><dt>22.33. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.6.3.4.4">Priority-Queue Data-Structure Tags.</a></dt><dt>B.1. <a href="appendix_porting.html#fig.build_hacking.deps">Configure and Build File Dependencies</a></dt></dl></div><div class="list-of-tables"><p><strong>List of Tables</strong></p><dl><dt>1.1. <a href="status.html#table.cxx98_status">C++ 1998/2003 Implementation Status</a></dt><dt>1.2. <a href="status.html#table.cxx11_status">C++ 2011 Implementation Status</a></dt><dt>1.3. <a href="status.html#table.cxx14_status">C++ 2014 Implementation Status</a></dt><dt>1.4. <a href="status.html#table.ts_status">C++ Technical Specifications Implementation Status</a></dt><dt>1.5. <a href="status.html#table.cxx17_status">C++ 2017 Implementation Status</a></dt><dt>1.6. <a href="status.html#table.cxx17_ts_status">C++ Technical Specifications Implementation Status</a></dt><dt>1.7. <a href="status.html#table.tr1_status">C++ TR1 Implementation Status</a></dt><dt>1.8. <a href="status.html#table.decfp_status">C++ TR 24733 Implementation Status</a></dt><dt>3.1. <a href="using.html#table.cmd_options">C++ Command Options</a></dt><dt>3.2. <a href="using_headers.html#table.cxx98_headers">C++ 1998 Library Headers</a></dt><dt>3.3. <a href="using_headers.html#table.cxx98_cheaders">C++ 1998 Library Headers for C Library Facilities</a></dt><dt>3.4. <a href="using_headers.html#table.cxx11_headers">C++ 2011 Library Headers</a></dt><dt>3.5. <a href="using_headers.html#table.cxx11_cheaders">C++ 2011 Library Headers for C Library Facilities</a></dt><dt>3.6. <a href="using_headers.html#table.tr1_headers">C++ TR 1 Library Headers</a></dt><dt>3.7. <a href="using_headers.html#table.tr1_cheaders">C++ TR 1 Library Headers for C Library Facilities</a></dt><dt>3.8. <a href="using_headers.html#table.decfp_headers">C++ TR 24733 Decimal Floating-Point Header</a></dt><dt>3.9. <a href="using_headers.html#table.abi_headers">C++ ABI Headers</a></dt><dt>3.10. <a href="using_headers.html#table.ext_headers">Extension Headers</a></dt><dt>3.11. <a href="using_headers.html#table.debug_headers">Extension Debug Headers</a></dt><dt>3.12. <a href="using_headers.html#table.profile_headers">Extension Profile Headers</a></dt><dt>3.13. <a href="using_headers.html#table.parallel_headers">Extension Parallel Headers</a></dt><dt>17.1. <a href="debug_mode_using.html#table.debug_mode_containers">Debugging Containers</a></dt><dt>17.2. <a href="debug_mode_using.html#table.debug_mode_containers_cxx11">Debugging Containers C++11</a></dt><dt>18.1. <a href="parallel_mode_using.html#table.parallel_algos">Parallel Algorithms</a></dt><dt>19.1. <a href="profile_mode_design.html#table.profile_code_loc">Profile Code Location</a></dt><dt>19.2. <a href="profile_mode_diagnostics.html#table.profile_diagnostics">Profile Diagnostics</a></dt><dt>21.1. <a href="bitmap_allocator_impl.html#table.bitmap_alloc">Bitmap Allocator Memory Map</a></dt><dt>B.1. <a href="documentation_hacking.html#table.doxygen_prereq">Doxygen Prerequisites</a></dt><dt>B.2. <a href="documentation_hacking.html#table.doxygen_cmp">HTML to Doxygen Markup Comparison</a></dt><dt>B.3. <a href="documentation_hacking.html#table.docbook_prereq">Docbook Prerequisites</a></dt><dt>B.4. <a href="documentation_hacking.html#table.docbook_cmp">HTML to Docbook XML Markup Comparison</a></dt><dt>B.5. <a href="documentation_hacking.html#table.docbook_elem">Docbook XML Element Use</a></dt><dt>B.6. <a href="api.html#table.extension_allocators">Extension Allocators</a></dt><dt>B.7. <a href="api.html#table.extension_allocators2">Extension Allocators Continued</a></dt></dl></div><div class="list-of-equations"><p><strong>List of Equations</strong></p><dl><dt>22.1. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.2.15">Ranged Hash Function</a></dt><dt>22.2. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.3">Range-Hashing, Division Method</a></dt><dt>22.3. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.9">Division via Prime Modulo</a></dt><dt>22.4. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.3.11">Division via Bit Mask</a></dt><dt>22.5. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.4.7">
 		A Standard String Hash Function
 	      </a></dt><dt>22.6. <a href="policy_data_structures_design.html#id-1.3.5.9.4.4.2.3.2.4.12">
 		Only k String DNA Hash
Index: libstdc++-v3/doc/html/manual/numerics_and_c.html
===================================================================
--- libstdc++-v3/doc/html/manual/numerics_and_c.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/numerics_and_c.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Interacting with C</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="numerics.html" title="Chapter 12.  Numerics" /><link rel="prev" href="generalized_numeric_operations.html" title="Generalized Operations" /><link rel="next" href="io.html" title="Chapter 13.  Input and Output" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Interacting with C</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="generalized_numeric_operations.html">Prev</a> </td><th width="60%" align="center">Chapter 12. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Interacting with C</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="numerics.html" title="Chapter 12.  Numerics" /><link rel="prev" href="generalized_numeric_operations.html" title="Generalized Operations" /><link rel="next" href="io.html" title="Chapter 13.  Input and Output" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Interacting with C</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="generalized_numeric_operations.html">Prev</a> </td><th width="60%" align="center">Chapter 12. 
   Numerics
   
 </th><td width="20%" align="right"> <a accesskey="n" href="io.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.numerics.c"></a>Interacting with C</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="numerics.c.array"></a>Numerics vs. Arrays</h3></div></div></div><p>One of the major reasons why FORTRAN can chew through numbers so well
Index: libstdc++-v3/doc/html/manual/appendix_gpl.html
===================================================================
--- libstdc++-v3/doc/html/manual/appendix_gpl.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/appendix_gpl.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix D.  GNU General Public License version 3</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="appendix_free.html" title="Appendix C.  Free Software Needs Free Documentation" /><link rel="next" href="appendix_gfdl.html" title="Appendix E. GNU Free Documentation License" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix D. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Appendix D.  GNU General Public License version 3</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix.html" title="Part IV.  Appendices" /><link rel="prev" href="appendix_free.html" title="Appendix C.  Free Software Needs Free Documentation" /><link rel="next" href="appendix_gfdl.html" title="Appendix E. GNU Free Documentation License" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Appendix D. 
     <acronym class="acronym">GNU</acronym> General Public License version 3
   </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="appendix_free.html">Prev</a> </td><th width="60%" align="center">Part IV. 
   Appendices
Index: libstdc++-v3/doc/html/manual/source_code_style.html
===================================================================
--- libstdc++-v3/doc/html/manual/source_code_style.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/source_code_style.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Coding Style</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_contributing.html" title="Appendix A.  Contributing" /><link rel="prev" href="source_organization.html" title="Directory Layout and Source Conventions" /><link rel="next" href="source_design_notes.html" title="Design Notes" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Coding Style</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="source_organization.html">Prev</a> </td><th width="60%" align="center">Appendix A. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Coding Style</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="appendix_contributing.html" title="Appendix A.  Contributing" /><link rel="prev" href="source_organization.html" title="Directory Layout and Source Conventions" /><link rel="next" href="source_design_notes.html" title="Design Notes" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Coding Style</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="source_organization.html">Prev</a> </td><th width="60%" align="center">Appendix A. 
   Contributing
   
 </th><td width="20%" align="right"> <a accesskey="n" href="source_design_notes.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="contrib.coding_style"></a>Coding Style</h2></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/streambufs.html
===================================================================
--- libstdc++-v3/doc/html/manual/streambufs.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/streambufs.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Stream Buffers</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="io.html" title="Chapter 13.  Input and Output" /><link rel="prev" href="io.html" title="Chapter 13.  Input and Output" /><link rel="next" href="stringstreams.html" title="Memory Based Streams" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Stream Buffers</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="io.html">Prev</a> </td><th width="60%" align="center">Chapter 13. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Stream Buffers</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="io.html" title="Chapter 13.  Input and Output" /><link rel="prev" href="io.html" title="Chapter 13.  Input and Output" /><link rel="next" href="stringstreams.html" title="Memory Based Streams" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Stream Buffers</th></tr><tr><td width="20%" align="left"><a accesskey="p" href="io.html">Prev</a> </td><th width="60%" align="center">Chapter 13. 
   Input and Output
   
 </th><td width="20%" align="right"> <a accesskey="n" href="stringstreams.html">Next</a></td></tr></table><hr /></div><div class="section"><div class="titlepage"><div><div><h2 class="title" style="clear: both"><a id="std.io.streambufs"></a>Stream Buffers</h2></div></div></div><div class="section"><div class="titlepage"><div><div><h3 class="title"><a id="io.streambuf.derived"></a>Derived streambuf Classes</h3></div></div></div><p>
Index: libstdc++-v3/doc/html/manual/utilities.html
===================================================================
--- libstdc++-v3/doc/html/manual/utilities.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/html/manual/utilities.html	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 6.  Utilities</title><meta name="generator" content="DocBook XSL-NS Stylesheets V1.78.1" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="concept_checking.html" title="Concept Checking" /><link rel="next" href="pairs.html" title="Pairs" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 6. 
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"><html xmlns="http://www.w3.org/1999/xhtml"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8" /><title>Chapter 6.  Utilities</title><meta name="generator" content="DocBook XSL Stylesheets Vsnapshot" /><meta name="keywords" content="ISO C++, library" /><meta name="keywords" content="ISO C++, runtime, library" /><link rel="home" href="../index.html" title="The GNU C++ Library" /><link rel="up" href="std_contents.html" title="Part II.  Standard Contents" /><link rel="prev" href="concept_checking.html" title="Concept Checking" /><link rel="next" href="pairs.html" title="Pairs" /></head><body><div class="navheader"><table width="100%" summary="Navigation header"><tr><th colspan="3" align="center">Chapter 6. 
   Utilities
   
 </th></tr><tr><td width="20%" align="left"><a accesskey="p" href="concept_checking.html">Prev</a> </td><th width="60%" align="center">Part II. 
Index: libstdc++-v3/doc/doxygen/mainpage.html
===================================================================
--- libstdc++-v3/doc/doxygen/mainpage.html	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/doc/doxygen/mainpage.html	(.../branches/gcc-7-branch)
@@ -28,7 +28,7 @@
 
 <p>There are two types of documentation for libstdc++.  One is the
    distribution documentation, which can be read online
-   <a href="http://gcc.gnu.org/onlinedocs/libstdc++/index.html">here</a>
+   <a href="https://gcc.gnu.org/onlinedocs/libstdc++/index.html">here</a>
    or offline from the file doc/html/index.html in the library source
    directory.
 </p>
@@ -78,11 +78,11 @@
    pages.  See the section "Documentation Style"
    in <code>doc/xml/manual/appendix_contributing.xml</code> in the
    source tree for how to create (and write) the doxygen markup.
-  This style guide can also be viewed on the <a href="http://gcc.gnu.org/onlinedocs/libstdc++/manual/bk01apas04.html">web</a>.
+  This style guide can also be viewed on the <a href="https://gcc.gnu.org/onlinedocs/libstdc++/manual/documentation_hacking.html">web</a>.
 
 <h2>License, Copyright, and Other Lawyerly Verbosity</h2>
 <p>The libstdc++ documentation is released under
-   <a href="http://gcc.gnu.org/onlinedocs/libstdc++/manual/bk01pt01ch01s02.html">
+   <a href="https://gcc.gnu.org/onlinedocs/libstdc++/manual/appendix_gpl.html">
    these terms</a>.
 </p>
 <p>Part of the generated documentation involved comments and notes from
Index: libstdc++-v3/include/Makefile.in
===================================================================
--- libstdc++-v3/include/Makefile.in	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/Makefile.in	(.../branches/gcc-7-branch)
@@ -389,7 +389,6 @@
 	${bits_srcdir}/boost_concept_check.h \
 	${bits_srcdir}/c++0x_warning.h \
 	${bits_srcdir}/c++14_warning.h \
-	${bits_srcdir}/c++17_warning.h \
 	${bits_srcdir}/char_traits.h \
 	${bits_srcdir}/codecvt.h \
 	${bits_srcdir}/concept_check.h \
Index: libstdc++-v3/include/std/optional
===================================================================
--- libstdc++-v3/include/std/optional	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/optional	(.../branches/gcc-7-branch)
@@ -29,10 +29,10 @@
 #ifndef _GLIBCXX_OPTIONAL
 #define _GLIBCXX_OPTIONAL 1
 
-#if __cplusplus <= 201402L
-# include <bits/c++17_warning.h>
-#else
+#pragma GCC system_header
 
+#if __cplusplus >= 201703L
+
 #include <utility>
 #include <type_traits>
 #include <stdexcept>
@@ -51,6 +51,8 @@
    *  @{
    */
 
+#define __cpp_lib_optional 201603
+
   template<typename _Tp>
     class optional;
 
@@ -1000,23 +1002,23 @@
 
   // Hash.
 
-  template<typename _Tp, bool
-           = __poison_hash<remove_const_t<_Tp>>::__enable_hash_call>
+  template<typename _Tp, typename _Up = remove_const_t<_Tp>,
+           bool = __poison_hash<_Up>::__enable_hash_call>
     struct __optional_hash_call_base
     {
       size_t
       operator()(const optional<_Tp>& __t) const
-      noexcept(noexcept(hash<_Tp> {}(*__t)))
+      noexcept(noexcept(hash<_Up>{}(*__t)))
       {
         // We pick an arbitrary hash for disengaged optionals which hopefully
         // usual values of _Tp won't typically hash to.
         constexpr size_t __magic_disengaged_hash = static_cast<size_t>(-3333);
-        return __t ? hash<_Tp> {}(*__t) : __magic_disengaged_hash;
+        return __t ? hash<_Up>{}(*__t) : __magic_disengaged_hash;
       }
     };
 
-  template<typename _Tp>
-    struct __optional_hash_call_base<_Tp, false> {};
+  template<typename _Tp, typename _Up>
+    struct __optional_hash_call_base<_Tp, _Up, false> {};
 
   template<typename _Tp>
     struct hash<optional<_Tp>>
Index: libstdc++-v3/include/std/any
===================================================================
--- libstdc++-v3/include/std/any	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/any	(.../branches/gcc-7-branch)
@@ -31,9 +31,7 @@
 
 #pragma GCC system_header
 
-#if __cplusplus <= 201402L
-# include <bits/c++17_warning.h>
-#else
+#if __cplusplus >= 201703L
 
 #include <typeinfo>
 #include <new>
@@ -68,6 +66,8 @@
 #endif
   }
 
+#define __cpp_lib_any 201603
+
   /**
    *  @brief A type-safe container of any type.
    * 
Index: libstdc++-v3/include/std/shared_mutex
===================================================================
--- libstdc++-v3/include/std/shared_mutex	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/shared_mutex	(.../branches/gcc-7-branch)
@@ -31,9 +31,7 @@
 
 #pragma GCC system_header
 
-#if __cplusplus <= 201103L
-# include <bits/c++14_warning.h>
-#else
+#if __cplusplus >= 201402L
 
 #include <bits/c++config.h>
 #include <condition_variable>
@@ -51,7 +49,7 @@
 #ifdef _GLIBCXX_USE_C99_STDINT_TR1
 #ifdef _GLIBCXX_HAS_GTHREADS
 
-#if __cplusplus > 201402L
+#if __cplusplus >= 201703L
 #define __cpp_lib_shared_mutex 201505
   class shared_mutex;
 #endif
Index: libstdc++-v3/include/std/string_view
===================================================================
--- libstdc++-v3/include/std/string_view	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/string_view	(.../branches/gcc-7-branch)
@@ -35,9 +35,7 @@
 
 #pragma GCC system_header
 
-#if __cplusplus <= 201402L
-# include <bits/c++17_warning.h>
-#else
+#if __cplusplus >= 201703L
 
 #include <limits>
 #include <iosfwd>
@@ -49,6 +47,8 @@
 {
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
+#define __cpp_lib_string_view 201603
+
   /**
    *  @class basic_string_view <string_view>
    *  @brief  A non-owning reference to a string.
@@ -106,7 +106,7 @@
         _M_str{__str}
       { }
 
-      basic_string_view&
+      constexpr basic_string_view&
       operator=(const basic_string_view&) noexcept = default;
 
       // [string.view.iterators], iterators
@@ -127,19 +127,19 @@
       cend() const noexcept
       { return this->_M_str + this->_M_len; }
 
-      const_reverse_iterator
+      constexpr const_reverse_iterator
       rbegin() const noexcept
       { return const_reverse_iterator(this->end()); }
 
-      const_reverse_iterator
+      constexpr const_reverse_iterator
       rend() const noexcept
       { return const_reverse_iterator(this->begin()); }
 
-      const_reverse_iterator
+      constexpr const_reverse_iterator
       crbegin() const noexcept
       { return const_reverse_iterator(this->end()); }
 
-      const_reverse_iterator
+      constexpr const_reverse_iterator
       crend() const noexcept
       { return const_reverse_iterator(this->begin()); }
 
@@ -208,7 +208,7 @@
 
       // [string.view.modifiers], modifiers:
 
-      void
+      constexpr void
       remove_prefix(size_type __n)
       {
 	__glibcxx_assert(this->_M_len >= __n);
@@ -216,15 +216,16 @@
 	this->_M_len -= __n;
       }
 
-      void
+      constexpr void
       remove_suffix(size_type __n)
       { this->_M_len -= __n; }
 
-      void
+      constexpr void
       swap(basic_string_view& __sv) noexcept
       {
-	std::swap(this->_M_len, __sv._M_len);
-	std::swap(this->_M_str, __sv._M_str);
+	auto __tmp = *this;
+	*this = __sv;
+	__sv = __tmp;
       }
 
 
@@ -261,7 +262,7 @@
 				     __pos, this->size()), basic_string_view{});
       }
 
-      int
+      constexpr int
       compare(basic_string_view __str) const noexcept
       {
 	int __ret = traits_type::compare(this->_M_str, __str._M_str,
@@ -271,24 +272,24 @@
 	return __ret;
       }
 
-      int
+      constexpr int
       compare(size_type __pos1, size_type __n1, basic_string_view __str) const
       { return this->substr(__pos1, __n1).compare(__str); }
 
-      int
+      constexpr int
       compare(size_type __pos1, size_type __n1,
 	      basic_string_view __str, size_type __pos2, size_type __n2) const
       { return this->substr(__pos1, __n1).compare(__str.substr(__pos2, __n2)); }
 
-      int
+      constexpr int
       compare(const _CharT* __str) const noexcept
       { return this->compare(basic_string_view{__str}); }
 
-      int
+      constexpr int
       compare(size_type __pos1, size_type __n1, const _CharT* __str) const
       { return this->substr(__pos1, __n1).compare(basic_string_view{__str}); }
 
-      int
+      constexpr int
       compare(size_type __pos1, size_type __n1,
 	      const _CharT* __str, size_type __n2) const
       {
@@ -296,78 +297,78 @@
 		   .compare(basic_string_view(__str, __n2));
       }
 
-      size_type
+      constexpr size_type
       find(basic_string_view __str, size_type __pos = 0) const noexcept
       { return this->find(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find(_CharT __c, size_type __pos=0) const noexcept;
 
-      size_type
+      constexpr size_type
       find(const _CharT* __str, size_type __pos, size_type __n) const noexcept;
 
-      size_type
+      constexpr size_type
       find(const _CharT* __str, size_type __pos=0) const noexcept
       { return this->find(__str, __pos, traits_type::length(__str)); }
 
-      size_type
+      constexpr size_type
       rfind(basic_string_view __str, size_type __pos = npos) const noexcept
       { return this->rfind(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       rfind(_CharT __c, size_type __pos = npos) const noexcept;
 
-      size_type
+      constexpr size_type
       rfind(const _CharT* __str, size_type __pos, size_type __n) const noexcept;
 
-      size_type
+      constexpr size_type
       rfind(const _CharT* __str, size_type __pos = npos) const noexcept
       { return this->rfind(__str, __pos, traits_type::length(__str)); }
 
-      size_type
+      constexpr size_type
       find_first_of(basic_string_view __str, size_type __pos = 0) const noexcept
       { return this->find_first_of(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find_first_of(_CharT __c, size_type __pos = 0) const noexcept
       { return this->find(__c, __pos); }
 
-      size_type
+      constexpr size_type
       find_first_of(const _CharT* __str, size_type __pos, size_type __n) const;
 
-      size_type
+      constexpr size_type
       find_first_of(const _CharT* __str, size_type __pos = 0) const noexcept
       { return this->find_first_of(__str, __pos, traits_type::length(__str)); }
 
-      size_type
+      constexpr size_type
       find_last_of(basic_string_view __str,
 		   size_type __pos = npos) const noexcept
       { return this->find_last_of(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find_last_of(_CharT __c, size_type __pos=npos) const noexcept
       { return this->rfind(__c, __pos); }
 
-      size_type
+      constexpr size_type
       find_last_of(const _CharT* __str, size_type __pos, size_type __n) const;
 
-      size_type
+      constexpr size_type
       find_last_of(const _CharT* __str, size_type __pos = npos) const noexcept
       { return this->find_last_of(__str, __pos, traits_type::length(__str)); }
 
-      size_type
+      constexpr size_type
       find_first_not_of(basic_string_view __str,
 			size_type __pos = 0) const noexcept
       { return this->find_first_not_of(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find_first_not_of(_CharT __c, size_type __pos = 0) const noexcept;
 
-      size_type
+      constexpr size_type
       find_first_not_of(const _CharT* __str,
 			size_type __pos, size_type __n) const;
 
-      size_type
+      constexpr size_type
       find_first_not_of(const _CharT* __str, size_type __pos = 0) const noexcept
       {
 	return this->find_first_not_of(__str, __pos,
@@ -374,19 +375,19 @@
 				       traits_type::length(__str));
       }
 
-      size_type
+      constexpr size_type
       find_last_not_of(basic_string_view __str,
 		       size_type __pos = npos) const noexcept
       { return this->find_last_not_of(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find_last_not_of(_CharT __c, size_type __pos = npos) const noexcept;
 
-      size_type
+      constexpr size_type
       find_last_not_of(const _CharT* __str,
 		       size_type __pos, size_type __n) const;
 
-      size_type
+      constexpr size_type
       find_last_not_of(const _CharT* __str,
 		       size_type __pos = npos) const noexcept
       {
@@ -394,7 +395,7 @@
 				      traits_type::length(__str));
       }
 
-      size_type
+      constexpr size_type
       _M_check(size_type __pos, const char* __s) const
       {
 	if (__pos > this->size())
@@ -405,7 +406,7 @@
       }
 
       // NB: _M_limit doesn't check for a bad __pos value.
-      size_type
+      constexpr size_type
       _M_limit(size_type __pos, size_type __off) const _GLIBCXX_NOEXCEPT
       {
 	const bool __testoff =  __off < this->size() - __pos;
@@ -445,109 +446,109 @@
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator==(basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.size() == __y.size() && __x.compare(__y) == 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator==(basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.size() == __y.size() && __x.compare(__y) == 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator==(__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.size() == __y.size() && __x.compare(__y) == 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator!=(basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return !(__x == __y); }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator!=(basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return !(__x == __y); }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator!=(__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return !(__x == __y); }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator< (basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) < 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator< (basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.compare(__y) < 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator< (__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) < 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator> (basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) > 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator> (basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.compare(__y) > 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator> (__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) > 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator<=(basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) <= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator<=(basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.compare(__y) <= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator<=(__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) <= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator>=(basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) >= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator>=(basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.compare(__y) >= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator>=(__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) >= 0; }
Index: libstdc++-v3/include/std/numeric
===================================================================
--- libstdc++-v3/include/std/numeric	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/numeric	(.../branches/gcc-7-branch)
@@ -125,7 +125,11 @@
 
 #if __cplusplus > 201402L
 
+#define __cpp_lib_gcd_lcm 201606
+// These were used in drafts of SD-6:
 #define __cpp_lib_gcd 201606
+#define __cpp_lib_lcm 201606
+
   /// Greatest common divisor
   template<typename _Mn, typename _Nn>
     constexpr common_type_t<_Mn, _Nn>
@@ -138,7 +142,6 @@
       return __detail::__gcd(__m, __n);
     }
 
-#define __cpp_lib_lcm 201606
   /// Least common multiple
   template<typename _Mn, typename _Nn>
     constexpr common_type_t<_Mn, _Nn>
Index: libstdc++-v3/include/std/type_traits
===================================================================
--- libstdc++-v3/include/std/type_traits	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/type_traits	(.../branches/gcc-7-branch)
@@ -2758,9 +2758,14 @@
 
   template<typename _Result, typename _Ret>
     struct __is_invocable_impl<_Result, _Ret, __void_t<typename _Result::type>>
-    : __or_<is_void<_Ret>, is_convertible<typename _Result::type, _Ret>>::type
+    : is_convertible<typename _Result::type, _Ret>::type
     { };
 
+  template<typename _Result>
+    struct __is_invocable_impl<_Result, void, __void_t<typename _Result::type>>
+    : true_type
+    { };
+
   template<typename _Fn, typename... _ArgTypes>
     struct __is_invocable
     : __is_invocable_impl<__invoke_result<_Fn, _ArgTypes...>, void>::type
@@ -2857,10 +2862,26 @@
              __call_is_nothrow_<_Fn, _ArgTypes...>>::type
     { };
 
+  template<typename _Result, typename _Ret, typename = void>
+    struct __is_nt_invocable_impl : false_type { };
+
+  template<typename _Result, typename _Ret>
+    struct __is_nt_invocable_impl<_Result, _Ret,
+				  __void_t<typename _Result::type>>
+    : __and_<is_convertible<typename _Result::type, _Ret>,
+	     is_nothrow_constructible<_Ret, typename _Result::type>>
+    { };
+
+  template<typename _Result>
+    struct __is_nt_invocable_impl<_Result, void,
+				  __void_t<typename _Result::type>>
+    : true_type
+    { };
+
   /// std::is_nothrow_invocable_r
   template<typename _Ret, typename _Fn, typename... _ArgTypes>
     struct is_nothrow_invocable_r
-    : __and_<__is_invocable_impl<__invoke_result<_Fn, _ArgTypes...>, _Ret>,
+    : __and_<__is_nt_invocable_impl<__invoke_result<_Fn, _ArgTypes...>, _Ret>,
              __call_is_nothrow_<_Fn, _ArgTypes...>>::type
     { };
 
@@ -3043,14 +3064,16 @@
 template <typename _From, typename _To>
   inline constexpr bool is_convertible_v = is_convertible<_From, _To>::value;
 
-#ifdef __has_builtin
-# if !__has_builtin(__has_unique_object_representations)
-// Try not to break non-GNU compilers that don't support the built-in:
-#  define _GLIBCXX_NO_BUILTIN_HAS_UNIQ_OBJ_REP 1
+#if __GNUC__ >= 7
+# define _GLIBCXX_HAVE_BUILTIN_HAS_UNIQ_OBJ_REP 1
+#elif defined(__is_identifier)
+// For non-GNU compilers:
+# if ! __is_identifier(__has_unique_object_representations)
+#  define _GLIBCXX_HAVE_BUILTIN_HAS_UNIQ_OBJ_REP 1
 # endif
 #endif
 
-#ifndef _GLIBCXX_NO_BUILTIN_HAS_UNIQ_OBJ_REP
+#ifdef _GLIBCXX_HAVE_BUILTIN_HAS_UNIQ_OBJ_REP
 # define __cpp_lib_has_unique_object_representations 201606
   /// has_unique_object_representations
   template<typename _Tp>
@@ -3060,13 +3083,13 @@
       )>
     { };
 #endif
-#undef _GLIBCXX_NO_BUILTIN_HAS_UNIQ_OBJ_REP
+#undef _GLIBCXX_HAVE_BUILTIN_HAS_UNIQ_OBJ_REP
 
 #if __GNUC__ >= 7
 # define _GLIBCXX_HAVE_BUILTIN_IS_AGGREGATE 1
-#elif defined __has_builtin
+#elif defined(__is_identifier)
 // For non-GNU compilers:
-# if __has_builtin(__is_aggregate)
+# if ! __is_identifier(__is_aggregate)
 #  define _GLIBCXX_HAVE_BUILTIN_IS_AGGREGATE 1
 # endif
 #endif
Index: libstdc++-v3/include/std/chrono
===================================================================
--- libstdc++-v3/include/std/chrono	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/chrono	(.../branches/gcc-7-branch)
@@ -215,8 +215,8 @@
         treat_as_floating_point<_Rep>::value;
 #endif // C++17
 
-#if __cplusplus > 201402L
-# define __cpp_lib_chrono 201510
+#if __cplusplus >= 201703L
+# define __cpp_lib_chrono 201611
 
     template<typename _ToDur, typename _Rep, typename _Period>
       constexpr enable_if_t<__is_duration<_ToDur>::value, _ToDur>
@@ -622,7 +622,8 @@
 	{ }
 
 	// conversions
-	template<typename _Dur2>
+	template<typename _Dur2,
+		 typename = _Require<is_convertible<_Dur2, _Dur>>>
 	  constexpr time_point(const time_point<clock, _Dur2>& __t)
 	  : __d(__t.time_since_epoch())
 	  { }
Index: libstdc++-v3/include/std/mutex
===================================================================
--- libstdc++-v3/include/std/mutex	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/mutex	(.../branches/gcc-7-branch)
@@ -556,8 +556,8 @@
         }
     }
 
-#if __cplusplus > 201402L
-#define __cpp_lib_scoped_lock 201707
+#if __cplusplus >= 201703L
+#define __cpp_lib_scoped_lock 201703
   /** @brief A scoped lock type for multiple lockable objects.
    *
    * A scoped_lock controls mutex ownership within a scope, releasing
@@ -688,6 +688,12 @@
         __set_once_functor_lock_ptr(0);
 #endif
 
+#ifdef __clang_analyzer__
+      // PR libstdc++/82481
+      __once_callable = nullptr;
+      __once_call = nullptr;
+#endif
+
       if (__e)
 	__throw_system_error(__e);
     }
Index: libstdc++-v3/include/std/istream
===================================================================
--- libstdc++-v3/include/std/istream	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/istream	(.../branches/gcc-7-branch)
@@ -150,9 +150,9 @@
        *  whatever data is appropriate for the type of the argument.
        *
        *  If an exception is thrown during extraction, ios_base::badbit
-       *  will be turned on in the stream's error state without causing an
-       *  ios_base::failure to be thrown.  The original exception will then
-       *  be rethrown.
+       *  will be turned on in the stream's error state (without causing an
+       *  ios_base::failure to be thrown) and the original exception will
+       *  be rethrown if badbit is set in the exceptions mask.
       */
 
       //@{
@@ -286,9 +286,9 @@
        *  by gcount().
        *
        *  If an exception is thrown during extraction, ios_base::badbit
-       *  will be turned on in the stream's error state without causing an
-       *  ios_base::failure to be thrown.  The original exception will then
-       *  be rethrown.
+       *  will be turned on in the stream's error state (without causing an
+       *  ios_base::failure to be thrown) and the original exception will
+       *  be rethrown if badbit is set in the exceptions mask.
       */
 
       /**
Index: libstdc++-v3/include/std/variant
===================================================================
--- libstdc++-v3/include/std/variant	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/variant	(.../branches/gcc-7-branch)
@@ -31,9 +31,7 @@
 
 #pragma GCC system_header
 
-#if __cplusplus <= 201402L
-# include <bits/c++17_warning.h>
-#else
+#if __cplusplus >= 201703L
 
 #include <type_traits>
 #include <utility>
@@ -73,6 +71,8 @@
 
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
+#define __cpp_lib_variant 201603
+
   template<typename... _Types> class tuple;
   template<typename... _Types> class variant;
   template <typename> struct hash;
Index: libstdc++-v3/include/std/sstream
===================================================================
--- libstdc++-v3/include/std/sstream	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/std/sstream	(.../branches/gcc-7-branch)
@@ -302,12 +302,14 @@
 	__xfer_bufptrs(const basic_stringbuf& __from, basic_stringbuf* __to)
 	: _M_to{__to}, _M_goff{-1, -1, -1}, _M_poff{-1, -1, -1}
 	{
-	  const _CharT* __str = __from._M_string.data();
+	  const _CharT* const __str = __from._M_string.data();
+	  const _CharT* __end = nullptr;
 	  if (__from.eback())
 	    {
-	    _M_goff[0] = __from.eback() - __str;
-	    _M_goff[1] = __from.gptr() - __str;
-	    _M_goff[2] = __from.egptr() - __str;
+	      _M_goff[0] = __from.eback() - __str;
+	      _M_goff[1] = __from.gptr() - __str;
+	      _M_goff[2] = __from.egptr() - __str;
+	      __end = __from.egptr();
 	    }
 	  if (__from.pbase())
 	    {
@@ -314,7 +316,18 @@
 	      _M_poff[0] = __from.pbase() - __str;
 	      _M_poff[1] = __from.pptr() - __from.pbase();
 	      _M_poff[2] = __from.epptr() - __str;
+	      if (__from.pptr() > __end)
+		__end = __from.pptr();
 	    }
+
+	  // Set _M_string length to the greater of the get and put areas.
+	  if (__end)
+	    {
+	      // The const_cast avoids changing this constructor's signature,
+	      // because it is exported from the dynamic library.
+	      auto& __mut_from = const_cast<basic_stringbuf&>(__from);
+	      __mut_from._M_string._M_length(__end - __str);
+	    }
 	}
 
 	~__xfer_bufptrs()
Index: libstdc++-v3/include/experimental/string_view
===================================================================
--- libstdc++-v3/include/experimental/string_view	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/experimental/string_view	(.../branches/gcc-7-branch)
@@ -219,7 +219,7 @@
 
       // [string.view.modifiers], modifiers:
 
-      void
+      constexpr void
       remove_prefix(size_type __n)
       {
 	__glibcxx_assert(this->_M_len >= __n);
@@ -227,15 +227,16 @@
 	this->_M_len -= __n;
       }
 
-      void
+      constexpr void
       remove_suffix(size_type __n)
       { this->_M_len -= __n; }
 
-      void
+      constexpr void
       swap(basic_string_view& __sv) noexcept
       {
-	std::swap(this->_M_len, __sv._M_len);
-	std::swap(this->_M_str, __sv._M_str);
+	auto __tmp = *this;
+	*this = __sv;
+	__sv = __tmp;
       }
 
 
@@ -285,7 +286,7 @@
 				     __pos, this->size()), basic_string_view{});
       }
 
-      int
+      constexpr int
       compare(basic_string_view __str) const noexcept
       {
 	int __ret = traits_type::compare(this->_M_str, __str._M_str,
@@ -295,24 +296,24 @@
 	return __ret;
       }
 
-      int
+      constexpr int
       compare(size_type __pos1, size_type __n1, basic_string_view __str) const
       { return this->substr(__pos1, __n1).compare(__str); }
 
-      int
+      constexpr int
       compare(size_type __pos1, size_type __n1,
 	      basic_string_view __str, size_type __pos2, size_type __n2) const
       { return this->substr(__pos1, __n1).compare(__str.substr(__pos2, __n2)); }
 
-      int
+      constexpr int
       compare(const _CharT* __str) const noexcept
       { return this->compare(basic_string_view{__str}); }
 
-      int
+      constexpr int
       compare(size_type __pos1, size_type __n1, const _CharT* __str) const
       { return this->substr(__pos1, __n1).compare(basic_string_view{__str}); }
 
-      int
+      constexpr int
       compare(size_type __pos1, size_type __n1,
 	      const _CharT* __str, size_type __n2) const
       {
@@ -320,78 +321,78 @@
 		   .compare(basic_string_view(__str, __n2));
       }
 
-      size_type
+      constexpr size_type
       find(basic_string_view __str, size_type __pos = 0) const noexcept
       { return this->find(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find(_CharT __c, size_type __pos=0) const noexcept;
 
-      size_type
+      constexpr size_type
       find(const _CharT* __str, size_type __pos, size_type __n) const noexcept;
 
-      size_type
+      constexpr size_type
       find(const _CharT* __str, size_type __pos=0) const noexcept
       { return this->find(__str, __pos, traits_type::length(__str)); }
 
-      size_type
+      constexpr size_type
       rfind(basic_string_view __str, size_type __pos = npos) const noexcept
       { return this->rfind(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       rfind(_CharT __c, size_type __pos = npos) const noexcept;
 
-      size_type
+      constexpr size_type
       rfind(const _CharT* __str, size_type __pos, size_type __n) const noexcept;
 
-      size_type
+      constexpr size_type
       rfind(const _CharT* __str, size_type __pos = npos) const noexcept
       { return this->rfind(__str, __pos, traits_type::length(__str)); }
 
-      size_type
+      constexpr size_type
       find_first_of(basic_string_view __str, size_type __pos = 0) const noexcept
       { return this->find_first_of(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find_first_of(_CharT __c, size_type __pos = 0) const noexcept
       { return this->find(__c, __pos); }
 
-      size_type
+      constexpr size_type
       find_first_of(const _CharT* __str, size_type __pos, size_type __n) const;
 
-      size_type
+      constexpr size_type
       find_first_of(const _CharT* __str, size_type __pos = 0) const noexcept
       { return this->find_first_of(__str, __pos, traits_type::length(__str)); }
 
-      size_type
+      constexpr size_type
       find_last_of(basic_string_view __str,
 		   size_type __pos = npos) const noexcept
       { return this->find_last_of(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find_last_of(_CharT __c, size_type __pos=npos) const noexcept
       { return this->rfind(__c, __pos); }
 
-      size_type
+      constexpr size_type
       find_last_of(const _CharT* __str, size_type __pos, size_type __n) const;
 
-      size_type
+      constexpr size_type
       find_last_of(const _CharT* __str, size_type __pos = npos) const noexcept
       { return this->find_last_of(__str, __pos, traits_type::length(__str)); }
 
-      size_type
+      constexpr size_type
       find_first_not_of(basic_string_view __str,
 			size_type __pos = 0) const noexcept
       { return this->find_first_not_of(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find_first_not_of(_CharT __c, size_type __pos = 0) const noexcept;
 
-      size_type
+      constexpr size_type
       find_first_not_of(const _CharT* __str,
 			size_type __pos, size_type __n) const;
 
-      size_type
+      constexpr size_type
       find_first_not_of(const _CharT* __str, size_type __pos = 0) const noexcept
       {
 	return this->find_first_not_of(__str, __pos,
@@ -398,19 +399,19 @@
 				       traits_type::length(__str));
       }
 
-      size_type
+      constexpr size_type
       find_last_not_of(basic_string_view __str,
 		       size_type __pos = npos) const noexcept
       { return this->find_last_not_of(__str._M_str, __pos, __str._M_len); }
 
-      size_type
+      constexpr size_type
       find_last_not_of(_CharT __c, size_type __pos = npos) const noexcept;
 
-      size_type
+      constexpr size_type
       find_last_not_of(const _CharT* __str,
 		       size_type __pos, size_type __n) const;
 
-      size_type
+      constexpr size_type
       find_last_not_of(const _CharT* __str,
 		       size_type __pos = npos) const noexcept
       {
@@ -452,109 +453,109 @@
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator==(basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.size() == __y.size() && __x.compare(__y) == 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator==(basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.size() == __y.size() && __x.compare(__y) == 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator==(__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.size() == __y.size() && __x.compare(__y) == 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator!=(basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return !(__x == __y); }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator!=(basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return !(__x == __y); }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator!=(__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return !(__x == __y); }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator< (basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) < 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator< (basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.compare(__y) < 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator< (__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) < 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator> (basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) > 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator> (basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.compare(__y) > 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator> (__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) > 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator<=(basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) <= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator<=(basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.compare(__y) <= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator<=(__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) <= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator>=(basic_string_view<_CharT, _Traits> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) >= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator>=(basic_string_view<_CharT, _Traits> __x,
                __detail::__idt<basic_string_view<_CharT, _Traits>> __y) noexcept
     { return __x.compare(__y) >= 0; }
 
   template<typename _CharT, typename _Traits>
-    inline bool
+    constexpr bool
     operator>=(__detail::__idt<basic_string_view<_CharT, _Traits>> __x,
                basic_string_view<_CharT, _Traits> __y) noexcept
     { return __x.compare(__y) >= 0; }
Index: libstdc++-v3/include/experimental/bits/string_view.tcc
===================================================================
--- libstdc++-v3/include/experimental/bits/string_view.tcc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/experimental/bits/string_view.tcc	(.../branches/gcc-7-branch)
@@ -49,7 +49,7 @@
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find(const _CharT* __str, size_type __pos, size_type __n) const noexcept
     {
@@ -70,7 +70,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find(_CharT __c, size_type __pos) const noexcept
     {
@@ -86,7 +86,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     rfind(const _CharT* __str, size_type __pos, size_type __n) const noexcept
     {
@@ -106,7 +106,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     rfind(_CharT __c, size_type __pos) const noexcept
     {
@@ -123,7 +123,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_first_of(const _CharT* __str, size_type __pos, size_type __n) const
     {
@@ -139,7 +139,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_last_of(const _CharT* __str, size_type __pos, size_type __n) const
     {
@@ -160,7 +160,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_first_not_of(const _CharT* __str, size_type __pos, size_type __n) const
     {
@@ -172,7 +172,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_first_not_of(_CharT __c, size_type __pos) const noexcept
     {
@@ -183,7 +183,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_last_not_of(const _CharT* __str, size_type __pos, size_type __n) const
     {
@@ -204,7 +204,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_last_not_of(_CharT __c, size_type __pos) const noexcept
     {
Index: libstdc++-v3/include/experimental/bits/fs_path.h
===================================================================
--- libstdc++-v3/include/experimental/bits/fs_path.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/experimental/bits/fs_path.h	(.../branches/gcc-7-branch)
@@ -724,10 +724,10 @@
     pointer   operator->() const { return std::__addressof(**this); }
 
     iterator& operator++();
-    iterator  operator++(int) { auto __tmp = *this; ++_M_cur; return __tmp; }
+    iterator  operator++(int) { auto __tmp = *this; ++*this; return __tmp; }
 
     iterator& operator--();
-    iterator  operator--(int) { auto __tmp = *this; --_M_cur; return __tmp; }
+    iterator  operator--(int) { auto __tmp = *this; --*this; return __tmp; }
 
     friend bool operator==(const iterator& __lhs, const iterator& __rhs)
     { return __lhs._M_equals(__rhs); }
Index: libstdc++-v3/include/ext/new_allocator.h
===================================================================
--- libstdc++-v3/include/ext/new_allocator.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/ext/new_allocator.h	(.../branches/gcc-7-branch)
@@ -96,7 +96,7 @@
       // NB: __n is permitted to be 0.  The C++ standard says nothing
       // about what the return value is when __n == 0.
       pointer
-      allocate(size_type __n, const void* = 0)
+      allocate(size_type __n, const void* = static_cast<const void*>(0))
       {
 	if (__n > this->max_size())
 	  std::__throw_bad_alloc();
Index: libstdc++-v3/include/bits/c++17_warning.h
===================================================================
--- libstdc++-v3/include/bits/c++17_warning.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/c++17_warning.h	(.../branches/gcc-7-branch)	(nonexistent)
@@ -1,37 +0,0 @@
-// Copyright (C) 2016-2017 Free Software Foundation, Inc.
-//
-// This file is part of the GNU ISO C++ Library.  This library is free
-// software; you can redistribute it and/or modify it under the
-// terms of the GNU General Public License as published by the
-// Free Software Foundation; either version 3, or (at your option)
-// any later version.
-
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-
-// Under Section 7 of GPL version 3, you are granted additional
-// permissions described in the GCC Runtime Library Exception, version
-// 3.1, as published by the Free Software Foundation.
-
-// You should have received a copy of the GNU General Public License and
-// a copy of the GCC Runtime Library Exception along with this program;
-// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
-// <http://www.gnu.org/licenses/>.
-
-/** @file bits/c++17_warning.h
- *  This is an internal header file, included by other library headers.
- *  Do not attempt to use it directly. @headername{iosfwd}
- */
-
-#ifndef _CXX17_WARNING_H
-#define _CXX17_WARNING_H 1
-
-#if __cplusplus <= 201402L
-#error This file requires compiler and library support \
-for the ISO C++ 2017 standard. This support must be enabled \
-with the -std=c++17 or -std=gnu++17 compiler options.
-#endif
-
-#endif
Index: libstdc++-v3/include/bits/hashtable.h
===================================================================
--- libstdc++-v3/include/bits/hashtable.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/hashtable.h	(.../branches/gcc-7-branch)
@@ -973,17 +973,8 @@
 	    _M_bucket_count = __bkt_count;
 	  }
 
-	__try
-	  {
-	    for (; __f != __l; ++__f)
-	      this->insert(*__f);
-	  }
-	__catch(...)
-	  {
-	    clear();
-	    _M_deallocate_buckets();
-	    __throw_exception_again;
-	  }
+	for (; __f != __l; ++__f)
+	  this->insert(*__f);
       }
 
   template<typename _Key, typename _Value,
Index: libstdc++-v3/include/bits/basic_ios.h
===================================================================
--- libstdc++-v3/include/bits/basic_ios.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/basic_ios.h	(.../branches/gcc-7-branch)
@@ -157,8 +157,8 @@
       setstate(iostate __state)
       { this->clear(this->rdstate() | __state); }
 
-      // Flip the internal state on for the proper state bits, then re
-      // throws the propagated exception if bit also set in
+      // Flip the internal state on for the proper state bits, then
+      // rethrows the propagated exception if bit also set in
       // exceptions().
       void
       _M_setstate(iostate __state)
Index: libstdc++-v3/include/bits/stl_stack.h
===================================================================
--- libstdc++-v3/include/bits/stl_stack.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/stl_stack.h	(.../branches/gcc-7-branch)
@@ -86,7 +86,7 @@
    *
    *  The second template parameter defines the type of the underlying
    *  sequence/container.  It defaults to std::deque, but it can be
-   *  any type that supports @c back, @c push_back, and @c pop_front,
+   *  any type that supports @c back, @c push_back, and @c pop_back,
    *  such as std::list, std::vector, or an appropriate user-defined
    *  type.
    *
Index: libstdc++-v3/include/bits/stl_iterator_base_types.h
===================================================================
--- libstdc++-v3/include/bits/stl_iterator_base_types.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/stl_iterator_base_types.h	(.../branches/gcc-7-branch)
@@ -200,7 +200,8 @@
    *  sugar for internal library use only.
   */
   template<typename _Iter>
-    inline typename iterator_traits<_Iter>::iterator_category
+    inline _GLIBCXX_CONSTEXPR
+    typename iterator_traits<_Iter>::iterator_category
     __iterator_category(const _Iter&)
     { return typename iterator_traits<_Iter>::iterator_category(); }
 
Index: libstdc++-v3/include/bits/basic_string.h
===================================================================
--- libstdc++-v3/include/bits/basic_string.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/basic_string.h	(.../branches/gcc-7-branch)
@@ -115,8 +115,24 @@
       template<typename _Tp, typename _Res>
 	using _If_sv = enable_if_t<
 	  __and_<is_convertible<const _Tp&, __sv_type>,
+		 __not_<is_convertible<const _Tp*, const basic_string*>>,
 		 __not_<is_convertible<const _Tp&, const _CharT*>>>::value,
 	  _Res>;
+
+      // Allows an implicit conversion to __sv_type.
+      static __sv_type
+      _S_to_string_view(__sv_type __svt) noexcept
+      { return __svt; }
+
+      // Wraps a string_view by explicit conversion and thus
+      // allows to add an internal constructor that does not
+      // participate in overload resolution when a string_view
+      // is provided.
+      struct __sv_wrapper
+      {
+	explicit __sv_wrapper(__sv_type __sv) noexcept : _M_sv(__sv) { }
+	__sv_type _M_sv;
+      };
 #endif
 
       // Use empty-base optimization: http://www.cantrip.org/emptyopt.html
@@ -593,7 +609,7 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Construct string from a substring of a string_view.
-       *  @param  __t   Source string view.
+       *  @param  __t   Source object convertible to string view.
        *  @param  __pos The index of the first character to copy from __t.
        *  @param  __n   The number of characters to copy from __t.
        *  @param  __a   Allocator to use.
@@ -601,16 +617,27 @@
       template<typename _Tp, typename = _If_sv<_Tp, void>>
 	basic_string(const _Tp& __t, size_type __pos, size_type __n,
 		     const _Alloc& __a = _Alloc())
-	: basic_string(__sv_type(__t).substr(__pos, __n), __a) { }
+	: basic_string(_S_to_string_view(__t).substr(__pos, __n), __a) { }
 
       /**
        *  @brief  Construct string from a string_view.
-       *  @param  __sv  Source string view.
+       *  @param  __t  Source object convertible to string view.
        *  @param  __a  Allocator to use (default is default allocator).
        */
+      template<typename _Tp, typename = _If_sv<_Tp, void>>
+	explicit
+	basic_string(const _Tp& __t, const _Alloc& __a = _Alloc())
+	: basic_string(__sv_wrapper(_S_to_string_view(__t)), __a) { }
+
+      /**
+       *  @brief  Only internally used: Construct string from a string view
+       *          wrapper.
+       *  @param  __svw  string view wrapper.
+       *  @param  __a  Allocator to use.
+       */
       explicit
-      basic_string(__sv_type __sv, const _Alloc& __a = _Alloc())
-      : basic_string(__sv.data(), __sv.size(), __a) { }
+      basic_string(__sv_wrapper __svw, const _Alloc& __a)
+      : basic_string(__svw._M_sv.data(), __svw._M_sv.size(), __a) { }
 #endif // C++17
 
       /**
@@ -756,12 +783,12 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Set value to string constructed from a string_view.
-       *  @param  __sv  A string_view.
+       *  @param  __svt  An object convertible to string_view.
        */
-      template<typename _Tp>
-	_If_sv<_Tp, basic_string&>
-	operator=(_Tp __sv)
-	{ return this->assign(__sv); }
+     template<typename _Tp>
+       _If_sv<_Tp, basic_string&>
+       operator=(const _Tp& __svt)
+       { return this->assign(__svt); }
 
       /**
        *  @brief  Convert to a string_view.
@@ -768,7 +795,7 @@
        *  @return A string_view.
        */
       operator __sv_type() const noexcept
-      {	return __sv_type(data(), size()); }
+      { return __sv_type(data(), size()); }
 #endif // C++17
 
       // Iterators:
@@ -1157,12 +1184,13 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Append a string_view.
-       *  @param __sv  The string_view to be appended.
+       *  @param __svt  An object convertible to string_view to be appended.
        *  @return  Reference to this string.
        */
-      basic_string&
-      operator+=(__sv_type __sv)
-      {	return this->append(__sv); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	operator+=(const _Tp& __svt)
+	{ return this->append(__svt); }
 #endif // C++17
 
       /**
@@ -1265,22 +1293,26 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Append a string_view.
-       *  @param __sv  The string_view to be appended.
+       *  @param __svt  An object convertible to string_view to be appended.
        *  @return  Reference to this string.
        */
-      basic_string&
-      append(__sv_type __sv)
-      { return this->append(__sv.data(), __sv.size()); }
+      template<typename _Tp>
+        _If_sv<_Tp, basic_string&>
+        append(const _Tp& __svt)
+        {
+          __sv_type __sv = __svt;
+          return this->append(__sv.data(), __sv.size());
+        }
 
       /**
        *  @brief  Append a range of characters from a string_view.
-       *  @param __sv  The string_view to be appended from.
+       *  @param __svt  An object convertible to string_view to be appended from.
        *  @param __pos The position in the string_view to append from.
        *  @param __n   The number of characters to append from the string_view.
        *  @return  Reference to this string.
        */
-      template <typename _Tp>
-	_If_sv<_Tp, basic_string&>
+      template<typename _Tp>
+        _If_sv<_Tp, basic_string&>
 	append(const _Tp& __svt, size_type __pos, size_type __n = npos)
 	{
 	  __sv_type __sv = __svt;
@@ -1433,21 +1465,25 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Set value from a string_view.
-       *  @param __sv  The source string_view.
+       *  @param __svt  The source object convertible to string_view.
        *  @return  Reference to this string.
        */
-      basic_string&
-      assign(__sv_type __sv)
-      {	return this->assign(__sv.data(), __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	assign(const _Tp& __svt)
+	{
+	  __sv_type __sv = __svt;
+	  return this->assign(__sv.data(), __sv.size());
+	}
 
       /**
        *  @brief  Set value from a range of characters in a string_view.
-       *  @param __sv  The source string_view.
+       *  @param __svt  The source object convertible to string_view.
        *  @param __pos  The position in the string_view to assign from.
        *  @param __n  The number of characters to assign.
        *  @return  Reference to this string.
        */
-      template <typename _Tp>
+      template<typename _Tp>
 	_If_sv<_Tp, basic_string&>
 	assign(const _Tp& __svt, size_type __pos, size_type __n = npos)
 	{
@@ -1692,23 +1728,27 @@
       /**
        *  @brief  Insert a string_view.
        *  @param __pos  Iterator referencing position in string to insert at.
-       *  @param __sv   The string_view to insert.
+       *  @param __svt  The object convertible to string_view to insert.
        *  @return  Reference to this string.
       */
-      basic_string&
-      insert(size_type __pos, __sv_type __sv)
-      {	return this->insert(__pos, __sv.data(), __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	insert(size_type __pos, const _Tp& __svt)
+	{
+	  __sv_type __sv = __svt;
+	  return this->insert(__pos, __sv.data(), __sv.size());
+	}
 
       /**
        *  @brief  Insert a string_view.
        *  @param __pos  Iterator referencing position in string to insert at.
-       *  @param __sv   The string_view to insert from.
+       *  @param __svt  The object convertible to string_view to insert from.
        *  @param __pos  Iterator referencing position in string_view to insert
        *  from.
        *  @param __n    The number of characters to insert.
        *  @return  Reference to this string.
       */
-      template <typename _Tp>
+      template<typename _Tp>
 	_If_sv<_Tp, basic_string&>
 	insert(size_type __pos1, const _Tp& __svt,
 	       size_type __pos2, size_type __n = npos)
@@ -2120,23 +2160,27 @@
        *  @brief  Replace range of characters with string_view.
        *  @param __pos  The position to replace at.
        *  @param __n    The number of characters to replace.
-       *  @param __sv  The string_view to insert.
+       *  @param __svt  The object convertible to string_view to insert.
        *  @return  Reference to this string.
       */
-      basic_string&
-      replace(size_type __pos, size_type __n, __sv_type __sv)
-      {	return this->replace(__pos, __n, __sv.data(), __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	replace(size_type __pos, size_type __n, const _Tp& __svt)
+	{
+	  __sv_type __sv = __svt;
+	  return this->replace(__pos, __n, __sv.data(), __sv.size());
+	}
 
       /**
        *  @brief  Replace range of characters with string_view.
        *  @param __pos1  The position to replace at.
        *  @param __n1    The number of characters to replace.
-       *  @param __sv    The string_view to insert from.
+       *  @param __svt   The object convertible to string_view to insert from.
        *  @param __pos2  The position in the string_view to insert from.
        *  @param __n2    The number of characters to insert.
        *  @return  Reference to this string.
       */
-      template <typename _Tp>
+      template<typename _Tp>
 	_If_sv<_Tp, basic_string&>
 	replace(size_type __pos1, size_type __n1, const _Tp& __svt,
 		size_type __pos2, size_type __n2 = npos)
@@ -2153,12 +2197,16 @@
           to replace at.
        *  @param __i2    An iterator referencing the end position
           for the replace.
-       *  @param __sv    The string_view to insert from.
+       *  @param __svt   The object convertible to string_view to insert from.
        *  @return  Reference to this string.
       */
-      basic_string&
-      replace(const_iterator __i1, const_iterator __i2, __sv_type __sv)
-      {	return this->replace(__i1 - begin(), __i2 - __i1, __sv); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	replace(const_iterator __i1, const_iterator __i2, const _Tp& __svt)
+	{
+	  __sv_type __sv = __svt;
+	  return this->replace(__i1 - begin(), __i2 - __i1, __sv);
+	}
 #endif // C++17
 
     private:
@@ -2288,13 +2336,18 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find position of a string_view.
-       *  @param __sv  The string_view to locate.
+       *  @param __svt  The object convertible to string_view to locate.
        *  @param __pos  Index of character to search from (default 0).
        *  @return  Index of start of first occurrence.
       */
-      size_type
-      find(__sv_type __sv, size_type __pos = 0) const noexcept
-      {	return this->find(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find(const _Tp& __svt, size_type __pos = 0) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -2345,13 +2398,18 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find last position of a string_view.
-       *  @param __sv   The string_view to locate.
+       *  @param __svt  The object convertible to string_view to locate.
        *  @param __pos  Index of character to search back from (default end).
        *  @return  Index of start of last occurrence.
       */
-      size_type
-      rfind(__sv_type __sv, size_type __pos = npos) const noexcept
-      {	return this->rfind(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	rfind(const _Tp& __svt, size_type __pos = npos) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->rfind(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -2419,13 +2477,19 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find position of a character of a string_view.
-       *  @param __sv   A string_view containing characters to locate.
+       *  @param __svt  An object convertible to string_view containing
+       *                characters to locate.
        *  @param __pos  Index of character to search from (default 0).
        *  @return  Index of first occurrence.
       */
-      size_type
-      find_first_of(__sv_type __sv, size_type __pos = 0) const noexcept
-      {	return this->find_first_of(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find_first_of(const _Tp& __svt, size_type __pos = 0) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find_first_of(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -2497,13 +2561,19 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find last position of a character of string.
-       *  @param __sv   A string_view containing characters to locate.
+       *  @param __svt  An object convertible to string_view containing
+       *                characters to locate.
        *  @param __pos  Index of character to search back from (default end).
        *  @return  Index of last occurrence.
       */
-      size_type
-      find_last_of(__sv_type __sv, size_type __pos = npos) const noexcept
-      {	return this->find_last_of(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find_last_of(const _Tp& __svt, size_type __pos = npos) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find_last_of(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -2574,13 +2644,19 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find position of a character not in a string_view.
-       *  @param __sv   A string_view containing characters to avoid.
+       *  @param __svt  A object convertible to string_view containing
+       *                characters to avoid.
        *  @param __pos  Index of character to search from (default 0).
        *  @return  Index of first occurrence.
        */
-      size_type
-      find_first_not_of(__sv_type __sv, size_type __pos = 0) const noexcept
-      {	return this->find_first_not_of(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find_first_not_of(const _Tp& __svt, size_type __pos = 0) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find_first_not_of(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -2650,13 +2726,19 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find last position of a character not in a string_view.
-       *  @param __sv   A string_view containing characters to avoid.
+       *  @param __svt  An object convertible to string_view containing
+       *                characters to avoid.
        *  @param __pos  Index of character to search back from (default end).
        *  @return  Index of last occurrence.
        */
-      size_type
-      find_last_not_of(__sv_type __sv, size_type __pos = npos) const noexcept
-      {	return this->find_last_not_of(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find_last_not_of(const _Tp& __svt, size_type __pos = npos) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find_last_not_of(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -2754,46 +2836,57 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Compare to a string_view.
-       *  @param __sv  A string_view to compare against.
+       *  @param __svt An object convertible to string_view to compare against.
        *  @return  Integer < 0, 0, or > 0.
        */
-      int
-      compare(__sv_type __sv) const
-      {
-	const size_type __size = this->size();
-	const size_type __osize = __sv.size();
-	const size_type __len = std::min(__size, __osize);
+      template<typename _Tp>
+	_If_sv<_Tp, int>
+	compare(const _Tp& __svt) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  const size_type __size = this->size();
+	  const size_type __osize = __sv.size();
+	  const size_type __len = std::min(__size, __osize);
 
-	int __r = traits_type::compare(_M_data(), __sv.data(), __len);
-	if (!__r)
-	  __r = _S_compare(__size, __osize);
-	return __r;
-      }
+	  int __r = traits_type::compare(_M_data(), __sv.data(), __len);
+	  if (!__r)
+	    __r = _S_compare(__size, __osize);
+	  return __r;
+	}
 
       /**
        *  @brief  Compare to a string_view.
        *  @param __pos  A position in the string to start comparing from.
        *  @param __n  The number of characters to compare.
-       *  @param __sv   A string_view to compare against.
+       *  @param __svt  An object convertible to string_view to compare
+       *                against.
        *  @return  Integer < 0, 0, or > 0.
        */
-      int
-      compare(size_type __pos, size_type __n, __sv_type __sv) const
-      { return __sv_type(*this).substr(__pos, __n).compare(__sv); }
+      template<typename _Tp>
+	_If_sv<_Tp, int>
+	compare(size_type __pos, size_type __n, const _Tp& __svt) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return __sv_type(*this).substr(__pos, __n).compare(__sv);
+	}
 
       /**
        *  @brief  Compare to a string_view.
        *  @param __pos1  A position in the string to start comparing from.
        *  @param __n1  The number of characters to compare.
-       *  @param __sv   A string_view to compare against.
+       *  @param __svt  An object convertible to string_view to compare
+       *                against.
        *  @param __pos2  A position in the string_view to start comparing from.
        *  @param __n2  The number of characters to compare.
        *  @return  Integer < 0, 0, or > 0.
        */
-      template <typename _Tp>
+      template<typename _Tp>
 	_If_sv<_Tp, int>
 	compare(size_type __pos1, size_type __n1, const _Tp& __svt,
 		size_type __pos2, size_type __n2 = npos) const
+	noexcept(is_same<_Tp, __sv_type>::value)
 	{
 	  __sv_type __sv = __svt;
 	  return __sv_type(*this)
@@ -2918,7 +3011,10 @@
       int
       compare(size_type __pos, size_type __n1, const _CharT* __s,
 	      size_type __n2) const;
-  };
+
+      // Allow basic_stringbuf::__xfer_bufptrs to call _M_length:
+      template<typename, typename, typename> friend class basic_stringbuf;
+    };
 _GLIBCXX_END_NAMESPACE_CXX11
 #else  // !_GLIBCXX_USE_CXX11_ABI
   // Reference-counted COW string implentation
@@ -3343,8 +3439,24 @@
       template<typename _Tp, typename _Res>
 	using _If_sv = enable_if_t<
 	  __and_<is_convertible<const _Tp&, __sv_type>,
+		 __not_<is_convertible<const _Tp*, const basic_string*>>,
 		 __not_<is_convertible<const _Tp&, const _CharT*>>>::value,
 	  _Res>;
+
+      // Allows an implicit conversion to __sv_type.
+      static __sv_type
+      _S_to_string_view(__sv_type __svt) noexcept
+      { return __svt; }
+
+      // Wraps a string_view by explicit conversion and thus
+      // allows to add an internal constructor that does not
+      // participate in overload resolution when a string_view
+      // is provided.
+      struct __sv_wrapper
+      {
+	explicit __sv_wrapper(__sv_type __sv) noexcept : _M_sv(__sv) { }
+	__sv_type _M_sv;
+      };
 #endif
 
     public:
@@ -3471,7 +3583,7 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Construct string from a substring of a string_view.
-       *  @param  __t   Source string view.
+       *  @param  __t   Source object convertible to string view.
        *  @param  __pos The index of the first character to copy from __t.
        *  @param  __n   The number of characters to copy from __t.
        *  @param  __a   Allocator to use.
@@ -3479,16 +3591,27 @@
       template<typename _Tp, typename = _If_sv<_Tp, void>>
 	basic_string(const _Tp& __t, size_type __pos, size_type __n,
 		     const _Alloc& __a = _Alloc())
-	: basic_string(__sv_type(__t).substr(__pos, __n), __a) { }
+	: basic_string(_S_to_string_view(__t).substr(__pos, __n), __a) { }
 
       /**
        *  @brief  Construct string from a string_view.
-       *  @param  __sv  Source string view.
+       *  @param  __t  Source object convertible to string view.
        *  @param  __a  Allocator to use (default is default allocator).
        */
+      template<typename _Tp, typename = _If_sv<_Tp, void>>
+	explicit
+	basic_string(const _Tp& __t, const _Alloc& __a = _Alloc())
+	: basic_string(__sv_wrapper(_S_to_string_view(__t)), __a) { }
+
+      /**
+       *  @brief  Only internally used: Construct string from a string view
+       *          wrapper.
+       *  @param  __svw  string view wrapper.
+       *  @param  __a  Allocator to use.
+       */
       explicit
-      basic_string(__sv_type __sv, const _Alloc& __a = _Alloc())
-      : basic_string(__sv.data(), __sv.size(), __a) { }
+      basic_string(__sv_wrapper __svw, const _Alloc& __a)
+      : basic_string(__svw._M_sv.data(), __svw._M_sv.size(), __a) { }
 #endif // C++17
 
       /**
@@ -3559,12 +3682,12 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Set value to string constructed from a string_view.
-       *  @param  __sv  A string_view.
+       *  @param  __svt An object convertible to  string_view.
        */
       template<typename _Tp>
 	_If_sv<_Tp, basic_string&>
-	operator=(_Tp __sv)
-	{ return this->assign(__sv); }
+	operator=(const _Tp& __svt)
+	{ return this->assign(__svt); }
 
       /**
        *  @brief  Convert to a string_view.
@@ -3981,12 +4104,13 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Append a string_view.
-       *  @param __sv  The string_view to be appended.
+       *  @param __svt The object convertible to string_view to be appended.
        *  @return  Reference to this string.
        */
-      basic_string&
-      operator+=(__sv_type __sv)
-      { return this->append(__sv); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	operator+=(const _Tp& __svt)
+	{ return this->append(__svt); }
 #endif // C++17
 
       /**
@@ -4072,22 +4196,27 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Append a string_view.
-       *  @param __sv  The string_view to be appended.
+       *  @param __svt The object convertible to string_view to be appended.
        *  @return  Reference to this string.
        */
-      basic_string&
-      append(__sv_type __sv)
-      { return this->append(__sv.data(), __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	append(const _Tp& __svt)
+	{
+	  __sv_type __sv = __svt;
+	  return this->append(__sv.data(), __sv.size());
+	}
 
       /**
        *  @brief  Append a range of characters from a string_view.
-       *  @param __sv  The string_view to be appended from.
+       *  @param __svt The object convertible to string_view to be appended
+       *               from.
        *  @param __pos The position in the string_view to append from.
        *  @param __n   The number of characters to append from the string_view.
        *  @return  Reference to this string.
        */
-      template <typename _Tp>
-	_If_sv<_Tp, basic_string&>
+      template<typename _Tp>
+        _If_sv<_Tp, basic_string&>
 	append(const _Tp& __svt, size_type __pos, size_type __n = npos)
 	{
 	  __sv_type __sv = __svt;
@@ -4225,23 +4354,27 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Set value from a string_view.
-       *  @param __sv  The source string_view.
+       *  @param __svt The source object convertible to string_view.
        *  @return  Reference to this string.
        */
-      basic_string&
-      assign(__sv_type __sv)
-      { return this->assign(__sv.data(), __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	assign(const _Tp& __svt)
+	{
+	  __sv_type __sv = __svt;
+	  return this->assign(__sv.data(), __sv.size());
+	}
 
       /**
        *  @brief  Set value from a range of characters in a string_view.
-       *  @param __sv  The source string_view.
+       *  @param __svt  The source object convertible to string_view.
        *  @param __pos  The position in the string_view to assign from.
        *  @param __n  The number of characters to assign.
        *  @return  Reference to this string.
        */
-      template <typename _Tp>
-	_If_sv<_Tp, basic_string&>
-	assign(const _Tp& __svt, size_type __pos, size_type __n = npos)
+      template<typename _Tp>
+        _If_sv<_Tp, basic_string&>
+        assign(const _Tp& __svt, size_type __pos, size_type __n = npos)
 	{
 	  __sv_type __sv = __svt;
 	  return assign(__sv.data()
@@ -4429,25 +4562,29 @@
       /**
        *  @brief  Insert a string_view.
        *  @param __pos  Iterator referencing position in string to insert at.
-       *  @param __sv   The string_view to insert.
+       *  @param __svt  The object convertible to string_view to insert.
        *  @return  Reference to this string.
       */
-      basic_string&
-      insert(size_type __pos, __sv_type __sv)
-      { return this->insert(__pos, __sv.data(), __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	insert(size_type __pos, const _Tp& __svt)
+	{
+	  __sv_type __sv = __svt;
+	  return this->insert(__pos, __sv.data(), __sv.size());
+	}
 
       /**
        *  @brief  Insert a string_view.
        *  @param __pos  Iterator referencing position in string to insert at.
-       *  @param __sv   The string_view to insert from.
+       *  @param __svt  The object convertible to string_view to insert from.
        *  @param __pos  Iterator referencing position in string_view to insert
        *  from.
        *  @param __n    The number of characters to insert.
        *  @return  Reference to this string.
       */
-      template <typename _Tp>
-	_If_sv<_Tp, basic_string&>
-	insert(size_type __pos1, const _Tp& __svt,
+      template<typename _Tp>
+        _If_sv<_Tp, basic_string&>
+        insert(size_type __pos1, const _Tp& __svt,
 	       size_type __pos2, size_type __n = npos)
 	{
 	  __sv_type __sv = __svt;
@@ -4790,7 +4927,7 @@
 	return this->replace(__i1 - _M_ibegin(), __i2 - __i1,
 			     __k1.base(), __k2 - __k1);
       }
-      
+
 #if __cplusplus >= 201103L
       /**
        *  @brief  Replace range of characters with initializer_list.
@@ -4816,31 +4953,35 @@
        *  @brief  Replace range of characters with string_view.
        *  @param __pos  The position to replace at.
        *  @param __n    The number of characters to replace.
-       *  @param __sv  The string_view to insert.
+       *  @param __svt  The object convertible to string_view to insert.
        *  @return  Reference to this string.
       */
-      basic_string&
-      replace(size_type __pos, size_type __n, __sv_type __sv)
-      { return this->replace(__pos, __n, __sv.data(), __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	replace(size_type __pos, size_type __n, const _Tp& __svt)
+	{
+	  __sv_type __sv = __svt;
+	  return this->replace(__pos, __n, __sv.data(), __sv.size());
+	}
 
       /**
        *  @brief  Replace range of characters with string_view.
        *  @param __pos1  The position to replace at.
        *  @param __n1    The number of characters to replace.
-       *  @param __sv    The string_view to insert from.
+       *  @param __svt   The object convertible to string_view to insert from.
        *  @param __pos2  The position in the string_view to insert from.
        *  @param __n2    The number of characters to insert.
        *  @return  Reference to this string.
       */
-      template <typename _Tp>
-	_If_sv<_Tp, basic_string&>
-	replace(size_type __pos1, size_type __n1, const _Tp& __svt,
+      template<typename _Tp>
+        _If_sv<_Tp, basic_string&>
+        replace(size_type __pos1, size_type __n1, const _Tp& __svt,
 		size_type __pos2, size_type __n2 = npos)
 	{
 	  __sv_type __sv = __svt;
-	  return this->replace(__pos1, __n1, __sv.data()
-			       + __sv._M_check(__pos2, "basic_string::replace"),
-			       __sv._M_limit(__pos2, __n2));
+	  return this->replace(__pos1, __n1,
+	      __sv.data() + __sv._M_check(__pos2, "basic_string::replace"),
+	      __sv._M_limit(__pos2, __n2));
 	}
 
       /**
@@ -4849,12 +4990,16 @@
           to replace at.
        *  @param __i2    An iterator referencing the end position
           for the replace.
-       *  @param __sv    The string_view to insert from.
+       *  @param __svt   The object convertible to string_view to insert from.
        *  @return  Reference to this string.
       */
-      basic_string&
-      replace(const_iterator __i1, const_iterator __i2, __sv_type __sv)
-      { return this->replace(__i1 - begin(), __i2 - __i1, __sv); }
+      template<typename _Tp>
+	_If_sv<_Tp, basic_string&>
+	replace(const_iterator __i1, const_iterator __i2, const _Tp& __svt)
+	{
+	  __sv_type __sv = __svt;
+	  return this->replace(__i1 - begin(), __i2 - __i1, __sv);
+	}
 #endif // C++17
 
     private:
@@ -5059,13 +5204,18 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find position of a string_view.
-       *  @param __sv  The string_view to locate.
+       *  @param __svt  The object convertible to string_view to locate.
        *  @param __pos  Index of character to search from (default 0).
        *  @return  Index of start of first occurrence.
       */
-      size_type
-      find(__sv_type __sv, size_type __pos = 0) const noexcept
-      { return this->find(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find(const _Tp& __svt, size_type __pos = 0) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -5132,13 +5282,18 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find last position of a string_view.
-       *  @param __sv   The string_view to locate.
+       *  @param __svt  The object convertible to string_view to locate.
        *  @param __pos  Index of character to search back from (default end).
        *  @return  Index of start of last occurrence.
       */
-      size_type
-      rfind(__sv_type __sv, size_type __pos = npos) const noexcept
-      { return this->rfind(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	rfind(const _Tp& __svt, size_type __pos = npos) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->rfind(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -5210,13 +5365,19 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find position of a character of a string_view.
-       *  @param __sv   A string_view containing characters to locate.
+       *  @param __svt  An object convertible to string_view containing
+       *                characters to locate.
        *  @param __pos  Index of character to search from (default 0).
        *  @return  Index of first occurrence.
       */
-      size_type
-      find_first_of(__sv_type __sv, size_type __pos = 0) const noexcept
-      { return this->find_first_of(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find_first_of(const _Tp& __svt, size_type __pos = 0) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find_first_of(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -5288,13 +5449,19 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find last position of a character of string.
-       *  @param __sv   A string_view containing characters to locate.
+       *  @param __svt  An object convertible to string_view containing
+       *                characters to locate.
        *  @param __pos  Index of character to search back from (default end).
        *  @return  Index of last occurrence.
       */
-      size_type
-      find_last_of(__sv_type __sv, size_type __pos = npos) const noexcept
-      { return this->find_last_of(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find_last_of(const _Tp& __svt, size_type __pos = npos) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find_last_of(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -5363,13 +5530,19 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find position of a character not in a string_view.
-       *  @param __sv   A string_view containing characters to avoid.
+       *  @param __svt  An object convertible to string_view containing
+       *                characters to avoid.
        *  @param __pos  Index of character to search from (default 0).
        *  @return  Index of first occurrence.
        */
-      size_type
-      find_first_not_of(__sv_type __sv, size_type __pos = 0) const noexcept
-      { return this->find_first_not_of(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find_first_not_of(const _Tp& __svt, size_type __pos = 0) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find_first_not_of(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -5439,13 +5612,19 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Find last position of a character not in a string_view.
-       *  @param __sv   A string_view containing characters to avoid.
+       *  @param __svt  An object convertible to string_view containing
+       *                characters to avoid.
        *  @param __pos  Index of character to search back from (default end).
        *  @return  Index of last occurrence.
        */
-      size_type
-      find_last_not_of(__sv_type __sv, size_type __pos = npos) const noexcept
-      { return this->find_last_not_of(__sv.data(), __pos, __sv.size()); }
+      template<typename _Tp>
+	_If_sv<_Tp, size_type>
+	find_last_not_of(const _Tp& __svt, size_type __pos = npos) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return this->find_last_not_of(__sv.data(), __pos, __sv.size());
+	}
 #endif // C++17
 
       /**
@@ -5495,46 +5674,57 @@
 #if __cplusplus > 201402L
       /**
        *  @brief  Compare to a string_view.
-       *  @param __sv  A string_view to compare against.
+       *  @param __svt An object convertible to string_view to compare against.
        *  @return  Integer < 0, 0, or > 0.
        */
-      int
-      compare(__sv_type __sv) const
-      {
-	const size_type __size = this->size();
-	const size_type __osize = __sv.size();
-	const size_type __len = std::min(__size, __osize);
+      template<typename _Tp>
+	_If_sv<_Tp, int>
+	compare(const _Tp& __svt) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	   __sv_type __sv = __svt;
+	  const size_type __size = this->size();
+	  const size_type __osize = __sv.size();
+	  const size_type __len = std::min(__size, __osize);
 
-	int __r = traits_type::compare(_M_data(), __sv.data(), __len);
-	if (!__r)
-	  __r = _S_compare(__size, __osize);
-	return __r;
-      }
+	  int __r = traits_type::compare(_M_data(), __sv.data(), __len);
+	  if (!__r)
+	    __r = _S_compare(__size, __osize);
+	  return __r;
+	}
 
       /**
        *  @brief  Compare to a string_view.
        *  @param __pos  A position in the string to start comparing from.
        *  @param __n  The number of characters to compare.
-       *  @param __sv   A string_view to compare against.
+       *  @param __svt  An object convertible to string_view to compare
+       *                against.
        *  @return  Integer < 0, 0, or > 0.
        */
-      int
-      compare(size_type __pos, size_type __n, __sv_type __sv) const
-      { return __sv_type(*this).substr(__pos, __n).compare(__sv); }
+      template<typename _Tp>
+	_If_sv<_Tp, int>
+	compare(size_type __pos, size_type __n, const _Tp& __svt) const
+	noexcept(is_same<_Tp, __sv_type>::value)
+	{
+	  __sv_type __sv = __svt;
+	  return __sv_type(*this).substr(__pos, __n).compare(__sv);
+	}
 
       /**
        *  @brief  Compare to a string_view.
        *  @param __pos1  A position in the string to start comparing from.
        *  @param __n1  The number of characters to compare.
-       *  @param __sv   A string_view to compare against.
+       *  @param __svt   An object convertible to string_view to compare
+       *                 against.
        *  @param __pos2  A position in the string_view to start comparing from.
        *  @param __n2  The number of characters to compare.
        *  @return  Integer < 0, 0, or > 0.
        */
-      template <typename _Tp>
+      template<typename _Tp>
 	_If_sv<_Tp, int>
 	compare(size_type __pos1, size_type __n1, const _Tp& __svt,
 		size_type __pos2, size_type __n2 = npos) const
+	noexcept(is_same<_Tp, __sv_type>::value)
 	{
 	  __sv_type __sv = __svt;
 	  return __sv_type(*this)
Index: libstdc++-v3/include/bits/istream.tcc
===================================================================
--- libstdc++-v3/include/bits/istream.tcc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/istream.tcc	(.../branches/gcc-7-branch)
@@ -48,28 +48,36 @@
     {
       ios_base::iostate __err = ios_base::goodbit;
       if (__in.good())
-	{
-	  if (__in.tie())
-	    __in.tie()->flush();
-	  if (!__noskip && bool(__in.flags() & ios_base::skipws))
-	    {
-	      const __int_type __eof = traits_type::eof();
-	      __streambuf_type* __sb = __in.rdbuf();
-	      __int_type __c = __sb->sgetc();
+	__try
+	  {
+	    if (__in.tie())
+	      __in.tie()->flush();
+	    if (!__noskip && bool(__in.flags() & ios_base::skipws))
+	      {
+		const __int_type __eof = traits_type::eof();
+		__streambuf_type* __sb = __in.rdbuf();
+		__int_type __c = __sb->sgetc();
 
-	      const __ctype_type& __ct = __check_facet(__in._M_ctype);
-	      while (!traits_type::eq_int_type(__c, __eof)
-		     && __ct.is(ctype_base::space, 
-				traits_type::to_char_type(__c)))
-		__c = __sb->snextc();
+		const __ctype_type& __ct = __check_facet(__in._M_ctype);
+		while (!traits_type::eq_int_type(__c, __eof)
+		       && __ct.is(ctype_base::space,
+				  traits_type::to_char_type(__c)))
+		  __c = __sb->snextc();
 
-	      // _GLIBCXX_RESOLVE_LIB_DEFECTS
-	      // 195. Should basic_istream::sentry's constructor ever
-	      // set eofbit?
-	      if (traits_type::eq_int_type(__c, __eof))
-		__err |= ios_base::eofbit;
-	    }
-	}
+		// _GLIBCXX_RESOLVE_LIB_DEFECTS
+		// 195. Should basic_istream::sentry's constructor ever
+		// set eofbit?
+		if (traits_type::eq_int_type(__c, __eof))
+		  __err |= ios_base::eofbit;
+	      }
+	  }
+	__catch(__cxxabiv1::__forced_unwind&)
+	  {
+	    __in._M_setstate(ios_base::badbit);
+	    __throw_exception_again;
+	  }
+	__catch(...)
+	  { __in._M_setstate(ios_base::badbit); }
 
       if (__in.good() && __err == ios_base::goodbit)
 	_M_ok = true;
Index: libstdc++-v3/include/bits/sstream.tcc
===================================================================
--- libstdc++-v3/include/bits/sstream.tcc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/sstream.tcc	(.../branches/gcc-7-branch)
@@ -88,6 +88,25 @@
 	return traits_type::not_eof(__c);
 
       const __size_type __capacity = _M_string.capacity();
+
+#if _GLIBCXX_USE_CXX11_ABI
+      if ((this->epptr() - this->pbase()) < __capacity)
+	{
+	  // There is additional capacity in _M_string that can be used.
+	  char_type* __base = const_cast<char_type*>(_M_string.data());
+	  _M_pbump(__base, __base + __capacity, this->pptr() - this->pbase());
+	  if (_M_mode & ios_base::in)
+	    {
+	      const __size_type __nget = this->gptr() - this->eback();
+	      const __size_type __eget = this->egptr() - this->eback();
+	      this->setg(__base, __base + __nget, __base + __eget + 1);
+	    }
+	  *this->pptr() = traits_type::to_char_type(__c);
+	  this->pbump(1);
+	  return __c;
+	}
+#endif
+
       const __size_type __max_size = _M_string.max_size();
       const bool __testput = this->pptr() < this->epptr();
       if (__builtin_expect(!__testput && __capacity == __max_size, false))
Index: libstdc++-v3/include/bits/char_traits.h
===================================================================
--- libstdc++-v3/include/bits/char_traits.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/char_traits.h	(.../branches/gcc-7-branch)
@@ -40,6 +40,10 @@
 #include <bits/postypes.h>      // For streampos
 #include <cwchar>               // For WEOF, wmemmove, wmemset, etc.
 
+#ifndef _GLIBCXX_ALWAYS_INLINE
+#define _GLIBCXX_ALWAYS_INLINE inline __attribute__((__always_inline__))
+#endif
+
 namespace __gnu_cxx _GLIBCXX_VISIBILITY(default)
 {
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
@@ -139,7 +143,7 @@
       { return !eq_int_type(__c, eof()) ? __c : to_int_type(char_type()); }
     };
 
-// #define __cpp_lib_constexpr_char_traits 201611
+#define __cpp_lib_constexpr_char_traits 201611
 
   template<typename _CharT>
     _GLIBCXX14_CONSTEXPR int
@@ -212,6 +216,42 @@
 {
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
+#if __cplusplus > 201402
+  /**
+   *  @brief Determine whether the characters of a NULL-terminated
+   *  string are known at compile time.
+   *  @param  __s  The string.
+   *
+   *  Assumes that _CharT is a built-in character type.
+   */
+  template<typename _CharT>
+    static _GLIBCXX_ALWAYS_INLINE constexpr bool
+    __constant_string_p(const _CharT* __s)
+    {
+      while (__builtin_constant_p(*__s) && *__s)
+	__s++;
+      return __builtin_constant_p(*__s);
+    }
+
+  /**
+   *  @brief Determine whether the characters of a character array are
+   *  known at compile time.
+   *  @param  __a  The character array.
+   *  @param  __n  Number of characters.
+   *
+   *  Assumes that _CharT is a built-in character type.
+   */
+  template<typename _CharT>
+    static _GLIBCXX_ALWAYS_INLINE constexpr bool
+    __constant_char_array_p(const _CharT* __a, size_t __n)
+    {
+      size_t __i = 0;
+      while (__builtin_constant_p(__a[__i]) && __i < __n)
+	__i++;
+      return __i == __n;
+    }
+#endif
+
   // 21.1
   /**
    *  @brief  Basis for explicit traits specializations.
@@ -256,21 +296,39 @@
 		< static_cast<unsigned char>(__c2));
       }
 
-      static /* _GLIBCXX17_CONSTEXPR */ int
+      static _GLIBCXX17_CONSTEXPR int
       compare(const char_type* __s1, const char_type* __s2, size_t __n)
       {
+#if __cplusplus > 201402
+	if (__builtin_constant_p(__n)
+	    && __constant_char_array_p(__s1, __n)
+	    && __constant_char_array_p(__s2, __n))
+	  return __gnu_cxx::char_traits<char_type>::compare(__s1, __s2, __n);
+#endif
 	if (__n == 0)
 	  return 0;
 	return __builtin_memcmp(__s1, __s2, __n);
       }
 
-      static /* _GLIBCXX17_CONSTEXPR */ size_t
+      static _GLIBCXX17_CONSTEXPR size_t
       length(const char_type* __s)
-      { return __builtin_strlen(__s); }
+      {
+#if __cplusplus > 201402
+	if (__constant_string_p(__s))
+	  return __gnu_cxx::char_traits<char_type>::length(__s);
+#endif
+	return __builtin_strlen(__s);
+      }
 
-      static /* _GLIBCXX17_CONSTEXPR */ const char_type*
+      static _GLIBCXX17_CONSTEXPR const char_type*
       find(const char_type* __s, size_t __n, const char_type& __a)
       {
+#if __cplusplus > 201402
+	if (__builtin_constant_p(__n)
+	    && __builtin_constant_p(__a)
+	    && __constant_char_array_p(__s, __n))
+	  return __gnu_cxx::char_traits<char_type>::find(__s, __n, __a);
+#endif
 	if (__n == 0)
 	  return 0;
 	return static_cast<const char_type*>(__builtin_memchr(__s, __a, __n));
@@ -347,24 +405,45 @@
       lt(const char_type& __c1, const char_type& __c2) _GLIBCXX_NOEXCEPT
       { return __c1 < __c2; }
 
-      static /* _GLIBCXX17_CONSTEXPR */ int
+      static _GLIBCXX17_CONSTEXPR int
       compare(const char_type* __s1, const char_type* __s2, size_t __n)
       {
+#if __cplusplus > 201402
+	if (__builtin_constant_p(__n)
+	    && __constant_char_array_p(__s1, __n)
+	    && __constant_char_array_p(__s2, __n))
+	  return __gnu_cxx::char_traits<char_type>::compare(__s1, __s2, __n);
+#endif
 	if (__n == 0)
 	  return 0;
-	return wmemcmp(__s1, __s2, __n);
+	else
+	  return wmemcmp(__s1, __s2, __n);
       }
 
-      static /* _GLIBCXX17_CONSTEXPR */ size_t
+      static _GLIBCXX17_CONSTEXPR size_t
       length(const char_type* __s)
-      { return wcslen(__s); }
+      {
+#if __cplusplus > 201402
+	if (__constant_string_p(__s))
+	  return __gnu_cxx::char_traits<char_type>::length(__s);
+	else
+#endif
+	  return wcslen(__s);
+      }
 
-      static /* _GLIBCXX17_CONSTEXPR */ const char_type*
+      static _GLIBCXX17_CONSTEXPR const char_type*
       find(const char_type* __s, size_t __n, const char_type& __a)
       {
+#if __cplusplus > 201402
+	if (__builtin_constant_p(__n)
+	    && __builtin_constant_p(__a)
+	    && __constant_char_array_p(__s, __n))
+	  return __gnu_cxx::char_traits<char_type>::find(__s, __n, __a);
+#endif
 	if (__n == 0)
 	  return 0;
-	return wmemchr(__s, __a, __n);
+	else
+	  return wmemchr(__s, __a, __n);
       }
 
       static char_type*
Index: libstdc++-v3/include/bits/string_view.tcc
===================================================================
--- libstdc++-v3/include/bits/string_view.tcc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/string_view.tcc	(.../branches/gcc-7-branch)
@@ -36,9 +36,7 @@
 
 #pragma GCC system_header
 
-#if __cplusplus <= 201402L
-# include <bits/c++17_warning.h>
-#else
+#if __cplusplus >= 201703L
 
 namespace std _GLIBCXX_VISIBILITY(default)
 {
@@ -45,7 +43,7 @@
 _GLIBCXX_BEGIN_NAMESPACE_VERSION
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find(const _CharT* __str, size_type __pos, size_type __n) const noexcept
     {
@@ -66,7 +64,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find(_CharT __c, size_type __pos) const noexcept
     {
@@ -82,7 +80,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     rfind(const _CharT* __str, size_type __pos, size_type __n) const noexcept
     {
@@ -102,7 +100,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     rfind(_CharT __c, size_type __pos) const noexcept
     {
@@ -119,7 +117,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_first_of(const _CharT* __str, size_type __pos, size_type __n) const
     {
@@ -135,7 +133,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_last_of(const _CharT* __str, size_type __pos, size_type __n) const
     {
@@ -156,7 +154,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_first_not_of(const _CharT* __str, size_type __pos, size_type __n) const
     {
@@ -168,7 +166,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_first_not_of(_CharT __c, size_type __pos) const noexcept
     {
@@ -179,7 +177,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_last_not_of(const _CharT* __str, size_type __pos, size_type __n) const
     {
@@ -200,7 +198,7 @@
     }
 
   template<typename _CharT, typename _Traits>
-    typename basic_string_view<_CharT, _Traits>::size_type
+    constexpr typename basic_string_view<_CharT, _Traits>::size_type
     basic_string_view<_CharT, _Traits>::
     find_last_not_of(_CharT __c, size_type __pos) const noexcept
     {
Index: libstdc++-v3/include/bits/fstream.tcc
===================================================================
--- libstdc++-v3/include/bits/fstream.tcc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/bits/fstream.tcc	(.../branches/gcc-7-branch)
@@ -699,7 +699,7 @@
  
  	   if (__n == 0)
  	     {
- 	       _M_set_buffer(0);
+	       // Set _M_reading. Buffer is already in initial 'read' mode.
  	       _M_reading = true;
  	     }
  	   else if (__len == 0)
Index: libstdc++-v3/include/c_global/cstddef
===================================================================
--- libstdc++-v3/include/c_global/cstddef	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/c_global/cstddef	(.../branches/gcc-7-branch)
@@ -57,9 +57,11 @@
 }
 #endif
 
-#if __cplusplus > 201402L
+#if __cplusplus >= 201703L
 namespace std
 {
+#define __cpp_lib_byte 201603
+
   /// std::byte
   enum class byte : unsigned char {};
 
Index: libstdc++-v3/include/Makefile.am
===================================================================
--- libstdc++-v3/include/Makefile.am	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/include/Makefile.am	(.../branches/gcc-7-branch)
@@ -96,7 +96,6 @@
 	${bits_srcdir}/boost_concept_check.h \
 	${bits_srcdir}/c++0x_warning.h \
 	${bits_srcdir}/c++14_warning.h \
-	${bits_srcdir}/c++17_warning.h \
 	${bits_srcdir}/char_traits.h \
 	${bits_srcdir}/codecvt.h \
 	${bits_srcdir}/concept_check.h \
Index: libstdc++-v3/libsupc++/cxxabi.h
===================================================================
--- libstdc++-v3/libsupc++/cxxabi.h	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/libsupc++/cxxabi.h	(.../branches/gcc-7-branch)
@@ -182,7 +182,7 @@
    *  with GNU extensions. For example, this function is used in
    *  __gnu_cxx::__verbose_terminate_handler.
    *
-   *  See http://gcc.gnu.org/onlinedocs/libstdc++/manual/bk01pt12ch39.html
+   *  See https://gcc.gnu.org/onlinedocs/libstdc++/manual/ext_demangling.html
    *  for other examples of use.
    *
    *  @note The same demangling functionality is available via
Index: libstdc++-v3/ChangeLog
===================================================================
--- libstdc++-v3/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,405 @@
+2017-10-25  Jonathan Wakely  <jwakely@redhat.com>
+
+	* doc/xml/manual/status_cxx1998.xml: Correct statement about
+	what the doc covers.
+	* doc/xml/manual/status_cxx2011.xml: Likewise.
+	* doc/xml/manual/status_cxx2014.xml: Likewise.
+	* doc/xml/manual/status_cxx2017.xml: Update C++17 status, and
+	information on feature-test macros.
+	* doc/xml/manual/status_cxxtr1.xml: Correct statement about what
+	the doc covers.
+	* doc/xml/manual/status_cxxtr24733.xml: Likewise.
+	* doc/html/*: Regenerate.
+
+2017-10-23  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport from mainline
+	2017-07-18  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/81395
+	* include/bits/fstream.tcc (basic_filebuf::xsgetn): Don't set buffer
+	pointers for write mode after reading.
+	* testsuite/27_io/basic_filebuf/sgetn/char/81395.cc: New.
+
+2017-10-21  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/experimental/filesystem/path/itr/traversal.cc: Do not
+	increment past-the-end iterators.
+
+2017-10-20  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/chrono (__cpp_lib_chrono): Update macro value to
+	indicate support for P0505R0.
+	* testsuite/20_util/duration/arithmetic/constexpr_c++17.cc: Check
+	for updated macro.
+
+	* include/c_global/cstddef: Define __cpp_lib_byte feature-test macro.
+	* testsuite/18_support/byte/requirements.cc: Check macro.
+
+	Backport from mainline
+	2017-10-13  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/82481
+	* include/std/mutex (call_once): Suppress clang-tidy warnings about
+	dangling references.
+
+	Backport from mainline
+	2017-09-12  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/79433
+	* doc/xml/manual/status_cxx2017.xml: Update feature-test macros.
+	* doc/html/*: Regenerate.
+	* include/Makefile.am: Remove <bits/c++17_warning.h>.
+	* include/Makefile.in: Regenerate.
+	* include/bits/c++17_warning.h: Remove.
+	* include/bits/string_view.tcc: Do not include <bits/c++17_warning.h>
+	for pre-C++17 modes.
+	* include/std/any: Likewise.
+	(__cpp_lib_any): Define.
+	* include/std/mutex (__cpp_lib_scoped_lock): Adjust value as per new
+	SD-6 draft.
+	* include/std/numeric (__cpp_lib_gcd_lcm): Define as per new SD-6
+	draft.
+	* include/std/optional: Do not include <bits/c++17_warning.h>.
+	(__cpp_lib_optional): Define.
+	* include/std/shared_mutex: Do not include <bits/c++14_warning.h>.
+	* include/std/string_view: Do not include <bits/c++17_warning.h>.
+	(__cpp_lib_string_view): Define.
+	* include/std/variant: Do not include <bits/c++17_warning.h>.
+	(__cpp_lib_variant): Define.
+	* testsuite/20_util/optional/cons/value_neg.cc: Adjust dg-error line
+	numbers.
+	* testsuite/26_numerics/gcd/1.cc: Test for __cpp_lib_gcd_lcm.
+	* testsuite/26_numerics/gcd/gcd_neg.cc: Adjust dg-error line
+	numbers.
+	* testsuite/26_numerics/lcm/1.cc: Test for __cpp_lib_gcd_lcm.
+	* testsuite/26_numerics/lcm/lcm_neg.cc: Adjust dg-error line
+	numbers.
+	* testsuite/30_threads/scoped_lock/requirements/typedefs.cc: Adjust
+	expected value of __cpp_lib_scoped_lock.
+
+	Backport from mainline
+	2017-10-19  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/experimental/bits/fs_path.h (path::iterator++(int))
+	(path::iterator--(int)): Fix for paths with only one component.
+	* testsuite/experimental/filesystem/path/itr/traversal.cc: Test
+	post-increment and post-decrement.
+
+2017-09-21  Jonathan Wakely  <jwakely@redhat.com>
+
+	* testsuite/25_algorithms/clamp/1.cc: Fix order of arguments and
+	expected results when using predicate defining reverse order.
+	* testsuite/25_algorithms/clamp/constexpr.cc: Likewise.
+
+2017-09-20  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport from mainline
+	2017-06-14  Jonathan Wakely  <jwakely@redhat.com>
+
+	* doc/xml/manual/test.xml: Correct instructions on running tests.
+	* testsuite/27_io/basic_ios/copyfmt/char/1.cc: Adjust to pass when
+	-D_GLIBCXX_USE_CXX11_ABI=0 added to RUNTESTFLAGS.
+	* testsuite/27_io/basic_ios/exceptions/char/1.cc: Likewise.
+	* testsuite/27_io/basic_istream/extractors_arithmetic/char/
+	exceptions_failbit.cc: Likewise.
+	* testsuite/27_io/basic_istream/extractors_arithmetic/wchar_t/
+	exceptions_failbit.cc: Likewise.
+	* testsuite/27_io/basic_istream/extractors_other/char/
+	exceptions_null.cc: Likewise.
+	* testsuite/27_io/basic_istream/extractors_other/wchar_t/
+	exceptions_null.cc: Likewise.
+	* testsuite/27_io/basic_istream/sentry/char/12297.cc: Likewise.
+	* testsuite/27_io/basic_istream/sentry/wchar_t/12297.cc: Likewise.
+	* testsuite/27_io/basic_ostream/inserters_other/char/
+	exceptions_null.cc: Likewise.
+	* testsuite/27_io/basic_ostream/inserters_other/wchar_t/
+	exceptions_null.cc: Likewise.
+	* testsuite/27_io/ios_base/storage/2.cc: Likewise.
+
+	PR libstdc++/79162
+	* include/bits/basic_string.h [!_GLIBCXX_USE_CXX11_ABI]
+	(basic_string::_If_sv): Remove from the overload set when the
+	argument is derived from basic_string.
+
+	PR libstdc++/79162
+	* include/bits/basic_string.h (basic_string::_If_sv): Remove from the
+	overload set when the argument is derived from basic_string.
+	* testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc: New
+	test.
+	* testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc:
+	New test.
+
+	* testsuite/24_iterators/range_access_cpp17.cc: Fix order of dg-do
+	and dg-options directives. Fix invalid test.
+
+	Backport from mainline
+	2017-09-20  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/82262
+	* include/std/optional (__optional_hash_call_base): Add template
+	parameter for remove_const_t<_Tp> and use it consistently.
+	* testsuite/20_util/optional/hash.cc: Test optional<const T>.
+
+	Backport from mainline
+	2017-09-19  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/82254
+	* include/std/type_traits (__is_invocable): Add partial specialization
+	for INVOKE<void> case and remove is_void<R> check from partial
+	specialization for INVOKE<R> case.
+	(__is_nt_invocable_impl): New helper for is_nothrow_invocable_r.
+	(is_nothrow_invocable_r): Use __is_nt_invocable_impl.
+	* testsuite/20_util/is_nothrow_invocable/value.cc: Add tests for
+	conversions that can throw or fail to convert. Use static assert
+	strings to explain negative results.
+	* testsuite/20_util/is_nothrow_invocable/value_ext.cc: Use
+	is_nothrow_constructible in is_nt_invocable_conv.
+
+2017-09-13  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport from mainline
+	2017-09-04  Daniel Kruegler  <daniel.kruegler@gmail.com>
+
+	PR libstdc++/79162
+	Implement LWG 2946, LWG 2758's resolution missed further corrections
+	* include/bits/basic_string.h (basic_string::compare): Add missing
+	required noexcept specifications.
+	(basic_string): Introduce internal _S_to_string_view and __sv_wrapper
+	for implicit string_view conversion.
+	(basic_string::basic_string): Fix explicit string_view conversion by
+	implicit conversion using _S_to_string_view and __sv_wrapper.
+	(basic_string): Introduce internal basic_string(__sv_wrapper, Alloc)
+	constructor.
+	(basic_string): Fix operator=(T) template by operator=(const T&)
+	template for uncopyable types (PR 79162).
+	(basic_string::operator+=, basic_string::append, basic_string::assign)
+	(basic_string::insert, basic_string::replace, basic_string::find)
+	(basic_string::rfind, basic_string::find_first_of)
+	(basic_string::find_last_of, basic_string::find_first_not_of)
+	(basic_string::find_last_not_of, basic_string::compare): Replace
+	__sv_type argument by template const T& (LWG 2946) and correct
+	documentation describing __sv_type argument.
+	(basic_string::find, basic_string::rfind, basic_string::find_first_of)
+	(basic_string::find_last_of, basic_string::find_first_not_of)
+	(basic_string::find_last_not_of, basic_string::compare): Replace
+	unconditional noexcept specification by conditional noexcept
+	specification to partially balance the removal of noexcept by LWG 2946.
+	* testsuite/21_strings/basic_string/79162.cc: New.
+	* testsuite/21_strings/basic_string/lwg2946.cc: New.
+
+2017-09-13  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/81468
+	* include/std/chrono (time_point(const time_point<_Dur2>&)): Add
+	missing constraint from LWG DR 1177.
+	* testsuite/20_util/duration/cons/dr1177.cc: New.
+	* testsuite/20_util/time_point/cons/81468.cc: New.
+	* testsuite/20_util/duration/literals/range.cc: Update dg-error line.
+
+	* doc/doxygen/mainpage.html: Fix broken URLs.
+
+	PR libstdc++/81835
+	* doc/xml/manual/extensions.xml: Replace unstable URL.
+	* doc/html/manual/ext_demangling.html: Regenerate.
+	* libsupc++/cxxabi.h (__cxa_demangle): Fix broken URL.
+
+2017-09-12  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport from mainline
+	2017-09-12  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/70483
+	* include/experimental/bits/string_view.tcc (basic_string_view::find)
+	(basic_string_view::rfind, basic_string_view::find_first_of)
+	(basic_string_view::find_last_of, basic_string_view::find_first_not_of)
+	(basic_string_view::find_last_not_of): Add constexpr specifier.
+	* include/experimental/string_view (basic_string_view::remove_prefix)
+	(basic_string_view::remove_suffix, basic_string_view::swap)
+	(basic_string_view::compare, basic_string_view::find)
+	(basic_string_view::rfind, basic_string_view::find_first_of)
+	(basic_string_view::find_last_of, basic_string_view::find_first_not_of)
+	(basic_string_view::find_last_not_of, operator==, operator!=)
+	(operator<, operator>, operator<=, operator>=): Likewise.
+	* testsuite/experimental/string_view/operations/compare/char/70483.cc:
+	New.
+
+	Backport from mainline
+	2017-09-11  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/70483
+	* include/bits/string_view.tcc (basic_string_view::find)
+	(basic_string_view::rfind, basic_string_view::find_first_of)
+	(basic_string_view::find_last_of, basic_string_view::find_first_not_of)
+	(basic_string_view::find_last_not_of): Add constexpr specifier.
+	* include/std/string_view (basic_string_view::operator=)
+	(basic_string_view::rbegin, basic_string_view::rend)
+	(basic_string_view::crbegin, basic_string_view::crend)
+	(basic_string_view::remove_prefix, basic_string_view::remove_suffix)
+	(basic_string_view::swap, basic_string_view::compare)
+	(basic_string_view::find, basic_string_view::rfind)
+	(basic_string_view::find_first_of, basic_string_view::find_last_of)
+	(basic_string_view::find_first_not_of)
+	(basic_string_view::find_last_not_of, basic_string_view::_M_check)
+	(basic_string_view::_M_limit, operator==, operator!=, operator<)
+	(operator>, operator<=, operator>=): Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/remove_prefix/
+	char/1.cc: Repeat tests in constexpr context.
+	* testsuite/21_strings/basic_string_view/modifiers/remove_prefix/
+	wchar_t/1.cc: Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/remove_suffix/
+	char/1.cc: Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/remove_suffix/
+	wchar_t/1.cc: Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/char/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/char/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operators/char/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/range_access/char/1.cc: Test
+	cbegin, cend, rbegin, rend, crbegin and crend.
+	* testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc:
+	Likewise.
+	* testsuite/21_strings/basic_string_view/operations/compare/char/1.cc:
+	Remove trailing whitespace.
+	* testsuite/21_strings/basic_string_view/operations/compare/wchar_t/
+	1.cc: Likewise.
+	* testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc:
+	New.
+	* testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc:
+	New.
+	* testsuite/21_strings/basic_string_view/operations/compare/char/2.cc:
+	New.
+	* testsuite/21_strings/basic_string_view/operations/compare/wchar_t/
+	2.cc: New.
+
+	Backport from mainline
+	2017-06-12  Pedro Alves  <palves@redhat.com>
+
+	* doc/xml/manual/status_cxx2017.xml: Update C++17 constexpr
+	char_traits status.
+	* doc/html/*: Regenerate.
+
+	* include/bits/char_traits.h (_GLIBCXX_ALWAYS_INLINE): Define if
+	not already defined.
+	(__cpp_lib_constexpr_char_traits): Uncomment.
+	(__constant_string_p, __constant_char_array_p): New.
+	(std::char_traits<char>, std::char_traits<wchar_t>): Add
+	_GLIBCXX17_CONSTEXPR on compare, length and find and use
+	__constant_string_p, __constant_char_array_p and
+	__builtin_constant_p to defer to __gnu_cxx::char_traits at compile
+	time.
+
+	* testsuite/21_strings/char_traits/requirements/
+	constexpr_functions_c++17.cc: Uncomment
+	__cpp_lib_constexpr_char_traits tests.  Uncomment
+	test_compare<char>, test_length<char>, test_find<char>,
+	test_compare<wchar_t>, test_length<wchar_t> and test_find<wchar_t>
+	static_assert tests.
+
+2017-09-04  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport from mainline
+	2017-08-31  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR c++/82039
+	* include/ext/new_allocator.h (__gnu_cxx::new_allocator::allocate):
+	Adjust null pointer constant to avoid warning.
+
+	Backport from mainline
+	2017-08-21  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/81912
+	* include/bits/stl_iterator_base_types.h (__iterator_category): Add
+	constexpr for C++11 and later.
+	* testsuite/24_iterators/container_access.cc: Add target selector.
+	* testsuite/24_iterators/range_access.cc: Fix clause number in
+	comment.
+	* testsuite/24_iterators/range_access_cpp14.cc: Likewise.
+	* testsuite/24_iterators/range_access_cpp17.cc: New.
+
+	Backport from mainline
+	2017-08-09  Jonathan Wakely  <jwakely@redhat.com>
+
+	* include/std/type_traits (_GLIBCXX_NO_BUILTIN_HAS_UNIQ_OBJ_REP):
+	Replace with _GLIBCXX_HAVE_BUILTIN_HAS_UNIQ_OBJ_REP and use
+	__is_identifier to set it.
+
+	Backport from mainline
+	2017-08-09  Katsuhiko Nishimra  <ktns.87@gmail.com>
+
+	* include/std/type_traits (_GLIBCXX_HAVE_BUILTIN_IS_AGGREGATE): Use
+	__is_identifier instead of __has_builtin.
+
+	Backport from mainline
+	2017-08-18  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/81891
+	* include/bits/hashtable.h (_Hashtable(_InputIterator, _InputIterator,
+	size_type, const _H1&, const _H2&, const _Hash&, const _Equal&,
+	const _ExtractKey&, const allocator_type&)): Let destructor do clean
+	up if an exception is thrown.
+	* testsuite/23_containers/unordered_map/cons/81891.cc: New.
+
+	Backport from mainline
+	2017-07-31  Marek Polacek  <polacek@redhat.com>
+
+	PR libstdc++/81599
+	* include/bits/stl_stack.h: Fix typo.
+
+	Backport from mainline
+	2017-07-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/81338
+	* include/bits/basic_string.h [_GLIBCXX_USE_CXX11_ABI] (basic_string):
+	Declare basic_stringbuf to be a friend.
+	* include/bits/sstream.tcc (basic_stringbuf::overflow)
+	[_GLIBCXX_USE_CXX11_ABI]: Use unused capacity before reallocating.
+	* include/std/sstream (basic_stringbuf::__xfer_bufptrs): Update string
+	length to buffer length.
+	* testsuite/27_io/basic_stringstream/assign/81338.cc: New.
+
+2017-08-20  John David Anglin  <danglin@gcc.gnu.org>
+
+	PR testsuite/81056
+	* testsuite/17_intro/names.cc: Undef 'd' and 'r' on __hpux__.
+
+2017-08-14  Jonathan Wakely  <jwakely@redhat.com>
+
+	Backport from mainline
+	2017-08-09  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/79820
+	PR libstdc++/81751
+	* config/io/basic_file_stdio.cc (sys_open(FILE*, ios_base::openmode)):
+	Call fflush on the stream instead of calling sync() while _M_cfile is
+	null. Restore original value of errno.
+	* testsuite/ext/stdio_filebuf/char/79820.cc: New.
+	* testsuite/ext/stdio_filebuf/char/81751.cc: New.
+
+	Backport from mainline
+	2017-07-25  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR libstdc++/53984
+	* include/bits/basic_ios.h (basic_ios::_M_setstate): Adjust comment.
+	* include/bits/istream.tcc (basic_istream::sentry): Handle exceptions
+	during construction.
+	* include/std/istream: Adjust comments for formatted input functions
+	and unformatted input functions.
+	* testsuite/27_io/basic_fstream/53984.cc: New.
+	* testsuite/27_io/basic_istream/sentry/char/53984.cc: New.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: libstdc++-v3/testsuite/25_algorithms/clamp/1.cc
===================================================================
--- libstdc++-v3/testsuite/25_algorithms/clamp/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/25_algorithms/clamp/1.cc	(.../branches/gcc-7-branch)
@@ -30,12 +30,12 @@
   VERIFY( y == 3 );
   VERIFY( z == 4 );
 
-  const int xc = std::clamp(1, 2, 4, std::greater<int>());
-  const int yc = std::clamp(3, 2, 4, std::greater<int>());
-  const int zc = std::clamp(5, 2, 4, std::greater<int>());
-  VERIFY( xc == 4 );
-  VERIFY( yc == 2 );
-  VERIFY( zc == 2 );
+  const int xc = std::clamp(1, 4, 2, std::greater<int>());
+  const int yc = std::clamp(3, 4, 2, std::greater<int>());
+  const int zc = std::clamp(5, 4, 2, std::greater<int>());
+  VERIFY( xc == 2 );
+  VERIFY( yc == 3 );
+  VERIFY( zc == 4 );
 }
 
 int
Index: libstdc++-v3/testsuite/25_algorithms/clamp/constexpr.cc
===================================================================
--- libstdc++-v3/testsuite/25_algorithms/clamp/constexpr.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/25_algorithms/clamp/constexpr.cc	(.../branches/gcc-7-branch)
@@ -27,5 +27,5 @@
 # error "Feature-test macro for clamp has wrong value"
 #endif
 
-static_assert(std::clamp(2, 0, 1) == 1, "");
-static_assert(std::clamp(2, 0, 1, std::greater<int>()) == 0, "");
+static_assert(std::clamp(2, 0, 1) == 1);
+static_assert(std::clamp(2, 1, 0, std::greater<int>()) == 1);
Index: libstdc++-v3/testsuite/24_iterators/container_access.cc
===================================================================
--- libstdc++-v3/testsuite/24_iterators/container_access.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/24_iterators/container_access.cc	(.../branches/gcc-7-branch)
@@ -1,4 +1,4 @@
-// { dg-do run }
+// { dg-do run { target c++1z } }
 // { dg-options "-std=gnu++17" }
 
 // Copyright (C) 2015-2017 Free Software Foundation, Inc.
@@ -62,7 +62,6 @@
   static_assert(s == 3);
   constexpr auto e = std::empty(il3);
   static_assert(!e);
-
 }
 
 void
Index: libstdc++-v3/testsuite/24_iterators/range_access.cc
===================================================================
--- libstdc++-v3/testsuite/24_iterators/range_access.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/24_iterators/range_access.cc	(.../branches/gcc-7-branch)
@@ -17,7 +17,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// 24.6.5, range access [iterator.range]
+// C++ 2011 24.6.5, range access [iterator.range]
 
 #include <iterator>
 
Index: libstdc++-v3/testsuite/24_iterators/range_access_cpp14.cc
===================================================================
--- libstdc++-v3/testsuite/24_iterators/range_access_cpp14.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/24_iterators/range_access_cpp14.cc	(.../branches/gcc-7-branch)
@@ -17,7 +17,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// 24.6.5, range access [iterator.range]
+// C++ 2014 24.7, range access [iterator.range]
 
 #include <iterator>
 #include <vector>
Index: libstdc++-v3/testsuite/24_iterators/range_access_cpp17.cc
===================================================================
--- libstdc++-v3/testsuite/24_iterators/range_access_cpp17.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/24_iterators/range_access_cpp17.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,57 @@
+// { dg-options "-std=gnu++17" }
+// { dg-do compile { target c++1z } }
+
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// C++ 2017 27.7, range access [iterator.range]
+
+#include <iterator>
+
+void
+test01()
+{
+  using std::reverse_iterator;
+  static int i[1];
+  static_assert(std::cbegin(i) == i);
+  static_assert(std::cend(i) == i+1);
+  static_assert(std::rbegin(i) == reverse_iterator<int*>(i+1));
+  static_assert(std::rend(i) == reverse_iterator<int*>(i));
+  static_assert(std::crbegin(i) == reverse_iterator<int*>(i+1));
+  static_assert(std::crend(i) == reverse_iterator<int*>(i));
+}
+
+void
+test02()
+{
+  static int i[] = { 1, 2 };
+  static_assert(std::distance(std::begin(i), std::end(i)) == 2);
+  static_assert(std::distance(std::cbegin(i), std::cend(i)) == 2);
+}
+
+void
+test03()
+{
+  using std::reverse_iterator;
+  static constexpr std::initializer_list<int> il{1};
+  static_assert(std::cbegin(il) == il.begin());
+  static_assert(std::cend(il) == il.end());
+  static_assert(std::rbegin(il) == reverse_iterator<const int*>(il.end()));
+  static_assert(std::rend(il) == reverse_iterator<const int*>(il.begin()));
+  static_assert(std::crbegin(il) == reverse_iterator<const int*>(il.end()));
+  static_assert(std::crend(il) == reverse_iterator<const int*>(il.begin()));
+}
Index: libstdc++-v3/testsuite/18_support/byte/requirements.cc
===================================================================
--- libstdc++-v3/testsuite/18_support/byte/requirements.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/18_support/byte/requirements.cc	(.../branches/gcc-7-branch)
@@ -20,6 +20,12 @@
 
 #include <cstddef>
 
+#ifndef __cpp_lib_byte
+# error "Feature-test macro for byte missing"
+#elif __cpp_lib_byte != 201603
+# error "Feature-test macro for byte has wrong value"
+#endif
+
 static_assert( sizeof(std::byte) == sizeof(unsigned char) );
 static_assert( alignof(std::byte) == alignof(unsigned char) );
 
Index: libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/typedefs.cc
===================================================================
--- libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/typedefs.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/30_threads/scoped_lock/requirements/typedefs.cc	(.../branches/gcc-7-branch)
@@ -27,7 +27,7 @@
 
 #ifndef __cpp_lib_scoped_lock
 # error "Feature-test macro for scoped_lock missing"
-#elif __cpp_lib_scoped_lock != 201707
+#elif __cpp_lib_scoped_lock != 201703
 # error "Feature-test macro for scoped_lock has wrong value"
 #endif
 
Index: libstdc++-v3/testsuite/ext/stdio_filebuf/char/81751.cc
===================================================================
--- libstdc++-v3/testsuite/ext/stdio_filebuf/char/81751.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/ext/stdio_filebuf/char/81751.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,53 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-require-fileio "" }
+
+#include <ext/stdio_filebuf.h>
+#include <cstdio>
+#include <cerrno>
+#include <testsuite_hooks.h>
+
+void
+test01()
+{
+  FILE* out = std::fopen("81751.txt", "w");
+  std::fwrite("Some words.", 1, 10, out);
+
+  FILE* in1 = std::fopen("81751.txt", "r");
+  __gnu_cxx::stdio_filebuf<char> buf1(in1, std::ios::in, BUFSIZ);
+  int c = buf1.sgetc();
+  VERIFY( c == std::char_traits<char>::eof() ); // PR libstdc++/81751
+
+  std::fflush(out);
+  FILE* in2 = std::fopen("81751.txt", "r");
+  __gnu_cxx::stdio_filebuf<char> buf2(in2, std::ios::in, BUFSIZ);
+  c = buf2.sgetc();
+  VERIFY( c == 'S' );
+
+  buf1.close();
+  buf2.close();
+  std::fclose(in1);
+  std::fclose(in2);
+  std::fclose(out);
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/ext/stdio_filebuf/char/79820.cc
===================================================================
--- libstdc++-v3/testsuite/ext/stdio_filebuf/char/79820.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/ext/stdio_filebuf/char/79820.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,39 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-require-fileio "" }
+
+#include <ext/stdio_filebuf.h>
+#include <cstdio>
+#include <cerrno>
+#include <testsuite_hooks.h>
+
+void
+test01()
+{
+  FILE* f = std::fopen("79820.txt", "w");
+  std::fclose(f);
+  errno = 127;
+  __gnu_cxx::stdio_filebuf<char> b(f, std::ios::out, BUFSIZ);
+  VERIFY(errno == 127); // PR libstdc++/79820
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/23_containers/unordered_map/cons/81891.cc
===================================================================
--- libstdc++-v3/testsuite/23_containers/unordered_map/cons/81891.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/23_containers/unordered_map/cons/81891.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,68 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do run { target c++11 } }
+
+#include <unordered_map>
+#include <testsuite_hooks.h>
+#include <testsuite_allocator.h>
+
+struct fails_on_copy {
+  fails_on_copy() = default;
+  fails_on_copy(const fails_on_copy&) { throw 0; };
+};
+
+using value_type = std::pair<int, fails_on_copy>;
+
+void
+test01()
+{
+  value_type p;
+  try
+  {
+    std::unordered_map<int, fails_on_copy> umap(&p, &p + 1);
+  }
+  catch(...)
+  { }
+}
+
+void
+test02()
+{
+  using Alloc = __gnu_test::tracker_allocator<value_type>;
+  using std::hash;
+  using std::equal_to;
+
+  value_type p;
+  try
+  {
+    std::unordered_map<int, fails_on_copy, hash<int>, equal_to<int>, Alloc>
+	umap(&p, &p + 1);
+  }
+  catch(...)
+  { }
+
+  using counter = __gnu_test::tracker_allocator_counter;
+  VERIFY(counter::get_allocation_count() == counter::get_deallocation_count());
+}
+
+int
+main()
+{
+  test01();
+  test02();
+}
Index: libstdc++-v3/testsuite/27_io/basic_stringstream/assign/81338.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_stringstream/assign/81338.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/27_io/basic_stringstream/assign/81338.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,40 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do run { target c++11 } }
+
+#include <sstream>
+#include <testsuite_hooks.h>
+
+void
+test01()
+{
+  std::stringstream ss;
+  for (int i = 0; i < 100; ++i)
+  {
+    ss << 'a';
+    VERIFY( static_cast<bool>(ss) );
+    VERIFY( ss.str() == "a" );
+    ss = std::stringstream();
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/27_io/ios_base/storage/2.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/ios_base/storage/2.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/ios_base/storage/2.cc	(.../branches/gcc-7-branch)
@@ -26,11 +26,8 @@
 // Skip test at -m64 on Darwin because RLIMITS are not being honored.
 // Radar 6467883: 10.4/10.5 setrlimits are not honored by memory allocators
 // Radar 6467884: 10.X systems are not robust when paging space is exceeded
-// { dg-skip-if "" { *-*-darwin* && lp64 } { "*" } { "" } } 
+// { dg-skip-if "" { *-*-darwin* && lp64 } { "*" } { "" } }
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 #include <sstream>
 #include <iostream>
 #include <limits>
@@ -52,12 +49,19 @@
   // pword
   ios.pword(1) = v;
   VERIFY( ios.pword(1) == v );
-  
-  try 
+
+  // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
+  try
     {
       v = ios.pword(max);
     }
-  catch(std::ios_base::failure& obj)
+  catch(exception_type&)
     {
       // Ok.
       VERIFY( ios.bad() );
@@ -69,7 +73,7 @@
   VERIFY( v == 0 );
 
   VERIFY( ios.pword(1) == v );
-  
+
   // max is different code path from max-1
   v = &test;
   try
@@ -76,7 +80,7 @@
     {
       v = ios.pword(std::numeric_limits<int>::max());
     }
-  catch(std::ios_base::failure& obj)
+  catch(exception_type&)
     {
       // Ok.
       VERIFY( ios.bad() );
@@ -90,12 +94,12 @@
   // iword
   ios.iword(1) = 1;
   VERIFY( ios.iword(1) == 1 );
-  
-  try 
+
+  try
     {
       l = ios.iword(max);
     }
-  catch(std::ios_base::failure& obj)
+  catch(exception_type&)
     {
       // Ok.
       VERIFY( ios.bad() );
@@ -110,11 +114,11 @@
 
   // max is different code path from max-1
   l = 1;
-  try 
+  try
     {
       l = ios.iword(std::numeric_limits<int>::max());
     }
-  catch(std::ios_base::failure& obj)
+  catch(exception_type&)
     {
       // Ok.
       VERIFY( ios.bad() );
Index: libstdc++-v3/testsuite/27_io/basic_ios/copyfmt/char/1.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_ios/copyfmt/char/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_ios/copyfmt/char/1.cc	(.../branches/gcc-7-branch)
@@ -17,9 +17,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 // 27.4.4.2 basic_ios member functions
 
 // NB: Don't include any other headers in this file.
@@ -36,13 +33,13 @@
   // basic_ios& copyfmt(const basic_ios& rhs)
   {
     std::ios ios_01(0);
-    std::ios ios_02(0);  
+    std::ios ios_02(0);
     ios_01.exceptions(std::ios_base::eofbit);
     ios_02.exceptions(std::ios_base::eofbit);
-    
+
     try {
-    ios_01.copyfmt(ios_02);
-    }		 
+      ios_01.copyfmt(ios_02);
+    }
     catch(...) {
       VERIFY( false );
     }
@@ -49,8 +46,15 @@
   }
 
   {
+    // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
     std::ios ios_01(0);
-    std::ios ios_02(0);  
+    std::ios ios_02(0);
     ios_01.clear(std::ios_base::eofbit);
     ios_02.exceptions(std::ios_base::eofbit);
 
@@ -57,8 +61,8 @@
     try {
       ios_01.copyfmt(ios_02);
       VERIFY( false );
-    }		 
-    catch(std::ios_base::failure& fail) {
+    }
+    catch(exception_type&) {
       VERIFY( true );
     }
     catch(...) {
@@ -67,7 +71,7 @@
   }
 }
 
-int main() 
+int main()
 {
   test02();
   return 0;
Index: libstdc++-v3/testsuite/27_io/basic_ios/exceptions/char/1.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_ios/exceptions/char/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_ios/exceptions/char/1.cc	(.../branches/gcc-7-branch)
@@ -17,9 +17,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 // 27.4.4.2 basic_ios member functions
 
 // NB: Don't include any other headers in this file.
@@ -44,7 +41,7 @@
     std::ios ios_01(0);
     try {
       ios_01.exceptions(std::ios_base::eofbit);
-    }		 
+    }
     catch(...) {
       VERIFY( false );
     }
@@ -53,13 +50,20 @@
   }
 
   {
+    // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
     std::ios ios_01(0);
     ios_01.clear(std::ios_base::eofbit);
     try {
       ios_01.exceptions(std::ios_base::eofbit);
       VERIFY( false );
-    }		 
-    catch(std::ios_base::failure& fail) {
+    }
+    catch(exception_type&) {
       iostate02 = ios_01.exceptions();
       VERIFY( static_cast<bool>(iostate02 & std::ios_base::eofbit) );
     }
@@ -69,7 +73,7 @@
   }
 }
 
-int main() 
+int main()
 {
   test01();
   return 0;
Index: libstdc++-v3/testsuite/27_io/basic_fstream/53984.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_fstream/53984.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/27_io/basic_fstream/53984.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,64 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-require-fileio "" }
+
+// PR libstdc++/53984
+
+#include <fstream>
+#include <testsuite_hooks.h>
+
+void
+test01()
+{
+  std::ifstream in(".");
+  if (in)
+  {
+    char c;
+    if (in.get(c))
+    {
+      // Reading a directory doesn't produce an error on this target
+      // so the formatted input functions below wouldn't fail anyway
+      // (see PR libstdc++/81808).
+      return;
+    }
+    int x;
+    in.clear();
+    // Formatted input function should set badbit, but not throw:
+    in >> x;
+    VERIFY( in.bad() );
+
+    in.clear();
+    in.exceptions(std::ios::badbit);
+    try
+    {
+      // Formatted input function should set badbit, and throw:
+      in >> x;
+      VERIFY( false );
+    }
+    catch (const std::exception&)
+    {
+      VERIFY( in.bad() );
+    }
+  }
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/27_io/basic_istream/sentry/wchar_t/12297.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_istream/sentry/wchar_t/12297.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_istream/sentry/wchar_t/12297.cc	(.../branches/gcc-7-branch)
@@ -15,9 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 // 27.6.1.1.2 class basic_istream::sentry
 
 #include <sstream>
@@ -28,16 +25,23 @@
   using namespace std;
   wistringstream stream;
   stream.exceptions(ios_base::eofbit);
-  
+
+  // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
   try
     {
       wistream::sentry sentry(stream, false);
       VERIFY( false );
     }
-  catch (ios_base::failure&)
+  catch (exception_type&)
     {
       VERIFY( stream.rdstate() == (ios_base::eofbit | ios_base::failbit) );
     }
-  
+
   return 0;
 }
Index: libstdc++-v3/testsuite/27_io/basic_istream/sentry/char/53984.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_istream/sentry/char/53984.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/27_io/basic_istream/sentry/char/53984.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,41 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+#include <streambuf>
+#include <istream>
+#include <testsuite_hooks.h>
+
+struct SB : std::streambuf
+{
+  virtual int_type underflow() { throw 1; }
+};
+
+void
+test01()
+{
+  SB sb;
+  std::istream is(&sb);
+  int i;
+  is >> i;
+  VERIFY( is.bad() );
+}
+
+int
+main()
+{
+  test01();
+}
Index: libstdc++-v3/testsuite/27_io/basic_istream/sentry/char/12297.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_istream/sentry/char/12297.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_istream/sentry/char/12297.cc	(.../branches/gcc-7-branch)
@@ -15,12 +15,8 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-
 // 27.6.1.1.2 class basic_istream::sentry
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 #include <sstream>
 #include <testsuite_hooks.h>
 
@@ -29,16 +25,23 @@
   using namespace std;
   istringstream stream;
   stream.exceptions(ios_base::eofbit);
-  
+
+  // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
   try
     {
       istream::sentry sentry(stream, false);
       VERIFY( false );
     }
-  catch (ios_base::failure&)
+  catch (exception_type&)
     {
       VERIFY( stream.rdstate() == (ios_base::eofbit | ios_base::failbit) );
     }
-  
+
   return 0;
 }
Index: libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/exceptions_null.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/exceptions_null.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/wchar_t/exceptions_null.cc	(.../branches/gcc-7-branch)
@@ -15,9 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 #include <istream>
 #include <ostream>
 #include <streambuf>
@@ -38,12 +35,19 @@
   wistringstream stream;
   stream.exceptions(ios_base::failbit);
 
+  // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
   try
     {
       stream >> static_cast<wstreambuf*>(0);
       VERIFY( false );
     }
-  catch (ios_base::failure&)
+  catch (exception_type&)
     {
     }
 
Index: libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/exceptions_null.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/exceptions_null.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_istream/extractors_other/char/exceptions_null.cc	(.../branches/gcc-7-branch)
@@ -15,9 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 #include <istream>
 #include <ostream>
 #include <streambuf>
@@ -38,12 +35,19 @@
   istringstream stream;
   stream.exceptions(ios_base::failbit);
 
+  // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
   try
     {
       stream >> static_cast<streambuf*>(0);
       VERIFY(false);
     }
-  catch (ios_base::failure&)
+  catch (exception_type&)
     {
     }
 
Index: libstdc++-v3/testsuite/27_io/basic_istream/extractors_arithmetic/wchar_t/exceptions_failbit.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_istream/extractors_arithmetic/wchar_t/exceptions_failbit.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_istream/extractors_arithmetic/wchar_t/exceptions_failbit.cc	(.../branches/gcc-7-branch)
@@ -15,9 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 #include <sstream>
 #include <testsuite_hooks.h>
 
@@ -29,7 +26,14 @@
 
   wistringstream stream(L"jaylib - champion sound");
   stream.exceptions(ios_base::failbit);
-  
+
+  // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
   try
     {
       T i;
@@ -36,13 +40,13 @@
       stream >> i;
       VERIFY( false );
     }
-  catch (const ios_base::failure&)
-    { 
+  catch (const exception_type&)
+    {
       // stream should set failbit and throw ios_base::failure.
       VERIFY( stream.fail() );
       VERIFY( !stream.bad() );
       VERIFY( !stream.eof() );
-    }  
+    }
   catch(...)
     { VERIFY( false ); }
 }
Index: libstdc++-v3/testsuite/27_io/basic_istream/extractors_arithmetic/char/exceptions_failbit.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_istream/extractors_arithmetic/char/exceptions_failbit.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_istream/extractors_arithmetic/char/exceptions_failbit.cc	(.../branches/gcc-7-branch)
@@ -15,9 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 #include <sstream>
 #include <testsuite_hooks.h>
 
@@ -29,7 +26,14 @@
 
   istringstream stream("jaylib - champion sound");
   stream.exceptions(ios_base::failbit);
-  
+
+  // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
   try
     {
       T i;
@@ -36,13 +40,13 @@
       stream >> i;
       VERIFY( false );
     }
-  catch (const ios_base::failure&)
-    { 
+  catch (const exception_type&)
+    {
       // stream should set failbit and throw ios_base::failure.
       VERIFY( stream.fail() );
       VERIFY( !stream.bad() );
       VERIFY( !stream.eof() );
-    }  
+    }
   catch(...)
     { VERIFY( false ); }
 }
Index: libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/exceptions_null.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/exceptions_null.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/wchar_t/exceptions_null.cc	(.../branches/gcc-7-branch)
@@ -15,9 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 #include <istream>
 #include <ostream>
 #include <streambuf>
@@ -39,13 +36,20 @@
 
   wostringstream stream;
   stream.exceptions(ios_base::badbit);
-	
+
+  // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
   try
     {
       stream << static_cast<wstreambuf*>(0);
       VERIFY( false );
     }
-  catch (ios_base::failure&)
+  catch (exception_type&)
     {
     }
 
Index: libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/exceptions_null.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/exceptions_null.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/27_io/basic_ostream/inserters_other/char/exceptions_null.cc	(.../branches/gcc-7-branch)
@@ -15,9 +15,6 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// The library throws the new definition of std::ios::failure
-// { dg-options "-D_GLIBCXX_USE_CXX11_ABI=1" }
-
 #include <istream>
 #include <ostream>
 #include <streambuf>
@@ -39,13 +36,20 @@
 
   ostringstream stream;
   stream.exceptions(ios_base::badbit);
-	
+
+  // The library throws the new definition of std::ios::failure
+#if _GLIBCXX_USE_CXX11_ABI
+    typedef std::ios_base::failure exception_type;
+#else
+    typedef std::exception exception_type;
+#endif
+
   try
     {
       stream << static_cast<streambuf*>(0);
       VERIFY( false );
     }
-  catch (ios_base::failure&)
+  catch (exception_type&)
     {
     }
 
Index: libstdc++-v3/testsuite/27_io/basic_filebuf/sgetn/char/81395.cc
===================================================================
--- libstdc++-v3/testsuite/27_io/basic_filebuf/sgetn/char/81395.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/27_io/basic_filebuf/sgetn/char/81395.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,46 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-require-fileio "" }
+
+// PR libstdc++/81395
+
+#include <fstream>
+#include <cstring>	// for std::memset
+#include <cstdio>	// For BUFSIZ
+
+using std::memset;
+
+int main()
+{
+  {
+    std::filebuf fb;
+    fb.open("test.txt", std::ios::out);
+    char data[BUFSIZ];
+    memset(data, 'A', sizeof(data));
+    fb.sputn(data, sizeof(data));
+  }
+
+  std::filebuf fb;
+  fb.open("test.txt", std::ios::in|std::ios::out);
+  char buf[BUFSIZ];
+  memset(buf, 0, sizeof(buf));
+  fb.sgetn(buf, sizeof(buf));
+  // Switch from reading to writing without seeking first:
+  fb.sputn("B", 1);
+  fb.pubsync();
+}
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/wchar_t/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/wchar_t/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/wchar_t/1.cc	(.../branches/gcc-7-branch)
@@ -33,10 +33,29 @@
   VERIFY( str0 == wstring_view{L"olympus mo"} );
 }
 
+constexpr bool
+test02()
+{
+  using std::wstring_view;
+
+  wstring_view str0{L"olympus mons"};
+  wstring_view::pointer p = str0.data();
+  str0.remove_suffix(2);
+  if ( str0.data() != p)
+    return false;
+  if ( str0.length() != 10 )
+    return false;
+  if ( str0 != wstring_view{L"olympus mo"} )
+    return false;
+
+  return true;
+}
+
 int
 main()
 { 
   test01();
+  static_assert( test02() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/char/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/char/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_suffix/char/1.cc	(.../branches/gcc-7-branch)
@@ -33,10 +33,29 @@
   VERIFY( str0 == string_view{"olympus mo"} );
 }
 
+constexpr bool
+test02()
+{
+  using std::string_view;
+
+  string_view str0{"olympus mons"};
+  string_view::pointer p = str0.data();
+  str0.remove_suffix(2);
+  if ( str0.data() != p)
+    return false;
+  if ( str0.length() != 10 )
+    return false;
+  if ( str0 != string_view{"olympus mo"} )
+    return false;
+
+  return true;
+}
+
 int
 main()
 { 
   test01();
+  static_assert( test02() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/wchar_t/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/wchar_t/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/wchar_t/1.cc	(.../branches/gcc-7-branch)
@@ -33,10 +33,29 @@
   VERIFY( str0 == wstring_view{L"pus mons"} );
 }
 
+constexpr bool
+test02()
+{
+  using std::wstring_view;
+
+  wstring_view str0{L"olympus mons"};
+  wstring_view::pointer p = str0.data();
+  str0.remove_prefix(4);
+  if ( str0.data() != p + 4)
+    return false;
+  if ( str0.length() != 8 )
+    return false;
+  if ( str0 != wstring_view{L"pus mons"} )
+    return false;
+
+  return true;
+}
+
 int
 main()
 { 
   test01();
+  static_assert( test02() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/char/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/char/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/remove_prefix/char/1.cc	(.../branches/gcc-7-branch)
@@ -33,10 +33,29 @@
   VERIFY( str0 == string_view{"pus mons"} );
 }
 
+constexpr bool
+test02()
+{
+  using std::string_view;
+
+  string_view str0{"olympus mons"};
+  string_view::pointer p = str0.data();
+  str0.remove_prefix(4);
+  if ( str0.data() != p + 4)
+    return false;
+  if ( str0.length() != 8 )
+    return false;
+  if ( str0 != string_view{"pus mons"} )
+    return false;
+
+  return true;
+}
+
 int
 main()
 { 
   test01();
+  static_assert( test02() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/wchar_t/1.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,35 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17" }
+// { dg-do compile { target c++1z } }
+
+#include <string_view>
+
+constexpr bool
+test01()
+{
+  using std::wstring_view;
+
+  wstring_view s1{L"last"};
+  wstring_view s2{L"first"};
+
+  s1.swap(s2);
+  return s1 == L"first" && s2 == L"last";
+}
+
+static_assert( test01() );
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/modifiers/swap/char/1.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,35 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17" }
+// { dg-do compile { target c++1z } }
+
+#include <string_view>
+
+constexpr bool
+test01()
+{
+  using std::string_view;
+
+  string_view s1{"last"};
+  string_view s2{"first"};
+
+  s1.swap(s2);
+  return s1 == "first" && s2 == "last";
+}
+
+static_assert( test01() );
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/1.cc	(.../branches/gcc-7-branch)
@@ -61,10 +61,10 @@
   csz01 = str01.find(str04, 5);
   VERIFY( csz01 == 5 );
   csz01 = str01.find(str04, str01.size());
-  VERIFY( csz01 == str01.size() ); 
+  VERIFY( csz01 == str01.size() );
   csz01 = str01.find(str04, str01.size()+1);
-  VERIFY( csz01 == npos ); 
-  
+  VERIFY( csz01 == npos );
+
   // size_type find(const wchar_t* s, size_type pos, size_type n) const;
   csz01 = str01.find(str_lit01, 0, 3);
   VERIFY( csz01 == 0 );
@@ -85,10 +85,79 @@
   VERIFY( csz01 == npos );
 }
 
+constexpr bool
+test02()
+{
+  typedef std::wstring_view::size_type csize_type;
+  typedef std::wstring_view::const_reference cref;
+  typedef std::wstring_view::reference ref;
+  csize_type npos = std::wstring_view::npos;
+  csize_type csz01 = 0, csz02 = 0;
+
+  const wchar_t str_lit01[] = L"mave";
+  const std::wstring_view str01(L"mavericks, santa cruz");
+  std::wstring_view str02(str_lit01);
+  std::wstring_view str03(L"s, s");
+  std::wstring_view str04;
+
+#undef VERIFY
+#define VERIFY(x) if(!(x)) return false
+
+  // size_type find(const wstring_view&, size_type pos = 0) const;
+  csz01 = str01.find(str01);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str01, 4);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find(str02, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str02, 3);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find(str03, 0);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find(str03, 3);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find(str03, 12);
+  VERIFY( csz01 == npos );
+
+  // An empty string_view consists of no characters
+  // therefore it should be found at every point in a string_view,
+  // except beyond the end
+  csz01 = str01.find(str04, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str04, 5);
+  VERIFY( csz01 == 5 );
+  csz01 = str01.find(str04, str01.size());
+  VERIFY( csz01 == str01.size() );
+  csz01 = str01.find(str04, str01.size()+1);
+  VERIFY( csz01 == npos );
+
+  // size_type find(const wchar_t* s, size_type pos, size_type n) const;
+  csz01 = str01.find(str_lit01, 0, 3);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str_lit01, 3, 0);
+  VERIFY( csz01 == 3 );
+
+  // size_type find(const wchar_t* s, size_type pos = 0) const;
+  csz01 = str01.find(str_lit01);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str_lit01, 3);
+  VERIFY( csz01 == npos );
+
+  // size_type find(wchar_t c, size_type pos = 0) const;
+  csz01 = str01.find(L'z');
+  csz02 = str01.size() - 1;
+  VERIFY( csz01 == csz02 );
+  csz01 = str01.find(L'/');
+  VERIFY( csz01 == npos );
+
+  return true;
+}
+
 int
 main()
-{ 
+{
   test01();
+  static_assert( test02() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/2.cc	(.../branches/gcc-7-branch)
@@ -59,13 +59,13 @@
   // An empty string_view consists of no characters
   // therefore it should be found at every point in a string_view,
   // except beyond the end
-  // However, str1.find_first_of(str2,pos) finds the first character in 
+  // However, str1.find_first_of(str2,pos) finds the first character in
   // str1 (starting at pos) that exists in str2, which is none for empty str2
   csz01 = str01.find_first_of(str04, 0);
   VERIFY( csz01 == npos );
   csz01 = str01.find_first_of(str04, 5);
   VERIFY( csz01 == npos );
-  
+
   // size_type find_first_of(const wchar_t* s, size_type pos, size_type n) const;
   csz01 = str01.find_first_of(str_lit01, 0, 3);
   VERIFY( csz01 == 0 );
@@ -84,10 +84,78 @@
   VERIFY( csz01 == csz02 );
 }
 
+constexpr bool
+test04()
+{
+  typedef std::wstring_view::size_type csize_type;
+  csize_type npos = std::wstring_view::npos;
+  csize_type csz01 = 0, csz02 = 0;
+
+  const wchar_t str_lit01[] = L"mave";
+  const std::wstring_view str01(L"mavericks, santa cruz");
+  std::wstring_view str02(str_lit01);
+  std::wstring_view str03(L"s, s");
+  std::wstring_view str04;
+
+#undef VERIFY
+#define VERIFY(x) if(!(x)) return false
+
+  // size_type find_first_of(const wstring_view&, size_type pos = 0) const;
+  std::wstring_view str05(L"xena rulez");
+  csz01 = str01.find_first_of(str01);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_of(str01, 4);
+  VERIFY( csz01 == 4 );
+  csz01 = str01.find_first_of(str02, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_of(str02, 3);
+  VERIFY( csz01 == 3 );
+  csz01 = str01.find_first_of(str03, 0);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find_first_of(str03, 3);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find_first_of(str03, 12);
+  VERIFY( csz01 == 16 );
+  csz01 = str01.find_first_of(str05, 0);
+  VERIFY( csz01 == 1 );
+  csz01 = str01.find_first_of(str05, 4);
+  VERIFY( csz01 == 4 );
+
+  // An empty string_view consists of no characters
+  // therefore it should be found at every point in a string_view,
+  // except beyond the end
+  // However, str1.find_first_of(str2,pos) finds the first character in
+  // str1 (starting at pos) that exists in str2, which is none for empty str2
+  csz01 = str01.find_first_of(str04, 0);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find_first_of(str04, 5);
+  VERIFY( csz01 == npos );
+
+  // size_type find_first_of(const wchar_t* s, size_type pos, size_type n) const;
+  csz01 = str01.find_first_of(str_lit01, 0, 3);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_of(str_lit01, 3, 0);
+  VERIFY( csz01 == npos );
+
+  // size_type find_first_of(const wchar_t* s, size_type pos = 0) const;
+  csz01 = str01.find_first_of(str_lit01);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_of(str_lit01, 3);
+  VERIFY( csz01 == 3 );
+
+  // size_type find_first_of(wchar_t c, size_type pos = 0) const;
+  csz01 = str01.find_first_of(L'z');
+  csz02 = str01.size() - 1;
+  VERIFY( csz01 == csz02 );
+
+  return true;
+}
+
 int
 main()
-{ 
+{
   test02();
+  static_assert( test04() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/wchar_t/3.cc	(.../branches/gcc-7-branch)
@@ -84,10 +84,78 @@
   VERIFY( csz01 == npos );
 }
 
+constexpr bool
+test04()
+{
+  typedef std::wstring_view::size_type csize_type;
+  csize_type npos = std::wstring_view::npos;
+  csize_type csz01 = 0;
+
+  const std::wstring_view str01(L"Bob Rock, per me");
+  const wchar_t str_lit01[] = L"Bob Rock";
+  std::wstring_view str02(L"ovvero Trivi");
+  std::wstring_view str03(str_lit01);
+  std::wstring_view str04;
+
+#undef VERIFY
+#define VERIFY(x) if(!(x)) return false
+
+  // size_type find_first_not_of(const string_view&, size_type pos = 0) const;
+  csz01 = str01.find_first_not_of(str01);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find_first_not_of(str02, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_not_of(str02, 10);
+  VERIFY( csz01 == 10 );
+  csz01 = str01.find_first_not_of(str02, 12);
+  VERIFY( csz01 == 14 );
+  csz01 = str01.find_first_not_of(str03, 0);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find_first_not_of(str03, 15);
+  VERIFY( csz01 == 15 );
+  csz01 = str01.find_first_not_of(str03, 16);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find_first_not_of(str04, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_not_of(str04, 12);
+  VERIFY( csz01 == 12 );
+  csz01 = str03.find_first_not_of(str01, 0);
+  VERIFY( csz01 == npos );
+  csz01 = str04.find_first_not_of(str02, 0);
+  VERIFY( csz01 == npos );
+
+  // size_type find_first_not_of(const char* s, size_type pos, size_type n) const;
+  csz01 = str01.find_first_not_of(str_lit01, 0, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_not_of(str_lit01, 0, 8);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find_first_not_of(str_lit01, 10, 0);
+  VERIFY( csz01 == 10 );
+
+  // size_type find_first_not_of(const char* s, size_type pos = 0) const;
+  csz01 = str01.find_first_not_of(str_lit01);
+  VERIFY( csz01 == 8 );
+  csz01 = str02.find_first_not_of(str_lit01, 2);
+  VERIFY( csz01 == 2 );
+
+  // size_type find_first_not_of(char c, size_type pos = 0) const;
+  csz01 = str01.find_first_not_of(L'B');
+  VERIFY( csz01 == 1 );
+  csz01 = str01.find_first_not_of(L'o', 1);
+  VERIFY( csz01 == 2 );
+  csz01 = str02.find_first_not_of(L'z');
+  VERIFY( csz01 == 0 );
+  csz01 = str04.find_first_not_of(L'S');
+  VERIFY( csz01 == npos );
+
+  return true;
+}
+
 int
 main()
-{ 
+{
   test03();
+  static_assert( test04() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/1.cc	(.../branches/gcc-7-branch)
@@ -61,10 +61,10 @@
   csz01 = str01.find(str04, 5);
   VERIFY( csz01 == 5 );
   csz01 = str01.find(str04, str01.size());
-  VERIFY( csz01 == str01.size() ); 
+  VERIFY( csz01 == str01.size() );
   csz01 = str01.find(str04, str01.size()+1);
-  VERIFY( csz01 == npos ); 
-  
+  VERIFY( csz01 == npos );
+
   // size_type find(const char* s, size_type pos, size_type n) const;
   csz01 = str01.find(str_lit01, 0, 3);
   VERIFY( csz01 == 0 );
@@ -85,10 +85,80 @@
   VERIFY( csz01 == npos );
 }
 
+constexpr bool
+test02()
+{
+  typedef std::string_view::size_type csize_type;
+  typedef std::string_view::const_reference cref;
+  typedef std::string_view::reference ref;
+  csize_type npos = std::string_view::npos;
+  csize_type csz01 = 0, csz02 = 0;
+
+  const char str_lit01[] = "mave";
+  const std::string_view str01("mavericks, santa cruz");
+  std::string_view str02(str_lit01);
+  std::string_view str03("s, s");
+  std::string_view str04;
+
+#undef VERIFY
+#define VERIFY(x) if(!(x)) return false
+
+  // size_type find(const string_view&, size_type pos = 0) const;
+  csz01 = str01.find(str01);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str01, 4);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find(str02, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str02, 3);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find(str03, 0);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find(str03, 3);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find(str03, 12);
+  VERIFY( csz01 == npos );
+
+  // An empty string_view consists of no characters
+  // therefore it should be found at every point in a string_view,
+  // except beyond the end
+  csz01 = str01.find(str04, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str04, 5);
+  VERIFY( csz01 == 5 );
+  csz01 = str01.find(str04, str01.size());
+  VERIFY( csz01 == str01.size() );
+  csz01 = str01.find(str04, str01.size()+1);
+  VERIFY( csz01 == npos );
+
+  // size_type find(const char* s, size_type pos, size_type n) const;
+  csz01 = str01.find(str_lit01, 0, 3);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str_lit01, 3, 0);
+  VERIFY( csz01 == 3 );
+
+  // size_type find(const char* s, size_type pos = 0) const;
+  csz01 = str01.find(str_lit01);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find(str_lit01, 3);
+  VERIFY( csz01 == npos );
+
+  // size_type find(char c, size_type pos = 0) const;
+  csz01 = str01.find('z');
+  csz02 = str01.size() - 1;
+  VERIFY( csz01 == csz02 );
+  csz01 = str01.find('/');
+  VERIFY( csz01 == npos );
+
+  return true;
+}
+
+
 int
 main()
-{ 
+{
   test01();
+  static_assert( test02() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/2.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/2.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/2.cc	(.../branches/gcc-7-branch)
@@ -59,13 +59,13 @@
   // An empty string_view consists of no characters
   // therefore it should be found at every point in a string_view,
   // except beyond the end
-  // However, str1.find_first_of(str2,pos) finds the first character in 
+  // However, str1.find_first_of(str2,pos) finds the first character in
   // str1 (starting at pos) that exists in str2, which is none for empty str2
   csz01 = str01.find_first_of(str04, 0);
   VERIFY( csz01 == npos );
   csz01 = str01.find_first_of(str04, 5);
   VERIFY( csz01 == npos );
-  
+
   // size_type find_first_of(const char* s, size_type pos, size_type n) const;
   csz01 = str01.find_first_of(str_lit01, 0, 3);
   VERIFY( csz01 == 0 );
@@ -84,10 +84,78 @@
   VERIFY( csz01 == csz02 );
 }
 
+constexpr bool
+test03()
+{
+  typedef std::string_view::size_type csize_type;
+  csize_type npos = std::string_view::npos;
+  csize_type csz01 = 0, csz02 = 0;
+
+  const char str_lit01[] = "mave";
+  const std::string_view str01("mavericks, santa cruz");
+  std::string_view str02(str_lit01);
+  std::string_view str03("s, s");
+  std::string_view str04;
+
+#undef VERIFY
+#define VERIFY(x) if(!(x)) return false
+
+  // size_type find_first_of(const string_view&, size_type pos = 0) const;
+  std::string_view str05("xena rulez");
+  csz01 = str01.find_first_of(str01);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_of(str01, 4);
+  VERIFY( csz01 == 4 );
+  csz01 = str01.find_first_of(str02, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_of(str02, 3);
+  VERIFY( csz01 == 3 );
+  csz01 = str01.find_first_of(str03, 0);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find_first_of(str03, 3);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find_first_of(str03, 12);
+  VERIFY( csz01 == 16 );
+  csz01 = str01.find_first_of(str05, 0);
+  VERIFY( csz01 == 1 );
+  csz01 = str01.find_first_of(str05, 4);
+  VERIFY( csz01 == 4 );
+
+  // An empty string_view consists of no characters
+  // therefore it should be found at every point in a string_view,
+  // except beyond the end
+  // However, str1.find_first_of(str2,pos) finds the first character in
+  // str1 (starting at pos) that exists in str2, which is none for empty str2
+  csz01 = str01.find_first_of(str04, 0);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find_first_of(str04, 5);
+  VERIFY( csz01 == npos );
+
+  // size_type find_first_of(const char* s, size_type pos, size_type n) const;
+  csz01 = str01.find_first_of(str_lit01, 0, 3);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_of(str_lit01, 3, 0);
+  VERIFY( csz01 == npos );
+
+  // size_type find_first_of(const char* s, size_type pos = 0) const;
+  csz01 = str01.find_first_of(str_lit01);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_of(str_lit01, 3);
+  VERIFY( csz01 == 3 );
+
+  // size_type find_first_of(char c, size_type pos = 0) const;
+  csz01 = str01.find_first_of('z');
+  csz02 = str01.size() - 1;
+  VERIFY( csz01 == csz02 );
+
+  return true;
+}
+
 int
 main()
-{ 
+{
   test02();
+  static_assert( test03() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/3.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/3.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/find/char/3.cc	(.../branches/gcc-7-branch)
@@ -84,10 +84,78 @@
   VERIFY( csz01 == npos );
 }
 
+constexpr bool
+test04()
+{
+  typedef std::string_view::size_type csize_type;
+  csize_type npos = std::string_view::npos;
+  csize_type csz01 = 0;
+
+  const std::string_view str01("Bob Rock, per me");
+  const char str_lit01[] = "Bob Rock";
+  std::string_view str02("ovvero Trivi");
+  std::string_view str03(str_lit01);
+  std::string_view str04;
+
+#undef VERIFY
+#define VERIFY(x) if(!(x)) return false
+
+  // size_type find_first_not_of(const string_view&, size_type pos = 0) const;
+  csz01 = str01.find_first_not_of(str01);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find_first_not_of(str02, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_not_of(str02, 10);
+  VERIFY( csz01 == 10 );
+  csz01 = str01.find_first_not_of(str02, 12);
+  VERIFY( csz01 == 14 );
+  csz01 = str01.find_first_not_of(str03, 0);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find_first_not_of(str03, 15);
+  VERIFY( csz01 == 15 );
+  csz01 = str01.find_first_not_of(str03, 16);
+  VERIFY( csz01 == npos );
+  csz01 = str01.find_first_not_of(str04, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_not_of(str04, 12);
+  VERIFY( csz01 == 12 );
+  csz01 = str03.find_first_not_of(str01, 0);
+  VERIFY( csz01 == npos );
+  csz01 = str04.find_first_not_of(str02, 0);
+  VERIFY( csz01 == npos );
+
+  // size_type find_first_not_of(const char* s, size_type pos, size_type n) const;
+  csz01 = str01.find_first_not_of(str_lit01, 0, 0);
+  VERIFY( csz01 == 0 );
+  csz01 = str01.find_first_not_of(str_lit01, 0, 8);
+  VERIFY( csz01 == 8 );
+  csz01 = str01.find_first_not_of(str_lit01, 10, 0);
+  VERIFY( csz01 == 10 );
+
+  // size_type find_first_not_of(const char* s, size_type pos = 0) const;
+  csz01 = str01.find_first_not_of(str_lit01);
+  VERIFY( csz01 == 8 );
+  csz01 = str02.find_first_not_of(str_lit01, 2);
+  VERIFY( csz01 == 2 );
+
+  // size_type find_first_not_of(char c, size_type pos = 0) const;
+  csz01 = str01.find_first_not_of('B');
+  VERIFY( csz01 == 1 );
+  csz01 = str01.find_first_not_of('o', 1);
+  VERIFY( csz01 == 2 );
+  csz01 = str02.find_first_not_of('z');
+  VERIFY( csz01 == 0 );
+  csz01 = str04.find_first_not_of('S');
+  VERIFY( csz01 == npos );
+
+  return true;
+}
+
 int
 main()
-{ 
+{
   test03();
+  static_assert( test04() );
 
   return 0;
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/1.cc	(.../branches/gcc-7-branch)
@@ -62,9 +62,9 @@
   VERIFY(pass);
   return 0;
 }
- 
 
-int 
+
+int
 test01()
 {
   using std::wstring_view;
@@ -74,7 +74,7 @@
   wstring_view 	str_2;
 
   //sanity check
-  test_value(wcscmp(L"costa marbella", L"costa rica"), lt); 
+  test_value(wcscmp(L"costa marbella", L"costa rica"), lt);
   test_value(wcscmp(L"costa rica", L"costa rica"), z);
   test_value(wcscmp(str_1.data(), str_0.data()), lt);
   test_value(wcscmp(str_0.data(), str_1.data()), gt);
@@ -100,8 +100,8 @@
   test_value(str_1.compare(0, 4, str_2), z);
   test_value(str_1.compare(0, 5, str_2), gt);
 
-  // int compare(size_type pos1, size_type n1, const basic_string_view& str, 
-  //		 size_type pos2, size_type n2) const;	
+  // int compare(size_type pos1, size_type n1, const basic_string_view& str,
+  //		 size_type pos2, size_type n2) const;
   test_value(str_1.compare(0, 6, str_0, 0, 6), z);
   test_value(str_1.compare(0, 7, str_0, 0, 7), lt);
   test_value(str_0.compare(0, 7, str_1, 0, 7), gt);
@@ -111,21 +111,21 @@
   test_value(str_1.compare(L"costa rica"), lt);
   str_2 = str_0;
   test_value(str_2.compare(L"costa rica"), z);
-  test_value(str_2.compare(L"cost"), gt);			
-  test_value(str_2.compare(L"costa ricans"), lt);	   
+  test_value(str_2.compare(L"cost"), gt);
+  test_value(str_2.compare(L"costa ricans"), lt);
 
   // int compare(size_type pos, size_type n1, const charT* str,
   //             size_type n2 = npos) const;
-  test_value(str_1.compare(0, 6, L"costa rica", 0, 6), z); 
-  test_value(str_1.compare(0, 7, L"costa rica", 0, 7), lt); 
-  test_value(str_0.compare(0, 7, L"costa marbella", 0, 7), gt); 
+  test_value(str_1.compare(0, 6, L"costa rica", 0, 6), z);
+  test_value(str_1.compare(0, 7, L"costa rica", 0, 7), lt);
+  test_value(str_0.compare(0, 7, L"costa marbella", 0, 7), gt);
 
   return 0;
 }
 
 
-int 
-main() 
+int
+main()
 {
   test01();
 
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/2.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/2.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/wchar_t/2.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,30 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17" }
+// { dg-do compile { target c++1z } }
+
+#include <string_view>
+
+constexpr wchar_t c1[] = L"one";
+constexpr wchar_t c2[] = L"two";
+
+constexpr std::wstring_view s1{c1};
+constexpr std::wstring_view s2{c2};
+
+constexpr int n1 = s1.compare(s1);
+constexpr int n2 = s1.compare(s2);
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/1.cc	(.../branches/gcc-7-branch)
@@ -62,9 +62,8 @@
   VERIFY(pass);
   return 0;
 }
- 
 
-int 
+int
 test01()
 {
   using std::string_view;
@@ -74,7 +73,7 @@
   string_view 	str_2;
 
   //sanity check
-  test_value(strcmp("costa marbella", "costa rica"), lt); 
+  test_value(strcmp("costa marbella", "costa rica"), lt);
   test_value(strcmp("costa rica", "costa rica"), z);
   test_value(strcmp(str_1.data(), str_0.data()), lt);
   test_value(strcmp(str_0.data(), str_1.data()), gt);
@@ -100,8 +99,8 @@
   test_value(str_1.compare(0, 4, str_2), z);
   test_value(str_1.compare(0, 5, str_2), gt);
 
-  // int compare(size_type pos1, size_type n1, const basic_string_view& str, 
-  //		 size_type pos2, size_type n2) const;	
+  // int compare(size_type pos1, size_type n1, const basic_string_view& str,
+  //		 size_type pos2, size_type n2) const;
   test_value(str_1.compare(0, 6, str_0, 0, 6), z);
   test_value(str_1.compare(0, 7, str_0, 0, 7), lt);
   test_value(str_0.compare(0, 7, str_1, 0, 7), gt);
@@ -111,21 +110,21 @@
   test_value(str_1.compare("costa rica"), lt);
   str_2 = str_0;
   test_value(str_2.compare("costa rica"), z);
-  test_value(str_2.compare("cost"), gt);			
-  test_value(str_2.compare("costa ricans"), lt);	   
+  test_value(str_2.compare("cost"), gt);
+  test_value(str_2.compare("costa ricans"), lt);
 
   // int compare(size_type pos, size_type n1, const charT* str,
   //             size_type n2 = npos) const;
-  test_value(str_1.compare(0, 6, "costa rica", 0, 6), z); 
-  test_value(str_1.compare(0, 7, "costa rica", 0, 7), lt); 
-  test_value(str_0.compare(0, 7, "costa marbella", 0, 7), gt); 
+  test_value(str_1.compare(0, 6, "costa rica", 0, 6), z);
+  test_value(str_1.compare(0, 7, "costa rica", 0, 7), lt);
+  test_value(str_0.compare(0, 7, "costa marbella", 0, 7), gt);
 
   return 0;
 }
 
 
-int 
-main() 
+int
+main()
 {
   test01();
 
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/2.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/2.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/2.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,30 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17" }
+// { dg-do compile { target c++1z } }
+
+#include <string_view>
+
+constexpr char c1[] = "one";
+constexpr char c2[] = "two";
+
+constexpr std::string_view s1{c1};
+constexpr std::string_view s2{c2};
+
+constexpr int n1 = s1.compare(s1);
+constexpr int n2 = s1.compare(s2);
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/70483.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/70483.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operations/compare/char/70483.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,89 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-options "-std=gnu++17" }
+// { dg-do compile { target c++1z } }
+
+#include <string_view>
+
+struct constexpr_char_traits : std::char_traits<char>
+{
+  static constexpr size_t
+  length(const char* val)
+  {
+    size_t res = 0;
+    for (; val[res] != '\0'; ++res)
+      ;
+    return res;
+  }
+
+  static constexpr int
+  compare(const char* lhs, const char* rhs, std::size_t count)
+  {
+    for (size_t pos = 0; pos < count; ++pos)
+    {
+      if (lhs[pos] != rhs[pos])
+        return lhs[pos] - rhs[pos];
+    }
+    return 0;
+  }
+};
+
+using string_view = std::basic_string_view<char, constexpr_char_traits>;
+
+constexpr
+string_view get()
+{
+    string_view res = "x::";
+    string_view start_pattern = "x";
+    res = res.substr(res.find(start_pattern) + start_pattern.size());
+    res = res.substr(0, res.find_first_of(";]"));
+    res = res.substr(res.rfind("::"));
+    return res;
+}
+
+static_assert( get() == get() );
+
+using std::u16string_view;
+
+constexpr
+u16string_view get16()
+{
+    u16string_view res = u"x::";
+    u16string_view start_pattern = u"x";
+    res = res.substr(res.find(start_pattern) + start_pattern.size());
+    res = res.substr(0, res.find_first_of(u";]"));
+    res = res.substr(res.rfind(u"::"));
+    return res;
+}
+
+static_assert( get16() == get16() );
+
+using std::u32string_view;
+
+constexpr
+u32string_view get32()
+{
+    u32string_view res = U"x::";
+    u32string_view start_pattern = U"x";
+    res = res.substr(res.find(start_pattern) + start_pattern.size());
+    res = res.substr(0, res.find_first_of(U";]"));
+    res = res.substr(res.rfind(U"::"));
+    return res;
+}
+
+static_assert( get32() == get32() );
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/wchar_t/1.cc	(.../branches/gcc-7-branch)
@@ -18,7 +18,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// 24.6.5, range access [iterator.range]
+// C++17 27.7, range access [iterator.range]
 
 #include <string_view>
 
@@ -25,9 +25,23 @@
 void
 test01()
 {
-#ifdef _GLIBCXX_USE_WCHAR_T
   std::wstring_view ws(L"Hello, World!");
   std::begin(ws);
   std::end(ws);
-#endif
+  std::rbegin(ws);
+  std::rend(ws);
 }
+
+void
+test02()
+{
+  constexpr std::wstring_view ws(L"Hello, World!");
+  [[maybe_unused]] constexpr auto b = std::begin(ws);
+  [[maybe_unused]] constexpr auto e = std::end(ws);
+  [[maybe_unused]] constexpr auto cb = std::cbegin(ws);
+  [[maybe_unused]] constexpr auto ce = std::cend(ws);
+  [[maybe_unused]] constexpr auto rb = std::rbegin(ws);
+  [[maybe_unused]] constexpr auto re = std::rend(ws);
+  [[maybe_unused]] constexpr auto crb = std::crbegin(ws);
+  [[maybe_unused]] constexpr auto cre = std::crend(ws);
+}
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/char/1.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/char/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/range_access/char/1.cc	(.../branches/gcc-7-branch)
@@ -18,7 +18,7 @@
 // with this library; see the file COPYING3.  If not see
 // <http://www.gnu.org/licenses/>.
 
-// 24.6.5, range access [iterator.range]
+// C++17 27.7, range access [iterator.range]
 
 #include <string_view>
 
@@ -28,4 +28,20 @@
   std::string_view s("Hello, World!");
   std::begin(s);
   std::end(s);
+  std::rbegin(s);
+  std::rend(s);
 }
+
+void
+test02()
+{
+  constexpr std::string_view s("Hello, World!");
+  [[maybe_unused]] constexpr auto b = std::begin(s);
+  [[maybe_unused]] constexpr auto e = std::end(s);
+  [[maybe_unused]] constexpr auto cb = std::cbegin(s);
+  [[maybe_unused]] constexpr auto ce = std::cend(s);
+  [[maybe_unused]] constexpr auto rb = std::rbegin(s);
+  [[maybe_unused]] constexpr auto re = std::rend(s);
+  [[maybe_unused]] constexpr auto crb = std::crbegin(s);
+  [[maybe_unused]] constexpr auto cre = std::crend(s);
+}
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operators/wchar_t/2.cc	(.../branches/gcc-7-branch)
@@ -45,7 +45,7 @@
                   const basic_string_view<charT,traits,Allocator>& rhs);
 
 template<class charT, class traits, class Allocator>
-  bool operator!=(const basic_string_view<charT,traits,Allocator>& lhs, 
+  bool operator!=(const basic_string_view<charT,traits,Allocator>& lhs,
                   const charT* rhs);
 */
 
@@ -60,7 +60,7 @@
                   const charT* rhs);
 
 template<class charT, class traits, class Allocator>
-  bool operator< (const charT* lhs, 
+  bool operator< (const charT* lhs,
                   const basic_string_view<charT,traits,Allocator>& rhs);
 */
 
@@ -112,7 +112,7 @@
 #include <string_view>
 #include <testsuite_hooks.h>
 
-int
+void
 test01()
 {
   std::wstring_view 	str_0(L"costa rica");
@@ -120,7 +120,7 @@
   std::wstring_view 	str_2(L"cost");
   std::wstring_view	str_3(L"costa ricans");
   std::wstring_view  str_4;
-  
+
   str_4 = str_0;
   //comparisons between string_view objects
   VERIFY( !(str_0 == str_1) );
@@ -140,7 +140,7 @@
   VERIFY( str_3 != str_0 );
   VERIFY( !(str_0 != str_4) );
   VERIFY( !(str_4 != str_0) );
-   
+
   VERIFY( str_0 > str_1 ); //true cuz r>m
   VERIFY( str_0 > str_2 );
   VERIFY( !(str_0 > str_3) );
@@ -231,14 +231,137 @@
   VERIFY( !(L"costa ricans" <= str_0) );
   VERIFY( L"costa rica" <= str_0 );
   VERIFY( str_0 <= L"costa rica" );
+}
 
-  return 0;
+constexpr bool
+test02()
+{
+  std::wstring_view 	str_0(L"costa rica");
+  std::wstring_view 	str_1(L"costa marbella");
+  std::wstring_view 	str_2(L"cost");
+  std::wstring_view	str_3(L"costa ricans");
+  std::wstring_view  str_4;
+
+#undef VERIFY
+#define VERIFY(x) if (!(x)) return false
+
+  str_4 = str_0;
+  //comparisons between string_view objects
+  VERIFY( !(str_0 == str_1) );
+  VERIFY( !(str_0 == str_2) );
+  VERIFY( !(str_0 == str_3) );
+  VERIFY( !(str_1 == str_0) );
+  VERIFY( !(str_2 == str_0) );
+  VERIFY( !(str_3 == str_0) );
+  VERIFY( str_4 == str_0 );
+  VERIFY( str_0 == str_4 );
+
+  VERIFY( str_0 != str_1 );
+  VERIFY( str_0 != str_2 );
+  VERIFY( str_0 != str_3 );
+  VERIFY( str_1 != str_0 );
+  VERIFY( str_2 != str_0 );
+  VERIFY( str_3 != str_0 );
+  VERIFY( !(str_0 != str_4) );
+  VERIFY( !(str_4 != str_0) );
+
+  VERIFY( str_0 > str_1 ); //true cuz r>m
+  VERIFY( str_0 > str_2 );
+  VERIFY( !(str_0 > str_3) );
+  VERIFY( !(str_1 > str_0) ); //false cuz m<r
+  VERIFY( !(str_2 > str_0) );
+  VERIFY( str_3 > str_0 );
+  VERIFY( !(str_0 > str_4) );
+  VERIFY( !(str_4 > str_0) );
+
+  VERIFY( !(str_0 < str_1) ); //false cuz r>m
+  VERIFY( !(str_0 < str_2) );
+  VERIFY( str_0 < str_3 );
+  VERIFY( str_1 < str_0 ); //true cuz m<r
+  VERIFY( str_2 < str_0 );
+  VERIFY( !(str_3 < str_0) );
+  VERIFY( !(str_0 < str_4) );
+  VERIFY( !(str_4 < str_0) );
+
+  VERIFY( str_0 >= str_1 ); //true cuz r>m
+  VERIFY( str_0 >= str_2 );
+  VERIFY( !(str_0 >= str_3) );
+  VERIFY( !(str_1 >= str_0) );//false cuz m<r
+  VERIFY( !(str_2 >= str_0) );
+  VERIFY( str_3 >= str_0 );
+  VERIFY( str_0 >= str_4 );
+  VERIFY( str_4 >= str_0 );
+
+  VERIFY( !(str_0 <= str_1) );//false cuz r>m
+  VERIFY( !(str_0 <= str_2) );
+  VERIFY( str_0 <= str_3 );
+  VERIFY( str_1 <= str_0 );//true cuz m<r
+  VERIFY( str_2 <= str_0 );
+  VERIFY( !(str_3 <= str_0) );
+  VERIFY( str_0 <= str_4 );
+  VERIFY( str_4 <= str_0 );
+
+  //comparisons between string_view object and string_view literal
+  VERIFY( !(str_0 == L"costa marbella") );
+  VERIFY( !(str_0 == L"cost") );
+  VERIFY( !(str_0 == L"costa ricans") );
+  VERIFY( !(L"costa marbella" == str_0) );
+  VERIFY( !(L"cost" == str_0) );
+  VERIFY( !(L"costa ricans" == str_0) );
+  VERIFY( L"costa rica" == str_0 );
+  VERIFY( str_0 == L"costa rica" );
+
+  VERIFY( str_0 != L"costa marbella" );
+  VERIFY( str_0 != L"cost" );
+  VERIFY( str_0 != L"costa ricans" );
+  VERIFY( L"costa marbella" != str_0 );
+  VERIFY( L"cost" != str_0 );
+  VERIFY( L"costa ricans" != str_0 );
+  VERIFY( !(L"costa rica" != str_0) );
+  VERIFY( !(str_0 != L"costa rica") );
+
+  VERIFY( str_0 > L"costa marbella" ); //true cuz r>m
+  VERIFY( str_0 > L"cost" );
+  VERIFY( !(str_0 > L"costa ricans") );
+  VERIFY( !(L"costa marbella" > str_0) );//false cuz m<r
+  VERIFY( !(L"cost" > str_0) );
+  VERIFY( L"costa ricans" > str_0 );
+  VERIFY( !(L"costa rica" > str_0) );
+  VERIFY( !(str_0 > L"costa rica") );
+
+  VERIFY( !(str_0 < L"costa marbella") );//false cuz r>m
+  VERIFY( !(str_0 < L"cost") );
+  VERIFY( str_0 < L"costa ricans" );
+  VERIFY( L"costa marbella" < str_0 );//true cuz m<r
+  VERIFY( L"cost" < str_0 );
+  VERIFY( !(L"costa ricans" < str_0) );
+  VERIFY( !(L"costa rica" < str_0) );
+  VERIFY( !(str_0 < L"costa rica") );
+
+  VERIFY( str_0 >= L"costa marbella" );//true cuz r>m
+  VERIFY( str_0 >= L"cost" );
+  VERIFY( !(str_0 >= L"costa ricans") );
+  VERIFY( !(L"costa marbella" >= str_0) );//false cuz m<r
+  VERIFY( !(L"cost" >= str_0) );
+  VERIFY( L"costa ricans" >= str_0 );
+  VERIFY( L"costa rica" >= str_0 );
+  VERIFY( str_0 >= L"costa rica" );
+
+  VERIFY( !(str_0 <= L"costa marbella") );//false cuz r>m
+  VERIFY( !(str_0 <= L"cost") );
+  VERIFY( str_0 <= L"costa ricans" );
+  VERIFY( L"costa marbella" <= str_0 );//true cuz m<r
+  VERIFY( L"cost" <= str_0 );
+  VERIFY( !(L"costa ricans" <= str_0) );
+  VERIFY( L"costa rica" <= str_0 );
+  VERIFY( str_0 <= L"costa rica" );
+
+  return true;
 }
 
 int
-main() 
+main()
 {
   test01();
-
-  return 0;
+  static_assert( test02() );
 }
Index: libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/2.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/2.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/basic_string_view/operators/char/2.cc	(.../branches/gcc-7-branch)
@@ -112,7 +112,7 @@
 #include <string_view>
 #include <testsuite_hooks.h>
 
-int
+void
 test01()
 {
   std::string_view 	str_0("costa rica");
@@ -120,7 +120,7 @@
   std::string_view 	str_2("cost");
   std::string_view	str_3("costa ricans");
   std::string_view        str_4;
-  
+
   str_4 = str_0;
   //comparisons between string objects
   VERIFY( !(str_0 == str_1) );
@@ -140,7 +140,7 @@
   VERIFY( str_3 != str_0 );
   VERIFY( !(str_0 != str_4) );
   VERIFY( !(str_4 != str_0) );
-   
+
   VERIFY( str_0 > str_1 ); //true cuz r>m
   VERIFY( str_0 > str_2 );
   VERIFY( !(str_0 > str_3) );
@@ -231,14 +231,137 @@
   VERIFY( !("costa ricans" <= str_0) );
   VERIFY( "costa rica" <= str_0 );
   VERIFY( str_0 <= "costa rica" );
+}
 
-  return 0;
+constexpr bool
+test02()
+{
+  std::string_view 	str_0("costa rica");
+  std::string_view 	str_1("costa marbella");
+  std::string_view 	str_2("cost");
+  std::string_view	str_3("costa ricans");
+  std::string_view        str_4;
+
+#undef VERIFY
+#define VERIFY(x) if (!(x)) return false
+
+  str_4 = str_0;
+  //comparisons between string objects
+  VERIFY( !(str_0 == str_1) );
+  VERIFY( !(str_0 == str_2) );
+  VERIFY( !(str_0 == str_3) );
+  VERIFY( !(str_1 == str_0) );
+  VERIFY( !(str_2 == str_0) );
+  VERIFY( !(str_3 == str_0) );
+  VERIFY( str_4 == str_0 );
+  VERIFY( str_0 == str_4 );
+
+  VERIFY( str_0 != str_1 );
+  VERIFY( str_0 != str_2 );
+  VERIFY( str_0 != str_3 );
+  VERIFY( str_1 != str_0 );
+  VERIFY( str_2 != str_0 );
+  VERIFY( str_3 != str_0 );
+  VERIFY( !(str_0 != str_4) );
+  VERIFY( !(str_4 != str_0) );
+
+  VERIFY( str_0 > str_1 ); //true cuz r>m
+  VERIFY( str_0 > str_2 );
+  VERIFY( !(str_0 > str_3) );
+  VERIFY( !(str_1 > str_0) ); //false cuz m<r
+  VERIFY( !(str_2 > str_0) );
+  VERIFY( str_3 > str_0 );
+  VERIFY( !(str_0 > str_4) );
+  VERIFY( !(str_4 > str_0) );
+
+  VERIFY( !(str_0 < str_1) ); //false cuz r>m
+  VERIFY( !(str_0 < str_2) );
+  VERIFY( str_0 < str_3 );
+  VERIFY( str_1 < str_0 ); //true cuz m<r
+  VERIFY( str_2 < str_0 );
+  VERIFY( !(str_3 < str_0) );
+  VERIFY( !(str_0 < str_4) );
+  VERIFY( !(str_4 < str_0) );
+
+  VERIFY( str_0 >= str_1 ); //true cuz r>m
+  VERIFY( str_0 >= str_2 );
+  VERIFY( !(str_0 >= str_3) );
+  VERIFY( !(str_1 >= str_0) );//false cuz m<r
+  VERIFY( !(str_2 >= str_0) );
+  VERIFY( str_3 >= str_0 );
+  VERIFY( str_0 >= str_4 );
+  VERIFY( str_4 >= str_0 );
+
+  VERIFY( !(str_0 <= str_1) );//false cuz r>m
+  VERIFY( !(str_0 <= str_2) );
+  VERIFY( str_0 <= str_3 );
+  VERIFY( str_1 <= str_0 );//true cuz m<r
+  VERIFY( str_2 <= str_0 );
+  VERIFY( !(str_3 <= str_0) );
+  VERIFY( str_0 <= str_4 );
+  VERIFY( str_4 <= str_0 );
+
+  //comparisons between string object and string literal
+  VERIFY( !(str_0 == "costa marbella") );
+  VERIFY( !(str_0 == "cost") );
+  VERIFY( !(str_0 == "costa ricans") );
+  VERIFY( !("costa marbella" == str_0) );
+  VERIFY( !("cost" == str_0) );
+  VERIFY( !("costa ricans" == str_0) );
+  VERIFY( "costa rica" == str_0 );
+  VERIFY( str_0 == "costa rica" );
+
+  VERIFY( str_0 != "costa marbella" );
+  VERIFY( str_0 != "cost" );
+  VERIFY( str_0 != "costa ricans" );
+  VERIFY( "costa marbella" != str_0 );
+  VERIFY( "cost" != str_0 );
+  VERIFY( "costa ricans" != str_0 );
+  VERIFY( !("costa rica" != str_0) );
+  VERIFY( !(str_0 != "costa rica") );
+
+  VERIFY( str_0 > "costa marbella" ); //true cuz r>m
+  VERIFY( str_0 > "cost" );
+  VERIFY( !(str_0 > "costa ricans") );
+  VERIFY( !("costa marbella" > str_0) );//false cuz m<r
+  VERIFY( !("cost" > str_0) );
+  VERIFY( "costa ricans" > str_0 );
+  VERIFY( !("costa rica" > str_0) );
+  VERIFY( !(str_0 > "costa rica") );
+
+  VERIFY( !(str_0 < "costa marbella") );//false cuz r>m
+  VERIFY( !(str_0 < "cost") );
+  VERIFY( str_0 < "costa ricans" );
+  VERIFY( "costa marbella" < str_0 );//true cuz m<r
+  VERIFY( "cost" < str_0 );
+  VERIFY( !("costa ricans" < str_0) );
+  VERIFY( !("costa rica" < str_0) );
+  VERIFY( !(str_0 < "costa rica") );
+
+  VERIFY( str_0 >= "costa marbella" );//true cuz r>m
+  VERIFY( str_0 >= "cost" );
+  VERIFY( !(str_0 >= "costa ricans") );
+  VERIFY( !("costa marbella" >= str_0) );//false cuz m<r
+  VERIFY( !("cost" >= str_0) );
+  VERIFY( "costa ricans" >= str_0 );
+  VERIFY( "costa rica" >= str_0 );
+  VERIFY( str_0 >= "costa rica" );
+
+  VERIFY( !(str_0 <= "costa marbella") );//false cuz r>m
+  VERIFY( !(str_0 <= "cost") );
+  VERIFY( str_0 <= "costa ricans" );
+  VERIFY( "costa marbella" <= str_0 );//true cuz m<r
+  VERIFY( "cost" <= str_0 );
+  VERIFY( !("costa ricans" <= str_0) );
+  VERIFY( "costa rica" <= str_0 );
+  VERIFY( str_0 <= "costa rica" );
+
+  return true;
 }
 
 int
-main() 
+main()
 {
   test01();
-
-  return 0;
+  static_assert( test02() );
 }
Index: libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/21_strings/char_traits/requirements/constexpr_functions_c++17.cc	(.../branches/gcc-7-branch)
@@ -74,20 +74,20 @@
   }
 
 #ifndef __cpp_lib_constexpr_char_traits
-// #error Feature-test macro for constexpr char_traits is missing
+# error Feature-test macro for constexpr char_traits is missing
 #elif __cpp_lib_constexpr_char_traits != 201611
-// #error Feature-test macro for constexpr char_traits has the wrong value
+# error Feature-test macro for constexpr char_traits has the wrong value
 #endif
 
 static_assert( test_assign<std::char_traits<char>>() );
-// static_assert( test_compare<std::char_traits<char>>() );
-// static_assert( test_length<std::char_traits<char>>() );
-// static_assert( test_find<std::char_traits<char>>() );
+static_assert( test_compare<std::char_traits<char>>() );
+static_assert( test_length<std::char_traits<char>>() );
+static_assert( test_find<std::char_traits<char>>() );
 #ifdef _GLIBCXX_USE_WCHAR_T
 static_assert( test_assign<std::char_traits<wchar_t>>() );
-// static_assert( test_compare<std::char_traits<wchar_t>>() );
-// static_assert( test_length<std::char_traits<wchar_t>>() );
-// static_assert( test_find<std::char_traits<wchar_t>>() );
+static_assert( test_compare<std::char_traits<wchar_t>>() );
+static_assert( test_length<std::char_traits<wchar_t>>() );
+static_assert( test_find<std::char_traits<wchar_t>>() );
 #endif
 static_assert( test_assign<std::char_traits<char16_t>>() );
 static_assert( test_compare<std::char_traits<char16_t>>() );
Index: libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/21_strings/basic_string/cons/wchar_t/moveable2_c++17.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,53 @@
+// { dg-options "-std=gnu++17" }
+// { dg-do run { target c++1z } }
+
+// Copyright (C) 2011-2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// NOTE: This makes use of the fact that we know how moveable
+// is implemented on string (via swap). If the implementation changed
+// this test may begin to fail.
+
+#include <string>
+#include <utility>
+#include <testsuite_hooks.h>
+
+class tstring : public std::basic_string<wchar_t>
+{
+public:
+  tstring() : std::basic_string<wchar_t>() {}
+  tstring(tstring&& s) : std::basic_string<wchar_t>(std::move(s)) {}
+  tstring& operator=(tstring&& s) = default;
+};
+
+void test01()
+{
+  tstring a, b;
+  a.push_back(L'1');
+  b = std::move(a);
+  VERIFY( b.size() == 1 && b[0] == L'1' && a.size() == 0 );
+
+  tstring c(std::move(b));
+  VERIFY( c.size() == 1 && c[0] == L'1' );
+  VERIFY( b.size() == 0 );
+}
+
+int main()
+{
+  test01();
+  return 0;
+}
Index: libstdc++-v3/testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/21_strings/basic_string/cons/char/moveable2_c++17.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,53 @@
+// { dg-options "-std=gnu++17" }
+// { dg-do run { target c++1z } }
+
+// Copyright (C) 2011-2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// NOTE: This makes use of the fact that we know how moveable
+// is implemented on string (via swap). If the implementation changed
+// this test may begin to fail.
+
+#include <string>
+#include <utility>
+#include <testsuite_hooks.h>
+
+class tstring : public std::basic_string<char>
+{
+public:
+  tstring() : std::basic_string<char>() {}
+  tstring(tstring&& s) : std::basic_string<char>(std::move(s)) {}
+  tstring& operator=(tstring&& s) = default;
+};
+
+void test01()
+{
+  tstring a, b;
+  a.push_back('1');
+  b = std::move(a);
+  VERIFY( b.size() == 1 && b[0] == '1' && a.size() == 0 );
+
+  tstring c(std::move(b));
+  VERIFY( c.size() == 1 && c[0] == '1' );
+  VERIFY( b.size() == 0 );
+}
+
+int main()
+{
+  test01();
+  return 0;
+}
Index: libstdc++-v3/testsuite/21_strings/basic_string/lwg2946.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string/lwg2946.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/21_strings/basic_string/lwg2946.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,41 @@
+// { dg-options "-std=gnu++17" }
+// { dg-do compile }
+
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+#include <string>
+
+int main()
+{
+  std::string s({"abc", 1});
+  s = {"abc", 1};
+  s += {"abc", 1};
+  s.append({"abc", 1});
+  s.assign({"abc", 1});
+  s.insert(0, {"abc", 1});
+  s.replace(0, 1, {"abc", 1});
+  s.replace(s.begin(), s.begin(), {"abc", 1});
+  s.find({"abc", 1});
+  s.rfind({"abc", 1});
+  s.find_first_of({"abc", 1});
+  s.find_last_of({"abc", 1});
+  s.find_first_not_of({"abc", 1});
+  s.find_last_not_of({"abc", 1});
+  s.compare({"abc", 1});
+  s.compare(0, 1, {"abc", 1});
+}
Index: libstdc++-v3/testsuite/21_strings/basic_string/79162.cc
===================================================================
--- libstdc++-v3/testsuite/21_strings/basic_string/79162.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/21_strings/basic_string/79162.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,37 @@
+// { dg-options "-std=gnu++17" }
+// { dg-do compile }
+
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+#include <string>
+
+template <class DataType>
+class opt : public DataType
+{
+  opt(const opt &) = delete;
+  opt &operator=(const opt &) = delete;
+public:
+  opt() {}
+};
+
+int main()
+{
+  opt<std::string> PGOTestProfileFile;
+  std::string ProfileFileName;
+  ProfileFileName = PGOTestProfileFile;
+}
Index: libstdc++-v3/testsuite/26_numerics/lcm/1.cc
===================================================================
--- libstdc++-v3/testsuite/26_numerics/lcm/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/26_numerics/lcm/1.cc	(.../branches/gcc-7-branch)
@@ -20,9 +20,9 @@
 
 #include <numeric>
 
-#ifndef __cpp_lib_lcm
+#ifndef __cpp_lib_gcd_lcm
 # error "Feature-test macro for lcm missing"
-#elif __cpp_lib_lcm != 201606
+#elif __cpp_lib_gcd_lcm != 201606
 # error "Feature-test macro for lcm has wrong value"
 #endif
 
Index: libstdc++-v3/testsuite/26_numerics/lcm/lcm_neg.cc
===================================================================
--- libstdc++-v3/testsuite/26_numerics/lcm/lcm_neg.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/26_numerics/lcm/lcm_neg.cc	(.../branches/gcc-7-branch)
@@ -31,9 +31,9 @@
   std::lcm(0.1, 0.1);   // { dg-error "from here" }
 }
 
-// { dg-error "integers" "" { target *-*-* } 147 }
-// { dg-error "integers" "" { target *-*-* } 148 }
-// { dg-error "not bools" "" { target *-*-* } 149 }
-// { dg-error "not bools" "" { target *-*-* } 150 }
+// { dg-error "integers" "" { target *-*-* } 150 }
+// { dg-error "integers" "" { target *-*-* } 151 }
+// { dg-error "not bools" "" { target *-*-* } 152 }
+// { dg-error "not bools" "" { target *-*-* } 153 }
 // { dg-prune-output "deleted function" }
 // { dg-prune-output "invalid operands" }
Index: libstdc++-v3/testsuite/26_numerics/gcd/1.cc
===================================================================
--- libstdc++-v3/testsuite/26_numerics/gcd/1.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/26_numerics/gcd/1.cc	(.../branches/gcc-7-branch)
@@ -20,9 +20,9 @@
 
 #include <numeric>
 
-#ifndef __cpp_lib_gcd
+#ifndef __cpp_lib_gcd_lcm
 # error "Feature-test macro for gcd missing"
-#elif __cpp_lib_gcd != 201606
+#elif __cpp_lib_gcd_lcm != 201606
 # error "Feature-test macro for gcd has wrong value"
 #endif
 
Index: libstdc++-v3/testsuite/26_numerics/gcd/gcd_neg.cc
===================================================================
--- libstdc++-v3/testsuite/26_numerics/gcd/gcd_neg.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/26_numerics/gcd/gcd_neg.cc	(.../branches/gcc-7-branch)
@@ -31,9 +31,9 @@
   std::gcd(0.1, 0.1);   // { dg-error "from here" }
 }
 
-// { dg-error "integers" "" { target *-*-* } 134 }
-// { dg-error "integers" "" { target *-*-* } 135 }
-// { dg-error "not bools" "" { target *-*-* } 136 }
-// { dg-error "not bools" "" { target *-*-* } 137 }
+// { dg-error "integers" "" { target *-*-* } 138 }
+// { dg-error "integers" "" { target *-*-* } 139 }
+// { dg-error "not bools" "" { target *-*-* } 140 }
+// { dg-error "not bools" "" { target *-*-* } 141 }
 // { dg-prune-output "deleted function" }
 // { dg-prune-output "invalid operands" }
Index: libstdc++-v3/testsuite/experimental/filesystem/path/itr/traversal.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/filesystem/path/itr/traversal.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/experimental/filesystem/path/itr/traversal.cc	(.../branches/gcc-7-branch)
@@ -79,9 +79,27 @@
   }
 }
 
+void
+test03()
+{
+  path paths[] = { "single", "multiple/elements" };
+  for (const path& p : paths)
+    for (auto iter = p.begin(); iter != p.end(); ++iter)
+    {
+      auto iter2 = iter;
+      ++iter;
+      iter2++;
+      VERIFY( iter2 == iter );
+      --iter;
+      iter2--;
+      VERIFY( iter2 == iter );
+    }
+}
+
 int
 main()
 {
   test01();
   test02();
+  test03();
 }
Index: libstdc++-v3/testsuite/experimental/string_view/operations/compare/char/70483.cc
===================================================================
--- libstdc++-v3/testsuite/experimental/string_view/operations/compare/char/70483.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/experimental/string_view/operations/compare/char/70483.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,68 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do compile { target c++14 } }
+
+#include <experimental/string_view>
+
+struct constexpr_char_traits : std::char_traits<char>
+{
+  static constexpr size_t
+  length(const char* val)
+  {
+    size_t res = 0;
+    for (; val[res] != '\0'; ++res)
+      ;
+    return res;
+  }
+
+  static constexpr int
+  compare(const char* lhs, const char* rhs, std::size_t count)
+  {
+    for (size_t pos = 0; pos < count; ++pos)
+    {
+      if (lhs[pos] != rhs[pos])
+        return lhs[pos] - rhs[pos];
+    }
+    return 0;
+  }
+
+  static constexpr const char*
+  find(const char* p, std::size_t n, char c)
+  {
+    for (size_t pos = 0; pos < n; ++pos)
+      if (p[pos] == c)
+	return p + pos;
+    return nullptr;
+  }
+};
+
+using string_view
+  = std::experimental::basic_string_view<char, constexpr_char_traits>;
+
+constexpr
+string_view get()
+{
+    string_view res = "x::";
+    string_view start_pattern = "x";
+    res = res.substr(res.find(start_pattern) + start_pattern.size());
+    res = res.substr(0, res.find_first_of(";]"));
+    res = res.substr(res.rfind("::"));
+    return res;
+}
+
+static_assert( get() == get() );
Index: libstdc++-v3/testsuite/17_intro/names.cc
===================================================================
--- libstdc++-v3/testsuite/17_intro/names.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/17_intro/names.cc	(.../branches/gcc-7-branch)
@@ -107,4 +107,9 @@
 #undef y
 #endif
 
+#ifdef __hpux__
+#undef d
+#undef r
+#endif
+
 #include <bits/stdc++.h>
Index: libstdc++-v3/testsuite/20_util/duration/literals/range.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/duration/literals/range.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/20_util/duration/literals/range.cc	(.../branches/gcc-7-branch)
@@ -26,6 +26,6 @@
 
   // std::numeric_limits<int64_t>::max() == 9223372036854775807;
   auto h = 9223372036854775808h;
-  // { dg-error "cannot be represented" "" { target *-*-* } 892 }
+  // { dg-error "cannot be represented" "" { target *-*-* } 893 }
 }
 // { dg-prune-output "in constexpr expansion" } // needed for -O0
Index: libstdc++-v3/testsuite/20_util/duration/cons/dr1177.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/duration/cons/dr1177.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/20_util/duration/cons/dr1177.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,41 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do compile { target c++11 } }
+
+#include <chrono>
+#include <type_traits>
+
+using namespace std;
+using namespace std::chrono;
+
+// DR 1177
+static_assert(is_constructible<duration<float>, duration<double>>{},
+    "can convert duration with one floating point rep to another");
+static_assert(is_constructible<duration<float>, duration<int>>{},
+    "can convert duration with integral rep to one with floating point rep");
+static_assert(!is_constructible<duration<int>, duration<float>>{},
+    "cannot convert duration with floating point rep to one with integral rep");
+static_assert(is_constructible<duration<int>, duration<long>>{},
+    "can convert duration with one integral rep to another");
+
+static_assert(!is_constructible<duration<int>, duration<int, ratio<2,3>>>{},
+    "cannot convert duration to one with different period");
+static_assert(is_constructible<duration<float>, duration<int, ratio<2,3>>>{},
+    "unless it has a floating-point representation");
+static_assert(is_constructible<duration<float>, duration<int, ratio<1,3>>>{},
+    "or a period that is an integral multiple of the original");
Index: libstdc++-v3/testsuite/20_util/duration/arithmetic/constexpr_c++17.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/duration/arithmetic/constexpr_c++17.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/20_util/duration/arithmetic/constexpr_c++17.cc	(.../branches/gcc-7-branch)
@@ -20,6 +20,13 @@
 
 #include <chrono>
 #include <testsuite_common_types.h>
+
+#ifndef __cpp_lib_chrono
+# error "Feature-test macro for constexpr <chrono> missing"
+#elif __cpp_lib_chrono != 201611
+# error "Feature-test macro for constexpr <chrono> has wrong value"
+#endif
+
 constexpr auto test_operators()
 {
   std::chrono::nanoseconds d1 { 1 };
Index: libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value.cc	(.../branches/gcc-7-branch)
@@ -40,6 +40,10 @@
 
 void test01()
 {
+  struct T { T(int) { } };
+  struct NT { NT(int) noexcept { } };
+  struct Ex { explicit Ex(int) noexcept { } };
+
   using func_type = void(*)();
   static_assert( ! is_nt_invocable< func_type>(),     "");
 
@@ -55,28 +59,46 @@
   static_assert( ! is_nt_invocable< mem_type, int >(),   "");
   static_assert( ! is_nt_invocable< mem_type, int& >(),	"");
 
-  static_assert(   is_nt_invocable< mem_type, X& >(),       "");
-  static_assert(   is_nt_invocable_r< int,  mem_type, X& >(), "");
-  static_assert(   is_nt_invocable_r< int&, mem_type, X& >(), "");
-  static_assert(   is_nt_invocable_r< long, mem_type, X& >(), "");
-  static_assert(   is_nt_invocable_r< int&, mem_type, X* >(), "");
+  static_assert(   is_nt_invocable< mem_type, X& >(),          "");
+  static_assert(   is_nt_invocable_r< int,   mem_type, X& >(), "");
+  static_assert(   is_nt_invocable_r< int&,  mem_type, X& >(), "");
+  static_assert(   is_nt_invocable_r< long,  mem_type, X& >(), "");
+  static_assert( ! is_nt_invocable_r< long&, mem_type, X& >(),
+		   "conversion fails, cannot bind long& to int");
+  static_assert(   is_nt_invocable_r< int&,  mem_type, X* >(), "");
 
+  static_assert( ! is_nt_invocable_r< T,  mem_type, X& >(),
+		   "conversion throws");
+  static_assert(   is_nt_invocable_r< NT, mem_type, X& >(), "");
+  static_assert( ! is_nt_invocable_r< Ex, mem_type, X& >(),
+		   "conversion fails, would use explicit constructor");
+
   using memfun_type = int (X::*)();
 
-  static_assert( ! is_nt_invocable< memfun_type >(),     "");
-  static_assert( ! is_nt_invocable< memfun_type, int >(),  "");
-  static_assert( ! is_nt_invocable< memfun_type, int& >(), "");
-  static_assert( ! is_nt_invocable< memfun_type, X& >(),   "");
-  static_assert( ! is_nt_invocable< memfun_type, X* >(),   "");
+  static_assert( ! is_nt_invocable< memfun_type >(),       "no object");
+  static_assert( ! is_nt_invocable< memfun_type, int >(),  "no object");
+  static_assert( ! is_nt_invocable< memfun_type, int& >(), "no object");
+  static_assert( ! is_nt_invocable< memfun_type, X& >(),   "call throws");
+  static_assert( ! is_nt_invocable< memfun_type, X* >(),   "call throws");
 
+  static_assert( ! is_nt_invocable_r< T,  memfun_type, X& >(), "call throws");
+  static_assert( ! is_nt_invocable_r< NT, memfun_type, X& >(), "call throws");
+  static_assert( ! is_nt_invocable_r< Ex, memfun_type, X& >(), "call throws");
+
 #if __cpp_noexcept_function_type
   using memfun_type_nt = int (X::*)() noexcept;
 
-  static_assert( ! is_nt_invocable< memfun_type_nt >(),	    "");
-  static_assert( ! is_nt_invocable< memfun_type_nt, int >(),  "");
-  static_assert( ! is_nt_invocable< memfun_type_nt, int& >(), "");
+  static_assert( ! is_nt_invocable< memfun_type_nt >(),	      "no object");
+  static_assert( ! is_nt_invocable< memfun_type_nt, int >(),  "no object");
+  static_assert( ! is_nt_invocable< memfun_type_nt, int& >(), "no object");
   static_assert(   is_nt_invocable< memfun_type_nt, X& >(),   "");
   static_assert(   is_nt_invocable< memfun_type_nt, X* >(),   "");
+
+  static_assert( ! is_nt_invocable_r< T,  memfun_type_nt, X& >(),
+		   "conversion throws");
+  static_assert(   is_nt_invocable_r< NT, memfun_type_nt, X& >(), "");
+  static_assert( ! is_nt_invocable_r< Ex, memfun_type_nt, X& >(),
+		   "conversion fails, would use explicit constructor");
 #endif
 
   struct F {
@@ -89,12 +111,44 @@
   };
   using CF = const F;
 
-  static_assert( ! is_nt_invocable_r< int&,  F  >(), "");
-  static_assert(   is_nt_invocable_r< long&, CF >(),  "");
-  static_assert( ! is_nt_invocable_r< short&, F,   int >(), "" );
-  static_assert(   is_nt_invocable_r< char&,  F&,  int >(), "" );
-  static_assert(   is_nt_invocable_r< char&,  CF,  int >(), "" );
-  static_assert(   is_nt_invocable_r< char&,  CF&, int >(), "" );
+  static_assert( ! is_nt_invocable< F  >(), "call throws");
+  static_assert(   is_nt_invocable< CF >(), "");
 
-  static_assert( ! is_nt_invocable< F, int, int >(), "");
+  static_assert( ! is_nt_invocable_r< int&,  F  >(), "call throws");
+  static_assert(   is_nt_invocable_r< long&, CF >(), "");
+  static_assert( ! is_nt_invocable_r< T,     F  >(), "call throws");
+  static_assert( ! is_nt_invocable_r< NT,    F  >(), "call throws");
+  static_assert( ! is_nt_invocable_r< Ex,    F  >(), "call throws");
+  static_assert( ! is_nt_invocable_r< T,     CF >(), "conversion throws");
+  static_assert(   is_nt_invocable_r< NT,    CF >(), "" );
+  static_assert( ! is_nt_invocable_r< Ex,    CF >(), "conversion fails");
+
+  static_assert( ! is_nt_invocable< F,   int >(), "call throws");
+  static_assert(   is_nt_invocable< F&,  int >(), "");
+
+  static_assert( ! is_nt_invocable_r< short&, F,   int >(),
+		   "call throws" );
+  static_assert(   is_nt_invocable_r< char&,  F&,  int >(), "");
+  static_assert( ! is_nt_invocable_r< T,      F&,  int >(),
+		   "conversion throws");
+  static_assert(   is_nt_invocable_r< NT,     F&,  int >(), "");
+  static_assert( ! is_nt_invocable_r< Ex,     F&,  int >(),
+		   "conversion fails, would use explicit constructor");
+
+  static_assert(   is_nt_invocable< CF,   int >(), "");
+  static_assert(   is_nt_invocable< CF&,  int >(), "");
+
+  static_assert(   is_nt_invocable_r< char&,  CF,  int >(), "");
+  static_assert(   is_nt_invocable_r< char&,  CF&, int >(), "");
+
+  static_assert( ! is_nt_invocable_r< T,      CF&, int >(),
+		   "conversion throws");
+  static_assert(   is_nt_invocable_r< NT,     CF&, int >(), "");
+  static_assert( ! is_nt_invocable_r< Ex,     CF&, int >(),
+		   "conversion fails, would use explicit constructor");
+
+  static_assert( ! is_nt_invocable< F, int, int >(),
+		   "would call private member");
+  static_assert( ! is_nt_invocable_r<void, F, int, int >(),
+		   "would call private member");
 }
Index: libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value_ext.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value_ext.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/20_util/is_nothrow_invocable/value_ext.cc	(.../branches/gcc-7-branch)
@@ -27,7 +27,9 @@
   constexpr bool is_nt_invocable_conv(std::true_type)
   {
     using result_type = typename std::__invoke_result<T...>::type;
-    return std::is_void<R>::value || std::is_convertible<result_type, R>::value;
+    return std::is_void<R>::value
+      || (std::is_convertible<result_type, R>::value
+	  && std::is_nothrow_constructible<R, result_type>::value);
   }
 
 template<typename R, typename... T>
Index: libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/20_util/optional/cons/value_neg.cc	(.../branches/gcc-7-branch)
@@ -37,8 +37,8 @@
     std::optional<std::unique_ptr<int>> oup2 = new int;  // { dg-error "conversion" }
     struct U { explicit U(std::in_place_t); };
     std::optional<U> ou(std::in_place); // { dg-error "no matching" }
-    // { dg-error "no type" "" { target { *-*-* } } 488 }
-    // { dg-error "no type" "" { target { *-*-* } } 498 }
-    // { dg-error "no type" "" { target { *-*-* } } 555 }
+    // { dg-error "no type" "" { target { *-*-* } } 490 }
+    // { dg-error "no type" "" { target { *-*-* } } 500 }
+    // { dg-error "no type" "" { target { *-*-* } } 557 }
   }
 }
Index: libstdc++-v3/testsuite/20_util/optional/hash.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/optional/hash.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/testsuite/20_util/optional/hash.cc	(.../branches/gcc-7-branch)
@@ -29,14 +29,23 @@
 auto f(...) -> decltype(std::false_type());
 
 static_assert(!decltype(f<S>(0))::value, "");
-static_assert(!std::is_invocable_v<
-    std::hash<std::optional<S>>&, std::optional<S> const&> );
-static_assert(std::is_invocable_v<
-    std::hash<std::optional<int>>&, std::optional<int> const&> );
 
+template<typename T>
+constexpr bool hashable()
+{ return std::is_invocable_v<std::hash<T>&, const T&>; }
+
+static_assert(!hashable<std::optional<S>>());
+static_assert(!hashable<std::optional<const S>>());
+static_assert(hashable<std::optional<int>>());
+static_assert(hashable<std::optional<const int>>());
+
 int main()
 {
   int x = 42;
   std::optional<int> x2 = 42;
   VERIFY(std::hash<int>()(x) == std::hash<std::optional<int>>()(x2));
+
+  // PR libstdc++/82262
+  std::optional<const int> x3 = x2;
+  VERIFY(std::hash<int>()(x) == std::hash<std::optional<const int>>()(x3));
 }
Index: libstdc++-v3/testsuite/20_util/time_point/cons/81468.cc
===================================================================
--- libstdc++-v3/testsuite/20_util/time_point/cons/81468.cc	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libstdc++-v3/testsuite/20_util/time_point/cons/81468.cc	(.../branches/gcc-7-branch)
@@ -0,0 +1,34 @@
+// Copyright (C) 2017 Free Software Foundation, Inc.
+//
+// This file is part of the GNU ISO C++ Library.  This library is free
+// software; you can redistribute it and/or modify it under the
+// terms of the GNU General Public License as published by the
+// Free Software Foundation; either version 3, or (at your option)
+// any later version.
+
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+
+// You should have received a copy of the GNU General Public License along
+// with this library; see the file COPYING3.  If not see
+// <http://www.gnu.org/licenses/>.
+
+// { dg-do compile { target c++11 } }
+
+#include <chrono>
+#include <type_traits>
+
+using namespace std;
+using namespace std::chrono;
+
+template <class Duration>
+    using sys_time = time_point<system_clock, Duration>;
+
+static_assert(is_constructible<sys_time<milliseconds>, sys_time<seconds>>{},
+    "Can construct time_point from one with lower precision duration");
+
+// PR libstdc++/81468 - DR 1177
+static_assert(!is_constructible<sys_time<seconds>, sys_time<milliseconds>>{},
+    "Cannot construct time_point from one with higher precision duration");
Index: libstdc++-v3/config/io/basic_file_stdio.cc
===================================================================
--- libstdc++-v3/config/io/basic_file_stdio.cc	(.../tags/gcc_7_2_0_release)
+++ libstdc++-v3/config/io/basic_file_stdio.cc	(.../branches/gcc-7-branch)
@@ -195,11 +195,13 @@
     __basic_file* __ret = NULL;
     if (!this->is_open() && __file)
       {
-	int __err;
+	int __err, __save_errno = errno;
+	// POSIX guarantees that fflush sets errno on error, but C doesn't.
 	errno = 0;
 	do
-	  __err = this->sync();
+	  __err = fflush(__file);
 	while (__err && errno == EINTR);
+	errno = __save_errno;
 	if (!__err)
 	  {
 	    _M_cfile = __file;
Index: contrib/ChangeLog
===================================================================
--- contrib/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ contrib/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,7 @@
+2017-10-02  Thomas Schwinge  <thomas@codesourcery.com>
+
+	* gcc_update (files_and_dependencies): Handle libbacktrace.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: contrib/gcc_update
===================================================================
--- contrib/gcc_update	(.../tags/gcc_7_2_0_release)
+++ contrib/gcc_update	(.../branches/gcc-7-branch)
@@ -172,6 +172,10 @@
 liboffloadmic/plugin/aclocal.m4: liboffloadmic/plugin/configure.ac
 liboffloadmic/plugin/Makefile.in: liboffloadmic/plugin/Makefile.am
 liboffloadmic/plugin/configure: liboffloadmic/plugin/configure.ac
+libbacktrace/aclocal.m4: libbacktrace/configure.ac
+libbacktrace/Makefile.in: libbacktrace/Makefile.am libbacktrace/aclocal.m4
+libbacktrace/configure: libbacktrace/configure.ac libbacktrace/aclocal.m4
+libbacktrace/config.h.in: libbacktrace/configure.ac libbacktrace/aclocal.m4
 # Top level
 Makefile.in: Makefile.tpl Makefile.def
 configure: configure.ac config/acx.m4
Index: libbacktrace/elf.c
===================================================================
--- libbacktrace/elf.c	(.../tags/gcc_7_2_0_release)
+++ libbacktrace/elf.c	(.../branches/gcc-7-branch)
@@ -103,6 +103,7 @@
 #undef SHT_SYMTAB
 #undef SHT_STRTAB
 #undef SHT_DYNSYM
+#undef SHF_COMPRESSED
 #undef STT_OBJECT
 #undef STT_FUNC
 
@@ -195,6 +196,8 @@
 #define SHT_STRTAB 3
 #define SHT_DYNSYM 11
 
+#define SHF_COMPRESSED 0x800
+
 #if BACKTRACE_ELF_SIZE == 32
 
 typedef struct
@@ -700,7 +703,8 @@
 
       for (j = 0; j < (int) DEBUG_MAX; ++j)
 	{
-	  if (strcmp (name, debug_section_names[j]) == 0)
+	  if (strcmp (name, debug_section_names[j]) == 0
+              && (shdr->sh_flags & SHF_COMPRESSED) == 0)
 	    {
 	      sections[j].offset = shdr->sh_offset;
 	      sections[j].size = shdr->sh_size;
Index: libbacktrace/ChangeLog
===================================================================
--- libbacktrace/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ libbacktrace/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,13 @@
+2017-10-10  Paolo Carlini  <paolo.carlini@oracle.com>
+
+	* elf.c: Fix typo in the last commit, SFH_COMPRESSED vs SHF_COMPRESSED.
+
+2017-10-10  Ian Lance Taylor  <iant@golang.org>
+
+	PR go/80914
+	* elf.c (SHF_COMPRESSED): Define.
+	(elf_add): Ignore debug sections with SHF_COMPRESSED set.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: libgcc/config.host
===================================================================
--- libgcc/config.host	(.../tags/gcc_7_2_0_release)
+++ libgcc/config.host	(.../branches/gcc-7-branch)
@@ -245,6 +245,7 @@
 *-*-netbsd*)
   tmake_file="$tmake_file t-crtstuff-pic t-libgcc-pic t-eh-dw2-dip"
   tmake_file="$tmake_file t-slibgcc t-slibgcc-gld t-slibgcc-elf-ver"
+  tmake_file="$tmake_file t-slibgcc-libgcc"
   # NetBSD 1.7 and later are set up to use GCC's crtstuff for
   # ELF configurations.  We will clear extra_parts in the
   # a.out configurations.
Index: libgcc/ChangeLog
===================================================================
--- libgcc/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ libgcc/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,29 @@
+2017-11-05  Andreas Tobler  <andreast@gcc.gnu.org>
+
+	Backport from mainline
+	2017-11-04  Andreas Tobler  <andreast@gcc.gnu.org>
+
+	PR libgcc/82635
+	* config/i386/freebsd-unwind.h (MD_FALLBACK_FRAME_STATE_FOR): Use a
+	sysctl to determine whether we're in a trampoline.
+	Keep the pattern matching method for systems without
+	KERN_PROC_SIGTRAMP sysctl.
+
+2017-10-13  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/82274
+	* libgcc2.c (__mulvDI3): If both operands have
+	the same highpart of -1 and the topmost bit of lowpart is 0,
+	multiplication overflows even if both lowparts are 0.
+
+2017-09-28  Krister Walfridsson  <krister.walfridsson@gmail.com>
+
+	Backport from mainline
+	2017-05-14  Krister Walfridsson  <krister.walfridsson@gmail.com>
+
+	PR target/80600
+	* config.host (*-*-netbsd*): Add t-slibgcc-libgcc to tmake_file.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: libgcc/config/i386/freebsd-unwind.h
===================================================================
--- libgcc/config/i386/freebsd-unwind.h	(.../tags/gcc_7_2_0_release)
+++ libgcc/config/i386/freebsd-unwind.h	(.../branches/gcc-7-branch)
@@ -28,7 +28,10 @@
 
 #include <sys/types.h>
 #include <signal.h>
+#include <unistd.h>
+#include <sys/sysctl.h>
 #include <sys/ucontext.h>
+#include <sys/user.h>
 #include <machine/sigframe.h>
 
 #define REG_NAME(reg)	sf_uc.uc_mcontext.mc_## reg
@@ -36,6 +39,38 @@
 #ifdef __x86_64__
 #define MD_FALLBACK_FRAME_STATE_FOR x86_64_freebsd_fallback_frame_state
 
+#ifdef KERN_PROC_SIGTRAMP
+/* FreeBSD past 9.3 provides a kern.proc.sigtramp.<pid> sysctl that
+   returns the location of the signal trampoline. Use this to find
+   out whether we're in a trampoline.
+*/
+static int
+x86_64_outside_sigtramp_range (unsigned char *pc)
+{
+  static int sigtramp_range_determined = 0;
+  static unsigned char *sigtramp_start, *sigtramp_end;
+
+  if (sigtramp_range_determined == 0)
+    {
+      struct kinfo_sigtramp kst = {0};
+      size_t len = sizeof (kst);
+      int mib[4] = { CTL_KERN, KERN_PROC, KERN_PROC_SIGTRAMP, getpid() };
+
+      sigtramp_range_determined = 1;
+      if (sysctl (mib, 4, &kst, &len, NULL, 0) == 0)
+      {
+        sigtramp_range_determined = 2;
+        sigtramp_start = kst.ksigtramp_start;
+        sigtramp_end   = kst.ksigtramp_end;
+      }
+    }
+  if (sigtramp_range_determined < 2)  /* sysctl failed if < 2 */
+    return 1;
+
+  return (pc < sigtramp_start || pc >= sigtramp_end);
+}
+#endif
+
 static _Unwind_Reason_Code
 x86_64_freebsd_fallback_frame_state
 (struct _Unwind_Context *context, _Unwind_FrameState *fs)
@@ -43,6 +78,7 @@
   struct sigframe *sf;
   long new_cfa;
 
+#ifndef KERN_PROC_SIGTRAMP
   /* Prior to FreeBSD 9, the signal trampoline was located immediately
      before the ps_strings.  To support non-executable stacks on AMD64,
      the sigtramp was moved to a shared page for FreeBSD 9.  Unfortunately
@@ -62,12 +98,15 @@
         && *(unsigned int *)(context->ra +  8) == 0x01a1c0c7
         && *(unsigned int *)(context->ra + 12) == 0x050f0000 ))
     return _URC_END_OF_STACK;
+#else
+  if (x86_64_outside_sigtramp_range(context->ra))
+    return _URC_END_OF_STACK;
+#endif
 
   sf = (struct sigframe *) context->cfa;
   new_cfa = sf->REG_NAME(rsp);
   fs->regs.cfa_how = CFA_REG_OFFSET;
-  /* Register 7 is rsp  */
-  fs->regs.cfa_reg = 7;
+  fs->regs.cfa_reg =  __LIBGCC_STACK_POINTER_REGNUM__;
   fs->regs.cfa_offset = new_cfa - (long) context->cfa;
 
   /* The SVR4 register numbering macros aren't usable in libgcc.  */
Index: libgcc/libgcc2.c
===================================================================
--- libgcc/libgcc2.c	(.../tags/gcc_7_2_0_release)
+++ libgcc/libgcc2.c	(.../branches/gcc-7-branch)
@@ -375,7 +375,8 @@
 		}
 	      else
 		{
-		  if (uu.s.high == (Wtype) -1 && vv.s.high == (Wtype) - 1)
+		  if ((uu.s.high & vv.s.high) == (Wtype) -1
+		      && (uu.s.low | vv.s.low) != 0)
 		    {
 		      DWunion ww = {.ll = (UDWtype) (UWtype) uu.s.low
 				    * (UDWtype) (UWtype) vv.s.low};
Index: gcc/is-a.h
===================================================================
--- gcc/is-a.h	(.../tags/gcc_7_2_0_release)
+++ gcc/is-a.h	(.../branches/gcc-7-branch)
@@ -103,7 +103,12 @@
     Note that we have converted two sets of assertions in the calls to varpool
     into safe and efficient use of a variable.
 
+TYPE safe_dyn_cast <TYPE> (pointer)
 
+    Like dyn_cast <TYPE> (pointer), except that it accepts null pointers
+    and returns null results for them.
+
+
 If you use these functions and get a 'inline function not defined' or a
 'missing symbol' error message for 'is_a_helper<....>::test', it means that
 the connection between the types has not been made.  See below.
@@ -222,4 +227,13 @@
     return static_cast <T> (0);
 }
 
+/* Similar to dyn_cast, except that the pointer may be null.  */
+
+template <typename T, typename U>
+inline T
+safe_dyn_cast (U *p)
+{
+  return p ? dyn_cast <T> (p) : 0;
+}
+
 #endif  /* GCC_IS_A_H  */
Index: gcc/tree-vrp.c
===================================================================
--- gcc/tree-vrp.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-vrp.c	(.../branches/gcc-7-branch)
@@ -4897,7 +4897,12 @@
      operand of the ASSERT_EXPR.  Create it so the new name and the old one
      are registered in the replacement table so that we can fix the SSA web
      after adding all the ASSERT_EXPRs.  */
-  create_new_def_for (v, assertion, NULL);
+  tree new_def = create_new_def_for (v, assertion, NULL);
+  /* Make sure we preserve abnormalness throughout an ASSERT_EXPR chain
+     given we have to be able to fully propagate those out to re-create
+     valid SSA when removing the asserts.  */
+  if (SSA_NAME_OCCURS_IN_ABNORMAL_PHI (v))
+    SSA_NAME_OCCURS_IN_ABNORMAL_PHI (new_def) = 1;
 
   return assertion;
 }
Index: gcc/doc/sourcebuild.texi
===================================================================
--- gcc/doc/sourcebuild.texi	(.../tags/gcc_7_2_0_release)
+++ gcc/doc/sourcebuild.texi	(.../branches/gcc-7-branch)
@@ -1570,6 +1570,12 @@
 ARM Target supports @code{-mfpu=neon -mfloat-abi=softfp} or compatible
 options.  Some multilibs may be incompatible with these options.
 
+@item arm_neon_ok_no_float_abi
+@anchor{arm_neon_ok_no_float_abi}
+ARM Target supports NEON with @code{-mfpu=neon}, but without any
+-mfloat-abi= option.  Some multilibs may be incompatible with this
+option.
+
 @item arm_neonv2_ok
 @anchor{arm_neonv2_ok}
 ARM Target supports @code{-mfpu=neon-vfpv4 -mfloat-abi=softfp} or compatible
Index: gcc/doc/extend.texi
===================================================================
--- gcc/doc/extend.texi	(.../tags/gcc_7_2_0_release)
+++ gcc/doc/extend.texi	(.../branches/gcc-7-branch)
@@ -9473,6 +9473,7 @@
 @code{s && v} is equivalent to @code{s?v!=0:0} (the evaluation is
 short-circuit) and @code{v && s} is equivalent to @code{v!=0 & (s?-1:0)}.
 
+@findex __builtin_shuffle
 Vector shuffling is available using functions
 @code{__builtin_shuffle (vec, mask)} and
 @code{__builtin_shuffle (vec0, vec1, mask)}.
@@ -19476,8 +19477,11 @@
 @item btver2
 AMD Family 16h CPU.
 
+@item amdfam17h
+AMD Family 17h CPU.
+
 @item znver1
-AMD Family 17h CPU.
+AMD Family 17h Zen version 1.
 @end table
 
 Here is an example:
@@ -20635,7 +20639,7 @@
 The following built-in functions are available when @option{-mlzcnt} is used.
 All of them generate the machine instruction that is part of the name.
 @smallexample
-unsigned short __builtin_ia32_lzcnt_16(unsigned short);
+unsigned short __builtin_ia32_lzcnt_u16(unsigned short);
 unsigned int __builtin_ia32_lzcnt_u32(unsigned int);
 unsigned long long __builtin_ia32_lzcnt_u64 (unsigned long long);
 @end smallexample
Index: gcc/ipa-visibility.c
===================================================================
--- gcc/ipa-visibility.c	(.../tags/gcc_7_2_0_release)
+++ gcc/ipa-visibility.c	(.../branches/gcc-7-branch)
@@ -97,7 +97,8 @@
 	   && !DECL_EXTERNAL (node->decl)
 	   && !node->externally_visible
 	   && !node->used_from_other_partition
-	   && !node->in_other_partition);
+	   && !node->in_other_partition
+	   && node->get_availability () >= AVAIL_AVAILABLE);
 }
 
 /* Return true when function can be marked local.  */
Index: gcc/tree-chkp.c
===================================================================
--- gcc/tree-chkp.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-chkp.c	(.../branches/gcc-7-branch)
@@ -3277,7 +3277,7 @@
   return DECL_SIZE (field) && TREE_CODE (DECL_SIZE (field)) == INTEGER_CST
     && tree_to_uhwi (DECL_SIZE (field)) != 0
     && !(flag_chkp_flexible_struct_trailing_arrays
-	 && array_at_struct_end_p (ref, true))
+	 && array_at_struct_end_p (ref))
     && (!DECL_FIELD_OFFSET (field)
 	|| TREE_CODE (DECL_FIELD_OFFSET (field)) == INTEGER_CST)
     && (!DECL_FIELD_BIT_OFFSET (field)
Index: gcc/ipa-icf-gimple.c
===================================================================
--- gcc/ipa-icf-gimple.c	(.../tags/gcc_7_2_0_release)
+++ gcc/ipa-icf-gimple.c	(.../branches/gcc-7-branch)
@@ -361,10 +361,14 @@
       }
     case LABEL_DECL:
       {
+	if (t1 == t2)
+	  return true;
+
 	int *bb1 = m_label_bb_map.get (t1);
 	int *bb2 = m_label_bb_map.get (t2);
 
-	return return_with_debug (*bb1 == *bb2);
+	/* Labels can point to another function (non-local GOTOs).  */
+	return return_with_debug (bb1 != NULL && bb2 != NULL && *bb1 == *bb2);
       }
     case PARM_DECL:
     case RESULT_DECL:
@@ -539,11 +543,8 @@
     }
 }
 
-/* Compares two tree list operands T1 and T2 and returns true if these
-   two trees are semantically equivalent.  */
-
 bool
-func_checker::compare_tree_list_operand (tree t1, tree t2)
+func_checker::compare_asm_inputs_outputs (tree t1, tree t2)
 {
   gcc_assert (TREE_CODE (t1) == TREE_LIST);
   gcc_assert (TREE_CODE (t2) == TREE_LIST);
@@ -556,6 +557,16 @@
       if (!compare_operand (TREE_VALUE (t1), TREE_VALUE (t2)))
 	return return_false ();
 
+      tree p1 = TREE_PURPOSE (t1);
+      tree p2 = TREE_PURPOSE (t2);
+
+      gcc_assert (TREE_CODE (p1) == TREE_LIST);
+      gcc_assert (TREE_CODE (p2) == TREE_LIST);
+
+      if (strcmp (TREE_STRING_POINTER (TREE_VALUE (p1)),
+		  TREE_STRING_POINTER (TREE_VALUE (p2))) != 0)
+	return return_false ();
+
       t2 = TREE_CHAIN (t2);
     }
 
@@ -1004,7 +1015,7 @@
       tree input1 = gimple_asm_input_op (g1, i);
       tree input2 = gimple_asm_input_op (g2, i);
 
-      if (!compare_tree_list_operand (input1, input2))
+      if (!compare_asm_inputs_outputs (input1, input2))
 	return return_false_with_msg ("ASM input is different");
     }
 
@@ -1013,7 +1024,7 @@
       tree output1 = gimple_asm_output_op (g1, i);
       tree output2 = gimple_asm_output_op (g2, i);
 
-      if (!compare_tree_list_operand (output1, output2))
+      if (!compare_asm_inputs_outputs (output1, output2))
 	return return_false_with_msg ("ASM output is different");
     }
 
Index: gcc/ipa-icf-gimple.h
===================================================================
--- gcc/ipa-icf-gimple.h	(.../tags/gcc_7_2_0_release)
+++ gcc/ipa-icf-gimple.h	(.../branches/gcc-7-branch)
@@ -215,9 +215,9 @@
      is returned.  */
   bool compare_operand (tree t1, tree t2);
 
-  /* Compares two tree list operands T1 and T2 and returns true if these
-     two trees are semantically equivalent.  */
-  bool compare_tree_list_operand (tree t1, tree t2);
+  /* Compares GIMPLE ASM inputs (or outputs) where we iterate tree chain
+     and compare both TREE_PURPOSEs and TREE_VALUEs.  */
+  bool compare_asm_inputs_outputs (tree t1, tree t2);
 
   /* Verifies that trees T1 and T2, representing function declarations
      are equivalent from perspective of ICF.  */
Index: gcc/opts-common.c
===================================================================
--- gcc/opts-common.c	(.../tags/gcc_7_2_0_release)
+++ gcc/opts-common.c	(.../branches/gcc-7-branch)
@@ -988,7 +988,8 @@
       {
 	if (!handlers->handlers[i].handler (opts, opts_set, decoded,
 					    lang_mask, kind, loc,
-					    handlers, dc))
+					    handlers, dc,
+					    handlers->target_option_override_hook))
 	  return false;
       }
   
Index: gcc/c-family/c-cppbuiltin.c
===================================================================
--- gcc/c-family/c-cppbuiltin.c	(.../tags/gcc_7_2_0_release)
+++ gcc/c-family/c-cppbuiltin.c	(.../branches/gcc-7-branch)
@@ -987,6 +987,8 @@
 	}
       if (flag_new_ttp)
 	cpp_define (pfile, "__cpp_template_template_args=201611");
+      if (flag_threadsafe_statics)
+	cpp_define (pfile, "__cpp_threadsafe_static_init=200806");
     }
   /* Note that we define this for C as well, so that we know if
      __attribute__((cleanup)) will interface with EH.  */
Index: gcc/c-family/ChangeLog
===================================================================
--- gcc/c-family/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ gcc/c-family/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,49 @@
+2017-09-15  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/82112
+	* c-common.c (sync_resolve_size): Instead of c_dialect_cxx ()
+	assertion check that in the condition.
+	(get_atomic_generic_size): Likewise.  Before testing if parameter
+	has pointer type, if it has array type, call for C++
+	default_conversion to perform array-to-pointer conversion.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-08-29  Martin Liska  <mliska@suse.cz>
+
+	PR other/39851
+	* c-common.c (parse_optimize_options): Add argument to function
+	call.
+	* c-pragma.c (handle_pragma_diagnostic): Likewise.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-06-28  Martin Liska  <mliska@suse.cz>
+
+	PR ipa/81128
+	* c-attribs.c (handle_alias_ifunc_attribute): Append ifunc alias
+	to a function declaration.
+
+2017-09-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR c++/81852
+	* c-cppbuiltin.c (c_cpp_builtins): Define __cpp_threadsafe_static_init.
+
+2017-09-07  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-07-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/45784
+	* c-omp.c (c_finish_omp_for): If the condition is wrapped in
+	rhs of COMPOUND_EXPR(s), skip them and readd their lhs into
+	new COMPOUND_EXPRs around the rhs of the comparison.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: gcc/c-family/c-common.c
===================================================================
--- gcc/c-family/c-common.c	(.../tags/gcc_7_2_0_release)
+++ gcc/c-family/c-common.c	(.../branches/gcc-7-branch)
@@ -5597,7 +5597,7 @@
   /* And apply them.  */
   decode_options (&global_options, &global_options_set,
 		  decoded_options, decoded_options_count,
-		  input_location, global_dc);
+		  input_location, global_dc, NULL);
 
   targetm.override_options_after_change();
 
@@ -6576,10 +6576,9 @@
     }
 
   argtype = type = TREE_TYPE ((*params)[0]);
-  if (TREE_CODE (type) == ARRAY_TYPE)
+  if (TREE_CODE (type) == ARRAY_TYPE && c_dialect_cxx ())
     {
       /* Force array-to-pointer decay for C++.  */
-      gcc_assert (c_dialect_cxx());
       (*params)[0] = default_conversion ((*params)[0]);
       type = TREE_TYPE ((*params)[0]);
     }
@@ -6741,10 +6740,9 @@
 
   /* Get type of first parameter, and determine its size.  */
   type_0 = TREE_TYPE ((*params)[0]);
-  if (TREE_CODE (type_0) == ARRAY_TYPE)
+  if (TREE_CODE (type_0) == ARRAY_TYPE && c_dialect_cxx ())
     {
       /* Force array-to-pointer decay for C++.  */
-      gcc_assert (c_dialect_cxx());
       (*params)[0] = default_conversion ((*params)[0]);
       type_0 = TREE_TYPE ((*params)[0]);
     }
@@ -6783,6 +6781,12 @@
       /* __atomic_compare_exchange has a bool in the 4th position, skip it.  */
       if (n_param == 6 && x == 3)
         continue;
+      if (TREE_CODE (type) == ARRAY_TYPE && c_dialect_cxx ())
+	{
+	  /* Force array-to-pointer decay for C++.  */
+	  (*params)[x] = default_conversion ((*params)[x]);
+	  type = TREE_TYPE ((*params)[x]);
+	}
       if (!POINTER_TYPE_P (type))
 	{
 	  error_at (loc, "argument %d of %qE must be a pointer type", x + 1,
Index: gcc/c-family/c-omp.c
===================================================================
--- gcc/c-family/c-omp.c	(.../tags/gcc_7_2_0_release)
+++ gcc/c-family/c-omp.c	(.../branches/gcc-7-branch)
@@ -531,6 +531,12 @@
 	{
 	  bool cond_ok = false;
 
+	  /* E.g. C sizeof (vla) could add COMPOUND_EXPRs with
+	     evaluation of the vla VAR_DECL.  We need to readd
+	     them to the non-decl operand.  See PR45784.  */
+	  while (TREE_CODE (cond) == COMPOUND_EXPR)
+	    cond = TREE_OPERAND (cond, 1);
+
 	  if (EXPR_HAS_LOCATION (cond))
 	    elocus = EXPR_LOCATION (cond);
 
@@ -605,6 +611,21 @@
 		  else if (code != CILK_SIMD && code != CILK_FOR)
 		    cond_ok = false;
 		}
+
+	      if (cond_ok && TREE_VEC_ELT (condv, i) != cond)
+		{
+		  tree ce = NULL_TREE, *pce = &ce;
+		  tree type = TREE_TYPE (TREE_OPERAND (cond, 1));
+		  for (tree c = TREE_VEC_ELT (condv, i); c != cond;
+		       c = TREE_OPERAND (c, 1))
+		    {
+		      *pce = build2 (COMPOUND_EXPR, type, TREE_OPERAND (c, 0),
+				     TREE_OPERAND (cond, 1));
+		      pce = &TREE_OPERAND (*pce, 1);
+		    }
+		  TREE_OPERAND (cond, 1) = ce;
+		  TREE_VEC_ELT (condv, i) = cond;
+		}
 	    }
 
 	  if (!cond_ok)
Index: gcc/c-family/c-pragma.c
===================================================================
--- gcc/c-family/c-pragma.c	(.../tags/gcc_7_2_0_release)
+++ gcc/c-family/c-pragma.c	(.../branches/gcc-7-branch)
@@ -815,7 +815,7 @@
     }
 
   struct cl_option_handlers handlers;
-  set_default_handlers (&handlers);
+  set_default_handlers (&handlers, NULL);
   const char *arg = NULL;
   if (cl_options[option_index].flags & CL_JOINED)
     arg = option_string + 1 + cl_options[option_index].opt_len;
Index: gcc/c-family/c-attribs.c
===================================================================
--- gcc/c-family/c-attribs.c	(.../tags/gcc_7_2_0_release)
+++ gcc/c-family/c-attribs.c	(.../branches/gcc-7-branch)
@@ -1764,9 +1764,14 @@
 	TREE_STATIC (decl) = 1;
 
       if (!is_alias)
-	/* ifuncs are also aliases, so set that attribute too.  */
-	DECL_ATTRIBUTES (decl)
-	  = tree_cons (get_identifier ("alias"), args, DECL_ATTRIBUTES (decl));
+	{
+	  /* ifuncs are also aliases, so set that attribute too.  */
+	  DECL_ATTRIBUTES (decl)
+	    = tree_cons (get_identifier ("alias"), args,
+			 DECL_ATTRIBUTES (decl));
+	  DECL_ATTRIBUTES (decl) = tree_cons (get_identifier ("ifunc"),
+					      NULL, DECL_ATTRIBUTES (decl));
+	}
     }
   else
     {
Index: gcc/c/ChangeLog
===================================================================
--- gcc/c/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ gcc/c/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,12 @@
+2017-09-30  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-09-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/82340
+	* c-decl.c (build_compound_literal): Use c_apply_type_quals_to_decl
+	instead of trying to set just TREE_READONLY manually.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: gcc/c/c-decl.c
===================================================================
--- gcc/c/c-decl.c	(.../tags/gcc_7_2_0_release)
+++ gcc/c/c-decl.c	(.../branches/gcc-7-branch)
@@ -5264,9 +5264,7 @@
   DECL_ARTIFICIAL (decl) = 1;
   DECL_IGNORED_P (decl) = 1;
   TREE_TYPE (decl) = type;
-  TREE_READONLY (decl) = (TYPE_READONLY (type)
-			  || (TREE_CODE (type) == ARRAY_TYPE
-			      && TYPE_READONLY (TREE_TYPE (type))));
+  c_apply_type_quals_to_decl (TYPE_QUALS (strip_array_types (type)), decl);
   store_init_value (loc, decl, init, NULL_TREE);
 
   if (TREE_CODE (type) == ARRAY_TYPE && !COMPLETE_TYPE_P (type))
Index: gcc/DATESTAMP
===================================================================
--- gcc/DATESTAMP	(.../tags/gcc_7_2_0_release)
+++ gcc/DATESTAMP	(.../branches/gcc-7-branch)
@@ -1 +1 @@
-20170814
+20171112
Index: gcc/tree.c
===================================================================
--- gcc/tree.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree.c	(.../branches/gcc-7-branch)
@@ -4810,8 +4810,9 @@
    Record such modified types already made so we don't make duplicates.  */
 
 tree
-build_type_attribute_qual_variant (tree ttype, tree attribute, int quals)
+build_type_attribute_qual_variant (tree otype, tree attribute, int quals)
 {
+  tree ttype = otype;
   if (! attribute_list_equal (TYPE_ATTRIBUTES (ttype), attribute))
     {
       inchash::hash hstate;
@@ -4838,6 +4839,11 @@
 	}
 
       ttype = build_qualified_type (ttype, TYPE_UNQUALIFIED);
+      if (lang_hooks.types.copy_lang_qualifiers
+	  && otype != TYPE_MAIN_VARIANT (otype))
+	ttype = (lang_hooks.types.copy_lang_qualifiers
+		 (ttype, TYPE_MAIN_VARIANT (otype)));
+
       ntype = build_distinct_type_copy (ttype);
 
       TYPE_ATTRIBUTES (ntype) = attribute;
@@ -4884,6 +4890,9 @@
 	TYPE_CANONICAL (ntype) = TYPE_CANONICAL (ttype);
 
       ttype = build_qualified_type (ntype, quals);
+      if (lang_hooks.types.copy_lang_qualifiers
+	  && otype != TYPE_MAIN_VARIANT (otype))
+	ttype = lang_hooks.types.copy_lang_qualifiers (ttype, otype);
     }
   else if (TYPE_QUALS (ttype) != quals)
     ttype = build_qualified_type (ttype, quals);
@@ -13219,18 +13228,26 @@
   return NULL_TREE;
 }
 
-/* Returns true if REF is an array reference to an array at the end of
-   a structure.  If this is the case, the array may be allocated larger
-   than its upper bound implies.  When ALLOW_COMPREF is true considers
-   REF when it's a COMPONENT_REF in addition ARRAY_REF and
-   ARRAY_RANGE_REF.  */
+/* Returns true if REF is an array reference or a component reference
+   to an array at the end of a structure.
+   If this is the case, the array may be allocated larger
+   than its upper bound implies.  */
 
 bool
-array_at_struct_end_p (tree ref, bool allow_compref)
+array_at_struct_end_p (tree ref)
 {
-  if (TREE_CODE (ref) != ARRAY_REF
-      && TREE_CODE (ref) != ARRAY_RANGE_REF
-      && (!allow_compref || TREE_CODE (ref) != COMPONENT_REF))
+  tree atype;
+
+  if (TREE_CODE (ref) == ARRAY_REF
+      || TREE_CODE (ref) == ARRAY_RANGE_REF)
+    {
+      atype = TREE_TYPE (TREE_OPERAND (ref, 0));
+      ref = TREE_OPERAND (ref, 0);
+    }
+  else if (TREE_CODE (ref) == COMPONENT_REF
+	   && TREE_CODE (TREE_TYPE (TREE_OPERAND (ref, 1))) == ARRAY_TYPE)
+    atype = TREE_TYPE (TREE_OPERAND (ref, 1));
+  else
     return false;
 
   while (handled_component_p (ref))
@@ -13238,19 +13255,42 @@
       /* If the reference chain contains a component reference to a
          non-union type and there follows another field the reference
 	 is not at the end of a structure.  */
-      if (TREE_CODE (ref) == COMPONENT_REF
-	  && TREE_CODE (TREE_TYPE (TREE_OPERAND (ref, 0))) == RECORD_TYPE)
+      if (TREE_CODE (ref) == COMPONENT_REF)
 	{
-	  tree nextf = DECL_CHAIN (TREE_OPERAND (ref, 1));
-	  while (nextf && TREE_CODE (nextf) != FIELD_DECL)
-	    nextf = DECL_CHAIN (nextf);
-	  if (nextf)
-	    return false;
+	  if (TREE_CODE (TREE_TYPE (TREE_OPERAND (ref, 0))) == RECORD_TYPE)
+	    {
+	      tree nextf = DECL_CHAIN (TREE_OPERAND (ref, 1));
+	      while (nextf && TREE_CODE (nextf) != FIELD_DECL)
+		nextf = DECL_CHAIN (nextf);
+	      if (nextf)
+		return false;
+	    }
 	}
+      /* If we have a multi-dimensional array we do not consider
+         a non-innermost dimension as flex array if the whole
+	 multi-dimensional array is at struct end.
+	 Same for an array of aggregates with a trailing array
+	 member.  */
+      else if (TREE_CODE (ref) == ARRAY_REF)
+	return false;
+      else if (TREE_CODE (ref) == ARRAY_RANGE_REF)
+	;
+      /* If we view an underlying object as sth else then what we
+         gathered up to now is what we have to rely on.  */
+      else if (TREE_CODE (ref) == VIEW_CONVERT_EXPR)
+	break;
+      else
+	gcc_unreachable ();
 
       ref = TREE_OPERAND (ref, 0);
     }
 
+  /* The array now is at struct end.  Treat flexible arrays as
+     always subject to extend, even into just padding constrained by
+     an underlying decl.  */
+  if (! TYPE_SIZE (atype))
+    return true;
+
   tree size = NULL;
 
   if (TREE_CODE (ref) == MEM_REF
Index: gcc/tree.h
===================================================================
--- gcc/tree.h	(.../tags/gcc_7_2_0_release)
+++ gcc/tree.h	(.../branches/gcc-7-branch)
@@ -4870,12 +4870,10 @@
    EXP, an ARRAY_REF or an ARRAY_RANGE_REF.  */
 extern tree array_ref_low_bound (tree);
 
-/* Returns true if REF is an array reference to an array at the end of
-   a structure.  If this is the case, the array may be allocated larger
-   than its upper bound implies.  When second argument is true considers
-   REF when it's a COMPONENT_REF in addition ARRAY_REF and
-   ARRAY_RANGE_REF.  */
-extern bool array_at_struct_end_p (tree, bool = false);
+/* Returns true if REF is an array reference or a component reference
+   to an array at the end of a structure.  If this is the case, the array
+   may be allocated larger than its upper bound implies.  */
+extern bool array_at_struct_end_p (tree);
 
 /* Return a tree representing the offset, in bytes, of the field referenced
    by EXP.  This does not include any offset in DECL_FIELD_BIT_OFFSET.  */
Index: gcc/internal-fn.c
===================================================================
--- gcc/internal-fn.c	(.../tags/gcc_7_2_0_release)
+++ gcc/internal-fn.c	(.../branches/gcc-7-branch)
@@ -1754,8 +1754,8 @@
 		}
 
 	      /* At this point hipart{0,1} are both in [-1, 0].  If they are
-		 the same, overflow happened if res is negative, if they are
-		 different, overflow happened if res is positive.  */
+		 the same, overflow happened if res is non-positive, if they
+		 are different, overflow happened if res is positive.  */
 	      if (op0_sign != 1 && op1_sign != 1 && op0_sign != op1_sign)
 		emit_jump (hipart_different);
 	      else if (op0_sign == 1 || op1_sign == 1)
@@ -1763,7 +1763,7 @@
 					 NULL_RTX, NULL, hipart_different,
 					 PROB_EVEN);
 
-	      do_compare_rtx_and_jump (res, const0_rtx, LT, false, mode,
+	      do_compare_rtx_and_jump (res, const0_rtx, LE, false, mode,
 				       NULL_RTX, NULL, do_error,
 				       PROB_VERY_UNLIKELY);
 	      emit_jump (done_label);
Index: gcc/builtins.c
===================================================================
--- gcc/builtins.c	(.../tags/gcc_7_2_0_release)
+++ gcc/builtins.c	(.../branches/gcc-7-branch)
@@ -1194,6 +1194,7 @@
 expand_builtin_update_setjmp_buf (rtx buf_addr)
 {
   machine_mode sa_mode = STACK_SAVEAREA_MODE (SAVE_NONLOCAL);
+  buf_addr = convert_memory_address (Pmode, buf_addr);
   rtx stack_save
     = gen_rtx_MEM (sa_mode,
 		   memory_address
Index: gcc/gcc.c
===================================================================
--- gcc/gcc.c	(.../tags/gcc_7_2_0_release)
+++ gcc/gcc.c	(.../branches/gcc-7-branch)
@@ -872,8 +872,7 @@
 #endif
 
 #ifdef ENABLE_DEFAULT_PIE
-#define NO_PIE_SPEC		"no-pie|static"
-#define PIE_SPEC		NO_PIE_SPEC "|r|shared:;"
+#define PIE_SPEC		"!no-pie"
 #define NO_FPIE1_SPEC		"fno-pie"
 #define FPIE1_SPEC		NO_FPIE1_SPEC ":;"
 #define NO_FPIE2_SPEC		"fno-PIE"
@@ -894,7 +893,6 @@
 #define FPIE_OR_FPIC_SPEC	NO_FPIE_AND_FPIC_SPEC ":;"
 #else
 #define PIE_SPEC		"pie"
-#define NO_PIE_SPEC		PIE_SPEC "|r|shared:;"
 #define FPIE1_SPEC		"fpie"
 #define NO_FPIE1_SPEC		FPIE1_SPEC ":;"
 #define FPIE2_SPEC		"fPIE"
@@ -923,7 +921,7 @@
 #else
 #define LD_PIE_SPEC ""
 #endif
-#define LINK_PIE_SPEC "%{no-pie:} " "%{" PIE_SPEC ":" LD_PIE_SPEC "} "
+#define LINK_PIE_SPEC "%{static|shared|r:;" PIE_SPEC ":" LD_PIE_SPEC "} "
 #endif
 
 #ifndef LINK_BUILDID_SPEC
@@ -1011,8 +1009,10 @@
 #endif
 
 /* -u* was put back because both BSD and SysV seem to support it.  */
-/* %{static:} simply prevents an error message if the target machine
-   doesn't handle -static.  */
+/* %{static|no-pie:} simply prevents an error message:
+   1. If the target machine doesn't handle -static.
+   2. If PIE isn't enabled by default.
+ */
 /* We want %{T*} after %{L*} and %D so that it can be used to specify linker
    scripts which exist in user specified directories, or in standard
    directories.  */
@@ -1029,7 +1029,7 @@
    "%{fuse-ld=*:-fuse-ld=%*} " LINK_COMPRESS_DEBUG_SPEC \
    "%X %{o*} %{e*} %{N} %{n} %{r}\
     %{s} %{t} %{u*} %{z} %{Z} %{!nostdlib:%{!nostartfiles:%S}} \
-    %{static:} %{L*} %(mfwrap) %(link_libgcc) " \
+    %{static|no-pie:} %{L*} %(mfwrap) %(link_libgcc) " \
     VTABLE_VERIFICATION_SPEC " " SANITIZER_EARLY_SPEC " %o " CHKP_SPEC " \
     %{fopenacc|fopenmp|%:gt(%{ftree-parallelize-loops=*:%*} 1):\
 	%:include(libgomp.spec)%(link_gomp)}\
@@ -3742,7 +3742,8 @@
 		      unsigned int lang_mask ATTRIBUTE_UNUSED, int kind,
 		      location_t loc,
 		      const struct cl_option_handlers *handlers ATTRIBUTE_UNUSED,
-		      diagnostic_context *dc)
+		      diagnostic_context *dc,
+		      void (*) (void))
 {
   size_t opt_index = decoded->opt_index;
   const char *arg = decoded->arg;
Index: gcc/fold-const.c
===================================================================
--- gcc/fold-const.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fold-const.c	(.../branches/gcc-7-branch)
@@ -877,6 +877,13 @@
 	}
     }
 
+  if (*litp
+      && TREE_OVERFLOW_P (*litp))
+    *litp = drop_tree_overflow (*litp);
+  if (*minus_litp
+      && TREE_OVERFLOW_P (*minus_litp))
+    *minus_litp = drop_tree_overflow (*minus_litp);
+
   return var;
 }
 
@@ -4033,22 +4040,21 @@
 		      size_int (nbitsize - lbitsize - lbitpos));
 
   if (! const_p)
-    /* If not comparing with constant, just rework the comparison
-       and return.  */
-    return fold_build2_loc (loc, code, compare_type,
-			fold_build2_loc (loc, BIT_AND_EXPR, unsigned_type,
-				     make_bit_field_ref (loc, linner, lhs,
-							 unsigned_type,
-							 nbitsize, nbitpos,
-							 1, lreversep),
-				     mask),
-			fold_build2_loc (loc, BIT_AND_EXPR, unsigned_type,
-				     make_bit_field_ref (loc, rinner, rhs,
-							 unsigned_type,
-							 nbitsize, nbitpos,
-							 1, rreversep),
-				     mask));
+    {
+      if (nbitpos < 0)
+	return 0;
 
+      /* If not comparing with constant, just rework the comparison
+	 and return.  */
+      tree t1 = make_bit_field_ref (loc, linner, lhs, unsigned_type,
+				    nbitsize, nbitpos, 1, lreversep);
+      t1 = fold_build2_loc (loc, BIT_AND_EXPR, unsigned_type, t1, mask);
+      tree t2 = make_bit_field_ref (loc, rinner, rhs, unsigned_type,
+				    nbitsize, nbitpos, 1, rreversep);
+      t2 = fold_build2_loc (loc, BIT_AND_EXPR, unsigned_type, t2, mask);
+      return fold_build2_loc (loc, code, compare_type, t1, t2);
+    }
+
   /* Otherwise, we are handling the constant case.  See if the constant is too
      big for the field.  Warn and return a tree for 0 (false) if so.  We do
      this not only for its own sake, but to avoid having to test for this
@@ -4078,6 +4084,9 @@
 	}
     }
 
+  if (nbitpos < 0)
+    return 0;
+
   /* Single-bit compares should always be against zero.  */
   if (lbitsize == 1 && ! integer_zerop (rhs))
     {
@@ -5851,7 +5860,10 @@
 	 results.  */
       ll_mask = const_binop (BIT_IOR_EXPR, ll_mask, rl_mask);
       lr_mask = const_binop (BIT_IOR_EXPR, lr_mask, rr_mask);
-      if (lnbitsize == rnbitsize && xll_bitpos == xlr_bitpos)
+      if (lnbitsize == rnbitsize
+	  && xll_bitpos == xlr_bitpos
+	  && lnbitpos >= 0
+	  && rnbitpos >= 0)
 	{
 	  lhs = make_bit_field_ref (loc, ll_inner, ll_arg,
 				    lntype, lnbitsize, lnbitpos,
@@ -5875,10 +5887,14 @@
 	 Note that we still must mask the lhs/rhs expressions.  Furthermore,
 	 the mask must be shifted to account for the shift done by
 	 make_bit_field_ref.  */
-      if ((ll_bitsize + ll_bitpos == rl_bitpos
-	   && lr_bitsize + lr_bitpos == rr_bitpos)
-	  || (ll_bitpos == rl_bitpos + rl_bitsize
-	      && lr_bitpos == rr_bitpos + rr_bitsize))
+      if (((ll_bitsize + ll_bitpos == rl_bitpos
+	    && lr_bitsize + lr_bitpos == rr_bitpos)
+	   || (ll_bitpos == rl_bitpos + rl_bitsize
+	       && lr_bitpos == rr_bitpos + rr_bitsize))
+	  && ll_bitpos >= 0
+	  && rl_bitpos >= 0
+	  && lr_bitpos >= 0
+	  && rr_bitpos >= 0)
 	{
 	  tree type;
 
@@ -5947,6 +5963,9 @@
 	}
     }
 
+  if (lnbitpos < 0)
+    return 0;
+
   /* Construct the expression we will return.  First get the component
      reference we will make.  Unless the mask is all ones the width of
      that field, perform the mask operation.  Then compare with the
@@ -6175,6 +6194,7 @@
       t1 = extract_muldiv (op0, c, code, wide_type, &sub_strict_overflow_p);
       t2 = extract_muldiv (op1, c, code, wide_type, &sub_strict_overflow_p);
       if (t1 != 0 && t2 != 0
+	  && TYPE_OVERFLOW_WRAPS (ctype)
 	  && (code == MULT_EXPR
 	      /* If not multiplication, we can only do this if both operands
 		 are divisible by c.  */
@@ -6237,11 +6257,6 @@
       if (TYPE_UNSIGNED (ctype) && ctype != type)
 	break;
 
-      /* If we were able to eliminate our operation from the first side,
-	 apply our operation to the second side and reform the PLUS.  */
-      if (t1 != 0 && (TREE_CODE (t1) != code || code == MULT_EXPR))
-	return fold_build2 (tcode, ctype, fold_convert (ctype, t1), op1);
-
       /* The last case is if we are a multiply.  In that case, we can
 	 apply the distributive law to commute the multiply and addition
 	 if the multiplication of the constants doesn't overflow
@@ -7200,15 +7215,10 @@
 static int
 native_encode_string (const_tree expr, unsigned char *ptr, int len, int off)
 {
-  tree type = TREE_TYPE (expr);
-  HOST_WIDE_INT total_bytes;
+  if (! can_native_encode_string_p (expr))
+    return 0;
 
-  if (TREE_CODE (type) != ARRAY_TYPE
-      || TREE_CODE (TREE_TYPE (type)) != INTEGER_TYPE
-      || GET_MODE_BITSIZE (TYPE_MODE (TREE_TYPE (type))) != BITS_PER_UNIT
-      || !tree_fits_shwi_p (TYPE_SIZE_UNIT (type)))
-    return 0;
-  total_bytes = tree_to_shwi (TYPE_SIZE_UNIT (type));
+  HOST_WIDE_INT total_bytes = tree_to_shwi (TYPE_SIZE_UNIT (TREE_TYPE (expr)));
   if ((off == -1 && total_bytes > len)
       || off >= total_bytes)
     return 0;
@@ -7502,6 +7512,22 @@
     }
 }
 
+/* Return true iff a STRING_CST S is accepted by
+   native_encode_expr.  */
+
+bool
+can_native_encode_string_p (const_tree expr)
+{
+  tree type = TREE_TYPE (expr);
+
+  if (TREE_CODE (type) != ARRAY_TYPE
+      || TREE_CODE (TREE_TYPE (type)) != INTEGER_TYPE
+      || (GET_MODE_BITSIZE (TYPE_MODE (TREE_TYPE (type))) != BITS_PER_UNIT)
+      || !tree_fits_shwi_p (TYPE_SIZE_UNIT (type)))
+    return false;
+  return true;
+}
+
 /* Fold a VIEW_CONVERT_EXPR of a constant expression EXPR to type
    TYPE at compile-time.  If we're unable to perform the conversion
    return NULL_TREE.  */
@@ -8879,7 +8905,7 @@
       tree op0 = fold_convert_loc (loc, type, TREE_OPERAND (aref0, 1));
       tree op1 = fold_convert_loc (loc, type, TREE_OPERAND (aref1, 1));
       tree esz = fold_convert_loc (loc, type, array_ref_element_size (aref0));
-      tree diff = build2 (MINUS_EXPR, type, op0, op1);
+      tree diff = fold_build2_loc (loc, MINUS_EXPR, type, op0, op1);
       return fold_build2_loc (loc, PLUS_EXPR, type,
 			      base_offset,
 			      fold_build2_loc (loc, MULT_EXPR, type,
@@ -9638,11 +9664,6 @@
 		       + (lit0 != 0) + (lit1 != 0)
 		       + (minus_lit0 != 0) + (minus_lit1 != 0))))
 	    {
-	      bool any_overflows = false;
-	      if (lit0) any_overflows |= TREE_OVERFLOW (lit0);
-	      if (lit1) any_overflows |= TREE_OVERFLOW (lit1);
-	      if (minus_lit0) any_overflows |= TREE_OVERFLOW (minus_lit0);
-	      if (minus_lit1) any_overflows |= TREE_OVERFLOW (minus_lit1);
 	      var0 = associate_trees (loc, var0, var1, code, atype);
 	      con0 = associate_trees (loc, con0, con1, code, atype);
 	      lit0 = associate_trees (loc, lit0, lit1, code, atype);
@@ -9673,9 +9694,8 @@
 		}
 
 	      /* Don't introduce overflows through reassociation.  */
-	      if (!any_overflows
-		  && ((lit0 && TREE_OVERFLOW_P (lit0))
-		      || (minus_lit0 && TREE_OVERFLOW_P (minus_lit0))))
+	      if ((lit0 && TREE_OVERFLOW_P (lit0))
+		  || (minus_lit0 && TREE_OVERFLOW_P (minus_lit0)))
 		return NULL_TREE;
 
 	      if (minus_lit0)
Index: gcc/fold-const.h
===================================================================
--- gcc/fold-const.h	(.../tags/gcc_7_2_0_release)
+++ gcc/fold-const.h	(.../branches/gcc-7-branch)
@@ -28,6 +28,7 @@
 extern int native_encode_expr (const_tree, unsigned char *, int, int off = -1);
 extern tree native_interpret_expr (tree, const unsigned char *, int);
 extern bool can_native_encode_type_p (tree);
+extern bool can_native_encode_string_p (const_tree);
 
 /* Fold constants as much as possible in an expression.
    Returns the simplified expression.
Index: gcc/omp-low.c
===================================================================
--- gcc/omp-low.c	(.../tags/gcc_7_2_0_release)
+++ gcc/omp-low.c	(.../branches/gcc-7-branch)
@@ -800,6 +800,8 @@
 
   if (TREE_CODE (var) == LABEL_DECL)
     {
+      if (FORCED_LABEL (var) || DECL_NONLOCAL (var))
+	return var;
       new_var = create_artificial_label (DECL_SOURCE_LOCATION (var));
       DECL_CONTEXT (new_var) = current_function_decl;
       insert_decl_map (&ctx->cb, var, new_var);
@@ -6925,10 +6927,14 @@
       rhs_p = gimple_omp_for_initial_ptr (stmt, i);
       if (!is_gimple_min_invariant (*rhs_p))
 	*rhs_p = get_formal_tmp_var (*rhs_p, &body);
+      else if (TREE_CODE (*rhs_p) == ADDR_EXPR)
+	recompute_tree_invariant_for_addr_expr (*rhs_p);
 
       rhs_p = gimple_omp_for_final_ptr (stmt, i);
       if (!is_gimple_min_invariant (*rhs_p))
 	*rhs_p = get_formal_tmp_var (*rhs_p, &body);
+      else if (TREE_CODE (*rhs_p) == ADDR_EXPR)
+	recompute_tree_invariant_for_addr_expr (*rhs_p);
 
       rhs_p = &TREE_OPERAND (gimple_omp_for_incr (stmt, i), 1);
       if (!is_gimple_min_invariant (*rhs_p))
@@ -9089,7 +9095,7 @@
     }
   if (kind == NULL)
     {
-      gcc_checking_assert (flag_openmp);
+      gcc_checking_assert (flag_openmp || flag_openmp_simd);
       kind = "OpenMP";
     }
 
@@ -9349,7 +9355,7 @@
   /* opt_pass methods: */
   virtual bool gate (function *)
   {
-    return flag_cilkplus || flag_openacc || flag_openmp;
+    return flag_cilkplus || flag_openacc || flag_openmp || flag_openmp_simd;
   }
   virtual unsigned int execute (function *)
     {
Index: gcc/toplev.c
===================================================================
--- gcc/toplev.c	(.../tags/gcc_7_2_0_release)
+++ gcc/toplev.c	(.../branches/gcc-7-branch)
@@ -2115,7 +2115,8 @@
      enough to default flags appropriately.  */
   decode_options (&global_options, &global_options_set,
 		  save_decoded_options, save_decoded_options_count,
-		  UNKNOWN_LOCATION, global_dc);
+		  UNKNOWN_LOCATION, global_dc,
+		  targetm.target_option.override);
 
   handle_common_deferred_options ();
 
Index: gcc/tree-ssa-sccvn.c
===================================================================
--- gcc/tree-ssa-sccvn.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-ssa-sccvn.c	(.../branches/gcc-7-branch)
@@ -2304,7 +2304,7 @@
       memset (&op, 0, sizeof (op));
       op.type = vr->type;
       op.opcode = MEM_REF;
-      op.op0 = build_int_cst (ptr_type_node, at - rhs_offset);
+      op.op0 = build_int_cst (ptr_type_node, at - lhs_offset + rhs_offset);
       op.off = at - lhs_offset + rhs_offset;
       vr->operands[0] = op;
       op.type = TREE_TYPE (rhs);
@@ -2990,16 +2990,13 @@
 	      return false;
 
 	    /* Verify the controlling stmt is the same.  */
-	    gimple *last1 = last_stmt (idom1);
-	    gimple *last2 = last_stmt (idom2);
-	    if (gimple_code (last1) != GIMPLE_COND
-		|| gimple_code (last2) != GIMPLE_COND)
+	    gcond *last1 = safe_dyn_cast <gcond *> (last_stmt (idom1));
+	    gcond *last2 = safe_dyn_cast <gcond *> (last_stmt (idom2));
+	    if (! last1 || ! last2)
 	      return false;
 	    bool inverted_p;
-	    if (! cond_stmts_equal_p (as_a <gcond *> (last1),
-				      vp1->cclhs, vp1->ccrhs,
-				      as_a <gcond *> (last2),
-				      vp2->cclhs, vp2->ccrhs,
+	    if (! cond_stmts_equal_p (last1, vp1->cclhs, vp1->ccrhs,
+				      last2, vp2->cclhs, vp2->ccrhs,
 				      &inverted_p))
 	      return false;
 
@@ -3084,7 +3081,7 @@
   vp1.ccrhs = NULL_TREE;
   basic_block idom1 = get_immediate_dominator (CDI_DOMINATORS, vp1.block);
   if (EDGE_COUNT (idom1->succs) == 2)
-    if (gcond *last1 = dyn_cast <gcond *> (last_stmt (idom1)))
+    if (gcond *last1 = safe_dyn_cast <gcond *> (last_stmt (idom1)))
       {
 	vp1.cclhs = vn_valueize (gimple_cond_lhs (last1));
 	vp1.ccrhs = vn_valueize (gimple_cond_rhs (last1));
@@ -3130,7 +3127,7 @@
   vp1->ccrhs = NULL_TREE;
   basic_block idom1 = get_immediate_dominator (CDI_DOMINATORS, vp1->block);
   if (EDGE_COUNT (idom1->succs) == 2)
-    if (gcond *last1 = dyn_cast <gcond *> (last_stmt (idom1)))
+    if (gcond *last1 = safe_dyn_cast <gcond *> (last_stmt (idom1)))
       {
 	vp1->cclhs = vn_valueize (gimple_cond_lhs (last1));
 	vp1->ccrhs = vn_valueize (gimple_cond_rhs (last1));
Index: gcc/ChangeLog
===================================================================
--- gcc/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ gcc/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,779 @@
+2017-11-09  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	Backport from mainline
+	2017-11-01  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR rtl-optimization/64682
+	PR rtl-optimization/69567
+	PR rtl-optimization/69737
+	PR rtl-optimization/82683
+	* combine.c (distribute_notes) <REG_DEAD>: If the new I2 sets the same
+	register mentioned in the note, drop the note, unless it came from I3,
+	in which case it should go to I3 again.
+
+2017-11-07  Eric Botcazou  <ebotcazou@adacore.com>
+
+	Backport from mainline
+	2017-10-31  Matthew Fortune  <matthew.fortune@imgtec.com>
+                    Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR rtl-optimization/81803
+	* lra-constraints.c (curr_insn_transform): Also reload the whole
+	register for a strict subreg no wider than a word if this is for
+	a WORD_REGISTER_OPERATIONS target.
+
+2017-11-03  Wilco Dijkstra  <wdijkstr@arm.com>
+
+	PR middle-end/60580
+	* config/aarch64/aarch64.c (aarch64_frame_pointer_required)
+	Check special value of flag_omit_frame_pointer.
+	(aarch64_can_eliminate): Likewise.
+	(aarch64_override_options_after_change_1): Simplify handling of
+	-fomit-frame-pointer and -fomit-leaf-frame-pointer.
+
+2017-11-01  Martin Jambor  <mjambor@suse.cz>
+
+	PR c++/81702
+	* gimple-fold.c (gimple_get_virt_method_for_vtable): Remove assert.
+
+2017-10-31  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/82772
+	* config/alpha/sync.md (fetchop_constr) <and>: Change to "rINM".
+
+2017-10-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-10-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/82159
+	* expr.c (store_field): Don't optimize away bitsize == 0 store
+	from CALL_EXPR with addressable return type.
+
+	2017-09-21  Jakub Jelinek  <jakub@redhat.com>
+
+	PR sanitizer/81715
+	* tree-inline.c (expand_call_inline): Emit clobber stmts for
+	VAR_DECLs to which addressable non-volatile parameters are mapped
+	and for id->retvar after the return value assignment, though
+	for -fsanitize=kernel-address only.  Clear id->retval and id->retbnd
+	after inlining.
+
+	2017-09-18  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/82234
+	* doc/extend.texi: Add @findex entry for __builtin_shuffle.
+
+	2017-09-15  Jakub Jelinek  <jakub@redhat.com>
+
+	PR rtl-optimization/82192
+	* combine.c (make_extraction): Don't look through non-paradoxical
+	SUBREGs or TRUNCATE if pos + len is or might be bigger than
+	inner's mode.
+
+2017-10-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/82703
+	* config/i386/i386-protos.h (maybe_get_pool_constant): Removed.
+	* config/i386/i386.c (maybe_get_pool_constant): Removed.
+	(ix86_split_to_parts): Use avoid_constant_pool_reference instead of
+	maybe_get_pool_constant.
+	* config/i386/predicates.md (zero_extended_scalar_load_operand):
+	Likewise.
+
+2017-10-24  Qing Zhao <qing.zhao@oracle.com>
+	    Wilco Dijkstra  <wilco.dijkstra@arm.com>
+
+        * builtins.c (expand_builtin_update_setjmp_buf): Add a
+        converstion to Pmode from the buf_addr.
+
+2017-10-20  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82603
+	* tree-if-conv.c (predicate_mem_writes): Make sure to only
+	remove false predicated stores.
+
+2017-10-20  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-10-06  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82436
+	* tree-vect-slp.c (vect_supported_load_permutation_p): More
+	conservatively choose the vectorization factor when checking
+	whether we can perform the required load permutation.
+	(vect_transform_slp_perm_load): Assert when we may not fail.
+
+2017-10-19  Richard Earnshaw  <rearnsha@arm.com>
+
+	PR target/82445
+	* config/arm/arm.c (align_ok_ldrd_strd): New function.
+	(mem_ok_for_ldrd_strd): New parameter align.  Extract the alignment of
+	the mem into it.
+	(gen_operands_ldrd_strd): Validate the alignment of the accesses.
+
+2017-10-18  Segher Boessenkool  <segher@kernel.crashing.org>
+
+	PR rtl-optimization/82602
+	* ira.c (rtx_moveable_p): Return false for volatile asm.
+
+2017-10-18  Vladimir Makarov  <vmakarov@redhat.com>
+
+	PR middle-end/82556
+	* lra-constraints.c (curr_insn_transform): Use non-input operand
+	instead of output one for matched reload.
+
+2017-10-17  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/82549
+	* fold-const.c (optimize_bit_field_compare, fold_truth_andor_1):
+	Formatting fixes.  Instead of calling make_bit_field_ref with negative
+	bitpos return 0.
+
+2017-10-13  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/82274
+	* internal-fn.c (expand_mul_overflow): If both operands have
+	the same highpart of -1 or 0 and the topmost bit of lowpart
+	is different, overflow is if res <= 0 rather than res < 0.
+
+	PR target/82524
+	* config/i386/i386.md (addqi_ext_1, andqi_ext_1,
+	*andqi_ext_1_cc, *<code>qi_ext_1, *xorqi_ext_1_cc): Change
+	=Q constraints to +Q and into insn condition add check
+	that operands[0] and operands[1] are equal.
+	(*addqi_ext_2, *andqi_ext_2, *<code>qi_ext_2): Change
+	=Q constraints to +Q and into insn condition add check
+	that operands[0] is equal to either operands[1] or operands[2].
+
+2017-10-10  Andreas Tobler  <andreast@gcc.gnu.org>
+
+	Backported from mainline r253602
+	2017-10-10  Andreas Tobler  <andreast@gcc.gnu.org>
+
+	* config.gcc: (armv7*-*-freebsd*): New target.
+	(armv6*-*-freebsd*): Remove obsolete TARGET_FREEBSD_ARMv6 define.
+
+2017-10-06  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	Backport from mainline r253242.
+	2017-09-27  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	PR target/71727
+	* config/aarch64/aarch64.c
+	(aarch64_builtin_support_vector_misalignment): Always return false
+	when misalignment is unknown.
+
+2017-10-04  Jason Merrill  <jason@redhat.com>
+
+	PR c++/82406 - C++ error with noexcept function type
+	PR c++/70029 - ICE with ref-qualifier and -flto
+	* langhooks.h (struct lang_hooks_for_types): Add
+	copy_lang_qualifiers.
+	* attribs.c (build_type_attribute_qual_variant): Use it.
+	* langhooks-def.h (LANG_HOOKS_COPY_LANG_QUALIFIERS): Default to
+	NULL.
+	(LANG_HOOKS_FOR_TYPES_INITIALIZER): Use it.
+	* tree.c (verify_type): Re-enable TYPE_CANONICAL main variant check.
+
+2017-10-02  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-09-29  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR tree-optimization/82337
+	* gimple-ssa-strength-reduction.c (find_phi_def): Don't record a
+	phi definition if the PHI result appears in an abnormal PHI.
+	(find_basis_for_base_expr): Don't record a basis if the LHS of the
+	basis appears in an abnormal PHI.
+
+2017-09-30  Jakub Jelinek  <jakub@redhat.com>
+
+	* config/i386/i386.c (ix86_split_idivmod): Use mode instead of
+	always SImode for DIV and MOD in REG_EQUAL notes.
+
+	Backported from mainline
+	2017-09-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/82159
+	* gimplify.c (gimplify_modify_expr): Don't optimize away zero sized
+	lhs from calls if the lhs has addressable type.
+
+2017-09-29  Krister Walfridsson  <krister.walfridsson@gmail.com>
+
+	Backport from mainline
+	2017-06-29  Maya Rashish  <coypu@sdf.org>
+
+	PR target/77480
+	* config/netbsd.h (NETBSD_LIB_SPEC): Add -lc when creating shared
+	objects.
+
+2017-09-29  Krister Walfridsson  <krister.walfridsson@gmail.com>
+
+	Backport from mainline
+	2017-09-26  Krister Walfridsson  <krister.walfridsson@gmail.com>
+
+	PR target/39570
+	* gcc/config/netbsd-protos.h: New file.
+	* gcc/config/netbsd.c: New file.
+	* gcc/config/netbsd.h (SUBTARGET_INIT_BUILTINS): Define.
+	* gcc/config/t-netbsd: New file.
+	* gcc/config.gcc (tm_p_file): Add netbsd-protos.h.
+	(tmake_file) Add t-netbsd.
+	(extra_objs) Add netbsd.o.
+
+2017-09-28  Krister Walfridsson  <krister.walfridsson@gmail.com>
+
+	Backport from mainline
+	2017-05-14  Krister Walfridsson  <krister.walfridsson@gmail.com>
+
+	PR target/80600
+	* config/netbsd.h (NETBSD_LIBGCC_SPEC): Always add -lgcc.
+
+2017-09-27  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	Backport from trunk r249639.
+ 	2017-06-26  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	* doc/sourcebuild.texi (ARM-specific attributes): Document new
+	arm_neon_ok_no_float_abi effective target.
+
+2017-09-26  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-09-19  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82244
+	* tree-vrp.c (remove_range_assertions): Do not propagate
+	a constant to abnormals but replace the assert with a copy.
+
+	2017-09-21  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82276
+	PR tree-optimization/82244
+	* tree-vrp.c (build_assert_expr_for): Set
+	SSA_NAME_OCCURS_IN_ABNORMAL_PHI if the variable we assert on
+	has it set.
+	(remove_range_assertions): Revert earlier change.
+
+	2017-09-20  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82264
+	* tree-ssa-sccvn.c (vn_phi_eq): Use safe_dyn_cast to check
+	for GIMPLE_CONDs.
+	(vn_phi_lookup): Likewise.
+	(vn_phi_insert): Likewise.
+	* is-a.h (safe_dyn_cast): New.
+
+	2017-09-25  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82285
+	* tree-vect-patterns.c (vect_recog_bool_pattern): Also handle
+	enumeral types.
+
+	2017-09-22  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82291
+	* tree-if-conv.c (predicate_mem_writes): Make sure to
+	remove writes in blocks predicated with false.
+
+2017-09-21  Alan Modra  <amodra@gmail.com>
+
+	PR target/81996
+	* gcc/config/rs6000/rs6000.c (rs6000_return_addr): Use
+	stack_pointer_rtx for count 0.  Update comments.  Break up
+	large rtl expression.
+
+2017-09-21  Wilco Dijkstra  <wdijkstr@arm.com>
+
+	PR target/71951
+	* config/aarch64/aarch64.h (LIBGCC2_UNWIND_ATTRIBUTE): Define.
+
+2017-09-19  Uros Bizjak  <ubizjak@gmail.com>
+
+	* config/i386/i386.c (fold_builtin_cpu): Add M_AMDFAM17H
+	to processor_model and "amdfam17h" to arch_names_table.
+	* doc/extend.texi (__builtin_cpu_is): Document amdfam17h CPU name.
+
+2017-09-19  Martin Liska  <mliska@suse.cz>
+
+	PR c++/81355
+	* config/i386/i386.c (sorted_attr_string): Skip empty strings.
+
+2017-09-19  Martin Liska  <mliska@suse.cz>
+
+	Revert backport:
+	2017-08-10  Martin Liska  <mliska@suse.cz>
+
+	PR c++/81355
+	* c-attribs.c (handle_target_attribute):
+	Report warning for an empty string argument of target attribute.
+
+2017-09-18  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-09-04  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82084
+	* fold-const.h (can_native_encode_string_p): Declare.
+	* fold-const.c (can_native_encode_string_p): Factor out from ...
+	(native_encode_string): ... here.
+	* tree-vect-stmts.c (vectorizable_store): Call it to avoid
+	vectorizing stores from constants we later cannot handle.
+
+	2017-09-06  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82108
+	* tree-vect-stmts.c (vectorizable_load): Fix pointer adjustment
+	for gap in the non-permutation SLP case.
+
+2017-09-15  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-09-14  Jakub Jelinek  <jakub@redhat.com>
+ 
+	PR target/81325
+	* cfgbuild.c (find_bb_boundaries): Ignore debug insns in decisions
+	if and where to split a bb, except for splitting before debug insn
+	sequences followed by non-label real insn.  Delete debug insns
+	in between basic blocks.
+
+	2017-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/82112
+	* config/rs6000/rs6000-c.c (altivec_resolve_overloaded_builtin): For
+	ALTIVEC_BUILTIN_VEC_LD if arg1 has array type call default_conversion
+	on it early, rather than manual conversion late.  For
+	ALTIVEC_BUILTIN_VEC_ST if arg2 has array type call default_conversion
+	instead of performing manual conversion.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-09-14  Martin Liska  <mliska@suse.cz>
+
+	* gimple-ssa-strength-reduction.c (create_add_on_incoming_edge):
+	Add proper printf format.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-08-30  Martin Liska  <mliska@suse.cz>
+
+	PR inline-asm/82001
+	* ipa-icf-gimple.c (func_checker::compare_tree_list_operand):
+	Rename to ...
+	(func_checker::compare_asm_inputs_outputs): ... this function.
+	(func_checker::compare_gimple_asm): Use the function to compare
+	also ASM constrains.
+	* ipa-icf-gimple.h: Rename the function.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-08-29  Martin Liska  <mliska@suse.cz>
+
+	PR other/39851
+	* gcc.c (driver_handle_option): Add new argument.
+	* opts-common.c (handle_option): Pass
+	target_option_override_hook.
+	* opts-global.c (lang_handle_option): Add new option.
+	(set_default_handlers):  Add new argument.
+	(decode_options): Likewise.
+	* opts.c (target_handle_option): Likewise.
+	(common_handle_option): Call target_option_override_hook.
+	* opts.h (struct cl_option_handler_func): Add hook for
+	target option override.
+	(struct cl_option_handlers): Likewise.
+	(set_default_handlers): Add new argument.
+	(decode_options): Likewise.
+	(common_handle_option): Likewise.
+	(target_handle_option): Likewise.
+	* toplev.c (toplev::main): Pass targetm.target_option.override
+	hook.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-08-10  Martin Liska  <mliska@suse.cz>
+
+	PR c++/81355
+	* c-attribs.c (handle_target_attribute):
+	Report warning for an empty string argument of target attribute.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-08-08  Martin Liska  <mliska@suse.cz>
+
+	PR tree-opt/81696
+	* ipa-icf-gimple.c (func_checker::compare_cst_or_decl): Consider
+	LABEL_DECLs that can be from a different function.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-06-28  Martin Liska  <mliska@suse.cz>
+
+	PR ipa/81128
+	* ipa-visibility.c (non_local_p): Handle visibility.
+
+2017-09-12  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-09-05  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR target/81833
+	* config/rs6000/altivec.md (altivec_vsum2sws): Convert from a
+	define_insn to a define_expand.
+	(altivec_vsum2sws_direct): New define_insn.
+	(altivec_vsumsws): Convert from a define_insn to a define_expand.
+
+2017-09-11  Max Filippov  <jcmvbkbc@gmail.com>
+
+	Backport from mainline
+	PR target/82181
+	* config/xtensa/xtensa.c (xtensa_mem_offset): Check that both
+	words of DImode object are reachable by xtensa_uimm8x4 access.
+
+2017-09-10  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-05-11  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR target/80695
+	* config/rs6000/rs6000.c (rs6000_builtin_vectorization_cost):
+	Account for direct move costs for vec_construct of integer
+	vectors.
+
+	Backport from mainline
+	2017-07-23  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR target/80695
+	* config/rs6000/rs6000.c (rs6000_builtin_vectorization_cost):
+	Reduce cost estimate for direct moves.
+
+2017-09-08  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR target/81988
+	* config/sparc/sparc.md (mulsi3): Rename into *mulsi3_sp32.
+	(*mulsi3_sp64): New instruction.
+	(mulsi3): New expander.
+
+2017-09-07  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/81768
+	* omp-low.c (lower_omp_for): Recompute tree invariant if
+	gimple_omp_for_initial/final is ADDR_EXPR.
+
+	PR middle-end/81768
+	* omp-expand.c (expand_omp_simd): Force second operands of COND_EXPR
+	into gimple val before gimplification fo the COND_EXPR.
+
+	2017-09-04  Jakub Jelinek  <jakub@redhat.com>
+
+	* lra-remat.c (reg_overlap_for_remat_p): Fix a pasto.
+
+	2017-09-01  Jakub Jelinek  <jakub@redhat.com>
+
+	PR sanitizer/81923
+	* asan.c (create_odr_indicator): Strip name encoding from assembler
+	name before appending it after __odr_asan_.
+
+	2017-08-09  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/81687
+	* omp-low.c (omp_copy_decl): Don't remap FORCED_LABEL or DECL_NONLOCAL
+	LABEL_DECLs.
+	* tree-cfg.c (move_stmt_op): Don't adjust DECL_CONTEXT of FORCED_LABEL
+	or DECL_NONLOCAL labels.
+	(move_stmt_r) <case GIMPLE_LABEL>: Adjust DECL_CONTEXT of FORCED_LABEL
+	or DECL_NONLOCAL labels here.
+
+	2017-08-03  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/81621
+	* bb-reorder.c (pass_partition_blocks::execute): Return TODO_df_finish
+	after setting changeable df flags.
+
+	PR driver/81650
+	* calls.c (alloc_max_size): Use HOST_WIDE_INT_UC (10??)
+	instead of 10??LU, perform unit multiplication in wide_int,
+	don't change alloc_object_size_limit if the limit is larger
+	than SSIZE_MAX.
+
+	PR middle-end/81052
+	* omp-low.c (diagnose_sb_0): Handle flag_openmp_simd like flag_openmp.
+	(pass_diagnose_omp_blocks::gate): Enable also for flag_openmp_simd.
+
+2017-09-06  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline:
+	2017-08-30  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR tree-optimization/81987
+	* gimple-ssa-strength-reduction.c (insert_initializers): Don't
+	insert an initializer in a location not dominated by the stride
+	definition.
+
+2017-09-05  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-08-29  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+		    Jakub Jelinek  <jakub@redhat.com>
+		    Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/81503
+	* gimple-ssa-strength-reduction.c (replace_mult_candidate): Ensure
+	folded constant fits in the target type; reorder tests for clarity.
+
+2017-09-05  Pierre-Marie de Rodat  <derodat@adacore.com>
+
+	Backport from trunk
+	PR ada/79542
+	* dwarf2out.c (modified_type_die): For C typedef types that have
+	an ultimate origin, process the ultimate origin instead of the
+	input type.
+	(gen_typedef_die): Assert that input DECLs have no ultimate
+	origin.
+	(gen_type_die_with_usage): For typedef variants that have an
+	ultimate origin, just call gen_decl_die on the original DECL.
+	(process_scope_var): Avoid creating DIEs for local typedefs and
+	concrete static variables.
+
+2017-08-31  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-08-25  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR target/81504
+	* config/rs6000/rs6000.c (find_alignment_op): Add reference
+	parameter and_insn and return it.
+	(recombine_lvx_pattern): Insert a copy to ensure availability of
+	the base register of the copied masking operation at the point of
+	the instruction replacement.
+	(recombine_stvx_pattern): Likewise.
+
+2017-08-29  Michael Meissner  <meissner@linux.vnet.ibm.com>
+
+	Back port from trunk
+	2017-08-07  Michael Meissner  <meissner@linux.vnet.ibm.com>
+
+	PR target/81593
+	* config/rs6000/vsx.md (vsx_concat_<mode>_1): New combiner insns
+	to recognize inserting into a vector from a double word element
+	that was extracted from another vector, and eliminate extra
+	XXPERMDI instructions.
+	(vsx_concat_<mode>_2): Likewise.
+	(vsx_concat_<mode>_3): Likewise.
+	(vsx_set_<mode>, VSX_D): Rewrite vector set in terms of vector
+	concat to allow optimizing inserts from previous extracts.
+
+2017-08-29  Alan Modra  <amodra@gmail.com>
+
+	Apply from mainline
+	2017-08-12  Alan Modra  <amodra@gmail.com>
+	PR target/81170
+	PR target/81295
+	* config/rs6000/sysv4.h (STARTFILE_LINUX_SPEC): Upgrade to
+	match gnu-user.h startfile.
+	(ENDFILE_LINUX_SPEC): Similarly.
+
+	2017-08-08  Alan Modra  <amodra@gmail.com>
+		    H.J. Lu  <hongjiu.lu@intel.com>
+	PR target/81170
+	PR target/81295
+	PR driver/81523
+	* gcc.c (NO_PIE_SPEC): Delete.
+	(PIE_SPEC): Define as !no-pie/pie.  Move static|shared|r
+	exclusion..
+	(LINK_PIE_SPEC): ..to here.
+	(LINK_COMMAND_SPEC): Support -no-pie.
+	* config/gnu-user.h (GNU_USER_TARGET_STARTFILE_SPEC): Correct
+	chain of crtbegin*.o selection, update for PIE_SPEC changes and
+	format.
+	(GNU_USER_TARGET_ENDFILE_SPEC): Similarly.
+	* config/sol2.h (STARTFILE_CRTBEGIN_SPEC): Similarly.
+	(ENDFILE_CRTEND_SPEC): Similarly.
+
+2017-08-29  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-08-28  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/81977
+	* tree-ssa-sccvn.c (vn_reference_lookup_3): Fix look through
+	memcpy.
+
+	2017-08-28  Richard Biener  <rguenther@suse.de>
+
+	PR debug/81993
+	* dwarf2out.c (gen_remaining_tmpl_value_param_die_attributes):
+	Do nothing for removed DIEs.
+
+2017-08-28  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-06-14  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/81088
+	* fold-const.c (split_tree): Drop TREE_OVERFLOW flag from
+	literal constants.
+	(fold_binary_loc): When associating do not treat pre-existing
+	TREE_OVERFLOW on literal constants as a reason to allow
+	TREE_OVERFLOW on associated literal constants.
+
+	2017-06-13  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/81065
+	* fold-const.c (extract_muldiv_1): Remove bogus distribution
+	case of C * (x * C2 + C3).
+	(fold_addr_of_array_ref_difference): Properly fold index difference.
+
+	2017-06-07  Marek Polacek  <polacek@redhat.com>
+
+	PR sanitizer/80932
+	* fold-const.c (extract_muldiv_1) <case MINUS_EXPR>: Add
+	TYPE_OVERFLOW_WRAPS check. 
+
+2017-08-28  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-08-21  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/81884
+	* tree-ssa-alias.c (stmt_kills_ref_p): Handle array accesses
+	at struct end conservatively when comparing common bases.
+
+	2017-05-04  Richard Biener  <rguenther@suse.de>
+ 
+	* tree.c (array_at_struct_end_p): Handle arrays at struct
+	end with flexarrays more conservatively.  Refactor and treat
+	arrays of arrays or aggregates more strict.  Fix
+	VIEW_CONVERT_EXPR handling.  Remove allow_compref argument.
+	* tree.h (array_at_struct_end_p): Adjust prototype.
+	* gimple-fold.c (get_range_strlen): Likewise.
+	* tree-chkp.c (chkp_may_narrow_to_field): Likewise.
+
+2017-08-28  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-08-01  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/81181
+	* tree-ssa-pre.c (compute_antic_aux): Defer clean() to ...
+	(compute_antic): ... end of iteration here.
+
+	2017-08-08  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/81723
+	* tree-vect-slp.c (struct bst_traits): New hash traits.
+	(bst_fail): New global.
+	(vect_build_slp_tree_2): New worker, split out from ...
+	(vect_build_slp_tree): ... this now wrapping it with using
+	bst_fail set to cache SLP tree build fails.  Properly handle
+	max_tree_size.
+	(vect_analyze_slp_instance): Allocate and free bst_fail.
+
+	2017-08-24  Richard Biener  <rguenther@suse.de>
+
+	PR target/81921
+	* config/i386/i386.c: Include symbol-summary.h, ipa-prop.h
+	and ipa-inline.h.
+	(ix86_can_inline_p): When ix86_fpmath flags do not match
+	check whether the callee uses FP math at all.
+
+2017-08-23  Peter Bergner  <bergner@vnet.ibm.com>
+
+	Backport from mainline
+	2017-08-17  Peter Bergner  <bergner@vnet.ibm.com>
+
+	PR target/72804
+	* config/rs6000/vsx.md (*vsx_le_permute_<mode>): Add support for
+	operands residing in integer registers.
+	(*vsx_le_perm_load_<mode>): Likewise.
+	(*vsx_le_perm_store_<mode>): Likewise.
+	(define_peephole2): Add peepholes to optimize the above.
+
+2017-08-22  Peter Bergner  <bergner@vnet.ibm.com>
+
+	Backport from mainline
+	2017-08-17  Peter Bergner  <bergner@vnet.ibm.com>
+
+	PR target/80210
+	* config/rs6000/rs6000.c (rs6000_activate_target_options): New function.
+	(rs6000_set_current_function): Rewrite function to use it.
+
+2017-08-22  Sebastian Huber  <sebastian.huber@embedded-brains.de>
+
+	Backport from mainline
+	2017-08-22  Sebastian Huber  <sebastian.huber@embedded-brains.de>
+
+	* config.gcc (powerpc-*-rtems*): Add rs6000/linux64.opt.
+	* config/rs6000/rtems.h (ASM_PREFERRED_EH_DATA_FORMAT): New define.
+	(DOT_SYMBOLS): Likewise.
+	(MINIMAL_TOC_SECTION_ASM_OP): Likewise.
+	(RELOCATABLE_NEEDS_FIXUP): Likewise.
+	(RS6000_ABI_NAME): Likewise.
+	(TARGET_CMODEL): Likewise.
+	(TOC_SECTION_ASM_OP): Likewise.
+	(SET_CMODEL): New macro.
+	(SUBSUBTARGET_OVERRIDE_OPTIONS): Evaluate cmodel options.
+
+2017-08-22  Georg-Johann Lay  <avr@gjlay.de>
+
+	Backport from 2017-08-22 trunk r251256.
+
+	PR target/81910
+	* config/avr/avr.c (avr_handle_addr_attribute): Early return if
+	not VAR_P. Filter attribute warnings with OPT_Wattributes.
+	(avr_attribute_table) <io, io_low, address>: Initialize
+	.decl_required with true.
+
+2017-08-21  Georg-Johann Lay  <avr@gjlay.de>
+
+	PR target/79883
+	* config/avr/avr.c (avr_set_current_function): Typo in diagnostic.
+
+2017-08-19  Uros Bizjak  <ubizjak@gmail.com>
+
+	PR target/81894
+	* doc/extend.texi (x86 Built-in Functions): Correct the name of
+	__builtin_ia32_lzcnt_u16.
+
+2017-08-17  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline
+	2017-08-17  Maxim Ostapenko  <m.ostapenko@samsung.com>
+
+	PR target/81861
+	* config/i386/i386.c (ix86_option_override_internal): Save target
+	specific options after ix86_stack_protector_guard_reg was changed.
+
+2017-08-16  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-08-08  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR tree-optimization/81354
+	* gimple-ssa-strength-reduction.c (create_add_on_incoming_edge):
+	Insert on edges rather than explicitly creating landing pads.
+	(analyze_candidates_and_replace): Commit edge inserts.
+
+2017-08-15  Joseph Myers  <joseph@codesourcery.com>
+
+	PR target/78460
+	PR target/67712
+	* config/sh/sh-mem.cc (sh_expand_cmpnstr): Only unroll for
+	constant count if that count is less than 32.
+
+2017-08-14  Richard Biener  <rguenther@suse.de>
+
+	* BASE-VER: Set to 7.2.1.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
@@ -5411,11 +6187,6 @@
 	* doc/invoke.texi: Replace inequality signs with square brackets
 	for -Wnormalized.
 
-2017-02-22  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
-
-	PR tree-optimization/68644
-	* gcc.dg/tree-ssa/ivopts-lt-2.c: Skip for powerpc*-*-*.
-
 2017-02-22  Matthew Fortune  <matthew.fortune@imgtec.com>
 
 	PR target/78660
@@ -6987,8 +7758,6 @@
 	* tree-vrp.c (process_assert_insertions): Properly adjust common
 	when removing a duplicate.
 
-	* gcc.dg/torture/pr79276.c: New testcase.
-
 2017-01-30  Richard Biener  <rguenther@suse.de>
 
 	PR tree-optimization/79256
Index: gcc/testsuite/gcc.target/powerpc/pr81833-1.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/pr81833-1.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/pr81833-1.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,59 @@
+/* PR81833: This used to fail due to improper implementation of vec_msum.  */
+/* Test case relies on -mcpu=power7 or later.  Currently we don't have
+   machinery to express that, so we have two separate tests for -mcpu=power7
+   and -mcpu=power8 to catch 32-bit BE on P7 and 64-bit BE/LE on P8.  */
+
+/* { dg-do run } */
+/* { dg-require-effective-target p8vector_hw } */
+/* { dg-skip-if "do not override -mcpu" { powerpc*-*-* } { "-mcpu=*" } { "-mcpu=power8" } } */
+/* { dg-options "-mcpu=power8 -O2" } */
+
+#include <altivec.h>
+
+#define vec_u8  vector unsigned char
+#define vec_s8  vector signed char
+#define vec_u16 vector unsigned short
+#define vec_s16 vector signed short
+#define vec_u32 vector unsigned int
+#define vec_s32 vector signed int
+#define vec_f   vector float
+
+#define LOAD_ZERO const vec_u8 zerov = vec_splat_u8 (0)
+
+#define zero_u8v  (vec_u8)  zerov
+#define zero_s8v  (vec_s8)  zerov
+#define zero_u16v (vec_u16) zerov
+#define zero_s16v (vec_s16) zerov
+#define zero_u32v (vec_u32) zerov
+#define zero_s32v (vec_s32) zerov
+
+signed int __attribute__((noinline))
+scalarproduct_int16_vsx (const signed short *v1, const signed short *v2,
+			 int order)
+{
+  int i;
+  LOAD_ZERO;
+  register vec_s16 vec1;
+  register vec_s32 res = vec_splat_s32 (0), t;
+  signed int ires;
+
+  for (i = 0; i < order; i += 8) {
+    vec1 = vec_vsx_ld (0, v1);
+    t    = vec_msum (vec1, vec_vsx_ld (0, v2), zero_s32v);
+    res  = vec_sums (t, res);
+    v1  += 8;
+    v2  += 8;
+  }
+  res = vec_splat (res, 3);
+  vec_ste (res, 0, &ires);
+
+  return ires;
+}
+
+int main(void)
+{
+  const signed short test_vec[] = { 1, 1, 1, 1, 1, 1, 1, 1 };
+  if (scalarproduct_int16_vsx (test_vec, test_vec, 8) != 8)
+    __builtin_abort ();
+  return 0;
+}
Index: gcc/testsuite/gcc.target/powerpc/vec-setup-be-long.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/vec-setup-be-long.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/vec-setup-be-long.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,11 @@
+/* { dg-do run { target { powerpc64le*-*-linux* } } } */
+/* { dg-require-effective-target vsx_hw } */
+/* { dg-options "-O2 -mvsx -maltivec=be" } */
+
+/* Test various ways of creating vectors with 2 double words and accessing the
+   elements.  This test uses the long (on 64-bit systems) or long long datatype
+   (on 32-bit systems).
+
+   This test explicitly tests -maltivec=be to make sure things are correct.  */
+
+#include "vec-setup.h"
Index: gcc/testsuite/gcc.target/powerpc/pr81833-2.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/pr81833-2.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/pr81833-2.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,59 @@
+/* PR81833: This used to fail due to improper implementation of vec_msum.  */
+/* Test case relies on -mcpu=power7 or later.  Currently we don't have
+   machinery to express that, so we have two separate tests for -mcpu=power7
+   and -mcpu=power8 to catch 32-bit BE on P7 and 64-bit BE/LE on P8.  */
+
+/* { dg-do run } */
+/* { dg-require-effective-target vsx_hw } */
+/* { dg-skip-if "do not override -mcpu" { powerpc*-*-* } { "-mcpu=*" } { "-mcpu=power7" } } */
+/* { dg-options "-mcpu=power7 -O2" } */
+
+#include <altivec.h>
+
+#define vec_u8  vector unsigned char
+#define vec_s8  vector signed char
+#define vec_u16 vector unsigned short
+#define vec_s16 vector signed short
+#define vec_u32 vector unsigned int
+#define vec_s32 vector signed int
+#define vec_f   vector float
+
+#define LOAD_ZERO const vec_u8 zerov = vec_splat_u8 (0)
+
+#define zero_u8v  (vec_u8)  zerov
+#define zero_s8v  (vec_s8)  zerov
+#define zero_u16v (vec_u16) zerov
+#define zero_s16v (vec_s16) zerov
+#define zero_u32v (vec_u32) zerov
+#define zero_s32v (vec_s32) zerov
+
+signed int __attribute__((noinline))
+scalarproduct_int16_vsx (const signed short *v1, const signed short *v2,
+			 int order)
+{
+  int i;
+  LOAD_ZERO;
+  register vec_s16 vec1;
+  register vec_s32 res = vec_splat_s32 (0), t;
+  signed int ires;
+
+  for (i = 0; i < order; i += 8) {
+    vec1 = vec_vsx_ld (0, v1);
+    t    = vec_msum (vec1, vec_vsx_ld (0, v2), zero_s32v);
+    res  = vec_sums (t, res);
+    v1  += 8;
+    v2  += 8;
+  }
+  res = vec_splat (res, 3);
+  vec_ste (res, 0, &ires);
+
+  return ires;
+}
+
+int main(void)
+{
+  const signed short test_vec[] = { 1, 1, 1, 1, 1, 1, 1, 1 };
+  if (scalarproduct_int16_vsx (test_vec, test_vec, 8) != 8)
+    __builtin_abort ();
+  return 0;
+}
Index: gcc/testsuite/gcc.target/powerpc/pr82112.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/pr82112.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/pr82112.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,16 @@
+/* PR target/82112 */
+/* { dg-do compile } */
+/* { dg-require-effective-target powerpc_altivec_ok } */
+/* { dg-options "-maltivec -std=gnu90" } */
+
+#include <altivec.h>
+
+struct __attribute__((aligned (16))) S { unsigned char c[64]; } bar (void);
+vector unsigned char v;
+
+void
+foo (void)
+{
+  vec_ld (0, bar ().c);	/* { dg-error "invalid parameter combination for AltiVec intrinsic" } */
+  vec_st (v, 0, bar ().c);	/* { dg-error "invalid parameter combination for AltiVec intrinsic" } */
+}
Index: gcc/testsuite/gcc.target/powerpc/vec-setup.h
===================================================================
--- gcc/testsuite/gcc.target/powerpc/vec-setup.h	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/vec-setup.h	(.../branches/gcc-7-branch)
@@ -0,0 +1,366 @@
+#include <altivec.h>
+
+/* Test various ways of creating vectors with 2 double words and accessing the
+   elements.  This include files supports:
+
+	 testing double
+	 testing long on 64-bit systems
+	 testing long long on 32-bit systems.
+
+   The endian support is:
+
+	big endian
+	little endian with little endian element ordering
+	little endian with big endian element ordering.  */
+
+#ifdef DEBUG
+#include <stdio.h>
+#define DEBUG0(STR)		fputs (STR, stdout)
+#define DEBUG2(STR,A,B)		printf (STR, A, B)
+
+static int errors = 0;
+
+#else
+#include <stdlib.h>
+#define DEBUG0(STR)
+#define DEBUG2(STR,A,B)
+#endif
+
+#if defined(DO_DOUBLE)
+#define TYPE	double
+#define STYPE	"double"
+#define ZERO	0.0
+#define ONE	1.0
+#define TWO	2.0
+#define THREE	3.0
+#define FOUR	4.0
+#define FIVE	5.0
+#define SIX	6.0
+#define FMT	"g"
+
+#elif defined(_ARCH_PPC64)
+#define TYPE	long
+#define STYPE	"long"
+#define ZERO	0L
+#define ONE	1L
+#define TWO	2L
+#define THREE	3L
+#define FOUR	4L
+#define FIVE	5L
+#define SIX	6L
+#define FMT	"ld"
+
+#else
+#define TYPE	long long
+#define STYPE	"long long"
+#define ZERO	0LL
+#define ONE	1LL
+#define TWO	2LL
+#define THREE	3LL
+#define FOUR	4LL
+#define FIVE	5LL
+#define SIX	6LL
+#define FMT	"lld"
+#endif
+
+/* Macros to order the left/right values correctly.  Note, -maltivec=be does
+   not change the order for static initializations, so we have to handle it
+   specially.  */
+
+#if __BYTE_ORDER__ == __ORDER_BIG_ENDIAN__
+#define INIT_ORDER(A, B)	(TYPE) A, (TYPE) B
+#define ELEMENT_ORDER(A, B)	(TYPE) A, (TYPE) B
+#define ENDIAN			"-mbig"
+
+#elif __VEC_ELEMENT_REG_ORDER__ == __ORDER_BIG_ENDIAN__
+#define NO_ARRAY
+#define INIT_ORDER(A, B)	(TYPE) B, (TYPE) A
+#define ELEMENT_ORDER(A, B)	(TYPE) A, (TYPE) B
+#define ENDIAN			"-mlittle -maltivec=be"
+
+#else
+#define INIT_ORDER(A, B)	(TYPE) B, (TYPE) A
+#define ELEMENT_ORDER(A, B)	(TYPE) B, (TYPE) A
+#define ENDIAN			"-mlittle"
+#endif
+
+static volatile TYPE		five	= FIVE;
+static volatile TYPE		six	= SIX;
+static volatile vector TYPE	s_v12 = { ONE,   TWO };
+static volatile vector TYPE	g_v34 = { THREE, FOUR };
+
+
+__attribute__((__noinline__))
+static void
+vector_check (vector TYPE v, TYPE expect_hi, TYPE expect_lo)
+{
+  TYPE actual_hi, actual_lo;
+#ifdef DEBUG
+  const char *pass_fail;
+#endif
+
+  __asm__ ("xxlor %x0,%x1,%x1"		: "=&wa" (actual_hi) : "wa" (v));
+  __asm__ ("xxpermdi %x0,%x1,%x1,3"	: "=&wa" (actual_lo) : "wa" (v));
+
+#ifdef DEBUG
+  if ((actual_hi == expect_hi) && (actual_lo == expect_lo))
+    pass_fail = ", pass";
+  else
+    {
+      pass_fail = ", fail";
+      errors++;
+    }
+
+  printf ("Expected %" FMT ", %" FMT ", got %" FMT ", %" FMT "%s\n",
+	  expect_hi, expect_lo,
+	  actual_hi, actual_lo,
+	  pass_fail);
+#else
+  if ((actual_hi != expect_hi) || (actual_lo != expect_lo))
+    abort ();
+#endif
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+combine (TYPE op0, TYPE op1)
+{
+  return (vector TYPE) { op0, op1 };
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+combine_insert (TYPE op0, TYPE op1)
+{
+  vector TYPE ret = (vector TYPE) { ZERO, ZERO };
+  ret = vec_insert (op0, ret, 0);
+  ret = vec_insert (op1, ret, 1);
+  return ret;
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+concat_extract_00 (vector TYPE a, vector TYPE b)
+{
+  return (vector TYPE) { vec_extract (a, 0), vec_extract (b, 0) };
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+concat_extract_01 (vector TYPE a, vector TYPE b)
+{
+  return (vector TYPE) { vec_extract (a, 0), vec_extract (b, 1) };
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+concat_extract_10 (vector TYPE a, vector TYPE b)
+{
+  return (vector TYPE) { vec_extract (a, 1), vec_extract (b, 0) };
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+concat_extract_11 (vector TYPE a, vector TYPE b)
+{
+  return (vector TYPE) { vec_extract (a, 1), vec_extract (b, 1) };
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+concat_extract2_0s (vector TYPE a, TYPE b)
+{
+  return (vector TYPE) { vec_extract (a, 0), b };
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+concat_extract2_1s (vector TYPE a, TYPE b)
+{
+  return (vector TYPE) { vec_extract (a, 1), b };
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+concat_extract2_s0 (TYPE a, vector TYPE b)
+{
+  return (vector TYPE) { a, vec_extract (b, 0) };
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+concat_extract2_s1 (TYPE a, vector TYPE b)
+{
+  return (vector TYPE) { a, vec_extract (b, 1) };
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+concat_extract_nn (vector TYPE a, vector TYPE b, size_t i, size_t j)
+{
+  return (vector TYPE) { vec_extract (a, i), vec_extract (b, j) };
+}
+
+#ifndef NO_ARRAY
+__attribute__((__noinline__))
+static vector TYPE
+array_0 (vector TYPE v, TYPE a)
+{
+  v[0] = a;
+  return v;
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+array_1 (vector TYPE v, TYPE a)
+{
+  v[1] = a;
+  return v;
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+array_01 (vector TYPE v, TYPE a, TYPE b)
+{
+  v[0] = a;
+  v[1] = b;
+  return v;
+}
+
+__attribute__((__noinline__))
+static vector TYPE
+array_01b (TYPE a, TYPE b)
+{
+  vector TYPE v = (vector TYPE) { 0, 0 };
+  v[0] = a;
+  v[1] = b;
+  return v;
+}
+#endif
+
+int
+main (void)
+{
+  vector TYPE a = (vector TYPE) { ONE,   TWO  };
+  vector TYPE b = (vector TYPE) { THREE, FOUR };
+  size_t i, j;
+
+#ifndef NO_ARRAY
+  vector TYPE z = (vector TYPE) { ZERO,  ZERO };
+#endif
+
+  DEBUG2 ("Endian: %s, type: %s\n", ENDIAN, STYPE);
+  DEBUG0 ("\nStatic/global initialization\n");
+  vector_check (s_v12, INIT_ORDER (1, 2));
+  vector_check (g_v34, INIT_ORDER (3, 4));
+
+  DEBUG0 ("\nVector via constant runtime intiialization\n");
+  vector_check (a, INIT_ORDER (1, 2));
+  vector_check (b, INIT_ORDER (3, 4));
+
+  DEBUG0 ("\nCombine scalars using vector initialization\n");
+  vector_check (combine (1, 2), INIT_ORDER (1, 2));
+  vector_check (combine (3, 4), INIT_ORDER (3, 4));
+
+  DEBUG0 ("\nSetup with vec_insert\n");
+  a = combine_insert (1, 2);
+  b = combine_insert (3, 4);
+  vector_check (a, ELEMENT_ORDER (1, 2));
+  vector_check (b, ELEMENT_ORDER (3, 4));
+
+#ifndef NO_ARRAY
+  DEBUG0 ("\nTesting array syntax\n");
+  vector_check (array_0   (a, FIVE),      ELEMENT_ORDER (5, 2));
+  vector_check (array_1   (b, SIX),       ELEMENT_ORDER (3, 6));
+  vector_check (array_01  (z, FIVE, SIX), ELEMENT_ORDER (5, 6));
+  vector_check (array_01b (FIVE, SIX),    ELEMENT_ORDER (5, 6));
+
+  vector_check (array_0   (a, five),      ELEMENT_ORDER (5, 2));
+  vector_check (array_1   (b, six),       ELEMENT_ORDER (3, 6));
+  vector_check (array_01  (z, five, six), ELEMENT_ORDER (5, 6));
+  vector_check (array_01b (five, six),    ELEMENT_ORDER (5, 6));
+#else
+  DEBUG0 ("\nSkipping array syntax on -maltivec=be\n");
+#endif
+
+  DEBUG0 ("\nTesting concat and extract\n");
+  vector_check (concat_extract_00 (a, b), INIT_ORDER (1, 3));
+  vector_check (concat_extract_01 (a, b), INIT_ORDER (1, 4));
+  vector_check (concat_extract_10 (a, b), INIT_ORDER (2, 3));
+  vector_check (concat_extract_11 (a, b), INIT_ORDER (2, 4));
+
+  DEBUG0 ("\nTesting concat and extract #2\n");
+  vector_check (concat_extract2_0s (a, FIVE), INIT_ORDER (1, 5));
+  vector_check (concat_extract2_1s (a, FIVE), INIT_ORDER (2, 5));
+  vector_check (concat_extract2_s0 (SIX, a),  INIT_ORDER (6, 1));
+  vector_check (concat_extract2_s1 (SIX, a),  INIT_ORDER (6, 2));
+
+  DEBUG0 ("\nTesting variable concat and extract\n");
+  for (i = 0; i < 2; i++)
+    {
+      for (j = 0; j < 2; j++)
+	{
+	  static struct {
+	    TYPE hi;
+	    TYPE lo;
+	  } hilo[2][2] =
+	      { { { ONE, THREE }, { ONE, FOUR } },
+		{ { TWO, THREE }, { TWO, FOUR } } };
+
+	  vector_check (concat_extract_nn (a, b, i, j),
+			INIT_ORDER (hilo[i][j].hi, hilo[i][j].lo));
+	}
+    }
+
+  DEBUG0 ("\nTesting separate function\n");
+  vector_check (combine (vec_extract (a, 0), vec_extract (b, 0)),
+		INIT_ORDER (1, 3));
+
+  vector_check (combine (vec_extract (a, 0), vec_extract (b, 1)),
+		INIT_ORDER (1, 4));
+
+  vector_check (combine (vec_extract (a, 1), vec_extract (b, 0)),
+		INIT_ORDER (2, 3));
+
+  vector_check (combine (vec_extract (a, 1), vec_extract (b, 1)),
+		INIT_ORDER (2, 4));
+
+  vector_check (combine_insert (vec_extract (a, 0), vec_extract (b, 0)),
+		ELEMENT_ORDER (1, 3));
+
+  vector_check (combine_insert (vec_extract (a, 0), vec_extract (b, 1)),
+		ELEMENT_ORDER (1, 4));
+
+  vector_check (combine_insert (vec_extract (a, 1), vec_extract (b, 0)),
+		ELEMENT_ORDER (2, 3));
+
+  vector_check (combine_insert (vec_extract (a, 1), vec_extract (b, 1)),
+		ELEMENT_ORDER (2, 4));
+
+
+#if defined(DO_DOUBLE)
+  DEBUG0 ("\nTesting explicit 2df concat\n");
+  vector_check (__builtin_vsx_concat_2df (FIVE, SIX), INIT_ORDER (5, 6));
+  vector_check (__builtin_vsx_concat_2df (five, six), INIT_ORDER (5, 6));
+
+#elif defined(_ARCH_PPC64)
+  DEBUG0 ("\nTesting explicit 2di concat\n");
+  vector_check (__builtin_vsx_concat_2di (FIVE, SIX), INIT_ORDER (5, 6));
+  vector_check (__builtin_vsx_concat_2di (five, six), INIT_ORDER (5, 6));
+
+#else
+  DEBUG0 ("\nSkip explicit 2di concat on 32-bit\n");
+#endif
+
+#ifdef DEBUG
+  if (errors)
+    printf ("\n%d error%s were found", errors, (errors == 1) ? "" : "s");
+  else
+    printf ("\nNo errors were found.\n");
+
+  return errors;
+
+#else
+  return 0;
+#endif
+}
Index: gcc/testsuite/gcc.target/powerpc/vec-setup-be-double.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/vec-setup-be-double.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/vec-setup-be-double.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,12 @@
+/* { dg-do run { target { powerpc*-*-linux* } } } */
+/* { dg-require-effective-target vsx_hw } */
+/* { dg-options "-O2 -mvsx" } */
+
+/* Test various ways of creating vectors with 2 double words and accessing the
+   elements.  This test uses the double datatype.
+
+   This test explicitly tests -maltivec=be to make sure things are correct.  */
+
+#define DO_DOUBLE
+
+#include "vec-setup.h"
Index: gcc/testsuite/gcc.target/powerpc/pr80695-p8.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/pr80695-p8.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/pr80695-p8.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,18 @@
+/* { dg-do compile { target { powerpc*-*-* } } } */
+/* { dg-skip-if "do not override -mcpu" { powerpc*-*-* } { "-mcpu=*" } { "-mcpu=power8" } } */
+/* { dg-require-effective-target vect_int } */
+/* { dg-options "-mcpu=power8 -O3 -fdump-tree-slp-details" } */
+
+/* PR80695: Verify cost model for vec_construct on POWER8.  */
+
+long a[10] __attribute__((aligned(16)));
+
+void foo (long i, long j, long k, long l)
+{
+  a[6] = i;
+  a[7] = j;
+  a[8] = k;
+  a[9] = l;
+}
+
+/* { dg-final { scan-tree-dump-times "vectorization is not profitable" 1 "slp2" } } */
Index: gcc/testsuite/gcc.target/powerpc/pr80695-p9.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/pr80695-p9.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/pr80695-p9.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,18 @@
+/* { dg-do compile { target { powerpc*-*-* } } } */
+/* { dg-skip-if "do not override -mcpu" { powerpc*-*-* } { "-mcpu=*" } { "-mcpu=power9" } } */
+/* { dg-require-effective-target vect_int } */
+/* { dg-options "-mcpu=power9 -O3 -fdump-tree-slp-details" } */
+
+/* PR80695: Verify cost model for vec_construct on POWER9.  */
+
+long a[10] __attribute__((aligned(16)));
+
+void foo (long i, long j, long k, long l)
+{
+  a[6] = i;
+  a[7] = j;
+  a[8] = k;
+  a[9] = l;
+}
+
+/* { dg-final { scan-tree-dump-times "vectorization is not profitable" 1 "slp2" } } */
Index: gcc/testsuite/gcc.target/powerpc/vsx-extract-6.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/vsx-extract-6.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/vsx-extract-6.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,25 @@
+/* { dg-do compile { target { powerpc*-*-* && lp64 } } } */
+/* { dg-skip-if "" { powerpc*-*-darwin* } } */
+/* { dg-require-effective-target powerpc_vsx_ok } */
+/* { dg-options "-O2 -mvsx" } */
+
+vector unsigned long
+test_vpasted (vector unsigned long high, vector unsigned long low)
+{
+  vector unsigned long res;
+  res[1] = high[1];
+  res[0] = low[0];
+  return res;
+}
+
+/* { dg-final { scan-assembler-times {\mxxpermdi\M} 1    } } */
+/* { dg-final { scan-assembler-not   {\mvspltisw\M}      } } */
+/* { dg-final { scan-assembler-not   {\mxxlor\M}         } } */
+/* { dg-final { scan-assembler-not   {\mxxlxor\M}        } } */
+/* { dg-final { scan-assembler-not   {\mxxspltib\M}      } } */
+/* { dg-final { scan-assembler-not   {\mlxvx?\M}         } } */
+/* { dg-final { scan-assembler-not   {\mlxv[dw][24]x\M}  } } */
+/* { dg-final { scan-assembler-not   {\mlvx\M}           } } */
+/* { dg-final { scan-assembler-not   {\mstxvx?\M}        } } */
+/* { dg-final { scan-assembler-not   {\mstxv[dw][24]x\M} } } */
+/* { dg-final { scan-assembler-not   {\mstvx\M}          } } */
Index: gcc/testsuite/gcc.target/powerpc/vsx-extract-7.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/vsx-extract-7.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/vsx-extract-7.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,25 @@
+/* { dg-do compile { target { powerpc*-*-* } } } */
+/* { dg-skip-if "" { powerpc*-*-darwin* } } */
+/* { dg-require-effective-target powerpc_vsx_ok } */
+/* { dg-options "-O2 -mvsx" } */
+
+vector double
+test_vpasted (vector double high, vector double low)
+{
+  vector double res;
+  res[1] = high[1];
+  res[0] = low[0];
+  return res;
+}
+
+/* { dg-final { scan-assembler-times {\mxxpermdi\M} 1    } } */
+/* { dg-final { scan-assembler-not   {\mvspltisw\M}      } } */
+/* { dg-final { scan-assembler-not   {\mxxlor\M}         } } */
+/* { dg-final { scan-assembler-not   {\mxxlxor\M}        } } */
+/* { dg-final { scan-assembler-not   {\mxxspltib\M}      } } */
+/* { dg-final { scan-assembler-not   {\mlxvx?\M}         } } */
+/* { dg-final { scan-assembler-not   {\mlxv[dw][24]x\M}  } } */
+/* { dg-final { scan-assembler-not   {\mlvx\M}           } } */
+/* { dg-final { scan-assembler-not   {\mstxvx?\M}        } } */
+/* { dg-final { scan-assembler-not   {\mstxv[dw][24]x\M} } } */
+/* { dg-final { scan-assembler-not   {\mstvx\M}          } } */
Index: gcc/testsuite/gcc.target/powerpc/pr80210.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/pr80210.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/pr80210.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,10 @@
+/* Test for ICE arising from GCC target pragma.  */
+/* { dg-do compile } */
+/* { dg-options "-O2" } */
+
+double
+foo (double a)
+{
+  return __builtin_sqrt (a);
+}
+#pragma GCC target "no-powerpc-gpopt"
Index: gcc/testsuite/gcc.target/powerpc/vec-setup-double.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/vec-setup-double.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/vec-setup-double.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,11 @@
+/* { dg-do run { target { powerpc*-*-linux* } } } */
+/* { dg-require-effective-target vsx_hw } */
+/* { dg-options "-O2 -mvsx" } */
+
+/* Test various ways of creating vectors with 2 double words and accessing the
+   elements.  This test uses the double datatype and the default endian
+   order.  */
+
+#define DO_DOUBLE
+
+#include "vec-setup.h"
Index: gcc/testsuite/gcc.target/powerpc/pr72804.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/pr72804.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/pr72804.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,25 @@
+/* { dg-do compile { target { lp64 } } } */
+/* { dg-skip-if "" { powerpc*-*-darwin* } } */
+/* { dg-require-effective-target powerpc_vsx_ok } */
+/* { dg-options "-O2 -mvsx" } */
+
+__int128_t
+foo (__int128_t *src)
+{
+  return ~*src;
+}
+
+void
+bar (__int128_t *dst, __int128_t src)
+{
+  *dst =  ~src;
+}
+
+/* { dg-final { scan-assembler-times "not " 4 } } */
+/* { dg-final { scan-assembler-times "std " 2 } } */
+/* { dg-final { scan-assembler-times "ld " 2 } } */
+/* { dg-final { scan-assembler-not "lxvd2x" } } */
+/* { dg-final { scan-assembler-not "stxvd2x" } } */
+/* { dg-final { scan-assembler-not "xxpermdi" } } */
+/* { dg-final { scan-assembler-not "mfvsrd" } } */
+/* { dg-final { scan-assembler-not "mfvsrd" } } */
Index: gcc/testsuite/gcc.target/powerpc/vec-setup-long.c
===================================================================
--- gcc/testsuite/gcc.target/powerpc/vec-setup-long.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/powerpc/vec-setup-long.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,9 @@
+/* { dg-do run { target { powerpc*-*-linux* } } } */
+/* { dg-require-effective-target vsx_hw } */
+/* { dg-options "-O2 -mvsx" } */
+
+/* Test various ways of creating vectors with 2 double words and accessing the
+   elements.  This test uses the long (on 64-bit systems) or long long datatype
+   (on 32-bit systems).  The default endian order is used.  */
+
+#include "vec-setup.h"
Index: gcc/testsuite/gcc.target/arm/peep-strd-1.c
===================================================================
--- gcc/testsuite/gcc.target/arm/peep-strd-1.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/arm/peep-strd-1.c	(.../branches/gcc-7-branch)
@@ -6,4 +6,4 @@
   p[2] = a;
   p[3] = b;
 }
-/* { dg-final { scan-assembler "strd" } } */
+/* { dg-final { scan-assembler "strd\\t" } } */
Index: gcc/testsuite/gcc.target/arm/peep-strd-2.c
===================================================================
--- gcc/testsuite/gcc.target/arm/peep-strd-2.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/peep-strd-2.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,9 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_prefer_ldrd_strd } */
+/* { dg-options "-O2 -mno-unaligned-access" }  */
+void foo(int a, int b, int* p)
+{
+  p[2] = a;
+  p[3] = b;
+}
+/* { dg-final { scan-assembler-not "strd\\t" } } */
Index: gcc/testsuite/gcc.target/arm/peep-ldrd-1.c
===================================================================
--- gcc/testsuite/gcc.target/arm/peep-ldrd-1.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/arm/peep-ldrd-1.c	(.../branches/gcc-7-branch)
@@ -8,4 +8,4 @@
   *p = a;
   return a;
 }
-/* { dg-final { scan-assembler "ldrd" } } */
+/* { dg-final { scan-assembler "ldrd\\t" } } */
Index: gcc/testsuite/gcc.target/arm/peep-ldrd-2.c
===================================================================
--- gcc/testsuite/gcc.target/arm/peep-ldrd-2.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/arm/peep-ldrd-2.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,11 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target arm_prefer_ldrd_strd } */
+/* { dg-options "-O2 -mno-unaligned-access" }  */
+int foo(int a, int b, int* p, int *q)
+{
+  a = p[2] + p[3];
+  *q = a;
+  *p = a;
+  return a;
+}
+/* { dg-final { scan-assembler-not "ldrd\\t" } } */
Index: gcc/testsuite/gcc.target/arm/lto/pr65837-attr_0.c
===================================================================
--- gcc/testsuite/gcc.target/arm/lto/pr65837-attr_0.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/arm/lto/pr65837-attr_0.c	(.../branches/gcc-7-branch)
@@ -1,6 +1,7 @@
 /* { dg-lto-do run } */
 /* { dg-require-effective-target arm_neon_hw } */
-/* { dg-lto-options {{-flto}} } */
+/* { dg-require-effective-target arm_neon_ok_no_float_abi } */
+/* { dg-lto-options {{-flto -mfpu=neon}} } */
 
 #include "arm_neon.h"
 
Index: gcc/testsuite/gcc.target/arm/lto/pr65837_0.c
===================================================================
--- gcc/testsuite/gcc.target/arm/lto/pr65837_0.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/arm/lto/pr65837_0.c	(.../branches/gcc-7-branch)
@@ -1,7 +1,7 @@
 /* { dg-lto-do run } */
 /* { dg-require-effective-target arm_neon_hw } */
+/* { dg-require-effective-target arm_neon_ok_no_float_abi } */
 /* { dg-lto-options {{-flto -mfpu=neon}} } */
-/* { dg-suppress-ld-options {-mfpu=neon} } */
 
 #include "arm_neon.h"
 
Index: gcc/testsuite/gcc.target/aarch64/pr71727-2.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/pr71727-2.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/pr71727-2.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,16 @@
+/* { dg-do compile } */
+/* { dg-options "-mstrict-align -O3" } */
+
+unsigned char foo(const unsigned char *buffer, unsigned int length)
+{
+  unsigned char sum;
+  unsigned int  count;
+
+  for (sum = 0, count = 0; count < length; count++) {
+    sum = (unsigned char) (sum + *(buffer + count));
+  }
+
+  return sum;
+}
+
+/* { dg-final { scan-assembler-times "and\tw\[0-9\]+, w\[0-9\]+, 15" 1 } } */
Index: gcc/testsuite/gcc.target/aarch64/pr80295.c
===================================================================
--- gcc/testsuite/gcc.target/aarch64/pr80295.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/aarch64/pr80295.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,8 @@
+/* { dg-do compile } */
+/* { dg-options "-mabi=ilp32" } */
+
+void f (void *b) 
+{ 
+  __builtin_update_setjmp_buf (b); 
+}
+
Index: gcc/testsuite/gcc.target/i386/pr81921.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr81921.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr81921.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,14 @@
+/* { dg-do compile } */
+/* { dg-require-effective-target lto } */
+/* { dg-options "-flto -march=x86-64" } */
+
+extern __inline int  __attribute__((__gnu_inline__, __always_inline__, __artificial__, target("sse2")))
+_mm_loadu_si128 (int const *__P)
+{
+    return *__P;
+}
+
+void __attribute__((target("ssse3"))) foo (void *p)
+{
+  volatile int x = _mm_loadu_si128 (p);
+}
Index: gcc/testsuite/gcc.target/i386/pr82556.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr82556.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr82556.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,19 @@
+/* { dg-do compile } */
+/* { dg-options "-O2 -fno-strict-aliasing -fwrapv -fexcess-precision=standard" } */
+extern int foo();
+typedef struct {
+  char id;
+  unsigned char fork_flags;
+  short data_length;
+} Header;
+int a;
+void X() {
+  do {
+    char* b;
+    Header c;
+    if (a)
+      c.fork_flags |= 1;
+    __builtin_memcpy(b, &c, __builtin_offsetof(Header, data_length));
+    b += foo();
+  } while (1);
+}
Index: gcc/testsuite/gcc.target/i386/pr81128.c
===================================================================
--- gcc/testsuite/gcc.target/i386/pr81128.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/pr81128.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,65 @@
+/* PR ipa/81128 */
+/* { dg-do run } */
+/* { dg-options "-O3" } */
+/* { dg-require-ifunc "" } */
+
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <time.h>
+
+int resolver_fn = 0;
+int resolved_fn = 0;
+
+static inline void
+do_it_right_at_runtime_A ()
+{
+  resolved_fn++;
+}
+
+static inline void
+do_it_right_at_runtime_B ()
+{
+  resolved_fn++;
+}
+
+static inline void do_it_right_at_runtime (void);
+
+void do_it_right_at_runtime (void)
+  __attribute__ ((ifunc ("resolve_do_it_right_at_runtime")));
+
+static void (*resolve_do_it_right_at_runtime (void)) (void)
+{
+  srand (time (NULL));
+  int r = rand ();
+  resolver_fn++;
+
+  /* Use intermediate variable to get a warning for non-matching
+   * prototype. */
+  typeof(do_it_right_at_runtime) *func;
+  if (r & 1)
+    func = do_it_right_at_runtime_A;
+  else
+    func = do_it_right_at_runtime_B;
+
+  return (void *) func;
+}
+
+int
+main (void)
+{
+  const unsigned int ITERS = 10;
+
+  for (int i = ITERS; i > 0; i--)
+    {
+      do_it_right_at_runtime ();
+    }
+
+  if (resolver_fn != 1)
+    __builtin_abort ();
+
+  if (resolved_fn != 10)
+    __builtin_abort ();
+
+  return 0;
+}
Index: gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-1-nov.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-1-nov.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-1-nov.c	(.../branches/gcc-7-branch)
@@ -25,7 +25,7 @@
 static __attribute__((always_inline)) int
 foo1 (int *p1, ...)
 {
-  return foo2 (10, p1, __va_arg_pack ());
+  return foo2 (10, p1, __builtin_va_arg_pack ());
 }
 
 int prebuf[100];
Index: gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-1-lbv.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-1-lbv.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-1-lbv.c	(.../branches/gcc-7-branch)
@@ -28,7 +28,7 @@
 static __attribute__((always_inline)) int
 foo1 (int *p1, ...)
 {
-  return foo2 (10, p1, __va_arg_pack ());
+  return foo2 (10, p1, __builtin_va_arg_pack ());
 }
 
 int prebuf[100];
Index: gcc/testsuite/gcc.target/i386/mpx/mpx-os-support.h
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/mpx-os-support.h	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.target/i386/mpx/mpx-os-support.h	(.../branches/gcc-7-branch)
@@ -0,0 +1,16 @@
+/* Check if the OS supports executing MPX instructions.  */
+
+#define XCR_XFEATURE_ENABLED_MASK	0x0
+
+#define XSTATE_BNDREGS	0x8
+
+static int
+mpx_os_support (void)
+{
+  unsigned int eax, edx;
+  unsigned int ecx = XCR_XFEATURE_ENABLED_MASK;
+
+  __asm__ ("xgetbv" : "=a" (eax), "=d" (edx) : "c" (ecx));
+
+  return (eax & XSTATE_BNDREGS) != 0;
+}
Index: gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-1-ubv.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-1-ubv.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-1-ubv.c	(.../branches/gcc-7-branch)
@@ -28,7 +28,7 @@
 static __attribute__((always_inline)) int
 foo1 (int *p1, ...)
 {
-  return foo2 (10, p1, __va_arg_pack ());
+  return foo2 (10, p1, __builtin_va_arg_pack ());
 }
 
 int prebuf[100];
Index: gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-2-nov.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-2-nov.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-2-nov.c	(.../branches/gcc-7-branch)
@@ -27,7 +27,7 @@
 static __attribute__((always_inline)) int
 foo1 (int *p1, ...)
 {
-  return foo2 (10, p1, __va_arg_pack ());
+  return foo2 (10, p1, __builtin_va_arg_pack ());
 }
 
 int prebuf[100];
Index: gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-2-lbv.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-2-lbv.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-2-lbv.c	(.../branches/gcc-7-branch)
@@ -30,7 +30,7 @@
 static __attribute__((always_inline)) int
 foo1 (int *p1, ...)
 {
-  return foo2 (10, p1, __va_arg_pack ());
+  return foo2 (10, p1, __builtin_va_arg_pack ());
 }
 
 int prebuf[100];
Index: gcc/testsuite/gcc.target/i386/mpx/mpx-check.h
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/mpx-check.h	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/i386/mpx/mpx-check.h	(.../branches/gcc-7-branch)
@@ -1,8 +1,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
-
 #include "cpuid.h"
+#include "mpx-os-support.h"
 
 static int
 __attribute__ ((noinline))
@@ -16,14 +16,13 @@
 
 #define DEBUG
 
-#define XSTATE_BNDREGS (1 << 3)
+static int
+check_osxsave (void)
+{
+  unsigned int eax, ebx, ecx, edx;
 
-/* This should be an intrinsic, but isn't.  */
-static int xgetbv (unsigned x)
-{
-   unsigned eax, edx;
-   asm ("xgetbv" : "=a" (eax), "=d" (edx) : "c" (x)); 
-   return eax;
+  __cpuid (1, eax, ebx, ecx, edx);
+  return (ecx & bit_OSXSAVE) != 0;
 }
 
 int
@@ -31,13 +30,11 @@
 {
   unsigned int eax, ebx, ecx, edx;
 
-  if (__get_cpuid_max (0, NULL) < 7)
-    return 0;
+  if (!__get_cpuid_count (7, 0, &eax, &ebx, &ecx, &edx))
+    return NORUNRES;
 
-  __cpuid_count (7, 0, eax, ebx, ecx, edx);
-
   /* Run MPX test only if host has MPX support.  */
-  if ((ebx & bit_MPX) && (xgetbv (0) & XSTATE_BNDREGS))
+  if (check_osxsave () && (ebx & bit_MPX) && mpx_os_support ())
     mpx_test (argc, argv);
   else
     {
Index: gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-2-ubv.c
===================================================================
--- gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-2-ubv.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.target/i386/mpx/va-arg-pack-2-ubv.c	(.../branches/gcc-7-branch)
@@ -30,7 +30,7 @@
 static __attribute__((always_inline)) int
 foo1 (int *p1, ...)
 {
-  return foo2 (10, p1, __va_arg_pack ());
+  return foo2 (10, p1, __builtin_va_arg_pack ());
 }
 
 int prebuf[100];
Index: gcc/testsuite/go.test/go-test.exp
===================================================================
--- gcc/testsuite/go.test/go-test.exp	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/go.test/go-test.exp	(.../branches/gcc-7-branch)
@@ -213,29 +213,27 @@
 		#error FOO
 		#endif
 	    }] {
-		set goarch "mipso32"
+		set goarch "mips"
 	    } elseif [check_no_compiler_messages mipsn32 assembly {
 		#if _MIPS_SIM != _ABIN32
 		#error FOO
 		#endif
 	    }] {
-		set goarch "mipsn32"
+		set goarch "mips64p32"
 	    } elseif [check_no_compiler_messages mipsn64 assembly {
 		#if _MIPS_SIM != _ABI64
 		#error FOO
 		#endif
 	    }] {
-		set goarch "mipsn64"
-	    } elseif [check_no_compiler_messages mipso64 assembly {
-		#if _MIPS_SIM != _ABIO64
-		#error FOO
-		#endif
-	    }] {
-		set goarch "mipso64"
+		set goarch "mips64"
 	    } else {
 		perror "$target_triplet: unrecognized MIPS ABI"
 		return ""
 	    }
+
+	    if [istarget "mips*el-*-*"] {
+		append goarch "le"
+	    }
 	}
 	"powerpc*-*-*" {
 	    if [check_effective_target_ilp32] {
Index: gcc/testsuite/lib/target-supports.exp
===================================================================
--- gcc/testsuite/lib/target-supports.exp	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/lib/target-supports.exp	(.../branches/gcc-7-branch)
@@ -1777,6 +1777,7 @@
 	    expr 0
 	} else {
 	    check_runtime_nocache avx2_hw_available {
+		#include <stddef.h>
 		#include "cpuid.h"
 		int main ()
 		{
@@ -3427,8 +3428,9 @@
     global et_arm_neon_flags
     set et_arm_neon_flags ""
     if { [check_effective_target_arm32] } {
-	foreach flags {"" "-mfloat-abi=softfp" "-mfpu=neon" "-mfpu=neon -mfloat-abi=softfp" "-mfpu=neon -mfloat-abi=softfp -march=armv7-a"} {
+	foreach flags {"" "-mfloat-abi=softfp" "-mfpu=neon" "-mfpu=neon -mfloat-abi=softfp" "-mfpu=neon -mfloat-abi=softfp -march=armv7-a" "-mfloat-abi=hard" "-mfpu=neon -mfloat-abi=hard" "-mfpu=neon -mfloat-abi=hard -march=armv7-a"} {
 	    if { [check_no_compiler_messages_nocache arm_neon_ok object {
+		#include <arm_neon.h>
 		int dummy;
 		#ifndef __ARM_NEON__
 		#error not NEON
@@ -3453,6 +3455,38 @@
 		check_effective_target_arm_neon_ok_nocache]
 }
 
+# Return 1 if this is an ARM target supporting -mfpu=neon without any
+# -mfloat-abi= option.  Useful in tests where add_options is not
+# supported (such as lto tests).
+
+proc check_effective_target_arm_neon_ok_no_float_abi_nocache { } {
+    if { [check_effective_target_arm32] } {
+	foreach flags {"-mfpu=neon"} {
+	    if { [check_no_compiler_messages_nocache arm_neon_ok_no_float_abi object {
+		#include <arm_neon.h>
+		int dummy;
+		#ifndef __ARM_NEON__
+		#error not NEON
+		#endif
+		/* Avoid the case where a test adds -mfpu=neon, but the toolchain is
+		   configured for -mcpu=arm926ej-s, for example.  */
+		#if __ARM_ARCH < 7 || __ARM_ARCH_PROFILE == 'M'
+		#error Architecture does not support NEON.
+		#endif
+	    } "$flags"] } {
+		return 1
+	    }
+	}
+    }
+
+    return 0
+}
+
+proc check_effective_target_arm_neon_ok_no_float_abi { } {
+    return [check_cached_effective_target arm_neon_ok_no_float_abi \
+		check_effective_target_arm_neon_ok_no_float_abi_nocache]
+}
+
 proc check_effective_target_arm_crc_ok_nocache { } {
     global et_arm_crc_flags
     set et_arm_crc_flags "-march=armv8-a+crc"
@@ -5764,7 +5798,7 @@
 	  set et_vect_hw_misalign_saved($et_index) 1
 	}
 	if { [istarget arm*-*-*] } {
-	    set et_vect_hw_misalign_saved($et_index) [check_effective_target_arm_vect_no_misalign]
+	    set et_vect_hw_misalign_saved($et_index) [expr ![check_effective_target_arm_vect_no_misalign]]
 	}
     }
     verbose "check_effective_target_vect_hw_misalign:\
Index: gcc/testsuite/gfortran.dg/class_64.f90
===================================================================
--- gcc/testsuite/gfortran.dg/class_64.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/class_64.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,38 @@
+! { dg-do compile }
+! { dg-options "-fdump-tree-original" }
+!
+! Test the fix for PR80850 in which the _len field was not being
+! set for 'arg' in the call to 'foo'.
+!
+  type :: mytype
+    integer :: i
+  end type
+  class (mytype), pointer :: c
+
+  allocate (c, source = mytype (99_8))
+
+  call foo(c)
+  call bar(c)
+
+  deallocate (c)
+
+contains
+
+  subroutine foo (arg)
+    class(*) :: arg
+    select type (arg)
+      type is (mytype)
+        if (arg%i .ne. 99_8) call abort
+    end select
+  end subroutine
+
+  subroutine bar (arg)
+    class(mytype) :: arg
+    select type (arg)
+      type is (mytype)
+        if (arg%i .ne. 99_8) call abort
+    end select
+  end subroutine
+
+end
+! { dg-final { scan-tree-dump-times "arg.*._len" 1 "original" } }
Index: gcc/testsuite/gfortran.dg/auto_dealloc_1.f90
===================================================================
--- gcc/testsuite/gfortran.dg/auto_dealloc_1.f90	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/auto_dealloc_1.f90	(.../branches/gcc-7-branch)
@@ -50,7 +50,7 @@
     m%k%i = 45
   end subroutine
 
-end module 
+end module
 
 
-! { dg-final { scan-tree-dump-times "__builtin_free" 4 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_free" 10 "original" } }
Index: gcc/testsuite/gfortran.dg/equiv_pure.f90
===================================================================
--- gcc/testsuite/gfortran.dg/equiv_pure.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/equiv_pure.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,50 @@
+! { dg-do compile }
+module eq
+   implicit none
+   integer :: n1, n2
+   integer, dimension(2) :: a
+   equivalence (a(1), n1)
+   equivalence (a(2), n2)
+   common /a/ a
+end module eq
+
+module m
+   use eq
+   implicit none
+   type, public :: t
+     integer :: i
+   end type t
+end module m
+
+module p
+   implicit none
+   contains
+   pure integer function d(h)
+     use m
+     implicit none
+     integer, intent(in) :: h
+     d = h
+   end function
+end module p
+
+module q
+   implicit none
+   contains
+   pure integer function d(h)
+     use m, only : t
+     implicit none
+     integer, intent(in) :: h
+     d = h
+   end function
+end module q
+
+module r
+   implicit none
+   contains
+   pure integer function d(h)
+     use m, only : a          ! { dg-error "cannot be an EQUIVALENCE object" }
+     implicit none
+     integer, intent(in) :: h
+     d = h
+   end function
+end module r
Index: gcc/testsuite/gfortran.dg/dtio_12.f90
===================================================================
--- gcc/testsuite/gfortran.dg/dtio_12.f90	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/dtio_12.f90	(.../branches/gcc-7-branch)
@@ -70,5 +70,11 @@
   rewind (10)
   read (10, *) msg
   if (trim (msg) .ne. "77") call abort
+  rewind (10)
+  write (10,40) child (77)                         ! Modified using format label
+40 format(DT)
+  rewind (10)
+  read (10, *) msg
+  if (trim (msg) .ne. "77") call abort
   close(10)
 end
Index: gcc/testsuite/gfortran.dg/associate_26.f90
===================================================================
--- gcc/testsuite/gfortran.dg/associate_26.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/associate_26.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,15 @@
+! { dg-do compile }
+! { dg-options "-fcoarray=single" }
+!
+! Test the fix for PR78152
+!
+! Contributed by <physiker@toast2.net>
+!
+program co_assoc
+  implicit none
+  integer, parameter :: p = 5
+  real, allocatable :: a(:,:)[:,:]
+  allocate (a(p,p)[2,*])
+    associate (i => a(1:p, 1:p))
+  end associate
+end program co_assoc
Index: gcc/testsuite/gfortran.dg/warn_target_lifetime_3.f90
===================================================================
--- gcc/testsuite/gfortran.dg/warn_target_lifetime_3.f90	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/warn_target_lifetime_3.f90	(.../branches/gcc-7-branch)
@@ -3,7 +3,7 @@
 !
 ! PR fortran/55476
 !
-! Contribued by  Janus Weil
+! Contributed by Janus Weil
 !
 subroutine test
   integer, pointer :: p
Index: gcc/testsuite/gfortran.dg/class_63.f90
===================================================================
--- gcc/testsuite/gfortran.dg/class_63.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/class_63.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,80 @@
+! { dg-do run }
+!
+! Tests the fix for PR81758, in which the vpointer for 'ptr' in
+! function 'pointer_value' would be set to the vtable of the component
+! 'container' rather than that of the component 'vec_elem'. In this test
+! case it is ensured that there is a single typebound procedure for both
+! types, so that different values are returned. In the original problem
+! completely different procedures were involved so that a segfault resulted.
+!
+! Reduced from the original code of Dimitry Liakh  <liakhdi@ornl.gov> by
+!                                   Paul Thomas  <pault@gcc.gnu.org>
+!
+module types
+  type, public:: gfc_container_t
+  contains
+    procedure, public:: get_value => ContTypeGetValue
+  end type gfc_container_t
+
+  !Element of a container:
+  type, public:: gfc_cont_elem_t
+    integer :: value_p
+  contains
+    procedure, public:: get_value => ContElemGetValue
+  end type gfc_cont_elem_t
+
+  !Vector element:
+  type, extends(gfc_cont_elem_t), public:: vector_elem_t
+  end type vector_elem_t
+
+  !Vector:
+  type, extends(gfc_container_t), public:: vector_t
+    type(vector_elem_t), allocatable, private :: vec_elem
+  end type vector_t
+
+  type, public :: vector_iter_t
+    class(vector_t), pointer, private :: container => NULL()
+  contains
+    procedure, public:: get_vector_value => vector_Value
+    procedure, public:: get_pointer_value => pointer_value
+  end type
+
+contains
+  integer function ContElemGetValue (this)
+    class(gfc_cont_elem_t) :: this
+    ContElemGetValue = this%value_p
+  end function
+
+  integer function ContTypeGetValue (this)
+    class(gfc_container_t) :: this
+    ContTypeGetValue = 0
+  end function
+
+  integer function vector_Value (this)
+    class(vector_iter_t) :: this
+    vector_value = this%container%vec_elem%get_value()
+  end function
+
+  integer function pointer_value (this)
+    class(vector_iter_t), target :: this
+    class(gfc_cont_elem_t), pointer :: ptr
+    ptr => this%container%vec_elem
+    pointer_value = ptr%get_value()
+  end function
+
+  subroutine factory (arg)
+    class (vector_iter_t), pointer :: arg
+    allocate (vector_iter_t :: arg)
+    allocate (vector_t :: arg%container)
+    allocate (arg%container%vec_elem)
+    arg%container%vec_elem%value_p = 99
+  end subroutine
+end module
+
+  use types
+  class (vector_iter_t), pointer :: x
+
+  call factory (x)
+  if (x%get_vector_value() .ne. 99) call abort
+  if (x%get_pointer_value() .ne. 99) call abort
+end
Index: gcc/testsuite/gfortran.dg/typebound_proc_27.f03
===================================================================
--- gcc/testsuite/gfortran.dg/typebound_proc_27.f03	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/typebound_proc_27.f03	(.../branches/gcc-7-branch)
@@ -1,6 +1,6 @@
 ! { dg-do run }
 ! { dg-options "-fdump-tree-original" }
-! 
+!
 ! PR fortran/47586
 ! Missing deep copy for data pointer returning functions when the type
 ! has allocatable components
@@ -77,15 +77,15 @@
 ! statements.
 ! It is assumed that if the number of allocate is right, the number of
 ! deep copies is right too.
-! { dg-final { scan-tree-dump-times "__builtin_malloc" 12 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_malloc" 15 "original" } }
 
 !
 ! Realloc are only used for assignments to `that%i'.  Don't know why.
 ! { dg-final { scan-tree-dump-times "__builtin_realloc" 6 "original" } }
-! 
+!
 
 ! No leak: Only assignments to `this' use malloc.  Assignments to `that%i'
 ! take the realloc path after the first assignment, so don't count as a malloc.
-! { dg-final { scan-tree-dump-times "__builtin_free" 7 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_free" 10 "original" } }
 !
 
Index: gcc/testsuite/gfortran.dg/assumed_size_2.f90
===================================================================
--- gcc/testsuite/gfortran.dg/assumed_size_2.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/assumed_size_2.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,4 @@
+! { dg-do compile }
+subroutine foo(a)
+  dimension  a(*,*) ! { dg-error "Bad specification for assumed size array" }
+end
Index: gcc/testsuite/gfortran.dg/pr81735.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr81735.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/pr81735.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,25 @@
+! { dg-do compile }
+! { dg-options "-fdump-tree-original" }
+!
+! Contributed by Danila  <flashmozzg@gmail.com>
+!
+program fooprog
+    implicit none
+    type FooType
+        integer, allocatable :: x
+    end type FooType
+
+    type(FooType), pointer :: bar
+
+    bar => foo()
+
+contains
+    function foo() result(res)
+        type(FooType), pointer :: res
+
+        character(:), allocatable :: rt
+        rt = ""
+        res => null()
+    end function foo
+end program fooprog
+! { dg-final { scan-tree-dump-times "__builtin_free" 1 "original" } }
Index: gcc/testsuite/gfortran.dg/associate_29.f90
===================================================================
--- gcc/testsuite/gfortran.dg/associate_29.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/associate_29.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,30 @@
+! { dg-do compile }
+!
+! Test the fix for PR82121
+!
+! Contributed by Iain Miller  <iain.miller@ecmwf.int>
+!
+MODULE YOMCDDH
+  IMPLICIT NONE
+  SAVE
+  TYPE :: TCDDH
+    CHARACTER(len=12),ALLOCATABLE :: CADHTLS(:)
+  END TYPE TCDDH
+  CHARACTER(len=12),ALLOCATABLE :: CADHTTS(:)
+  TYPE(TCDDH), POINTER :: YRCDDH => NULL()
+END MODULE YOMCDDH
+
+
+SUBROUTINE SUCDDH()
+  USE YOMCDDH  , ONLY : YRCDDH,CADHTTS
+  IMPLICIT NONE
+  ALLOCATE (YRCDDH%CADHTLS(20))
+  ALLOCATE (CADHTTS(20))
+  ASSOCIATE(CADHTLS=>YRCDDH%CADHTLS, NORMCHAR=>CADHTTS)
+! Direct reference to character array compiled correctly
+!    YRCDDH%CADHTLS(1)='SVGTLF'
+! Reference to associated variable name failed to compile
+    CADHTLS(2)='SVGTLT'
+    NORMCHAR(1)='SVLTTC'
+  END ASSOCIATE
+END SUBROUTINE SUCDDH
Index: gcc/testsuite/gfortran.dg/class_66.f90
===================================================================
--- gcc/testsuite/gfortran.dg/class_66.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/class_66.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,28 @@
+! { dg- do run }
+!
+! Test the fix for PR78641 in which an ICE occured on assignment
+! of a class array constructor to a derived type array.
+!
+! Contributed by Damian Rouson  <damian@sourceryinstitute.org>
+!
+  implicit none
+  type foo
+    integer :: i = 99
+  end type
+  type(foo) :: bar(4)
+  class(foo), allocatable :: barfoo
+
+  allocate(barfoo,source = f(11))
+  bar = [f(33), [f(22), barfoo], f(1)]
+  if (any (bar%i .ne. [33, 22, 11, 1])) call abort
+  deallocate (barfoo)
+
+contains
+
+  function f(arg) result(foobar)
+    class(foo), allocatable :: foobar
+    integer :: arg
+    allocate(foobar,source = foo(arg))
+  end function
+
+end program
Index: gcc/testsuite/gfortran.dg/array_temporaries_4.f90
===================================================================
--- gcc/testsuite/gfortran.dg/array_temporaries_4.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/array_temporaries_4.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,59 @@
+! { dg-do compile }
+! { dg-options "-Warray-temporaries" }
+! Tests the fix for PR80164, in which the compiler segfaulted on this
+! when using -Warray-temporaries
+!
+!******************************************************************************
+module global
+  type :: a
+    integer :: b
+    character(8):: c
+  end type a
+  interface assignment(=)
+    module procedure a_to_a, c_to_a, a_to_c
+  end interface
+  interface operator(.ne.)
+    module procedure a_ne_a
+  end interface
+
+  type(a) :: x(4), y(4)
+  logical :: l1(4), t = .true., f= .false.
+contains
+!******************************************************************************
+  elemental subroutine a_to_a (m, n)
+    type(a), intent(in) :: n
+    type(a), intent(out) :: m
+    m%b = len ( trim(n%c))
+    m%c = n%c
+  end subroutine a_to_a
+  elemental subroutine c_to_a (m, n)
+    character(8), intent(in) :: n
+    type(a), intent(out) :: m
+    m%b = m%b + 1
+    m%c = n
+  end subroutine c_to_a
+  elemental subroutine a_to_c (m, n)
+    type(a), intent(in) :: n
+    character(8), intent(out) :: m
+    m = n%c
+  end subroutine a_to_c
+!******************************************************************************
+  elemental logical function a_ne_a (m, n)
+    type(a), intent(in) :: n
+    type(a), intent(in) :: m
+    a_ne_a = (m%b .ne. n%b) .or. (m%c .ne. n%c)
+  end function a_ne_a
+!******************************************************************************
+  elemental function foo (m)
+    type(a) :: foo
+    type(a), intent(in) :: m
+    foo%b = 0
+    foo%c = m%c
+  end function foo  
+end module global
+!******************************************************************************
+program test
+  use global
+  x = (/a (0, "one"),a (0, "two"),a (0, "three"),a (0, "four")/) ! { dg-warning "Creating array temporary" }
+  y = x
+end program test 
Index: gcc/testsuite/gfortran.dg/submodule_29.f08
===================================================================
--- gcc/testsuite/gfortran.dg/submodule_29.f08	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/submodule_29.f08	(.../branches/gcc-7-branch)
@@ -0,0 +1,56 @@
+! { dg-do run }
+!
+! Test the fix for PR80554 in which it was not recognised that the symbol 'i'
+! is host associated in the submodule 's' so that the new declaration in the
+! submodule was rejected.
+!
+! Contributed by Tamas Bela Feher  <tamas.bela.feher@ipp.mpg.de>
+!
+module M
+  implicit none
+  integer :: i = 0
+  character (100) :: buffer
+  interface
+    module subroutine write_i()
+    end subroutine
+  end interface
+  interface
+    module subroutine write_i_2()
+    end subroutine
+  end interface
+contains
+  subroutine foo
+    integer :: i
+  end
+end module
+
+submodule (M) S
+    integer :: i = 137
+  contains
+    module subroutine write_i()
+       write (buffer,*) i
+    end subroutine
+end submodule
+
+submodule (M:S) S2
+    integer :: i = 1037
+  contains
+    module subroutine write_i_2()
+       write (buffer,*) i
+    end subroutine
+end submodule
+
+program test_submod_variable
+  use M
+  implicit none
+  integer :: j
+  i = 42
+  call write_i
+  read (buffer, *) j
+  if (i .ne. 42) call abort
+  if (j .ne. 137) call abort
+  call write_i_2
+  read (buffer, *) j
+  if (i .ne. 42) call abort
+  if (j .ne. 1037) call abort
+end program
Index: gcc/testsuite/gfortran.dg/associate_9.f03
===================================================================
--- gcc/testsuite/gfortran.dg/associate_9.f03	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/associate_9.f03	(.../branches/gcc-7-branch)
@@ -1,8 +1,6 @@
 ! { dg-do compile }
 ! { dg-options "-std=f2003 -fall-intrinsics" }
 
-! FIXME: Change into run test and remove excess error expectation.
-
 ! PR fortran/38936
 ! Association to derived-type, where the target type is not know
 ! during parsing (only resolution).
@@ -46,5 +44,3 @@
     IF (x%comp /= 10) CALL abort ()
   END ASSOCIATE
 END PROGRAM main
-
-! { dg-excess-errors "Syntex error in IF" }
Index: gcc/testsuite/gfortran.dg/finalize_28.f90
===================================================================
--- gcc/testsuite/gfortran.dg/finalize_28.f90	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/finalize_28.f90	(.../branches/gcc-7-branch)
@@ -21,4 +21,4 @@
     integer, intent(out) :: edges(:,:)
   end subroutine coo_dump_edges
 end module coo_graphs
-! { dg-final { scan-tree-dump-times "__builtin_free" 3 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_free" 6 "original" } }
Index: gcc/testsuite/gfortran.dg/pr69739.f90
===================================================================
--- gcc/testsuite/gfortran.dg/pr69739.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/pr69739.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,39 @@
+! { dg-do run }
+!
+! Test the fix for PR69739 in which the statement
+! R = operate(A, X) caused an ICE.
+!
+! Contributed by John  <jwmwalrus@gmail.com>
+!
+module test
+
+  implicit none
+  type, public :: sometype
+    real :: a    =  0.
+  end type
+contains
+
+  function dosomething(A) result(r)
+    type(sometype), intent(IN) :: A(:,:,:)
+    integer :: N
+    real, allocatable ::   R(:), X(:)
+
+    N = PRODUCT(UBOUND(A))
+    allocate (R(N),X(N))
+    X = [(real(N), N = 1, size(X, 1))]
+    R = operate(A, X)
+  end function
+
+  function operate(A, X)
+    type(sometype), intent(IN) :: A(:,:,:)
+    real, intent(IN) :: X(:)
+    real :: operate(1:PRODUCT(UBOUND(A)))
+
+    operate = x
+  end function
+end module test
+
+  use test
+  type(sometype) :: a(2, 2, 2)
+  if (any(int (dosomething(a)) .ne. [1,2,3,4,5,6])) call abort
+end
Index: gcc/testsuite/gfortran.dg/associate_28.f90
===================================================================
--- gcc/testsuite/gfortran.dg/associate_28.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/associate_28.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,64 @@
+! { dg-do run }
+!
+! Test the fix for PR81903
+!
+! Contributed by Karl May  <karl.may0@freenet.de>
+!
+Module TestMod_A
+  Type :: TestType_A
+    Real, Allocatable :: a(:,:)
+  End type TestType_A
+End Module TestMod_A
+Module TestMod_B
+  Type :: TestType_B
+   Real, Pointer, contiguous :: a(:,:)
+  End type TestType_B
+End Module TestMod_B
+Module TestMod_C
+  use TestMod_A
+  use TestMod_B
+  Implicit None
+  Type :: TestType_C
+    Class(TestType_A), Pointer :: TT_A(:)
+    Type(TestType_B), Allocatable :: TT_B(:)
+  contains
+    Procedure, Pass :: SetPt => SubSetPt
+  End type TestType_C
+  Interface
+    Module Subroutine SubSetPt(this)
+      class(TestType_C), Intent(InOut), Target :: this
+    End Subroutine
+  End Interface
+End Module TestMod_C
+Submodule(TestMod_C) SetPt
+contains
+  Module Procedure SubSetPt
+    Implicit None
+    integer :: i
+    integer :: sum_a = 0
+    outer:block
+      associate(x=>this%TT_B,y=>this%TT_A)
+        Do i=1,size(x)
+          x(i)%a=>y(i)%a
+          sum_a = sum_a + sum (int (x(i)%a))
+        End Do
+      end associate
+    End block outer
+    if (sum_a .ne. 30) call abort
+  End Procedure
+End Submodule SetPt
+Program Test
+  use TestMod_C
+  use TestMod_A
+  Implicit None
+  Type(TestType_C) :: tb
+  Type(TestType_A), allocatable, Target :: ta(:)
+  integer :: i
+  real :: src(2,2) = reshape ([(real(i), i = 1,4)],[2,2])
+  allocate(ta(2),tb%tt_b(2))
+  do i=1,size(ta)
+    allocate(ta(i)%a(2,2), source = src*real(i))
+  End do
+  tb%TT_A=>ta
+  call tb%setpt()
+End Program Test
Index: gcc/testsuite/gfortran.dg/class_65.f90
===================================================================
--- gcc/testsuite/gfortran.dg/class_65.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/class_65.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,41 @@
+! { dg-do run }
+!
+! Test the fix for PR81447 in which a vtable was not being created
+! in the module 'm' so that x->vptr in 's' did not have the same
+! value as that in 'p'.
+!
+! Contributed by Mat Cross  <mathewc@nag.co.uk>
+!
+Module m
+  Type :: t
+    integer :: i
+  End Type
+End Module
+
+Program p
+  Use m
+  Class (t), Allocatable :: x
+  Interface
+    Subroutine s(x)
+      Use m
+      Class (t), Allocatable :: x
+    End Subroutine
+  End Interface
+  Call s(x)
+  Select Type (x)
+  Type Is (t)
+    Continue
+  Class Is (t)
+    call abort
+  Class Default
+    call abort
+  End Select
+!  Print *, 'ok'
+End Program
+
+Subroutine s(x)
+  Use m, Only: t
+  Implicit None
+  Class (t), Allocatable :: x
+  Allocate (t :: x)
+End Subroutine
Index: gcc/testsuite/gfortran.dg/coarray_lib_realloc_1.f90
===================================================================
--- gcc/testsuite/gfortran.dg/coarray_lib_realloc_1.f90	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/coarray_lib_realloc_1.f90	(.../branches/gcc-7-branch)
@@ -21,14 +21,14 @@
 end
 
 ! For comp%ii: End of scope of x + y (2x) and for the LHS of the assignment (1x)
-! { dg-final { scan-tree-dump-times "__builtin_free" 3 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_free" 6 "original" } }
 
 ! For comp%CAF:  End of scope of x + y (2x); no LHS freeing for the CAF in assignment
-! { dg-final { scan-tree-dump-times "_gfortran_caf_deregister" 2 "original" } }
+! { dg-final { scan-tree-dump-times "_gfortran_caf_deregister" 3 "original" } }
 
 ! Only malloc "ii":
-! { dg-final { scan-tree-dump-times "__builtin_malloc" 1 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_malloc" 4 "original" } }
 
 ! But copy "ii" and "CAF":
-! { dg-final { scan-tree-dump-times "__builtin_memcpy|= MEM" 2 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_memcpy|= MEM" 5 "original" } }
 
Index: gcc/testsuite/gfortran.dg/zero_sized_7.f90
===================================================================
--- gcc/testsuite/gfortran.dg/zero_sized_7.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/zero_sized_7.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,18 @@
+! { dg-do compile }
+! PR 80118 - this used to ICE
+! Original test case by Marco Restelli
+module m
+implicit none
+
+  integer, parameter :: not_empty(1) = 0
+  integer, parameter :: empty1(0) = (/integer :: /)
+  integer, parameter :: empty2(0) = 0
+
+contains
+
+ subroutine sub(v)
+  integer, allocatable, intent(out) :: v(:)
+   v = 2*empty2 ! internal compiler error
+ end subroutine sub
+
+end module m
Index: gcc/testsuite/gfortran.dg/coarray/send_char_array_1.f90
===================================================================
--- gcc/testsuite/gfortran.dg/coarray/send_char_array_1.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/coarray/send_char_array_1.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,54 @@
+!{ dg-do run }
+ 
+program send_convert_char_array
+
+  implicit none
+
+  character(kind=1, len=:), allocatable, codimension[:] :: co_str_k1_scal
+  character(kind=1, len=:), allocatable :: str_k1_scal
+  character(kind=4, len=:), allocatable, codimension[:] :: co_str_k4_scal
+  character(kind=4, len=:), allocatable :: str_k4_scal
+
+  character(kind=1, len=:), allocatable, codimension[:] :: co_str_k1_arr(:)
+  character(kind=1, len=:), allocatable :: str_k1_arr(:)
+  character(kind=4, len=:), allocatable, codimension[:] :: co_str_k4_arr(:)
+  character(kind=4, len=:), allocatable :: str_k4_arr(:)
+
+  allocate(str_k1_scal, SOURCE='abcdefghij')
+  allocate(str_k4_scal, SOURCE=4_'abcdefghij')
+  allocate(character(len=20)::co_str_k1_scal[*]) ! allocate syncs here
+  allocate(character(kind=4, len=20)::co_str_k4_scal[*]) ! allocate syncs here
+
+  allocate(str_k1_arr, SOURCE=['abc', 'EFG', 'klm', 'NOP'])
+  allocate(str_k4_arr, SOURCE=[4_'abc', 4_'EFG', 4_'klm', 4_'NOP'])
+  allocate(character(len=5)::co_str_k1_arr(4)[*])
+  allocate(character(kind=4, len=5)::co_str_k4_arr(4)[*])
+
+  ! First check send/copy to self
+  co_str_k1_scal[1] = str_k1_scal
+  if (co_str_k1_scal /= str_k1_scal // '          ') call abort()
+
+  co_str_k4_scal[1] = str_k4_scal
+  if (co_str_k4_scal /= str_k4_scal // 4_'          ') call abort()
+
+  co_str_k4_scal[1] = str_k1_scal
+  if (co_str_k4_scal /= str_k4_scal // 4_'          ') call abort()
+
+  co_str_k1_scal[1] = str_k4_scal
+  if (co_str_k1_scal /= str_k1_scal // '          ') call abort()
+
+  co_str_k1_arr(:)[1] = str_k1_arr
+  if (any(co_str_k1_arr /= ['abc  ', 'EFG  ', 'klm  ', 'NOP  '])) call abort()
+ 
+  co_str_k4_arr(:)[1] = [4_'abc', 4_'EFG', 4_'klm', 4_'NOP']! str_k4_arr
+  if (any(co_str_k4_arr /= [4_'abc  ', 4_'EFG  ', 4_'klm  ', 4_'NOP  '])) call abort()
+
+  co_str_k4_arr(:)[1] = str_k1_arr
+  if (any(co_str_k4_arr /= [ 4_'abc  ', 4_'EFG  ', 4_'klm  ', 4_'NOP  '])) call abort()
+
+  co_str_k1_arr(:)[1] = str_k4_arr
+  if (any(co_str_k1_arr /= ['abc  ', 'EFG  ', 'klm  ', 'NOP  '])) call abort()
+
+end program send_convert_char_array
+
+! vim:ts=2:sts=2:sw=2:
Index: gcc/testsuite/gfortran.dg/alloc_comp_basics_1.f90
===================================================================
--- gcc/testsuite/gfortran.dg/alloc_comp_basics_1.f90	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/alloc_comp_basics_1.f90	(.../branches/gcc-7-branch)
@@ -141,4 +141,4 @@
     end subroutine check_alloc2
 
 end program alloc
-! { dg-final { scan-tree-dump-times "builtin_free" 18 "original" } }
+! { dg-final { scan-tree-dump-times "builtin_free" 21 "original" } }
Index: gcc/testsuite/gfortran.dg/pr81723.f
===================================================================
--- gcc/testsuite/gfortran.dg/pr81723.f	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/pr81723.f	(.../branches/gcc-7-branch)
@@ -0,0 +1,56 @@
+! { dg-do compile }
+! { dg-options "-O3 -fno-automatic" }
+
+      FUNCTION WWERF(Z)
+
+      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
+      COMPLEX*16 WWERF
+      COMPLEX*16 Z,ZH,R(37),S,T,V,W
+
+      PARAMETER (Z1 = 1, HF = Z1/2, Z10 = 10)
+      PARAMETER (C1 = 74/Z10, C2 = 83/Z10, C3 = Z10/32, C4 = 16/Z10)
+      PARAMETER (C = 1.12837 91670 95512 57D0, P = (2*C4)**33)
+
+      DOUBLE PRECISION GREAL,GIMAG,XARG,YARG
+      COMPLEX*16 ZARG,GCONJG,GCMPLX
+      GREAL( ZARG)=DREAL( ZARG)
+      GIMAG( ZARG)=DIMAG( ZARG)
+      GCONJG(ZARG)=DCONJG(ZARG)
+      GCMPLX(XARG,YARG)=DCMPLX(XARG,YARG)
+
+      X=Z
+      Y=GIMAG(Z)
+      XA=ABS(X)
+      YA=ABS(Y)
+      IF(YA .LT. C1 .AND. XA .LT. C2) THEN
+       ZH=GCMPLX(YA+C4,XA)
+       R(37)=0
+       DO 1 N = 36,1,-1
+       T=ZH+N*GCONJG(R(N+1))
+    1  R(N)=HF*T/(GREAL(T)**2+GIMAG(T)**2)
+       XL=P
+       S=0
+       DO 2 N = 33,1,-1
+       XL=C3*XL
+    2  S=R(N)*(S+XL)
+       V=C*S
+      ELSE
+       ZH=GCMPLX(YA,XA)
+       R(1)=0
+       DO 3 N = 9,1,-1
+       T=ZH+N*GCONJG(R(1))
+    3  R(1)=HF*T/(GREAL(T)**2+GIMAG(T)**2)
+       V=C*R(1)
+      END IF
+      IF(YA .EQ. 0) V=GCMPLX(EXP(-XA**2),GIMAG(V))
+      IF(Y .LT. 0) THEN
+       V=2*EXP(-GCMPLX(XA,YA)**2)-V
+       IF(X .GT. 0) V=GCONJG(V)
+      ELSE
+       IF(X .LT. 0) V=GCONJG(V)
+      END IF
+
+      WWERF=V
+
+      RETURN
+      END
Index: gcc/testsuite/gfortran.dg/associate_30.f90
===================================================================
--- gcc/testsuite/gfortran.dg/associate_30.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/associate_30.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,15 @@
+! { dg-do compile }
+!
+! Test the fix for PR67543
+!
+! Contributed by Gerhard Steinmetz  <gerhard.steinmetz.fortran@t-online.de>
+!
+   subroutine s1
+      associate (x => null())   ! { dg-error "cannot be NULL()" }
+      end associate
+   end subroutine
+
+   subroutine s2
+      associate (x => [null()]) ! { dg-error "has no type" }
+      end associate
+   end subroutine
Index: gcc/testsuite/gfortran.dg/derived_init_4.f90
===================================================================
--- gcc/testsuite/gfortran.dg/derived_init_4.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/derived_init_4.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,59 @@
+! { dg-do run }
+!
+! Test the fix for PR81048, where in the second call to 'g2' the
+! default initialization was "forgotten". 'g1', 'g1a' and 'g3' check
+! that this does not occur for scalars and explicit results.
+!
+! Contributed by David Smith  <dm577216smith@gmail.com>
+!
+program test
+   type f
+       integer :: f = -1
+   end type
+   type(f) :: a, b(3)
+   type(f), allocatable :: ans
+   b = g2(a)
+   b = g2(a)
+   ans = g1(a)
+   if (ans%f .ne. -1) call abort
+   ans = g1(a)
+   if (ans%f .ne. -1) call abort
+   ans = g1a(a)
+   if (ans%f .ne. -1) call abort
+   ans = g1a(a)
+   if (ans%f .ne. -1) call abort
+   b = g3(a)
+   b = g3(a)
+contains
+   function g3(a) result(res)
+      type(f) :: a, res(3)
+      do j = 1, 3
+         if (res(j)%f == -1) then
+             res(j)%f = a%f - 1
+         else
+             call abort
+         endif
+      enddo
+   end function g3
+
+   function g2(a)
+      type(f) :: a, g2(3)
+      do j = 1, 3
+         if (g2(j)%f == -1) then
+             g2(j)%f = a%f - 1
+         else
+             call abort
+         endif
+      enddo
+   end function g2
+
+   function g1(a)
+     type(f) :: g1, a
+     if (g1%f .ne. -1 ) call abort
+   end function
+
+   function g1a(a) result(res)
+     type(f) :: res, a
+     if (res%f .ne. -1 ) call abort
+   end function
+end program test
Index: gcc/testsuite/gfortran.dg/typebound_proc_36.f90
===================================================================
--- gcc/testsuite/gfortran.dg/typebound_proc_36.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/typebound_proc_36.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,77 @@
+! { dg-do run }
+!
+! Test the fix for PR82312.f90
+!
+! Posted on Stack Overflow:
+! https://stackoverflow.com/questions/46369744
+! /gfortran-associates-wrong-type-bound-procedure/46388339#46388339
+!
+module minimalisticcase
+    implicit none
+
+    type, public :: DataStructure
+        integer :: i
+    contains
+        procedure, pass :: init => init_data_structure
+        procedure, pass :: a => beginning_of_alphabet
+    end type
+
+    type, public :: DataLogger
+        type(DataStructure), pointer :: data_structure
+        contains
+                procedure, pass :: init => init_data_logger
+                procedure, pass :: do_something => do_something
+    end type
+
+    integer :: ctr = 0
+
+contains
+    subroutine init_data_structure(self)
+        implicit none
+        class(DataStructure), intent(inout) :: self
+        write(*,*) 'init_data_structure'
+        ctr = ctr + 1
+    end subroutine
+
+    subroutine beginning_of_alphabet(self)
+        implicit none
+        class(DataStructure), intent(inout) :: self
+
+        write(*,*) 'beginning_of_alphabet'
+        ctr = ctr + 10
+    end subroutine
+
+    subroutine init_data_logger(self, data_structure)
+        implicit none
+        class(DataLogger), intent(inout) :: self
+        class(DataStructure), target :: data_structure
+        write(*,*) 'init_data_logger'
+        ctr = ctr + 100
+
+        self%data_structure => data_structure ! Invalid change of 'self' vptr
+        call self%do_something()
+    end subroutine
+
+    subroutine do_something(self)
+        implicit none
+        class(DataLogger), intent(inout) :: self
+
+        write(*,*) 'do_something'
+        ctr = ctr + 1000
+
+    end subroutine
+end module
+
+program main
+    use minimalisticcase
+    implicit none
+
+    type(DataStructure) :: data_structure
+    type(DataLogger) :: data_logger
+
+    call data_structure%init()
+    call data_structure%a()
+    call data_logger%init(data_structure)
+
+    if (ctr .ne. 1111) call abort
+end program
Index: gcc/testsuite/gfortran.dg/allocatable_scalar_9.f90
===================================================================
--- gcc/testsuite/gfortran.dg/allocatable_scalar_9.f90	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/allocatable_scalar_9.f90	(.../branches/gcc-7-branch)
@@ -52,4 +52,4 @@
 end block
 end
 
-! { dg-final { scan-tree-dump-times "__builtin_free" 32 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_free" 54 "original" } }
Index: gcc/testsuite/gfortran.dg/execute_command_line_3.f90
===================================================================
--- gcc/testsuite/gfortran.dg/execute_command_line_3.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/execute_command_line_3.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,23 @@
+! { dg-do  run }
+! PR 82233 - there were program aborts for some of these commands.
+! Original test case by Urban Jost.
+program boom
+implicit none
+integer                       :: i,j 
+character(len=256)            :: msg
+character(len=:), allocatable :: command
+   command='notthere'
+   msg='' ! seems to only be defined if exitstatus.ne.0
+   ! ok -- these work
+   call execute_command_line(command , wait=.false., exitstat=i, cmdstat=j, cmdmsg=msg)
+   if (j /= 0 .or. msg /= '') call abort
+   call execute_command_line(command ,               exitstat=i, cmdstat=j, cmdmsg=msg )
+   if (j /= 3 .or. msg /= "Invalid command line" ) call abort
+   msg = ''
+   call execute_command_line(command , wait=.false., exitstat=i,            cmdmsg=msg )
+   if (j /= 3) call abort
+   call execute_command_line(command , wait=.false., exitstat=i                        )
+   if (msg /= '') call abort
+   call execute_command_line(command ,               exitstat=i, cmdstat=j             )
+
+end program boom
Index: gcc/testsuite/gfortran.dg/associate_27.f90
===================================================================
--- gcc/testsuite/gfortran.dg/associate_27.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/associate_27.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,23 @@
+! { dg-do run }
+!
+! Test the fix for PR80120
+!
+! Contributed by Marco Restelli  <mrestelli@gmail.com>
+!
+program p
+ implicit none
+
+ type :: t
+  character(len=25) :: text(2)
+ end type t
+ type(t) :: x
+
+ x%text(1) = "ABC"
+ x%text(2) = "defgh"
+
+ associate( c => x%text )
+   if (c(1)(:maxval(len_trim(c))) .ne. trim (x%text(1))) call abort
+   if (c(2)(:maxval(len_trim(c))) .ne. trim (x%text(2))) call abort
+ end associate
+
+end program p
Index: gcc/testsuite/gfortran.dg/move_alloc_15.f90
===================================================================
--- gcc/testsuite/gfortran.dg/move_alloc_15.f90	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gfortran.dg/move_alloc_15.f90	(.../branches/gcc-7-branch)
@@ -84,5 +84,5 @@
     end do
   end subroutine
 end program name
-! { dg-final { scan-tree-dump-times "__builtin_malloc" 11 "original" } }
-! { dg-final { scan-tree-dump-times "__builtin_free" 11 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_malloc" 14 "original" } }
+! { dg-final { scan-tree-dump-times "__builtin_free" 14 "original" } }
Index: gcc/testsuite/gfortran.dg/warn_target_lifetime_4.f90
===================================================================
--- gcc/testsuite/gfortran.dg/warn_target_lifetime_4.f90	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gfortran.dg/warn_target_lifetime_4.f90	(.../branches/gcc-7-branch)
@@ -0,0 +1,28 @@
+! { dg-do compile }
+! { dg-options "-Wtarget-lifetime" }
+!
+! PR fortran/81770: [5/6/7 Regression] Bogus warning: Pointer in pointer assignment might outlive the pointer target
+!
+! Contributed by Janus Weil <janus@gcc.gnu.org>
+
+module m
+
+   type t
+      integer, allocatable :: l
+   end type
+
+contains
+
+   subroutine sub(c_in, list)
+      type(t), target, intent(in)  :: c_in
+      integer, pointer, intent(out) :: list
+
+      type(t), pointer :: container
+
+      container => c_in
+
+      list => container%l
+
+   end subroutine
+
+end
Index: gcc/testsuite/gcc.c-torture/execute/pr81503.c
===================================================================
--- gcc/testsuite/gcc.c-torture/execute/pr81503.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.c-torture/execute/pr81503.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,15 @@
+unsigned short a = 41461;
+unsigned short b = 3419;
+int c = 0;
+
+void foo() {
+  if (a + b * ~(0 != 5))
+    c = -~(b * ~(0 != 5)) + 2147483647;
+}
+
+int main() {
+  foo();
+  if (c != 2147476810)
+    return -1;
+  return 0;
+}
Index: gcc/testsuite/gcc.c-torture/execute/pr82192.c
===================================================================
--- gcc/testsuite/gcc.c-torture/execute/pr82192.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.c-torture/execute/pr82192.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,22 @@
+/* PR rtl-optimization/82192 */
+
+unsigned long long int a = 0x95dd3d896f7422e2ULL;
+struct S { unsigned int m : 13; } b;
+
+__attribute__((noinline, noclone)) void
+foo (void)
+{
+  b.m = ((unsigned) a) >> (0x644eee9667723bf7LL
+			   | a & ~0xdee27af8U) - 0x644eee9667763bd8LL;
+}
+
+int
+main ()
+{
+  if (__INT_MAX__ != 0x7fffffffULL)
+    return 0;
+  foo ();
+  if (b.m != 0)
+    __builtin_abort ();
+  return 0;
+}
Index: gcc/testsuite/gcc.c-torture/execute/pr82524.c
===================================================================
--- gcc/testsuite/gcc.c-torture/execute/pr82524.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.c-torture/execute/pr82524.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,37 @@
+/* PR target/82524 */
+
+struct S { unsigned char b, g, r, a; };
+union U { struct S c; unsigned v; };
+
+static inline unsigned char
+foo (unsigned char a, unsigned char b)
+{
+  return ((a + 1) * b) >> 8;
+}
+
+__attribute__((noinline, noclone)) unsigned
+bar (union U *x, union U *y)
+{
+  union U z;
+  unsigned char v = x->c.a;
+  unsigned char w = foo (y->c.a, 255 - v);
+  z.c.r = foo (x->c.r, v) + foo (y->c.r, w);
+  z.c.g = foo (x->c.g, v) + foo (y->c.g, w);
+  z.c.b = foo (x->c.b, v) + foo (y->c.b, w);
+  z.c.a = 0;
+  return z.v;
+}
+
+int
+main ()
+{
+  union U a, b, c;
+  if ((unsigned char) ~0 != 255 || sizeof (unsigned) != 4)
+    return 0;
+  a.c = (struct S) { 255, 255, 255, 0 };
+  b.c = (struct S) { 255, 255, 255, 255 };
+  c.v = bar (&a, &b);
+  if (c.c.b != 255 || c.c.g != 255 || c.c.r != 255 || c.c.a != 0)
+    __builtin_abort ();
+  return 0;
+}
Index: gcc/testsuite/gcc.c-torture/compile/string-large-1.c
===================================================================
--- gcc/testsuite/gcc.c-torture/compile/string-large-1.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.c-torture/compile/string-large-1.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,119 @@
+/* Test built-in string functions with large sizes.  PR 78460.  */
+
+typedef __SIZE_TYPE__ size_t;
+
+#define SIZE1 ((size_t) -1)
+#define SIZE2 (SIZE1 >> 1)
+#define SIZE3 ((unsigned int) -1)
+#define SIZE4 (SIZE3 >> 1)
+
+volatile int v1, v2, v3, v4;
+void *volatile vp1, *volatile vp2, *volatile vp3, *volatile vp4;
+
+void
+test_memchr (const void *a, int b)
+{
+  vp1 = __builtin_memchr (a, b, SIZE1);
+  vp2 = __builtin_memchr (a, b, SIZE2);
+  vp3 = __builtin_memchr (a, b, SIZE3);
+  vp4 = __builtin_memchr (a, b, SIZE4);
+}
+
+void
+test_memcmp (const void *a, const void *b)
+{
+  v1 = __builtin_memcmp (a, b, SIZE1);
+  v2 = __builtin_memcmp (a, b, SIZE2);
+  v3 = __builtin_memcmp (a, b, SIZE3);
+  v4 = __builtin_memcmp (a, b, SIZE4);
+}
+
+void
+test_memcpy (void *a, const void *b)
+{
+  vp1 = __builtin_memcpy (a, b, SIZE1);
+  vp2 = __builtin_memcpy (a, b, SIZE2);
+  vp3 = __builtin_memcpy (a, b, SIZE3);
+  vp4 = __builtin_memcpy (a, b, SIZE4);
+}
+
+void
+test_memmove (void *a, const void *b)
+{
+  vp1 = __builtin_memmove (a, b, SIZE1);
+  vp2 = __builtin_memmove (a, b, SIZE2);
+  vp3 = __builtin_memmove (a, b, SIZE3);
+  vp4 = __builtin_memmove (a, b, SIZE4);
+}
+
+void
+test_mempcpy (void *a, const void *b)
+{
+  vp1 = __builtin_mempcpy (a, b, SIZE1);
+  vp2 = __builtin_mempcpy (a, b, SIZE2);
+  vp3 = __builtin_mempcpy (a, b, SIZE3);
+  vp4 = __builtin_mempcpy (a, b, SIZE4);
+}
+
+void
+test_memset (void *a, int b)
+{
+  vp1 = __builtin_memset (a, b, SIZE1);
+  vp2 = __builtin_memset (a, b, SIZE2);
+  vp3 = __builtin_memset (a, b, SIZE3);
+  vp4 = __builtin_memset (a, b, SIZE4);
+}
+
+void
+test_stpncpy (char *a, const char *b)
+{
+  vp1 = __builtin_stpncpy (a, b, SIZE1);
+  vp2 = __builtin_stpncpy (a, b, SIZE2);
+  vp3 = __builtin_stpncpy (a, b, SIZE3);
+  vp4 = __builtin_stpncpy (a, b, SIZE4);
+}
+
+void
+test_strndup (const char *a)
+{
+  vp1 = __builtin_strndup (a, SIZE1);
+  vp2 = __builtin_strndup (a, SIZE2);
+  vp3 = __builtin_strndup (a, SIZE3);
+  vp4 = __builtin_strndup (a, SIZE4);
+}
+
+void
+test_strncasecmp (const char *a, const char *b)
+{
+  v1 = __builtin_strncasecmp (a, b, SIZE1);
+  v2 = __builtin_strncasecmp (a, b, SIZE2);
+  v3 = __builtin_strncasecmp (a, b, SIZE3);
+  v4 = __builtin_strncasecmp (a, b, SIZE4);
+}
+
+void
+test_strncat (char *a, const char *b)
+{
+  vp1 = __builtin_strncat (a, b, SIZE1);
+  vp2 = __builtin_strncat (a, b, SIZE2);
+  vp3 = __builtin_strncat (a, b, SIZE3);
+  vp4 = __builtin_strncat (a, b, SIZE4);
+}
+
+void
+test_strncmp (const char *a, const char *b)
+{
+  v1 = __builtin_strncmp (a, b, SIZE1);
+  v2 = __builtin_strncmp (a, b, SIZE2);
+  v3 = __builtin_strncmp (a, b, SIZE3);
+  v4 = __builtin_strncmp (a, b, SIZE4);
+}
+
+void
+test_strncpy (char *a, const char *b)
+{
+  vp1 = __builtin_strncpy (a, b, SIZE1);
+  vp2 = __builtin_strncpy (a, b, SIZE2);
+  vp3 = __builtin_strncpy (a, b, SIZE3);
+  vp4 = __builtin_strncpy (a, b, SIZE4);
+}
Index: gcc/testsuite/gcc.c-torture/compile/pr82549.c
===================================================================
--- gcc/testsuite/gcc.c-torture/compile/pr82549.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.c-torture/compile/pr82549.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,9 @@
+/* PR tree-optimization/82549 */
+
+int a, b[1];
+
+int
+main ()
+{
+  return !a || b[-2] || b[-2];
+}
Index: gcc/testsuite/gcc.c-torture/compile/pr82337.c
===================================================================
--- gcc/testsuite/gcc.c-torture/compile/pr82337.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.c-torture/compile/pr82337.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,25 @@
+/* PR82337: SLSR needs to prevent abnormal SSA names from
+   serving as a basis. */
+char *a, *b, *c;
+
+struct d {
+  short e;
+  char f[];
+};
+
+extern void j (void);
+
+void
+g() {
+  struct d *h;
+  char *i;
+  int d;
+  do {
+    i = h->f + d;
+    20 ? j() : 0;
+    i = c;
+    if (__builtin_setjmp (h))
+      b = h->f + d;
+    d = (int)(*i);
+  } while (a);
+}
Index: gcc/testsuite/gnat.dg/incomplete5_pkg.adb
===================================================================
--- gcc/testsuite/gnat.dg/incomplete5_pkg.adb	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/incomplete5_pkg.adb	(.../branches/gcc-7-branch)
@@ -0,0 +1,13 @@
+package body Incomplete5_Pkg is
+
+   function Get_Handle (Object: Base_Object) return Access_Type is
+   begin
+      return Object.Handle;
+   end;
+
+   function From_Handle (Handle: Access_Type) return Base_Object is
+   begin
+      return (Handle=>Handle);
+   end;
+
+end Incomplete5_Pkg;
Index: gcc/testsuite/gnat.dg/incomplete5_pkg.ads
===================================================================
--- gcc/testsuite/gnat.dg/incomplete5_pkg.ads	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/incomplete5_pkg.ads	(.../branches/gcc-7-branch)
@@ -0,0 +1,15 @@
+generic
+   type Record_Type;
+package Incomplete5_Pkg is
+
+   type Access_Type is access Record_Type;
+
+   type Base_Object is tagged record
+      Handle: Access_Type;
+   end record;
+
+   function Get_Handle(Object: Base_Object) return Access_Type;
+
+   function From_Handle(Handle: Access_Type) return Base_Object;
+
+end Incomplete5_Pkg;
Index: gcc/testsuite/gnat.dg/array29.adb
===================================================================
--- gcc/testsuite/gnat.dg/array29.adb	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/array29.adb	(.../branches/gcc-7-branch)
@@ -0,0 +1,26 @@
+-- { dg-do compile }
+-- { dg-options "-O" }
+
+package body Array29 is
+
+  procedure Copy (Src : in Matrix; Dst : out Matrix) is
+  begin
+    for I in Src'Range (1) loop
+      for J in Src'Range (2) loop
+        Dst (I, J) := Src (I, J);
+      end loop;
+    end loop;
+  end;
+
+  procedure Proc is
+    N : constant := 2;
+    FM1 : constant Matrix (1 .. N, 1 .. N) := ((1.0, 2.0), (3.0, 4.0));
+    FM2 : constant Matrix (1 .. N, 1 .. N) := ((1.0, 2.0), (3.0, 4.0));
+    A : constant array (1 .. 2) of Matrix (1 .. N, 1 .. N)
+      := (Matrix (FM1), Matrix (FM2));
+    Final : Matrix (1 .. N, 1 .. N);
+  begin
+    Copy (Src => A (1), Dst => Final);
+  end;
+
+end Array29;
Index: gcc/testsuite/gnat.dg/array29.ads
===================================================================
--- gcc/testsuite/gnat.dg/array29.ads	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/array29.ads	(.../branches/gcc-7-branch)
@@ -0,0 +1,7 @@
+package Array29 is
+
+  type Matrix is array (Integer range <>, Integer range <>) of Long_Float;
+
+  procedure Proc;
+
+end Array29;
Index: gcc/testsuite/gnat.dg/debug13.adb
===================================================================
--- gcc/testsuite/gnat.dg/debug13.adb	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/debug13.adb	(.../branches/gcc-7-branch)
@@ -0,0 +1,38 @@
+--  { dg-options "-cargs -O2 -g -margs" }
+
+package body Debug13 is
+
+   procedure Compile (P : Natural)
+   is
+      Max_Pos : constant Natural := P;
+      type Position_Set is array (1 .. Max_Pos) of Boolean;
+
+      Empty  : constant Position_Set := (others => False);
+
+      type Position_Set_Array is array (1 .. Max_Pos) of Position_Set;
+
+      Follow  : Position_Set_Array := (others => Empty);
+
+      function Get_Follows return Position_Set;
+
+      procedure Make_DFA;
+
+      function Get_Follows return Position_Set is
+         Result : Position_Set := Empty;
+      begin
+         Result := Result or Follow (1);
+
+         return Result;
+      end Get_Follows;
+
+      procedure Make_DFA is
+         Next   : constant Position_Set := Get_Follows;
+      begin
+         null;
+      end Make_DFA;
+
+   begin
+      Make_DFA;
+   end Compile;
+
+end Debug13;
Index: gcc/testsuite/gnat.dg/debug13.ads
===================================================================
--- gcc/testsuite/gnat.dg/debug13.ads	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/debug13.ads	(.../branches/gcc-7-branch)
@@ -0,0 +1,5 @@
+package Debug13 is
+
+   procedure Compile (P : Natural);
+
+end Debug13;
Index: gcc/testsuite/gnat.dg/incomplete5.adb
===================================================================
--- gcc/testsuite/gnat.dg/incomplete5.adb	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/incomplete5.adb	(.../branches/gcc-7-branch)
@@ -0,0 +1,10 @@
+-- { dg-do compile }
+
+package body Incomplete5 is
+
+   function Get (O: Base_Object) return Integer is
+   begin
+      return Get_Handle(O).I;
+   end;
+
+end Incomplete5;
Index: gcc/testsuite/gnat.dg/incomplete5.ads
===================================================================
--- gcc/testsuite/gnat.dg/incomplete5.ads	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/incomplete5.ads	(.../branches/gcc-7-branch)
@@ -0,0 +1,25 @@
+with Incomplete5_Pkg;
+
+package Incomplete5 is
+
+   type Rec1 is private;
+
+   type Rec2 is private;
+
+   package My_G is new Incomplete5_Pkg (Rec1);
+
+   use My_G;
+
+   function Get (O: Base_Object) return Integer;
+
+private
+
+   type Rec1 is record
+      I : Integer;
+   end record;
+
+   type Rec2 is record
+      A : Access_Type;
+   end record;
+
+end Incomplete5;
Index: gcc/testsuite/gnat.dg/opt69.adb
===================================================================
--- gcc/testsuite/gnat.dg/opt69.adb	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/opt69.adb	(.../branches/gcc-7-branch)
@@ -0,0 +1,28 @@
+-- { dg-do compile }
+-- { dg-options "-O" }
+
+with Ada.Text_IO;
+
+procedure Opt69 is
+
+   procedure Inner
+     (A : String := (1 .. 15 => ASCII.NUL);
+      B : String := (1 .. 5 => ASCII.NUL);
+      C : String := (1 .. 5 => ASCII.NUL))
+   is
+      Aa : String (1 .. 15);
+      Bb : String (1 .. 5);
+      Cc : String (1 .. 5);
+   begin
+      Aa := A;
+      Bb := B;
+      Cc := C;
+
+      Ada.Text_IO.Put_Line (Aa);
+      Ada.Text_IO.Put_Line (Bb);
+      Ada.Text_IO.Put_Line (Cc);
+   end;
+
+begin
+   Inner;
+end;
Index: gcc/testsuite/gnat.dg/pack9.adb
===================================================================
--- gcc/testsuite/gnat.dg/pack9.adb	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gnat.dg/pack9.adb	(.../branches/gcc-7-branch)
@@ -1,7 +1,8 @@
 -- { dg-do compile }
 -- { dg-options "-O2 -gnatp -fdump-tree-optimized" }
--- See PR tree-optimization/46801 for the expected failure
 
+pragma Optimize_Alignment (Space);
+
 package body Pack9 is
 
   procedure Copy (X, Y : R2_Ptr) is
Index: gcc/testsuite/gnat.dg/specs/vfa.ads
===================================================================
--- gcc/testsuite/gnat.dg/specs/vfa.ads	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gnat.dg/specs/vfa.ads	(.../branches/gcc-7-branch)	(nonexistent)
@@ -1,14 +0,0 @@
--- { dg-do compile }
--- { dg-options "-g" }
-
-package VFA is
-
-  type Rec is record
-    A : Short_Integer;
-    B : Short_Integer;
-  end record;
-
-  type Rec_VFA is new Rec;
-  pragma Volatile_Full_Access (Rec_VFA);
-
-end VFA;
Index: gcc/testsuite/gnat.dg/specs/uc2.ads
===================================================================
--- gcc/testsuite/gnat.dg/specs/uc2.ads	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/specs/uc2.ads	(.../branches/gcc-7-branch)
@@ -0,0 +1,18 @@
+-- { dg-do compile }
+-- { dg-options "-O" }
+
+with Ada.Unchecked_Conversion;
+
+package UC2 is
+
+  subtype Word_Type is Integer range 0 .. 0;
+  type Arr is array (1 .. Word_Type'Size) of Boolean;
+  pragma Pack(Arr);
+
+  function Conv is
+     new Ada.Unchecked_Conversion (Source => Arr, Target => Word_Type);
+
+  A : Arr;
+  W : Word_Type := Conv(A);
+
+end UC2;
Index: gcc/testsuite/gnat.dg/specs/vfa2.ads
===================================================================
--- gcc/testsuite/gnat.dg/specs/vfa2.ads	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/specs/vfa2.ads	(.../branches/gcc-7-branch)
@@ -0,0 +1,110 @@
+-- { dg-do compile }
+-- { dg-options "-O" }
+
+package VFA2 is
+
+   type Bit is mod 2**1
+     with Size => 1;
+   type UInt2 is mod 2**2
+     with Size => 2;
+   type UInt22 is mod 2**22
+     with Size => 22;
+
+   type MODE_ENUM is
+     (
+      Function_0_Default,
+      Function_1,
+      Function_2,
+      Function_3,
+      Function_4,
+      Function_5,
+      Function_6,
+      Function_7)
+     with Size => 3;
+
+   type EPD_ENUM is
+     (
+      Disable_Pull_Down,
+      Enable_Pull_Down)
+     with Size => 1;
+
+   type EPUN_ENUM is
+     (
+      Enable_Pull_Up,
+      Disable_Pull_Up)
+     with Size => 1;
+
+   type EHS_ENUM is
+     (
+      Slow_Low_Noise_With,
+      Fast_Medium_Noise_W)
+     with Size => 1;
+
+   type EZI_ENUM is
+     (
+      Disable_Input_Buffer,
+      Enable_Input_Buffer)
+     with Size => 1;
+
+   type ZIF_ENUM is
+     (
+      Enable_Input_Glitch,
+      Disable_Input_Glitch)
+     with Size => 1;
+
+   type EHD_ENUM is
+     (
+      Normal_Drive_4_Ma_D,
+      Medium_Drive_8_Ma_D,
+      High_Drive_14_Ma_Dr,
+      Ultra_High_Drive_20)
+     with Size => 2;
+
+   type Pin_Type is (Normal_Drive, High_Drive, High_Speed);
+
+   type SFS_Register(Pin : Pin_Type := Normal_Drive) is record
+      MODE     : MODE_ENUM;
+      EPD      : EPD_ENUM;
+      EPUN     : EPUN_ENUM;
+      EZI      : EZI_ENUM;
+      ZIF      : ZIF_ENUM;
+      RESERVED : UInt22;
+
+      case Pin is
+         when Normal_Drive =>
+
+            ND_EHS_RESERVED : Bit;
+            ND_EHD_RESERVED : UInt2;
+
+         when High_Drive =>
+
+            EHD : EHD_ENUM;
+            HD_EHS_RESERVED : Bit;
+
+         when High_Speed =>
+            EHS    : EHS_ENUM;
+            HS_EHD_RESERVED : UInt2;
+
+      end case;
+   end record
+     with Unchecked_Union, Size => 32, Volatile_Full_Access;
+
+   for SFS_Register use record
+      MODE            at 0 range 0 .. 2;
+      EPD             at 0 range 3 .. 3;
+      EPUN            at 0 range 4 .. 4;
+      ND_EHS_RESERVED at 0 range 5 .. 5;
+      HD_EHS_RESERVED at 0 range 5 .. 5;
+      EHS             at 0 range 5 .. 5;
+      EZI             at 0 range 6 .. 6;
+      ZIF             at 0 range 7 .. 7;
+      ND_EHD_RESERVED at 0 range 8 .. 9;
+      EHD             at 0 range 8 .. 9;
+      HS_EHD_RESERVED at 0 range 8 .. 9;
+      RESERVED        at 0 range 10 .. 31;
+   end record;
+
+   type Normal_Drive_Pins is array (Integer range <>)
+     of SFS_Register(Normal_Drive) with Volatile;
+
+end VFA2;
Index: gcc/testsuite/gnat.dg/specs/atomic3.ads
===================================================================
--- gcc/testsuite/gnat.dg/specs/atomic3.ads	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/specs/atomic3.ads	(.../branches/gcc-7-branch)
@@ -0,0 +1,33 @@
+-- { dg-do compile }
+
+package Atomic3 is
+
+   type Four_Bits is mod 2**4;
+   type Fourteen_Bits is mod 2**14;
+   type Twenty_Eight_Bits is mod 2**28;
+
+   type Rec1 (Mode : Boolean := True) is record
+      Reserved : Four_Bits;
+      case Mode is
+         when True =>
+           High_Part : Fourteen_Bits;
+           Low_Part  : Fourteen_Bits;
+         when False =>
+           Data : Twenty_Eight_Bits;
+      end case;
+   end record;
+   for Rec1 use record
+      Reserved  at 0 range 28 .. 31;
+      High_Part at 0 range 14 .. 27;
+      Low_Part  at 0 range  0 .. 13;
+      Data      at 0 range  0 .. 27;
+   end record;
+   for Rec1'Size use 32;
+   pragma Unchecked_Union (Rec1);
+
+   type Rec2 is record
+      A : Rec1;
+      pragma Atomic (A);
+   end record;
+
+end Atomic3;
Index: gcc/testsuite/gnat.dg/specs/vfa1.ads
===================================================================
--- gcc/testsuite/gnat.dg/specs/vfa1.ads	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gnat.dg/specs/vfa1.ads	(.../branches/gcc-7-branch)
@@ -0,0 +1,14 @@
+-- { dg-do compile }
+-- { dg-options "-g" }
+
+package VFA1 is
+
+  type Rec is record
+    A : Short_Integer;
+    B : Short_Integer;
+  end record;
+
+  type Rec_VFA is new Rec;
+  pragma Volatile_Full_Access (Rec_VFA);
+
+end VFA1;
Index: gcc/testsuite/gcc.dg/pr82112.c
===================================================================
--- gcc/testsuite/gcc.dg/pr82112.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/pr82112.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,21 @@
+/* PR target/82112 */
+/* { dg-do compile } */
+/* { dg-options "-std=gnu90" } */
+
+struct S { int a[10]; } bar (void);
+int b, c;
+
+void
+foo (void)
+{
+  __atomic_load (bar ().a, &b, __ATOMIC_ACQUIRE);	/* { dg-error "argument 1 of .__atomic_load. must be a non-void pointer type" } */
+  __atomic_load (&b, bar ().a, __ATOMIC_ACQUIRE);	/* { dg-error "argument 2 of .__atomic_load. must be a pointer type" } */
+  __atomic_store (bar ().a, &b, __ATOMIC_SEQ_CST);	/* { dg-error "argument 1 of .__atomic_store. must be a non-void pointer type" } */
+  __atomic_store (&b, bar ().a, __ATOMIC_SEQ_CST);	/* { dg-error "argument 2 of .__atomic_store. must be a pointer type" } */
+  __atomic_exchange (bar ().a, &b, &c, __ATOMIC_RELAXED);	/* { dg-error "argument 1 of .__atomic_exchange. must be a non-void pointer type" } */
+  __atomic_exchange (&b, bar ().a, &c, __ATOMIC_RELAXED);	/* { dg-error "argument 2 of .__atomic_exchange. must be a pointer type" } */
+  __atomic_exchange (&b, &c, bar ().a, __ATOMIC_RELAXED);	/* { dg-error "argument 3 of .__atomic_exchange. must be a pointer type" } */
+  __atomic_compare_exchange (bar ().a, &b, &c, 1, __ATOMIC_RELAXED, __ATOMIC_RELAXED);	/* { dg-error "argument 1 of .__atomic_compare_exchange. must be a non-void pointer type" } */
+  __atomic_compare_exchange (&b, bar ().a, &c, 1, __ATOMIC_RELAXED, __ATOMIC_RELAXED);	/* { dg-error "argument 2 of .__atomic_compare_exchange. must be a pointer type" } */
+  __atomic_compare_exchange (&b, &c, bar ().a, 1, __ATOMIC_RELAXED, __ATOMIC_RELAXED);	/* { dg-error "argument 3 of .__atomic_compare_exchange. must be a pointer type" } */
+}
Index: gcc/testsuite/gcc.dg/gimplefe-14.c
===================================================================
--- gcc/testsuite/gcc.dg/gimplefe-14.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.dg/gimplefe-14.c	(.../branches/gcc-7-branch)
@@ -7,7 +7,9 @@
   int a;
 
   bb_2:
-  switch (argc_2(D)) {default: L2; case 1: L0; case 2: L1; }
+  /* Because of PR82114 we need to handle also 0 as base metal can have
+     argc == 0.  */
+  switch (argc_2(D)) {default: L2; case 0: L0; case 1: L0; case 2: L1; }
 
 L0:
   a_4 = 0;
Index: gcc/testsuite/gcc.dg/gomp/pr81768-2.c
===================================================================
--- gcc/testsuite/gcc.dg/gomp/pr81768-2.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/gomp/pr81768-2.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,15 @@
+/* PR middle-end/81768 */
+/* { dg-do compile } */
+
+float b[10][15][10];
+
+void
+foo (void)
+{
+  float *i;
+#pragma omp target parallel for schedule(static, 32) collapse(3)
+  for (i = &b[0][0][0]; i < &b[0][0][10]; i++)
+    for (float *j = &b[0][15][0]; j > &b[0][0][0]; j -= 10)
+      for (float *k = &b[0][0][10]; k > &b[0][0][0]; --k)
+        b[i - &b[0][0][0]][(j - &b[0][0][0]) / 10 - 1][(k - &b[0][0][0]) - 1] -= 3.5;
+}
Index: gcc/testsuite/gcc.dg/gomp/pr81768-1.c
===================================================================
--- gcc/testsuite/gcc.dg/gomp/pr81768-1.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/gomp/pr81768-1.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,15 @@
+/* PR middle-end/81768 */
+/* { dg-do compile } */
+
+float b[10][15][10];
+
+void
+foo (void)
+{
+  float *i;
+#pragma omp target parallel for simd schedule(static, 32) collapse(3)
+  for (i = &b[0][0][0]; i < &b[0][0][10]; i++)
+    for (float *j = &b[0][15][0]; j > &b[0][0][0]; j -= 10)
+      for (float *k = &b[0][0][10]; k > &b[0][0][0]; --k)
+	b[i - &b[0][0][0]][(j - &b[0][0][0]) / 10 - 1][(k - &b[0][0][0]) - 1] -= 3.5;
+}
Index: gcc/testsuite/gcc.dg/pr82274-2.c
===================================================================
--- gcc/testsuite/gcc.dg/pr82274-2.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/pr82274-2.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,26 @@
+/* PR target/82274 */
+/* { dg-do run } */
+/* { dg-options "-O2" } */
+
+int
+main ()
+{
+#ifdef __SIZEOF_INT128__
+  __int128 m = -(((__int128) 1) << (__CHAR_BIT__ * __SIZEOF_INT128__ / 2));
+  volatile __int128 mv = m;
+  __int128 r;
+#else
+  long long m = -(1LL << (__CHAR_BIT__ * __SIZEOF_LONG_LONG__ / 2));
+  volatile long long mv = m;
+  long long r;
+#endif
+  if (!__builtin_mul_overflow (mv, mv, &r))
+    __builtin_abort ();
+  if (!__builtin_mul_overflow_p (mv, mv, r))
+    __builtin_abort ();
+  if (!__builtin_mul_overflow (m, m, &r))
+    __builtin_abort ();
+  if (!__builtin_mul_overflow_p (m, m, r))
+    __builtin_abort ();
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/asan/pr81923.c
===================================================================
--- gcc/testsuite/gcc.dg/asan/pr81923.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/asan/pr81923.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,10 @@
+/* PR sanitizer/81923 */
+/* { dg-do link } */
+
+int foobar __asm (__USER_LABEL_PREFIX__ "barbaz") = 34;
+
+int
+main ()
+{
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/attr-alloc_size-11.c
===================================================================
--- gcc/testsuite/gcc.dg/attr-alloc_size-11.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.dg/attr-alloc_size-11.c	(.../branches/gcc-7-branch)
@@ -47,8 +47,8 @@
 
 /* The following tests fail because of missing range information.  The xfail
    exclusions are PR79356.  */
-TEST (signed char, SCHAR_MIN + 2, ALLOC_MAX);   /* { dg-warning "argument 1 range \\\[13, \[0-9\]+\\\] exceeds maximum object size 12" "missing range info for signed char" { xfail { ! { aarch64*-*-* arm*-*-* alpha*-*-* ia64-*-* mips*-*-* powerpc*-*-* sparc*-*-* s390*-*-* } } } } */
-TEST (short, SHRT_MIN + 2, ALLOC_MAX); /* { dg-warning "argument 1 range \\\[13, \[0-9\]+\\\] exceeds maximum object size 12" "missing range info for short" { xfail { ! { aarch64*-*-* arm*-*-* alpha*-*-* ia64-*-* mips*-*-* powerpc*-*-* sparc*-*-* s390x-*-* } } } } */
+TEST (signed char, SCHAR_MIN + 2, ALLOC_MAX);   /* { dg-warning "argument 1 range \\\[13, \[0-9\]+\\\] exceeds maximum object size 12" "missing range info for signed char" { xfail { ! { aarch64*-*-* arm*-*-* alpha*-*-* ia64-*-* mips*-*-* powerpc*-*-* sparc*-*-* s390*-*-* visium-*-* } } } } */
+TEST (short, SHRT_MIN + 2, ALLOC_MAX); /* { dg-warning "argument 1 range \\\[13, \[0-9\]+\\\] exceeds maximum object size 12" "missing range info for short" { xfail { ! { aarch64*-*-* arm*-*-* alpha*-*-* ia64-*-* mips*-*-* powerpc*-*-* sparc*-*-* s390x-*-* visium-*-* } } } } */
 TEST (int, INT_MIN + 2, ALLOC_MAX);    /* { dg-warning "argument 1 range \\\[13, \[0-9\]+\\\] exceeds maximum object size 12" } */
 TEST (int, -3, ALLOC_MAX);             /* { dg-warning "argument 1 range \\\[13, \[0-9\]+\\\] exceeds maximum object size 12" } */
 TEST (int, -2, ALLOC_MAX);             /* { dg-warning "argument 1 range \\\[13, \[0-9\]+\\\] exceeds maximum object size 12" } */
Index: gcc/testsuite/gcc.dg/pr81621.c
===================================================================
--- gcc/testsuite/gcc.dg/pr81621.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/pr81621.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,5 @@
+/* PR target/81621 */
+/* { dg-do compile { target freorder } } */
+/* { dg-options "-Og -fno-split-wide-types -freorder-blocks-and-partition" } */
+
+#include "graphite/scop-10.c"
Index: gcc/testsuite/gcc.dg/torture/pr82276.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr82276.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/torture/pr82276.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,32 @@
+/* { dg-do compile } */
+
+typedef struct a {
+  struct a *b;
+} a;
+
+extern int d(void);
+extern int g(void);
+extern int h(void);
+extern int _setjmp();
+extern int i(void);
+
+void c(void) {
+    1 ? d() : 0;
+    a *e;
+    while (e) {
+	e = (e == (a *) c) ? 0 : e->b;
+	while (e) {
+	    unsigned int f = 0;
+	    g();
+	    _setjmp(f);
+	    if (f & 6) {
+		;
+	    } else if (f & 2) {
+		;
+	    } else {
+		h();
+	    }
+	    i();
+	}
+    }
+}
Index: gcc/testsuite/gcc.dg/torture/pr82285.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr82285.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/torture/pr82285.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,16 @@
+/* { dg-do run } */
+
+enum tst { first = 0, second = 1 };
+
+int
+main ()
+{
+  enum tst data[16];
+
+  for (unsigned i = 0; i < 16; i++)
+    data[i] = (i < 5 ? second : first);
+
+  if (data[2] != second)
+    __builtin_abort ();
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/torture/pr81181.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr81181.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/torture/pr81181.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,30 @@
+/* { dg-do compile } */
+
+unsigned int lh;
+
+void
+ny (int t3, int ys, int rt, int p8)
+{
+  if (lh != 0)
+    {
+      if (0)
+	{
+oo:
+	  do
+	    {
+	      rt = (p8 != 0) ? t3 : 0;
+	      rt = (rt != 0 || lh != (unsigned int)ys);
+	      rt += lh + ys;
+	    }
+	  while (t3 <= 0);
+
+	  lh = ys;
+	  ys = rt;
+	}
+
+      if (lh != 0)
+	p8 = lh;
+    }
+
+  goto oo;
+}
Index: gcc/testsuite/gcc.dg/torture/pr82244.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr82244.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/torture/pr82244.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,31 @@
+/* { dg-do compile } */
+
+typedef struct a {
+  struct a *b;
+} a;
+
+extern int d(void);
+extern int g(void);
+extern int h(void);
+extern int _setjmp(void *);
+
+int c(void)
+{
+  1 ? d() : 0;
+
+  a *e;
+  while (e) {
+      e = (e == (a *) c) ? 0 : e->b;
+      while (e) {
+	  int f = 0;
+	  g();
+	  if (_setjmp(0)) {
+	      if (f & 6) {
+		  ;
+	      } else if (f & 2) {
+		  h();
+	      }
+	  }
+      }
+  }
+}
Index: gcc/testsuite/gcc.dg/torture/pr82603.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr82603.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/torture/pr82603.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,24 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-ftree-loop-vectorize" } */
+
+int
+mr (unsigned int lf, int ms)
+{
+  unsigned int sw = 0;
+  char *cu = (char *)&ms;
+
+  while (ms < 1)
+    {
+      if (lf == 0)
+	ms = 0;
+      else
+	ms = 0;
+      ms += ((lf > 0) && ((lf > sw) ? 1 : ++*cu));
+    }
+
+  if (lf != 0)
+    cu = (char *)&sw;
+  *cu = lf;
+
+  return ms;
+}
Index: gcc/testsuite/gcc.dg/torture/pr82264.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr82264.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/torture/pr82264.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,21 @@
+/* { dg-do compile } */
+
+char a;
+int c;
+unsigned b ();
+unsigned
+setjmp ()
+{
+}
+static void
+d ()
+{
+  if (b ())
+    c = 3;
+}
+void
+e ()
+{
+  d ();
+  a && ({ setjmp (); });
+}
Index: gcc/testsuite/gcc.dg/torture/pr82291.c
===================================================================
--- gcc/testsuite/gcc.dg/torture/pr82291.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/torture/pr82291.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,37 @@
+/* { dg-do run } */
+
+int a, c, d, *h;
+unsigned b;
+
+int *fn1 ()
+{ 
+  int *f[3], g = 0;
+  for (; g < 3; g++)
+    f[g] = &a;
+  if (--b > a)
+    { 
+      if (a > b)
+	d++;
+      return f[0];
+    }
+}
+
+void fn2 ()
+{ 
+  for (; c >= 0; --c)
+    { 
+      int j[] = { 0, 0, 0, 0, 0 };
+      int *k = fn1 ();
+      if (!k)
+	__builtin_abort ();
+      h = &j[4];
+    }
+}
+
+int main ()
+{ 
+  fn2 ();
+  if (d != 0)
+    __builtin_abort ();
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/pr81650.c
===================================================================
--- gcc/testsuite/gcc.dg/pr81650.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/pr81650.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,9 @@
+/* PR driver/81650 */
+/* { dg-do compile } */
+/* { dg-options "-Walloc-size-larger-than=9223372036854775807" } */
+
+void *
+foo (void)
+{
+  return __builtin_malloc (5);
+}
Index: gcc/testsuite/gcc.dg/pr82703.c
===================================================================
--- gcc/testsuite/gcc.dg/pr82703.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/pr82703.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,28 @@
+/* PR target/82703 */
+/* { dg-do run } */
+/* { dg-options "-O2 -fno-tree-sra -ftree-vectorize" } */
+
+__attribute__((noinline, noclone)) void
+compare (const double *p, const double *q)
+{
+  for (int i = 0; i < 3; ++i)
+    if (p[i] != q[i])
+      __builtin_abort ();
+}
+
+double vr[3] = { 4, 4, 4 };
+
+int
+main ()
+{
+  double v1[3] = { 1, 2, 3 };
+  double v2[3] = { 3, 2, 1 };
+  double v3[3];
+  __builtin_memcpy (v3, v1, sizeof (v1));
+  for (int i = 0; i < 3; ++i)
+    v3[i] += v2[i];
+  for (int i = 0; i < 3; ++i)
+    v1[i] += v2[i];
+  compare (v3, vr);
+  return 0;
+}
Index: gcc/testsuite/gcc.dg/tree-ssa/pr81588.c
===================================================================
--- gcc/testsuite/gcc.dg/tree-ssa/pr81588.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.dg/tree-ssa/pr81588.c	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 /* PR tree-optimization/81588 */
-/* { dg-do compile { target { ! "m68k*-*-* mmix*-*-* bfin*-*-* v850*-*-* moxie*-*-* cris*-*-* m32c*-*-* fr30*-*-* mcore*-*-* powerpc*-*-* xtensa*-*-* hppa*-*-* nios2*-*-*" } } } */
+/* { dg-do compile { target { ! { { logical_op_short_circuit && { ! "mips*-*-* avr-*-* s390*-*-*" } } || { m68k*-*-* bfin*-*-* v850*-*-* moxie*-*-* m32c*-*-* fr30*-*-* mcore*-*-* xtensa*-*-* hppa*-*-* } } } } } */
 /* { dg-options "-O2 -fdump-tree-reassoc1-details" } */
 /* { dg-additional-options "-mbranch-cost=2" { target mips*-*-* avr-*-* s390*-*-* i?86-*-* x86_64-*-* } } */
 
Index: gcc/testsuite/gcc.dg/tree-ssa/pr82340.c
===================================================================
--- gcc/testsuite/gcc.dg/tree-ssa/pr82340.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/tree-ssa/pr82340.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,14 @@
+/* PR c/82340 */
+/* { dg-do compile } */
+/* { dg-options "-O2 -fdump-tree-ssa" } */
+/* { dg-final { scan-tree-dump "D.\[0-9]*\\\[0\\\] ={v} 77;" "ssa" } } */
+
+int
+foo (void)
+{
+  int i;
+  volatile char *p = (volatile char[1]) { 77 };
+  for (i = 1; i < 10; i++)
+    *p = 4;
+  return *p;
+}
Index: gcc/testsuite/gcc.dg/pr81988.c
===================================================================
--- gcc/testsuite/gcc.dg/pr81988.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/pr81988.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,22 @@
+/* PR target/81988 */
+/* Testcase by James Cowgill <jcowgill+gcc@jcowgill.uk> */
+
+/* { dg-do assemble } */
+/* { dg-require-effective-target pie } */
+/* { dg-options "-O3 -fpie" } */
+
+int c, d;
+
+short **e;
+int *a;
+
+void foo(void)
+{
+  int g[64 * 35], *h = g;
+  do {
+    short *f = e[d];
+    for (int i = 0; i < 4; i++)
+      a[i] = a[i] + (h[364] + f[4] * h[64] + f[5] * h[i] + f[6] * h[i + 3 * 4] +
+                     f[7] * h[i + 4]);
+  } while (c);
+}
Index: gcc/testsuite/gcc.dg/ipa/pr82001.c
===================================================================
--- gcc/testsuite/gcc.dg/ipa/pr82001.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/ipa/pr82001.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,21 @@
+/* { dg-do compile { target i?86-*-* x86_64-*-* } } */
+/* { dg-options "-O2 -fdump-ipa-icf-details"  } */
+
+int
+mullo (int a, int b)
+{
+  asm("mul %%edx   # %%1 was %1"
+      : "+"
+	"a"(a),
+	"+d"(b));
+  return a;
+}
+
+int
+mulhi (int a, int b)
+{
+  asm("mul %%edx   # %%1 was %1" : "+d"(a), "+a"(b));
+  return a;
+}
+
+/* { dg-final { scan-ipa-dump "Equal symbols: 0" "icf"  } } */
Index: gcc/testsuite/gcc.dg/ipa/pr81696.c
===================================================================
--- gcc/testsuite/gcc.dg/ipa/pr81696.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/ipa/pr81696.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,26 @@
+/* { dg-options "-O2 -fdump-ipa-icf-details"  } */
+
+int
+main (int argc, char **argv)
+{
+  __label__ lab4, lab5, lab6;
+
+  void foo (void) { goto lab4; }
+  void foo2 (void) { goto lab4; }
+  void bar (void) { goto lab5; }
+  void baz (void) { goto lab6; }
+
+  if (argc)
+    foo ();
+  else
+    foo2 ();
+
+ lab4:;
+  bar ();
+ lab5:;
+  baz ();
+ lab6:;
+  return 0;
+}
+
+/* { dg-final { scan-ipa-dump "Equal symbols: 1" "icf"  } } */
Index: gcc/testsuite/gcc.dg/ipa/ipcp-cstagg-7.c
===================================================================
--- gcc/testsuite/gcc.dg/ipa/ipcp-cstagg-7.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.dg/ipa/ipcp-cstagg-7.c	(.../branches/gcc-7-branch)
@@ -62,4 +62,4 @@
   return bar (s, x);
 }
 
-/* { dg-final { scan-ipa-dump-times "Discovered an indirect call to a known target" 3 "cp" } } */
+/* { dg-final { scan-ipa-dump-times "Discovered an indirect call to a known target" 3 "cp" { xfail { hppa*-*-* && { ! lp64 } } } } } */
Index: gcc/testsuite/gcc.dg/vect/vect-align-1.c
===================================================================
--- gcc/testsuite/gcc.dg/vect/vect-align-1.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.dg/vect/vect-align-1.c	(.../branches/gcc-7-branch)
@@ -47,6 +47,6 @@
   return 0;
 }
 
-/* { dg-final { scan-tree-dump-times "Vectorizing an unaligned access" 1 "vect" { target vect_hw_misalign } } } */
-/* { dg-final { scan-tree-dump-times "Alignment of access forced using versioning" 1 "vect" { xfail vect_hw_misalign} } } */
+/* { dg-final { scan-tree-dump-times "Vectorizing an unaligned access" 1 "vect" { target { vect_hw_misalign && { arm_vect_no_misalign } } } } } */
+/* { dg-final { scan-tree-dump-times "Alignment of access forced using versioning" 1 "vect" { target { vect_hw_misalign && arm_vect_no_misalign } } } } */
 /* { dg-final { scan-tree-dump-times "vectorized 1 loops" 1 "vect" } } */
Index: gcc/testsuite/gcc.dg/vect/vect-align-2.c
===================================================================
--- gcc/testsuite/gcc.dg/vect/vect-align-2.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.dg/vect/vect-align-2.c	(.../branches/gcc-7-branch)
@@ -43,5 +43,5 @@
 
 
 /* { dg-final { scan-tree-dump-times "Alignment of access forced using peeling" 0 "vect" } } */
-/* { dg-final { scan-tree-dump-times "Alignment of access forced using versioning" 1 "vect" { xfail vect_hw_misalign} } } */
+/* { dg-final { scan-tree-dump-times "Alignment of access forced using versioning" 1 "vect" { target { vect_hw_misalign && arm_vect_no_misalign } } } } */
 /* { dg-final { scan-tree-dump-times "vectorized 1 loops" 1 "vect" } } */
Index: gcc/testsuite/gcc.dg/vect/pr82108.c
===================================================================
--- gcc/testsuite/gcc.dg/vect/pr82108.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/vect/pr82108.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,47 @@
+/* { dg-do run } */
+/* { dg-require-effective-target vect_float } */
+
+#include "tree-vect.h"
+
+void __attribute__((noinline,noclone))
+downscale_2 (const float* src, int src_n, float* dst)
+{
+  int i;
+
+  for (i = 0; i < src_n; i += 2) {
+      const float* a = src;
+      const float* b = src + 4;
+
+      dst[0] = (a[0] + b[0]) / 2;
+      dst[1] = (a[1] + b[1]) / 2;
+      dst[2] = (a[2] + b[2]) / 2;
+      dst[3] = (a[3] + b[3]) / 2;
+
+      src += 2 * 4;
+      dst +=     4;
+  }
+}
+
+int main ()
+{
+  const float in[4 * 4] = {
+      1, 2, 3, 4,
+      5, 6, 7, 8,
+
+      1, 2, 3, 4,
+      5, 6, 7, 8
+  };
+  float out[2 * 4];
+
+  check_vect ();
+
+  downscale_2 (in, 4, out);
+
+  if (out[0] != 3 || out[1] != 4 || out[2] != 5 || out[3] != 6
+      || out[4] != 3 || out[5] != 4 || out[6] != 5 || out[7] != 6)
+    __builtin_abort ();
+  
+  return 0;
+}
+
+/* { dg-final { scan-tree-dump-times "vectorized 1 loops" 1 "vect" } } */
Index: gcc/testsuite/gcc.dg/vect/vect-multitypes-1.c
===================================================================
--- gcc/testsuite/gcc.dg/vect/vect-multitypes-1.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/gcc.dg/vect/vect-multitypes-1.c	(.../branches/gcc-7-branch)
@@ -83,5 +83,5 @@
 
 /* { dg-final { scan-tree-dump-times "vectorized 1 loops" 2 "vect" { xfail { vect_no_align && { ! vect_hw_misalign } } } } } */
 /* { dg-final { scan-tree-dump-times "Alignment of access forced using peeling" 2 "vect" { xfail {{ vect_no_align && { ! vect_hw_misalign } } || {vect_sizes_32B_16B }}} } } */
-/* { dg-final { scan-tree-dump-times "Vectorizing an unaligned access" 4 "vect" { xfail {{ vect_no_align && { ! vect_hw_misalign } } || {vect_sizes_32B_16B }}} } } */
+/* { dg-final { scan-tree-dump-times "Vectorizing an unaligned access" 4 "vect" { target { vect_no_align && { { ! vect_hw_misalign } && vect_sizes_32B_16B } } }} } */
 
Index: gcc/testsuite/gcc.dg/vect/pr82436.c
===================================================================
--- gcc/testsuite/gcc.dg/vect/pr82436.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/vect/pr82436.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,35 @@
+/* { dg-do compile } */
+/* { dg-additional-options "-Ofast -fno-tree-scev-cprop" } */
+/* { dg-additional-options "-mavx2" { target { x86_64-*-* i?86-*-* } } } */
+
+struct reflection_type
+{
+  int h;
+  int k;
+  int l;
+  double f_exp;
+  double f_sigma;
+  _Complex double f_calc;
+  double f_pred;
+  double i_exp;
+  double i_sigma;
+  double i_pred;
+};
+
+double y, w;
+int foo (struct reflection_type *r, int n, unsigned s)
+{
+  int i;
+  y = 0;
+  w = 0;
+  for (i = 1; i < n; ++i)
+    {
+      struct reflection_type *x = &r[i*s];
+      double fpred = x->f_pred;
+      double fexp = x->f_exp;
+      double tem = (fpred - fexp);
+      y += __builtin_fabs (tem / x->f_sigma);
+      w += __builtin_fabs (tem / fexp);
+    }
+  return i;
+}
Index: gcc/testsuite/gcc.dg/pr82274-1.c
===================================================================
--- gcc/testsuite/gcc.dg/pr82274-1.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/gcc.dg/pr82274-1.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,16 @@
+/* PR target/82274 */
+/* { dg-do run } */
+/* { dg-shouldfail "trapv" } */
+/* { dg-options "-ftrapv" } */
+
+int
+main ()
+{
+#ifdef __SIZEOF_INT128__
+  volatile __int128 m = -(((__int128) 1) << (__CHAR_BIT__ * __SIZEOF_INT128__ / 2));
+#else
+  volatile long long m = -(1LL << (__CHAR_BIT__ * __SIZEOF_LONG_LONG__ / 2));
+#endif
+  m = m * m;
+  return 0;
+}
Index: gcc/testsuite/ChangeLog
===================================================================
--- gcc/testsuite/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,660 @@
+2017-11-10  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gnat.dg/opt69.adb: New test.
+
+2017-11-06  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/78641
+	* gfortran.dg/class_66.f90: New test.
+
+2017-11-06  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/69739
+	* gfortran.dg/pr69739.f90: New test.
+
+2017-11-04  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/82796
+	* gfortran.dg/equiv_pure.f90: New test.
+
+2017-11-04  Andre Vehreschild  <vehre@gcc.gnu.org>
+
+	* gfortran.dg/coarray/send_char_array_1.f90: New test.
+
+2017-11-03  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/81735
+	* gfortran.dg/pr81735.f90: New test.
+
+2017-11-01  Tamar Christina  <tamar.christina@arm.com>
+
+	Backported from trunk
+	* gcc.dg/vect/vect-align-1.c: Fix vect_hw_misalign condition.
+	* gcc.dg/vect/vect-align-2.c: Likewise.
+	* gcc.dg/vect/vect-multitypes-1.c: Likewise
+
+2017-11-01  Tamar Christina  <tamar.christina@arm.com>
+
+	Backported from trunk
+	* gcc.dg/vect/vect-multitypes-1.c: Correct target selector.
+
+2017-11-01  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	Backported from trunk
+	* lib/target-supports.exp (check_effective_target_vect_hw_misalign):
+	Fix arm check.
+
+2017-11-01  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/80554
+	* gfortran.dg/submodule_29.f08: New test.
+
+2017-11-01  Martin Jambor  <mjambor@suse.cz>
+
+	PR c++/81702
+	* g++.dg/tree-ssa/pr81702.C: New test.
+
+2017-11-01  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/80850
+	* gfortran.dg/class_64_f90 : New test.
+
+2017-10-30  Paolo Carlini  <paolo.carlini@oracle.com>
+
+	PR c++/82085
+	* g++.dg/cpp1y/var-templ56.C: New.
+
+2017-10-28  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/81758
+	* gfortran.dg/class_63.f90: New test.
+
+2017-10-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-10-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/82159
+	* g++.dg/opt/pr82159-2.C: New test.
+
+	2017-10-04  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/82373
+	* g++.dg/cpp1y/pr82373.C: New test.
+
+	2017-09-21  Jakub Jelinek  <jakub@redhat.com>
+
+	PR sanitizer/81715
+	* g++.dg/asan/pr81715.C: New test.
+
+	2017-09-15  Jakub Jelinek  <jakub@redhat.com>
+
+	PR rtl-optimization/82192
+	* gcc.c-torture/execute/pr82192.c: New test.
+
+2017-10-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/82703
+	* gcc.dg/pr82703.c: New test.
+
+2017-10-24  Qing Zhao <qing.zhao@oracle.com>
+	    Wilco Dijkstra  <wilco.dijkstra@arm.com>
+
+        PR middle-end/80295
+        * gcc.target/aarch64/pr80295.c: New test.
+
+2017-10-21  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/82312
+	* gfortran.dg/typebound_proc_36.f90 : New test.
+
+2017-10-20  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/79795
+	* gfortran.dg/assumed_size_2.f90: New test.
+
+2017-10-20  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82603
+	* gcc.dg/torture/pr82603.c: New testcase.
+
+2017-10-20  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-10-06  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82436
+	* gcc.dg/vect/pr82436.c: New testcase.
+
+2017-10-19  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	Backport from trunk
+	PR libfortran/82233
+	* gfortran.dg/execute_command_line_3.f90: New test.
+
+2017-10-19  Richard Earnshaw  <rearnsha@arm.com>
+
+	PR target/82445
+	* gcc.target/arm/peep-ldrd-1.c: Tighten test scan pattern.
+	* gcc.target/arm/peep-strd-1.c: Likewise.
+	* gcc.target/arm/peep-ldrd-2.c: New test.
+	* gcc.target/arm/peep-strd-2.c: New test.
+
+2017-10-18  Vladimir Makarov  <vmakarov@redhat.com>
+
+	PR middle-end/82556
+	* gcc.target/i386/pr82556.c: New.
+
+2017-10-17  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc.dg/attr-alloc_size-11.c: UnXFAIL for visium-*-*.
+
+2017-10-17  Nathan Sidwell  <nathan@acm.org>
+
+	PR c++/82560
+	* g++.dg/cpp0x/pr82560.C: New.
+
+2017-10-17  Jakub Jelinek  <jakub@redhat.com>
+
+	PR tree-optimization/82549
+	* gcc.c-torture/compile/pr82549.c: New test.
+
+2017-10-16  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/78512
+	* gfortran.dg/associate_9.f03: Remove XFAIL.
+	* gfortran.dg/associate_26.f90: New test.
+
+	PR fortran/80120
+	* gfortran.dg/associate_27.f90: New test.
+
+	PR fortran/81903
+	* gfortran.dg/associate_28.f90: New test.
+
+	PR fortran/82121
+	* gfortran.dg/associate_29.f90: New test.
+
+	PR fortran/67543
+	* gfortran.dg/associate_30.f90: New test.
+
+2017-10-16  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/81048
+	* gfortran.dg/derived_init_4.f90: New test.
+
+2017-10-13  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/82274
+	* gcc.dg/pr82274-1.c: New test.
+	* gcc.dg/pr82274-2.c: New test.
+
+	PR target/82524
+	* gcc.c-torture/execute/pr82524.c: New test.
+
+2017-10-09  James Cowgill  <James.Cowgill@imgtec.com>
+
+	* go.test/go-test.exp (go-set-goarch): Update MIPS architecture names.
+
+2017-10-06  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/82299
+	* g++.dg/cpp0x/pr82299.C: New test.
+
+2017-10-06  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	Backport from mainline r253251.
+	2017-09-27  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	PR target/71727
+	* gcc.target/aarch64/pr71727-2.c: New test.
+
+2017-10-03  Thomas Koenig  <tkoenig@gcc.gnu.org>
+	    Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/80118
+	* gfortran.dg/zero_sized_7.f90: New test.
+
+2017-10-02  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-09-29  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR tree-optimization/82337
+	* gcc.c-torture/compile/pr82337.c: New file.
+
+2017-09-30  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-09-29  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c/82340
+	* gcc.dg/tree-ssa/pr82340.c: New test.
+
+	2017-09-27  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/82159
+	* g++.dg/opt/pr82159.C: New test.
+
+2017-09-27  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	Backport from trunk r249639.
+	2017-06-26  Christophe Lyon  <christophe.lyon@linaro.org>
+
+	* lib/target-supports.exp
+	(check_effective_target_arm_neon_ok_nocache): Add flags with
+	-mfloat-abi=hard. Include arm_neon.h.
+	(check_effective_target_arm_neon_ok_no_float_abi_nocache): New.
+	(check_effective_target_arm_neon_ok_no_float_abi): New.
+	* gcc.target/arm/lto/pr65837_0.c: Require
+	arm_neon_ok_no_float_abi. Add -mfpu=neon to dg-lto-options.
+	* gcc.target/arm/lto/pr65837-attr_0.c: Require
+	arm_neon_ok_no_float_abi. Remove dg-suppress-ld-options.
+
+2017-09-26  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-09-19  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82244
+	* gcc.dg/torture/pr82244.c: New testcase.
+
+	2017-09-21  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82276
+	PR tree-optimization/82244
+	* gcc.dg/torture/pr82276.c: New testcase.
+
+	2017-09-20  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82264
+	* gcc.dg/torture/pr82264.c: New testcase.
+
+	2017-09-25  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82285
+	* gcc.dg/torture/pr82285.c: New testcase.
+
+	2017-09-22  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82291
+	* gcc.dg/torture/pr82291.c: New testcase.
+
+2017-09-22  Jakub Jelinek  <jakub@redhat.com>
+
+	PR sanitizer/81929
+	* g++.dg/ubsan/pr81929.C: New test.
+
+2017-09-19  Martin Liska  <mliska@suse.cz>
+
+	Revert backport:
+	2017-08-10  Martin Liska  <mliska@suse.cz>
+
+	PR c++/81355
+	* g++.dg/other/pr81355.C: New test.
+
+2017-09-18  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-09-04  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82084
+	* g++.dg/torture/pr82084.C: New testcase.
+
+	2017-09-06  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/82108
+	* gcc.dg/vect/pr82108.c: New testcase.
+
+2017-09-15  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-09-14  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/81325
+	* g++.dg/cpp0x/pr81325.C: New test.
+
+	2017-09-12  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/82112
+	* gcc.target/powerpc/pr82112.c: New test.
+	* g++.dg/ext/altivec-18.C: New test.
+
+	PR target/82112
+	* c-c++-common/pr82112.c: New test.
+	* gcc.dg/pr82112.c: New test.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-09-12  Martin Liska  <mliska@suse.cz>
+
+	PR testsuite/82114
+	* gcc.dg/gimplefe-14.c (main): Add handling of case 0.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-08-30  Martin Liska  <mliska@suse.cz>
+
+	PR inline-asm/82001
+	* gcc.dg/ipa/pr82001.c: New test.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-08-10  Martin Liska  <mliska@suse.cz>
+
+	PR c++/81355
+	* g++.dg/other/pr81355.C: New test.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-08-08  Martin Liska  <mliska@suse.cz>
+
+	PR tree-opt/81696
+	* gcc.dg/ipa/pr81696.c: New test.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-07-19  Martin Liska  <mliska@suse.cz>
+
+	PR sanitizer/63361
+	* c-c++-common/ubsan/float-cast-overflow-1.c: Add either
+	-ffloat-store or -mieee for targets that need it.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-06-28  Martin Liska  <mliska@suse.cz>
+
+	PR ipa/81128
+	* gcc.target/i386/pr81128.c: New test.
+
+2017-09-12  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-09-05  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR target/81833
+	* gcc.target/powerpc/pr81833-1.c: New file.
+	* gcc.target/powerpc/pr81833-2.c: New file.
+
+2017-09-10  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-05-11  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR target/80695
+	* gcc.target/powerpc/pr80695-p8.c: New file.
+	* gcc.target/powerpc/pr80695-p9.c: New file.
+
+2017-09-10  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR ada/79441
+	* gnat.dg/pack9.adb: Robustify.
+
+2017-09-10  Jonathan Wakely  <jwakely@redhat.com>
+
+	PR c++/81852
+	* g++.dg/cpp1y/feat-cxx11.C: Check __cpp_threadsafe_static_init.
+	* g++.dg/cpp1y/feat-cxx14.C: Likewise.
+	* g++.dg/cpp1y/feat-cxx98.C: Likewise.
+	* g++.dg/cpp1y/feat-neg.C: Likewise.
+	* g++.dg/cpp1z/feat-cxx1z.C: Likewise.
+
+2017-09-09  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gnat.dg/specs/atomic3.ads: New test.
+
+2017-09-09  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gnat.dg/specs/vfa.ads: Rename into...
+	* gnat.dg/specs/vfa1.ads: ...this.
+	* gnat.dg/specs/vfa2.ads: New test.
+
+2017-09-08  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc.dg/pr81988.c: New test.
+
+2017-09-07  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-09-05  Jakub Jelinek  <jakub@redhat.com>
+
+	PR middle-end/81768
+	* gcc.dg/gomp/pr81768-2.c: New test.
+
+	PR middle-end/81768
+	* gcc.dg/gomp/pr81768-1.c: New test.
+
+	2017-09-01  Jakub Jelinek  <jakub@redhat.com>
+
+	PR sanitizer/81923
+	* gcc.dg/asan/pr81923.c: New test.
+
+	2017-08-03  Jakub Jelinek  <jakub@redhat.com>
+
+	PR target/81621
+	* gcc.dg/pr81621.c: New test.
+
+	PR driver/81650
+	* gcc.dg/pr81650.c: New test.
+
+	PR middle-end/81052
+	* c-c++-common/pr81052.c: New test.
+
+2017-09-06  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline:
+	2017-08-30  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR tree-optimization/81987
+	* g++.dg/torture/pr81987.C: New file.
+
+2017-09-06  Jakub Jelinek  <jakub@redhat.com>
+
+	PR testsuite/82120
+	* gcc.dg/tree-ssa/pr81588.c: Don't run on logical_op_short_circuit
+	targets except for those where -mbranch-cost=2 is supported.
+
+2017-09-05  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-08-29  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+		    Jakub Jelinek  <jakub@redhat.com>
+		    Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/81503
+	* gcc.c-torture/execute/pr81503.c: New file.
+
+2017-09-05  Pierre-Marie de Rodat  <derodat@adacore.com>
+
+	Backport from trunk
+	PR ada/79542
+	* gnat.dg/debug13.ads, gnat.dg/debug13.adb: New testcase.
+
+2017-09-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gnat.dg/incomplete5.ad[sb]: New test.
+	* gnat.dg/incomplete5_pkg.ad[sb]: New helper.
+
+2017-09-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gnat.dg/specs/uc2.ads: New test.
+
+2017-09-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* testsuite/gnat.dg/array29.ad[sb]: New test.
+
+2017-09-04  Uros Bizjak  <ubizjak@gmail.com>
+
+	* gcc.target/i386/mpx/mpx-os-support.h: New file.
+	* gcc.target/i386/mpx/mpx-check.h: Include mpx-os-support.h.
+	(check_osxsave): New function.
+	(main): Use __get_cpuid_count and return NORUNRES on failure.
+	Use check_osxsave.
+	* gcc.target/i386/mpx/va-arg-pack-1-lbv.c (foo1): Use
+	__builtin_va_arg_pack instead of __va_arg_pack.
+	* gcc.target/i386/mpx/va-arg-pack-1-nov.c (foo1): Ditto.
+	* gcc.target/i386/mpx/va-arg-pack-1-ubv.c (foo1): Ditto.
+	* gcc.target/i386/mpx/va-arg-pack-2-lbv.c (foo1): Ditto.
+	* gcc.target/i386/mpx/va-arg-pack-2-nov.c (foo1): Ditto.
+	* gcc.target/i386/mpx/va-arg-pack-2-ubv.c (foo1): Ditto.
+
+2017-09-02  Janus Weil  <janus@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/81770
+	* gfortran.dg/warn_target_lifetime_3.f90: Fix a typo.
+	* gfortran.dg/warn_target_lifetime_4.f90: New testcase.
+
+2017-08-29  Michael Meissner  <meissner@linux.vnet.ibm.com>
+
+	Back port from trunk
+	2017-08-07  Michael Meissner  <meissner@linux.vnet.ibm.com>
+
+	PR target/81593
+	* gcc.target/powerpc/vec-setup.h: New tests to test various
+	combinations of setting up vectors of 2 double word elements.
+	* gcc.target/powerpc/vec-setup-long.c: Likewise.
+	* gcc.target/powerpc/vec-setup-double.c: Likewise.
+	* gcc.target/powerpc/vec-setup-be-long.c: Likewise.
+	* gcc.target/powerpc/vec-setup-be-double.c: Likewise.
+	* gcc.target/powerpc/vsx-extract-6.c: New tests for optimzing
+	vector inserts from vector extracts.
+	* gcc.target/powerpc/vsx-extract-7.c: Likewise.
+
+2017-08-29  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-08-28  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/81977
+	* g++.dg/torture/pr81977.C: New testcase.
+
+2017-08-28  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-06-14  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/81088
+	* c-c++-common/ubsan/pr81088.c: New testcase.
+
+	2017-06-13  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/81065
+	* c-c++-common/ubsan/pr81065.c: New testcase.
+
+	2017-06-08  Marek Polacek  <polacek@redhat.com>
+
+	PR sanitize/80932
+	* c-c++-common/ubsan/pr80932.c: Test with ints, not with long ints.
+
+	2017-06-07  Marek Polacek  <polacek@redhat.com>
+
+	PR sanitizer/80932
+	* c-c++-common/ubsan/pr80932.c: New test.
+
+2017-08-28  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-08-21  Richard Biener  <rguenther@suse.de>
+
+	PR middle-end/81884
+	* g++.dg/torture/pr81884.C: New testcase.
+
+2017-08-28  Richard Biener  <rguenther@suse.de>
+
+	Backport from mainline
+	2017-08-01  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/81181
+	* gcc.dg/torture/pr81181.c: New testcase.
+
+	2017-08-08  Richard Biener  <rguenther@suse.de>
+
+	PR tree-optimization/81723
+	* gfortran.dg/pr81723.f: New testcase.
+
+	2017-08-24  Richard Biener  <rguenther@suse.de>
+
+	PR target/81921
+	* gcc/testsuite/gcc.target/i386/pr81921.c: New testcase.
+
+2017-05-19  Uros Bizjak  <ubizjak@gmail.com>
+
+	Backport from mainline
+	2017-08-23  Daniel Santos  <daniel.santos@pobox.com>
+
+	* lib/target-supports.exp (check_avx2_hw_available):
+	Fix breakage due NULL being undefined.
+
+2017-08-23  Peter Bergner  <bergner@vnet.ibm.com>
+
+	Backport from mainline
+	2017-08-17  Peter Bergner  <bergner@vnet.ibm.com>
+
+	PR target/72804
+	* gcc.target/powerpc/pr72804.c: New test.
+
+2017-08-22  Jerry DeLisle  <jvdelisle@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/81296
+	* gfortran.dg/dtio_12.f90: Update test.
+
+2017-08-22  Peter Bergner  <bergner@vnet.ibm.com>
+
+	Backport from mainline
+	2017-08-17  Peter Bergner  <bergner@vnet.ibm.com>
+
+	PR target/80210
+	* gcc.target/powerpc/pr80210.c: New test.
+
+2017-08-22  Yvan Roux  <yvan.roux@linaro.org>
+
+	Backport from mainline
+	2017-08-22  Yvan Roux  <yvan.roux@linaro.org>
+
+	PR c++/80287
+	* g++.dg/pr80287.C: New test.
+
+2017-08-20  John David Anglin  <danglin@gcc.gnu.org>
+
+	PR ipa/77732
+	* gcc.dg/ipa/ipcp-cstagg-7.c: Xfail on 32-bit hppa.
+
+2017-08-18  Jerry DeLisle  <jvdelisle@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/80164
+	* gfortran.dg/array_temporaries_4.f90: New test.
+
+2017-08-16  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	Backport from mainline
+	2017-08-08  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR tree-optimization/81354
+	* g++.dg/torture/pr81354.C: New file.
+
+2017-08-15  Joseph Myers  <joseph@codesourcery.com>
+
+	PR target/78460
+	PR target/67712
+	* gcc.c-torture/compile/string-large-1.c: New test.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
@@ -150,7 +807,7 @@
 	* gfortran.dg/pr81175.f: New testcase.
 
 	2017-06-21  Marc Glisse  <marc.glisse@inria.fr>
- 
+
  	* gcc.dg/tree-ssa/addadd.c: Un-XFAIL.
  	* gcc.dg/tree-ssa/addadd-2.c: New file.
 
@@ -358,7 +1015,7 @@
 	* c-c++-common/ubsan/sanitize-recover-7.c (dg-options): Add -w.
 
 2017-06-24  Marek Polacek  <polacek@redhat.com>
-	
+
 	Backport from mainline
 	2017-05-04  Marek Polacek  <polacek@redhat.com>
 
@@ -2273,7 +2930,7 @@
 
 	PR fortran/80156
 	PR fortran/79382
-	* gfortran.dg/dtio_23.f90 : Remove the dg-error and add the
+	* gfortran.dg/dtio_23.f90: Remove the dg-error and add the
 	testcase for PR80156. Add a main programme that tests that
 	the typebound generic is accessible.
 
@@ -2609,13 +3266,13 @@
 2017-03-18  Paul Thomas  <pault@gcc.gnu.org>
 
 	PR fortran/79676
-	* gfortran.dg/submodule_28.f08 : New test.
+	* gfortran.dg/submodule_28.f08: New test.
 
 2017-03-18  Paul Thomas  <pault@gcc.gnu.org>
 
 	PR fortran/71838
-	* gfortran.dg/submodule_26.f08 : New test.
-	* gfortran.dg/submodule_27.f08 : New test.
+	* gfortran.dg/submodule_26.f08: New test.
+	* gfortran.dg/submodule_27.f08: New test.
 
 2017-03-17  Pat Haugen  <pthaugen@us.ibm.com>
 
@@ -3474,6 +4131,11 @@
 	PR lto/79587
 	* gcc.dg/tree-prof/pr79587.c: New test.
 
+2017-02-22  Bill Schmidt  <wschmidt@linux.vnet.ibm.com>
+
+	PR tree-optimization/68644
+	* gcc.dg/tree-ssa/ivopts-lt-2.c: Skip for powerpc*-*-*.
+
 2017-02-21  Marek Polacek  <polacek@redhat.com>
 
 	PR c++/79535
Index: gcc/testsuite/g++.dg/opt/pr82159-2.C
===================================================================
--- gcc/testsuite/g++.dg/opt/pr82159-2.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/opt/pr82159-2.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,65 @@
+// PR c++/82159
+// { dg-do compile }
+// { dg-options "" }
+
+template <typename T> struct D { T e; };
+struct F : D<int[0]> {
+  F(const F &);
+};
+struct G : F {
+  template <class T> G operator-(T);
+};
+template <class T> struct I {
+  typedef typename T::template J<I> ak;
+};
+template <class T> struct K { typename I<T>::ak an; };
+struct H {
+  G l;
+};
+struct C {
+  ~C();
+};
+template <class T> struct M : T {
+  template <typename U, typename V> M(U, V);
+  H h;
+  virtual void foo() { T::bar(&h); }
+};
+template <int, typename> class A;
+template <class> struct B {
+  typedef int BT;
+  struct BC {};
+  template <class T> struct BD {
+    G g;
+    BD(BT, T n) : g(n.l - 0) {}
+  };
+  B(BT, BC);
+};
+template <typename> struct O;
+template <int T, typename U>
+struct O<B<A<T, U> > > : public B<A<T, U> >::BC {};
+struct L : B<A<2, double> > {
+  struct P : C {
+    void bar(H *x) {
+      BT a;
+      BD<H>(a, *x);
+    }
+  };
+  template <typename U, typename V> L(U x, V n) : B(x, n) {}
+  int ll;
+  virtual int baz() { M<P>(this, ll); }
+};
+template <typename> class Q {
+  O<B<A<2, double> > > q;
+  virtual L baz() { L(0, q); }
+};
+template <template <class> class T> struct R {
+  R() { T<int>(); }
+};
+struct S {
+  template <class> class J : R<Q> {};
+};
+void foo() { K<S> c; }
+
+int main() {
+  return 0;
+}
Index: gcc/testsuite/g++.dg/opt/pr82159.C
===================================================================
--- gcc/testsuite/g++.dg/opt/pr82159.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/opt/pr82159.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,18 @@
+// PR c++/82159
+// { dg-do compile }
+// { dg-options "" }
+
+template<int N>
+struct S
+{
+  ~S () {}
+  template<int M> S<M> foo () { return S<M> (); }
+  unsigned char data[N];
+};
+
+int
+main ()
+{
+  S<16> d;
+  S<0> t = d.foo<0> ();
+}
Index: gcc/testsuite/g++.dg/ubsan/pr81929.C
===================================================================
--- gcc/testsuite/g++.dg/ubsan/pr81929.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/ubsan/pr81929.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,14 @@
+// PR sanitizer/81929
+// { dg-do compile }
+// { dg-options "-std=c++14 -fsanitize=undefined" }
+
+struct S { S &operator<< (long); S foo (); S (); };
+
+void
+bar ()
+{
+  static_cast<S&>(S () << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0
+		       << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0
+		       << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0
+		       << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0 << 0).foo ();
+}
Index: gcc/testsuite/g++.dg/cpp0x/nullptr39.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/nullptr39.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp0x/nullptr39.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,15 @@
+// PR c++/81671
+// { dg-do compile { target c++11 } }
+
+namespace std { typedef decltype(nullptr) nullptr_t; }
+
+template<class R, class CB> struct Bar
+{};
+template<class R> struct Bar<R, std::nullptr_t>
+{
+    template<std::nullptr_t> struct Bind { constexpr static int const cb = 0; };
+};
+int foo()
+{
+  return Bar<int, decltype(nullptr)>::Bind<nullptr>::cb;
+}
Index: gcc/testsuite/g++.dg/cpp0x/lambda/lambda-conv12.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/lambda/lambda-conv12.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp0x/lambda/lambda-conv12.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,18 @@
+// PR c++/80767
+// { dg-do compile { target c++11 } }
+
+template <typename T, typename U = T> struct A { using type = U; };
+template <typename F, typename... G> struct B : B<F>::type, B<G...>::type {
+  using type = B;
+  using B<F>::type::operator();
+};
+template <typename F> struct B<F> { using type = F; };
+struct {
+  template <typename... F,
+            typename Overload = typename B<typename A<F>::type...>::type>
+  Overload operator()(F...){}
+} a;
+int main() {
+  auto f = a([](int) {}, [](float) {});
+  f({});
+}
Index: gcc/testsuite/g++.dg/cpp0x/pr82299.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/pr82299.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp0x/pr82299.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,9 @@
+// PR c++/82299
+// { dg-do compile { target c++11 } }
+// { dg-options "-Wuseless-cast" }
+
+enum Enum : char { A = 0, B = 1 };
+
+struct S {
+  Enum e { Enum::A };	// { dg-bogus "useless cast to type" }
+};
Index: gcc/testsuite/g++.dg/cpp0x/pr81325.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/pr81325.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp0x/pr81325.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,84 @@
+// PR target/81325
+// { dg-do compile { target c++11 } }
+// { dg-options "-O2 -fcompare-debug" }
+
+struct A { A(const char *, const int & = 0); };
+template <typename> struct B;
+template <typename> struct C {
+  int _M_i;
+  void m_fn1() { __atomic_fetch_add(&_M_i, 0, __ATOMIC_RELAXED); }
+};
+struct D {
+  int *Data;
+  long Length = 0;
+  D(int) : Data() {}
+};
+template <> struct B<int> : C<int> {};
+struct F {
+  B<int> RefCount;
+  void m_fn2() { RefCount.m_fn1(); }
+};
+struct G {
+  F *Obj;
+  G(const G &p1) : Obj(p1.Obj) {
+    if (Obj) {
+      F *a = 0;
+      a->m_fn2();
+    }
+  }
+};
+struct H {
+  int CPlusPlus : 1;
+};
+struct I {
+  enum {} KindId;
+};
+template <typename ResultT, typename ArgT> struct J {
+  void operator()();
+  ResultT operator()(ArgT) {}
+};
+struct K {
+  int AllowBind;
+  I SupportedKind;
+  I RestrictKind;
+  G Implementation;
+};
+struct L {
+  L(int) : Implementation(Implementation) {}
+  K Implementation;
+};
+struct M {
+  int Param1;
+};
+struct N {
+  N(int, L &p2) : Param2(p2) {}
+  L Param2;
+};
+struct O {
+  L m_fn3();
+};
+L ignoringImpCasts(L);
+J<O, L> b;
+L hasName(const A &);
+M hasOverloadedOperatorName(D);
+J<O, int> c;
+struct P {
+  void m_fn4(L, int);
+};
+struct Q {
+  void m_fn5(P *);
+};
+H d;
+void Q::m_fn5(P *p1) {
+  if (!d.CPlusPlus) {
+    c();
+    L e = 0, f = ignoringImpCasts(e);
+    b(ignoringImpCasts(f)).m_fn3();
+  }
+  hasOverloadedOperatorName(0);
+  hasName("");
+  L g = 0;
+  N(0, g);
+  L h(0);
+  p1->m_fn4(h, 0);
+}
Index: gcc/testsuite/g++.dg/cpp0x/pr82560.C
===================================================================
--- gcc/testsuite/g++.dg/cpp0x/pr82560.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp0x/pr82560.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,28 @@
+// { dg-do run { target c++11 } }
+// PR82560, failed to destruct default arg inside new
+
+static int liveness = 0;
+
+struct Foo {
+
+  Foo (int) {
+    liveness++;
+  }
+
+  ~Foo() {
+    liveness--;
+  }
+
+};
+
+struct Bar {
+  Bar (Foo = 0) { }
+  ~Bar() { }
+};
+
+int main()
+{
+  delete new Bar();
+
+  return liveness != 0;;
+}
Index: gcc/testsuite/g++.dg/torture/pr81884.C
===================================================================
--- gcc/testsuite/g++.dg/torture/pr81884.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/torture/pr81884.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,39 @@
+/* { dg-do run } */
+
+typedef unsigned long uint64_t;
+
+struct value_t {
+    uint64_t _count;
+    value_t(uint64_t c) : _count(c) {}
+};
+
+struct X {
+    value_t eventTime;
+    uint64_t arr[0];
+};
+
+X* x;
+
+__attribute__((noclone, noinline))
+void initialize()
+{
+  x->arr[0] = 11;
+  x->arr[1] = 12;
+  x->eventTime = value_t(10);
+  x->arr[2] = 13;
+  x->arr[3] = 14;
+}
+
+int main()
+{
+  char buffer[sizeof(X) + sizeof(uint64_t)*4];
+  x = (X*)buffer;
+  x->eventTime = value_t(999);
+  x->arr[0] = 1;
+  x->arr[1] = 2;
+  x->arr[2] = 3;
+  x->arr[3] = 4;
+  initialize();
+  if (x->arr[0] != 11 || x->arr[1] != 12 || x->arr[2] != 13 || x->arr[3] != 14)
+    __builtin_abort ();
+}
Index: gcc/testsuite/g++.dg/torture/pr81354.C
===================================================================
--- gcc/testsuite/g++.dg/torture/pr81354.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/torture/pr81354.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,24 @@
+// PR81354 reported this test as crashing in a limited range of revisions.
+// { dg-do compile }
+
+struct T { double a; double b; };
+
+void foo(T Ad[], int As[2])
+{
+  int j;
+  int i;
+  int Bs[2] = {0,0};
+  T Bd[16];
+
+  for (j = 0; j < 4; j++) {
+    for (i = 0; i + 1 <= j + 1; i++) {
+      Ad[i + As[0] * j] = Bd[i + Bs[0] * j];
+    }
+
+    i = j + 1;  // <- comment out this line and it does not crash
+    for (; i + 1 < 5; i++) {
+      Ad[i + As[0] * j].a = 0.0;
+      Ad[i + As[0] * j].b = 0.0;
+    }
+  }
+}
Index: gcc/testsuite/g++.dg/torture/pr82084.C
===================================================================
--- gcc/testsuite/g++.dg/torture/pr82084.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/torture/pr82084.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,9 @@
+// { dg-do compile }
+
+#include <string>
+int main()
+{
+  wchar_t strs[4][2]= {  L"A", L"B", L"C" , L"D"};
+  std::wstring ss(strs[0]);
+  return 0;
+}
Index: gcc/testsuite/g++.dg/torture/pr81977.C
===================================================================
--- gcc/testsuite/g++.dg/torture/pr81977.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/torture/pr81977.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,55 @@
+/* { dg-do run } */
+/* { dg-require-effective-target int32plus } */
+
+#include <cstdint>
+
+typedef struct
+{
+  uint16_t  x ;
+  uint16_t  y ;
+  uint64_t  z ;
+} __attribute__((packed, aligned(1))) TestMsgType;
+
+struct Payload
+{
+  uint16_t header_info[2];
+  TestMsgType _pref;
+  void Pack(uint8_t *buffer)
+    {
+      __builtin_memcpy(buffer, &_pref, sizeof(_pref));
+    }
+  void UnPack(uint8_t *buffer)
+    {
+      __builtin_memcpy(&_pref, buffer, sizeof(_pref));
+    }
+};
+
+
+struct Msg
+{
+  Payload _payload;
+  void Pack(uint8_t *buffer)
+    {
+      _payload.Pack(buffer);
+    }
+
+  void UnPack(uint8_t *buffer)
+    {
+      _payload.UnPack(buffer);
+    }
+};
+
+int main()
+{
+  uint8_t * buffer = new uint8_t [30];
+  Msg msg;
+  Msg msg1;
+  msg._payload._pref.x             = 0xabcd;
+  msg._payload._pref.y             = 0xa;
+  msg._payload._pref.z             = 0x0001020304051617;
+  msg.Pack(&buffer[0]);
+  msg1.UnPack(&buffer[0]);
+  if (msg1._payload._pref.x != 0xabcd)
+    __builtin_abort ();
+  delete [] buffer;
+}
Index: gcc/testsuite/g++.dg/torture/pr81987.C
===================================================================
--- gcc/testsuite/g++.dg/torture/pr81987.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/torture/pr81987.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,61 @@
+extern short var_1;
+extern const short var_3;
+extern unsigned long int var_9;
+extern short var_13;
+extern const unsigned long int var_15;
+extern const unsigned long int var_37;
+extern unsigned long int var_40;
+extern long long int var_47;
+extern short var_48;
+extern const short var_54;
+extern long long int var_79;
+extern long long int var_81;
+extern long long int var_94;
+extern long long int var_95;
+extern long long int var_701;
+extern unsigned long int var_786;
+extern short var_788;
+extern long long int var_844;
+
+struct struct_1 {
+  short member_1_2 : 15;
+  static long long int member_1_3;
+};
+
+extern struct_1 struct_obj_6;
+extern struct_1 struct_obj_8;
+
+void foo() {
+  int a = var_3 <= 602154393864UL;
+  if (var_81 ? 0 : var_3 && var_9)
+    ;
+  else {
+    var_94 = 0;
+    if (var_3 && var_48 || var_13) {
+      if (var_48)
+	var_95 = 0;
+      short b((2364461588881776511UL + var_3) * (2 ? var_13 : 0) || var_1);
+      struct_obj_8.member_1_2 = b;
+      if (var_15) {
+	if (var_81)
+	  if (var_47)
+	    ;
+	  else if (var_40)
+	    var_701 = 0;
+      } else {
+	if (var_40)
+	  var_79 = 0;
+	if (var_54) {
+	  if (var_37)
+	    var_786 = 0;
+	  else
+	    var_788 = 0;
+	            struct_obj_6.member_1_3 =
+		      (2364461588881776511UL + var_3) * (2 ? var_13 : 0);
+	}
+      }
+      if ((2364461588881776511UL + var_3) * (2 ? var_13 : 0))
+	var_844 = 0;
+    }
+  }
+}
Index: gcc/testsuite/g++.dg/cpp1y/feat-cxx11.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/feat-cxx11.C	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/g++.dg/cpp1y/feat-cxx11.C	(.../branches/gcc-7-branch)
@@ -125,6 +125,12 @@
 #  error "__cpp_alias_templates != 200704"
 #endif
 
+#ifndef __cpp_threadsafe_static_init
+#  error "__cpp_threadsafe_static_init"
+#elif __cpp_threadsafe_static_init != 200806
+#  error "__cpp_threadsafe_static_init != 200806"
+#endif
+
 //  C++14 features allowed in C++11 in non-ANSI modes:
 
 #ifndef __cpp_binary_literals
Index: gcc/testsuite/g++.dg/cpp1y/lambda-generic-auto1.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/lambda-generic-auto1.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/lambda-generic-auto1.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,19 @@
+// Related to c++/81525
+// { dg-do compile { target c++14 } }
+
+template <class X>
+struct A
+{
+  template <class T>
+  static void f()
+  {
+    [](auto b) {
+      auto c = +b;
+    }(42);
+  }
+};
+
+int main()
+{
+  A<int>::f<int>();
+}
Index: gcc/testsuite/g++.dg/cpp1y/lambda-generic-this1.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/lambda-generic-this1.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/lambda-generic-this1.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,17 @@
+// PR c++/81236
+// { dg-do compile { target c++14 } }
+
+struct A { constexpr operator int() { return 24; } };
+
+struct MyType {
+  void crash() {
+    auto l = [&](auto i){
+      make_crash<i>(); // Line (1)
+    };
+
+    l(A{});
+  }
+    
+  template<int i>
+  void make_crash() {}
+};
Index: gcc/testsuite/g++.dg/cpp1y/var-templ56.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/var-templ56.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/var-templ56.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,11 @@
+// PR c++/82085
+// { dg-do compile { target c++14 } }
+
+template <const char& V>
+using char_sequence_t = int;
+
+template <typename T>
+constexpr char name_of_v = 'x';
+
+template <typename T>
+using type = char_sequence_t<name_of_v<T>>;
Index: gcc/testsuite/g++.dg/cpp1y/lambda-generic-const4.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/lambda-generic-const4.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/lambda-generic-const4.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,20 @@
+// PR c++/81525
+// { dg-do compile { target c++14 } }
+
+template <int i> struct A {
+  constexpr operator int () const { return i; }
+};
+template <int i> constexpr A<i> a = {};
+
+template <typename F> void foo (F f) {
+  f (A<0>{});
+}
+template <typename T>
+void bar (T) {
+  constexpr auto N = a<1>;
+  auto f = [&] (auto i) {
+    static_assert (static_cast<int>(N) == 1, "");
+  };
+  foo (f);
+}
+int main () { bar (0); }
Index: gcc/testsuite/g++.dg/cpp1y/feat-cxx14.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/feat-cxx14.C	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/g++.dg/cpp1y/feat-cxx14.C	(.../branches/gcc-7-branch)
@@ -118,6 +118,12 @@
 #  error "__cpp_alias_templates != 200704"
 #endif
 
+#ifndef __cpp_threadsafe_static_init
+#  error "__cpp_threadsafe_static_init"
+#elif __cpp_threadsafe_static_init != 200806
+#  error "__cpp_threadsafe_static_init != 200806"
+#endif
+
 //  C++14 features:
 
 #ifndef __cpp_binary_literals
Index: gcc/testsuite/g++.dg/cpp1y/feat-cxx98.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/feat-cxx98.C	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/g++.dg/cpp1y/feat-cxx98.C	(.../branches/gcc-7-branch)
@@ -15,6 +15,14 @@
 #  error "__cpp_exceptions != 199711"
 #endif
 
+//  C++11 features allowed in C++98:
+
+#ifndef __cpp_threadsafe_static_init
+#  error "__cpp_threadsafe_static_init"
+#elif __cpp_threadsafe_static_init != 200806
+#  error "__cpp_threadsafe_static_init != 200806"
+#endif
+
 //  C++14 features allowed in C++98 in non-ANSI modes:
 
 #ifndef __cpp_binary_literals
Index: gcc/testsuite/g++.dg/cpp1y/lambda-generic-const5.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/lambda-generic-const5.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/lambda-generic-const5.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,17 @@
+// PR c++/78840
+// { dg-do compile { target c++14 } }
+
+int global;
+
+void Bar (int);
+
+template<int I> void Foo () {
+  const int cst = global;
+  auto lam0 = [&]() -> void {
+    auto lam1 = [&]() -> void { cst; };
+    
+    Bar (cst);
+  };
+}
+
+template void Foo <0> ();
Index: gcc/testsuite/g++.dg/cpp1y/feat-neg.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/feat-neg.C	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/g++.dg/cpp1y/feat-neg.C	(.../branches/gcc-7-branch)
@@ -1,5 +1,5 @@
 // { dg-do compile }
-// { dg-options "-fno-rtti -fno-exceptions" }
+// { dg-options "-fno-rtti -fno-exceptions -fno-threadsafe-statics" }
 
 //  C++98 features with explicit opt-out:
 
@@ -10,3 +10,9 @@
 #ifndef __cpp_exceptions
 #  error "__cpp_exceptions" // { dg-error "error" }
 #endif
+
+//  C++11 features with explicit opt-out:
+
+#ifndef __cpp_threadsafe_static_init
+#  error "__cpp_threadsafe_static_init" // { dg-error "error" }
+#endif
Index: gcc/testsuite/g++.dg/cpp1y/lambda-generic-this1a.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/lambda-generic-this1a.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/lambda-generic-this1a.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,17 @@
+// PR c++/81236
+// { dg-do compile { target c++14 } }
+
+struct A { constexpr operator int() { return 24; } };
+
+struct MyType {
+  void crash() {
+    auto l = [&](auto i){
+      MyType::make_crash<i>(); // Line (1)
+    };
+
+    l(A{});
+  }
+    
+  template<int i>
+  void make_crash() {}
+};
Index: gcc/testsuite/g++.dg/cpp1y/pr82373.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1y/pr82373.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1y/pr82373.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,20 @@
+// PR c++/82373
+// { dg-do compile { target c++14 } }
+
+namespace N
+{
+  int (*fp)(int);
+  auto foo(int a)	// { dg-message "In function 'auto N::foo\\(int\\)'" "" { target *-*-* } 0 }
+  {
+    if (a)
+      return fp;
+    return nullptr;	// { dg-error "inconsistent deduction for auto return type: 'int \\(\\*\\)\\(int\\)' and then 'std::nullptr_t'" } */
+  }
+}
+int (*fp2)(int);
+auto bar(int a)		// { dg-message "In function 'auto bar\\(int\\)'" "" { target *-*-* } 0 }
+{
+  if (a)
+    return fp2;
+  return nullptr;	// { dg-error "inconsistent deduction for auto return type: 'int \\(\\*\\)\\(int\\)' and then 'std::nullptr_t'" } */
+}
Index: gcc/testsuite/g++.dg/cpp1z/feat-cxx1z.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1z/feat-cxx1z.C	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/g++.dg/cpp1z/feat-cxx1z.C	(.../branches/gcc-7-branch)
@@ -106,6 +106,12 @@
 #  error "__cpp_alias_templates != 200704"
 #endif
 
+#ifndef __cpp_threadsafe_static_init
+#  error "__cpp_threadsafe_static_init"
+#elif __cpp_threadsafe_static_init != 200806
+#  error "__cpp_threadsafe_static_init != 200806"
+#endif
+
 //  C++14 features:
 
 #ifndef __cpp_binary_literals
Index: gcc/testsuite/g++.dg/cpp1z/constexpr-lambda16.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1z/constexpr-lambda16.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1z/constexpr-lambda16.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,15 @@
+// PR c++/80642
+// { dg-do compile { target c++14 } }
+
+int main()
+{
+  [](auto i)
+    {
+      if (i)
+        {
+	  int j;
+	  return i + j;
+        }
+      return i;
+    }(0);
+}
Index: gcc/testsuite/g++.dg/cpp1z/lambda-inherit1.C
===================================================================
--- gcc/testsuite/g++.dg/cpp1z/lambda-inherit1.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/cpp1z/lambda-inherit1.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,23 @@
+// PR c++/80767
+// { dg-options -std=c++17 }
+
+template <typename... Fs> 
+struct overloader : Fs...
+{
+    overloader(Fs... fs) 
+        : Fs(fs)...
+    { } 
+
+    using Fs::operator()...;
+};
+
+struct a { void foo() { } };
+struct b { void bar() { } };
+struct c { void bar() { } };
+
+int main() {
+    overloader{
+        [](a x) { x.foo(); },
+        [](auto x) { x.bar(); }
+    }(a{});
+}
Index: gcc/testsuite/g++.dg/ext/attrib54.C
===================================================================
--- gcc/testsuite/g++.dg/ext/attrib54.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/ext/attrib54.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,14 @@
+// PR c++/82406
+
+class a
+{
+public:
+  template <typename b> void operator() (const b &);
+};
+void c () throw () __attribute__ ((__nonnull__));
+void
+d ()
+{
+  a e;
+  e (c);
+}
Index: gcc/testsuite/g++.dg/ext/altivec-18.C
===================================================================
--- gcc/testsuite/g++.dg/ext/altivec-18.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/ext/altivec-18.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,14 @@
+// PR target/82112
+// { dg-do compile { target powerpc*-*-* } }
+// { dg-require-effective-target powerpc_altivec_ok }
+// { dg-options "-maltivec" }
+
+#include <altivec.h>
+
+__attribute__((aligned (16))) extern const unsigned char c[16];
+
+void
+foo (void)
+{
+  vec_ld (0, c);
+}
Index: gcc/testsuite/g++.dg/ext/varargs2.C
===================================================================
--- gcc/testsuite/g++.dg/ext/varargs2.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/ext/varargs2.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,17 @@
+// { dg-do run }
+
+int c;
+struct X { X() {}; X(const X&) { ++c; } };
+void Foo (X, ...) {}
+void bin (X &p)
+{
+  Foo (p, p);
+}
+
+int main()
+{
+  X x;
+  bin(x);
+  if (c != 2)
+    __builtin_abort();
+}
Index: gcc/testsuite/g++.dg/pr80287.C
===================================================================
--- gcc/testsuite/g++.dg/pr80287.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/pr80287.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,13 @@
+// PR c++/80287
+// { dg-do compile { target c++11 } }
+// { dg-options "-g" }
+
+struct A {
+  operator long() {}
+} __attribute__((__may_alias__));
+
+struct {
+  A ino;
+} a;
+
+char b = a.ino;
Index: gcc/testsuite/g++.dg/other/bitfield6.C
===================================================================
--- gcc/testsuite/g++.dg/other/bitfield6.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/other/bitfield6.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,9 @@
+// PR c++/81607
+
+int a;
+
+struct b {
+  long c : 32;
+} d;
+
+char f = (903092 ? int(d.c) : 0) << a;
Index: gcc/testsuite/g++.dg/tree-ssa/pr81702.C
===================================================================
--- gcc/testsuite/g++.dg/tree-ssa/pr81702.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/tree-ssa/pr81702.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,110 @@
+// { dg-do compile }
+// { dg-options "-O2" }
+
+namespace std {
+  struct type_info
+  {
+    virtual bool __do_catch(const type_info *__thr_type, void **__thr_obj,
+       unsigned __outer) const;
+  };
+}
+
+template< typename VALUE_T, typename TYPE >
+struct List_policy
+{
+  typedef VALUE_T *Value_type;
+  typedef TYPE **Type;
+  typedef TYPE *Head_type;
+  typedef TYPE Item_type;
+};
+
+template< typename POLICY >
+class List
+{
+public:
+  typedef typename POLICY::Value_type Value_type;
+  class Iterator
+  {
+    typedef typename POLICY::Type Internal_type;
+  public:
+    typedef typename POLICY::Value_type value_type;
+    typedef typename POLICY::Value_type Value_type;
+    Value_type operator -> () const { return static_cast<Value_type>(*_c); }
+    Internal_type _c;
+  };
+  Iterator begin() { return Iterator(); }
+  Iterator end() { return Iterator(); }
+  typename POLICY::Head_type _f;
+};
+
+template<typename ELEM_TYPE> class H_list_item_t { };
+
+template< typename T, typename POLICY >
+class H_list : public List<POLICY>
+{
+public:
+  typedef typename POLICY::Item_type Item;
+  typedef List<POLICY> Base;
+  typedef typename Base::Iterator Iterator;
+  Iterator insert(T *e, Iterator const &pred)
+  {
+    Item **x = &this->_f;
+    *x = static_cast<Item*>(e);
+    return Iterator();
+  }
+};
+
+template< typename T >
+struct H_list_t : H_list<T, List_policy< T, H_list_item_t<T> > >
+{
+  H_list_t(bool b) : H_list<T, List_policy< T, H_list_item_t<T> > >(b) {}
+};
+
+template< typename BASE, typename MATCH_RESULT >
+struct Type_matcher : H_list_item_t<BASE>
+{
+  explicit Type_matcher(std::type_info const *type);
+  typedef MATCH_RESULT Match_result;
+
+private:
+  std::type_info *_type;
+  typedef H_list_t<BASE> List;
+  typedef typename List::Iterator Iterator;
+  static List _for_type;
+};
+
+template< typename BASE, typename MR >
+Type_matcher<BASE, MR>::Type_matcher(std::type_info const *t)
+{
+  Iterator c = _for_type.begin();
+  t->__do_catch(c->_type, 0, 0);
+  _for_type.insert(static_cast<BASE*>(this), _for_type.begin());
+}
+
+template< typename VI, typename HW >
+class Fa : public Type_matcher<Fa<VI, HW>, VI*>
+{
+public:
+  typedef Fa<VI, HW> Self;
+  virtual VI *do_match(HW *f) = 0;
+  explicit Fa(std::type_info const *type) : Type_matcher<Self, VI*>(type) {}
+};
+
+class Res {};
+typedef Fa<Res, Res> R_fac;
+
+template< typename VI, typename HW_BASE, typename HW, typename BASE >
+class Fa_t : public BASE
+{
+public:
+  Fa_t() : BASE(&typeid(HW)) {}
+  VI *do_match(HW_BASE *) { return 0; }
+};
+
+template< typename VI, typename HW >
+class Resource_factory_t : public Fa_t<VI, Res, HW, R_fac > {};
+
+class Foo {};
+class Foo2;
+class Foo3 : public Res {};
+Resource_factory_t<Foo3, Foo> _x;
Index: gcc/testsuite/g++.dg/lto/pr70029_0.C
===================================================================
--- gcc/testsuite/g++.dg/lto/pr70029_0.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/lto/pr70029_0.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,10 @@
+// PR c++/70029
+// { dg-lto-do assemble }
+
+struct A
+{
+  A();
+  int foo() && __attribute__ ((__warn_unused_result__)) { return 0; }
+};
+
+A a;
Index: gcc/testsuite/g++.dg/warn/Wbool-operation-1.C
===================================================================
--- gcc/testsuite/g++.dg/warn/Wbool-operation-1.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/warn/Wbool-operation-1.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,11 @@
+// PR c++/82040
+// { dg-do compile { target c++11 } }
+// { dg-options "-Wbool-operation" }
+
+template <class c>
+decltype (~c{})
+call ()
+{
+  return ~false; // { dg-warning "on an expression of type bool" }
+}
+template int call<bool>();
Index: gcc/testsuite/g++.dg/asan/pr81715.C
===================================================================
--- gcc/testsuite/g++.dg/asan/pr81715.C	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/g++.dg/asan/pr81715.C	(.../branches/gcc-7-branch)
@@ -0,0 +1,36 @@
+// PR sanitizer/81715
+// { dg-do compile }
+// Verify the variables for inlined foo parameters are reused
+// { dg-options "-fno-sanitize=address -fsanitize=kernel-address -O2 -Wframe-larger-than=16384" }
+
+struct S { int a, b, c, d, e; char f[1024]; };
+void baz (int *, int *, int *, struct S *, int *, int *);
+
+static inline struct S
+foo (int a, int b, int c, struct S d, int e, int f)
+{
+  struct S s;
+  baz (&a, &b, &c, &d, &e, &f);
+  s = d;
+  return s;
+}
+
+struct S g[64];
+
+void
+bar (int a, int b, int c, struct S d, int e, int f)
+{
+#define A(N) \
+  g[N+0] = foo (a, b, c, d, e, f);	\
+  g[N+1] = foo (a, b, c, d, e, f);	\
+  g[N+2] = foo (a, b, c, d, e, f);	\
+  g[N+3] = foo (a, b, c, d, e, f);	\
+  g[N+4] = foo (a, b, c, d, e, f);	\
+  g[N+5] = foo (a, b, c, d, e, f);	\
+  g[N+6] = foo (a, b, c, d, e, f);	\
+  g[N+7] = foo (a, b, c, d, e, f);	\
+  foo (a, b, c, d, e, f);		\
+  foo (a, b, c, d, e, f)
+  A(0); A(8); A(16); A(24);
+  A(32); A(40); A(48); A(56);
+}
Index: gcc/testsuite/c-c++-common/ubsan/pr81065.c
===================================================================
--- gcc/testsuite/c-c++-common/ubsan/pr81065.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/ubsan/pr81065.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,13 @@
+/* { dg-do run } */
+/* { dg-options "-fsanitize=undefined -fsanitize-undefined-trap-on-error" } */
+
+unsigned char x = 154;
+int foo() {
+  // 8575 * (254408 - 9057) = 8575 * 245351 = 2103884825 = 0x7d66bc19
+  return 8575 * (1652 * x - 9057);
+}
+
+int main() {
+  foo();
+  return 0;
+}
Index: gcc/testsuite/c-c++-common/ubsan/pr80932.c
===================================================================
--- gcc/testsuite/c-c++-common/ubsan/pr80932.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/ubsan/pr80932.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,17 @@
+/* PR sanitizer/80932 */
+/* { dg-do run } */
+/* { dg-options "-fsanitize=undefined -fsanitize-undefined-trap-on-error" } */
+
+int x = 1;
+
+int
+foo (void)
+{
+  return ((int) (2855545792U * x) - (int) (3269399503U * x)) * -5;
+}
+
+int
+main ()
+{
+  foo ();
+}
Index: gcc/testsuite/c-c++-common/ubsan/pr81088.c
===================================================================
--- gcc/testsuite/c-c++-common/ubsan/pr81088.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/ubsan/pr81088.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,11 @@
+/* { dg-do run } */
+/* { dg-options "-fsanitize=undefined -fsanitize-undefined-trap-on-error" } */
+
+short s = 2;
+short y = 1;
+int i;
+int main()
+{
+  i = -(s + (int)(~(unsigned)(0 / y))) + 0x7fffffff;
+  return 0;
+}
Index: gcc/testsuite/c-c++-common/ubsan/float-cast-overflow-1.c
===================================================================
--- gcc/testsuite/c-c++-common/ubsan/float-cast-overflow-1.c	(.../tags/gcc_7_2_0_release)
+++ gcc/testsuite/c-c++-common/ubsan/float-cast-overflow-1.c	(.../branches/gcc-7-branch)
@@ -1,6 +1,7 @@
 /* { dg-do run { target { lp64 || ilp32 } } } */
 /* { dg-options "-fsanitize=float-cast-overflow" } */
-/* { dg-additional-options "-msse2 -mfpmath=sse" { target { sse2_runtime && ia32 } } } */
+/* { dg-additional-options "-ffloat-store" { target { ia32 } } } */
+/* { dg-additional-options "-mieee" { target { { alpha*-*-* } || { sh*-*-* } } } } */
 
 #include <limits.h>
 #include "float-cast.h"
Index: gcc/testsuite/c-c++-common/pr82112.c
===================================================================
--- gcc/testsuite/c-c++-common/pr82112.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/pr82112.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,13 @@
+/* PR target/82112 */
+/* { dg-do compile } */
+
+int c[10], d[10], e[10], f[10], g[10], h[10], i[10], j[10], k[10], l[10];
+
+void
+foo (void)
+{
+  __atomic_load (c, d, __ATOMIC_ACQUIRE);
+  __atomic_store (e, f, __ATOMIC_SEQ_CST);
+  __atomic_exchange (g, h, i, __ATOMIC_RELAXED);
+  __atomic_compare_exchange (j, k, l, 1, __ATOMIC_RELAXED, __ATOMIC_RELAXED);
+}
Index: gcc/testsuite/c-c++-common/pr81052.c
===================================================================
--- gcc/testsuite/c-c++-common/pr81052.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/testsuite/c-c++-common/pr81052.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,28 @@
+/* PR middle-end/81052 */
+/* { dg-do compile } */
+/* { dg-options "-fopenmp-simd -O2" } */
+
+int
+foo (int x, int y)
+{
+  int i;
+#pragma omp simd
+  for (i = x; i < y; ++i)
+    return 0;			/* { dg-error "invalid branch to/from OpenMP structured block" } */
+  return 1;
+}
+
+#ifdef __cplusplus
+template <typename T>
+T
+bar (T x, T y)
+{
+  T i;
+#pragma omp simd
+  for (i = x; i < y; ++i)
+    return 0;			/* { dg-error "invalid branch to/from OpenMP structured block" "" { target c++ } } */
+  return 1;
+}
+
+int x = bar (1, 7);
+#endif
Index: gcc/cp/typeck.c
===================================================================
--- gcc/cp/typeck.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/typeck.c	(.../branches/gcc-7-branch)
@@ -5927,6 +5927,7 @@
 	{
 	  /* Warn if the expression has boolean value.  */
 	  if (TREE_CODE (TREE_TYPE (arg)) == BOOLEAN_TYPE
+	      && (complain & tf_warning)
 	      && warning_at (location, OPT_Wbool_operation,
 			     "%<~%> on an expression of type bool"))
 	    inform (location, "did you mean to use logical not (%<!%>)?");
@@ -8413,7 +8414,10 @@
     {
       tree elt = CONSTRUCTOR_ELT (rhs, 0)->value;
       if (check_narrowing (ENUM_UNDERLYING_TYPE (type), elt, complain))
-	rhs = cp_build_c_cast (type, elt, complain);
+	{
+	  warning_sentinel w (warn_useless_cast);
+	  rhs = cp_build_c_cast (type, elt, complain);
+	}
       else
 	rhs = error_mark_node;
     }
Index: gcc/cp/decl.c
===================================================================
--- gcc/cp/decl.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/decl.c	(.../branches/gcc-7-branch)
@@ -5579,9 +5579,10 @@
 		   "uninitialized const %qD", decl);
       else
 	{
-	  error_at (DECL_SOURCE_LOCATION (decl),
-		    "uninitialized variable %qD in %<constexpr%> function",
-		    decl);
+	  if (!is_instantiation_of_constexpr (current_function_decl))
+	    error_at (DECL_SOURCE_LOCATION (decl),
+		      "uninitialized variable %qD in %<constexpr%> function",
+		      decl);
 	  cp_function_chain->invalid_constexpr = true;
 	}
 
@@ -6099,7 +6100,10 @@
     {
       tree elt = CONSTRUCTOR_ELT (init, 0)->value;
       if (check_narrowing (ENUM_UNDERLYING_TYPE (type), elt, complain))
-	return cp_build_c_cast (type, elt, tf_warning_or_error);
+	{
+	  warning_sentinel w (warn_useless_cast);
+	  return cp_build_c_cast (type, elt, tf_warning_or_error);
+	}
       else
 	return error_mark_node;
     }
Index: gcc/cp/error.c
===================================================================
--- gcc/cp/error.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/error.c	(.../branches/gcc-7-branch)
@@ -1531,6 +1531,7 @@
   int do_outer_scope = ! (flags & TFF_UNQUALIFIED_NAME);
   tree exceptions;
   bool constexpr_p;
+  tree ret = NULL_TREE;
 
   flags &= ~(TFF_UNQUALIFIED_NAME | TFF_TEMPLATE_NAME);
   if (TREE_CODE (t) == TEMPLATE_DECL)
@@ -1593,7 +1594,7 @@
 		   && !DECL_DESTRUCTOR_P (t) && !deduction_guide_p (t));
   if (show_return)
     {
-      tree ret = fndecl_declared_return_type (t);
+      ret = fndecl_declared_return_type (t);
       dump_type_prefix (pp, ret, flags);
     }
 
@@ -1634,7 +1635,7 @@
 	}
 
       if (show_return)
-	dump_type_suffix (pp, TREE_TYPE (fntype), flags);
+	dump_type_suffix (pp, ret, flags);
       else if (deduction_guide_p (t))
 	{
 	  pp_cxx_ws_string (pp, "->");
Index: gcc/cp/tree.c
===================================================================
--- gcc/cp/tree.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/tree.c	(.../branches/gcc-7-branch)
@@ -2767,6 +2767,7 @@
 {
   tree obj;	    /* The object to be substituted for a PLACEHOLDER_EXPR.  */
   bool seen;	    /* Whether we've encountered a PLACEHOLDER_EXPR.  */
+  hash_set<tree> *pset;	/* To avoid walking same trees multiple times.  */
 };
 
 /* Like substitute_placeholder_in_expr, but handle C++ tree codes and
@@ -2789,8 +2790,8 @@
     case PLACEHOLDER_EXPR:
       {
 	tree x = obj;
-	for (; !(same_type_ignoring_top_level_qualifiers_p
-		 (TREE_TYPE (*t), TREE_TYPE (x)));
+	for (; !same_type_ignoring_top_level_qualifiers_p (TREE_TYPE (*t),
+							   TREE_TYPE (x));
 	     x = TREE_OPERAND (x, 0))
 	  gcc_assert (TREE_CODE (x) == COMPONENT_REF);
 	*t = x;
@@ -2822,8 +2823,7 @@
 		  valp = &TARGET_EXPR_INITIAL (*valp);
 	      }
 	    d->obj = subob;
-	    cp_walk_tree (valp, replace_placeholders_r,
-			  data_, NULL);
+	    cp_walk_tree (valp, replace_placeholders_r, data_, d->pset);
 	    d->obj = obj;
 	  }
 	*walk_subtrees = false;
@@ -2855,10 +2855,11 @@
     return exp;
 
   tree *tp = &exp;
-  replace_placeholders_t data = { obj, false };
+  hash_set<tree> pset;
+  replace_placeholders_t data = { obj, false, &pset };
   if (TREE_CODE (exp) == TARGET_EXPR)
     tp = &TARGET_EXPR_INITIAL (exp);
-  cp_walk_tree (tp, replace_placeholders_r, &data, NULL);
+  cp_walk_tree (tp, replace_placeholders_r, &data, &pset);
   if (seen_p)
     *seen_p = data.seen;
   return exp;
@@ -4217,6 +4218,21 @@
 			    TYPE_RAISES_EXCEPTIONS (typeb), ce_exact);
 }
 
+/* Copy the language-specific type variant modifiers from TYPEB to TYPEA.  For
+   C++, these are the exception-specifier and ref-qualifier.  */
+
+tree
+cxx_copy_lang_qualifiers (const_tree typea, const_tree typeb)
+{
+  tree type = CONST_CAST_TREE (typea);
+  if (TREE_CODE (type) == FUNCTION_TYPE || TREE_CODE (type) == METHOD_TYPE)
+    {
+      type = build_exception_variant (type, TYPE_RAISES_EXCEPTIONS (typeb));
+      type = build_ref_qualified_type (type, type_memfn_rqual (typeb));
+    }
+  return type;
+}
+
 /* Apply FUNC to all language-specific sub-trees of TP in a pre-order
    traversal.  Called from walk_tree.  */
 
Index: gcc/cp/ChangeLog
===================================================================
--- gcc/cp/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,119 @@
+2017-10-30  Paolo Carlini  <paolo.carlini@oracle.com>
+
+	PR c++/82085
+	* pt.c (tsubst_copy_and_build, [INDIRECT_REF]): For a REFERENCE_REF_P,
+	unconditionally call convert_from_reference.
+
+2017-10-27  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-10-04  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/82373
+	* error.c (dump_function_decl): If show_return, call dump_type_suffix
+	on the same return type dump_type_prefix has been called on.
+
+2017-10-17  Nathan Sidwell  <nathan@acm.org>
+
+	PR c++/82560
+	* call.c (build_over_call): Don't pass tf_no_cleanup to nested
+	calls.
+
+2017-10-06  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/82299
+	* decl.c (reshape_init): Suppress warn_useless_cast for direct enum
+	init.
+	* typeck.c (convert_for_assignment): Likewise.
+
+2017-10-05  Jason Merrill  <jason@redhat.com>
+
+	* call.c (convert_arg_to_ellipsis): Use the result of force_rvalue.
+
+2017-10-04  Jason Merrill  <jason@redhat.com>
+
+	PR c++/82406 - C++ error with noexcept function type
+	PR c++/70029 - ICE with ref-qualifier and -flto
+	* tree.c (cxx_copy_lang_qualifiers): New.
+	* cp-tree.h: Declare it.
+	* cp-objcp-common.h: Define LANG_HOOKS_COPY_LANG_QUALIFIERS.
+
+	PR c++/81525 - broken handling of auto in generic lambda.
+	* pt.c (tsubst_decl) [VAR_DECL]: Use strip_innermost_template_args.
+
+2017-09-22  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR bootstrap/81926
+	* cp-objcp-common.c (cp_get_debug_type): Do only one lookup
+
+2017-09-22  Jakub Jelinek  <jakub@redhat.com>
+
+	PR sanitizer/81929
+	* tree.c (struct replace_placeholders_t): Add pset field.
+	(replace_placeholders_r): Call cp_walk_tree with d->pset as
+	last argument instead of NULL.  Formatting fix.
+	(replace_placeholders): Add pset variable, add its address
+	into data.  Pass &pset instead of NULL to cp_walk_tree.
+
+2017-09-18  Jason Merrill  <jason@redhat.com>
+
+	PR c++/81236 - ICE with template-id in generic lambda
+	* parser.c (parsing_default_capturing_generic_lambda): Don't check
+	for enclosing template.
+	* semantics.c (finish_qualified_id_expr): Call it.
+	* cp-tree.h: Adjust.
+
+	PR c++/80767 - unnecessary instantiation of generic lambda
+	PR c++/82030 - ICE inheriting from multiple lambdas
+	* call.c (convert_like_real): Call build_user_type_conversion_1 if
+	cand is null.
+	(add_conv_candidate): Build a ck_user conversion with no candidate.
+
+	PR c++/80935 - wrong C++17 error with lambda
+	* decl.c (check_for_uninitialized_const_var): Check
+	is_instantiation_of_constexpr.
+
+	PR c++/81671 - nullptr_t template parameter
+	* pt.c (convert_nontype_argument): Fix nullptr_t check.
+
+	PR c++/81525 - wrong constant value with generic lambda
+	* pt.c (tsubst_decl) [VAR_DECL]: Avoid clobbering auto.
+	(tsubst_copy) [VAR_DECL]: Handle auto.
+
+2017-09-15  Jakub Jelinek  <jakub@redhat.com>
+
+	Backported from mainline
+	2017-09-14  Jakub Jelinek  <jakub@redhat.com>
+
+	PR c++/81314
+	* cp-gimplify.c (omp_var_to_track): Look through references.
+	(omp_cxx_notice_variable): Likewise.
+
+2017-09-09  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR bootstrap/81926
+	* cp-objcp-common.c (struct debug_type_hasher): New class.
+	(debug_type_hash): New variable.
+	(cp_get_debug_type): Associate the OFFSET_TYPEs with the types.
+
+2017-09-01  Marek Polacek  <polacek@redhat.com>
+
+	Backported from mainline
+	2017-09-01  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/82040
+	* typeck.c (cp_build_unary_op): Avoid re-entering reporting routines.
+
+2017-08-25  Marek Polacek  <polacek@redhat.com>
+
+	Backported from mainline
+	2017-08-08  Marek Polacek  <polacek@redhat.com>
+
+	PR c++/81607
+	* cp-gimplify.c (cp_fold): If folding exposed a branch of
+	a COND_EXPR, convert it to the original type of the COND_EXPR, if
+	they differ.		   
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
@@ -4,8 +120,8 @@
 
 2017-08-09  Leonid Koppel  <lkoppel@uwaterloo.ca>
 
-        PR c++/67054 - Inherited ctor with non-default-constructible members
-        * method.c (walk_field_subobs) Consider member initializers (NSDMIs)
+	PR c++/67054 - Inherited ctor with non-default-constructible members
+	* method.c (walk_field_subobs) Consider member initializers (NSDMIs)
 	when deducing an inheriting constructor.
 
 2017-07-27  Paolo Carlini  <paolo.carlini@oracle.com>
Index: gcc/cp/cp-gimplify.c
===================================================================
--- gcc/cp/cp-gimplify.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/cp-gimplify.c	(.../branches/gcc-7-branch)
@@ -924,6 +924,8 @@
   tree type = TREE_TYPE (decl);
   if (is_invisiref_parm (decl))
     type = TREE_TYPE (type);
+  else if (TREE_CODE (type) == REFERENCE_TYPE)
+    type = TREE_TYPE (type);
   while (TREE_CODE (type) == ARRAY_TYPE)
     type = TREE_TYPE (type);
   if (type == error_mark_node || !CLASS_TYPE_P (type))
@@ -976,6 +978,8 @@
 	      tree type = TREE_TYPE (decl);
 	      if (is_invisiref_parm (decl))
 		type = TREE_TYPE (type);
+	      else if (TREE_CODE (type) == REFERENCE_TYPE)
+		type = TREE_TYPE (type);
 	      while (TREE_CODE (type) == ARRAY_TYPE)
 		type = TREE_TYPE (type);
 	      get_copy_ctor (type, tf_none);
@@ -2311,9 +2315,9 @@
 
       /* A COND_EXPR might have incompatible types in branches if one or both
 	 arms are bitfields.  If folding exposed such a branch, fix it up.  */
-      if (TREE_CODE (x) != code)
-	if (tree type = is_bitfield_expr_with_lowered_type (x))
-	  x = fold_convert (type, x);
+      if (TREE_CODE (x) != code
+	  && !useless_type_conversion_p (TREE_TYPE (org_x), TREE_TYPE (x)))
+	x = fold_convert (TREE_TYPE (org_x), x);
 
       break;
 
Index: gcc/cp/pt.c
===================================================================
--- gcc/cp/pt.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/pt.c	(.../branches/gcc-7-branch)
@@ -6849,7 +6849,7 @@
     }
   else if (NULLPTR_TYPE_P (type))
     {
-      if (expr != nullptr_node)
+      if (!NULLPTR_TYPE_P (TREE_TYPE (expr)))
 	{
 	  if (complain & tf_error)
 	    error ("%qE is not a valid template argument for type %qT "
@@ -12896,7 +12896,17 @@
 		&& VAR_HAD_UNKNOWN_BOUND (t)
 		&& type != error_mark_node)
 	      type = strip_array_domain (type);
-	    type = tsubst (type, args, complain, in_decl);
+	    tree sub_args = args;
+	    if (tree auto_node = type_uses_auto (type))
+	      {
+		/* Mask off any template args past the variable's context so we
+		   don't replace the auto with an unrelated argument.  */
+		int nouter = TEMPLATE_TYPE_LEVEL (auto_node) - 1;
+		int extra = TMPL_ARGS_DEPTH (args) - nouter;
+		if (extra > 0)
+		  sub_args = strip_innermost_template_args (args, extra);
+	      }
+	    type = tsubst (type, sub_args, complain, in_decl);
 	  }
 	if (VAR_P (r))
 	  {
@@ -14687,6 +14697,10 @@
 			DECL_INITIALIZED_BY_CONSTANT_EXPRESSION_P (r)
 			  = TREE_CONSTANT (r) = true;
 		      DECL_INITIAL (r) = init;
+		      if (tree auto_node = type_uses_auto (TREE_TYPE (r)))
+			TREE_TYPE (r)
+			  = do_auto_deduction (TREE_TYPE (r), init, auto_node,
+					       complain, adc_variable_type);
 		    }
 		  gcc_assert (cp_unevaluated_operand || TREE_STATIC (r)
 			      || decl_constant_var_p (r)
@@ -16773,8 +16787,7 @@
 	    /* A type conversion to reference type will be enclosed in
 	       such an indirect ref, but the substitution of the cast
 	       will have also added such an indirect ref.  */
-	    if (TREE_CODE (TREE_TYPE (r)) == REFERENCE_TYPE)
-	      r = convert_from_reference (r);
+	    r = convert_from_reference (r);
 	  }
 	else
 	  r = build_x_indirect_ref (input_location, r, RO_UNARY_STAR,
Index: gcc/cp/semantics.c
===================================================================
--- gcc/cp/semantics.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/semantics.c	(.../branches/gcc-7-branch)
@@ -2008,7 +2008,9 @@
 					    qualifying_class);
       pop_deferring_access_checks ();
     }
-  else if (BASELINK_P (expr) && !processing_template_decl)
+  else if (BASELINK_P (expr)
+	   && (!processing_template_decl
+	       || parsing_default_capturing_generic_lambda ()))
     {
       /* See if any of the functions are non-static members.  */
       /* If so, the expression may be relative to 'this'.  */
@@ -3584,12 +3586,12 @@
 		    : CP_ID_KIND_UNQUALIFIED)));
 
       /* If the name was dependent on a template parameter and we're not in a
-	 default capturing generic lambda within a template, we will resolve the
+	 default capturing generic lambda, we will resolve the
 	 name at instantiation time.  FIXME: For lambdas, we should defer
 	 building the closure type until instantiation time then we won't need
 	 the extra test here.  */
       if (dependent_p
-	  && !parsing_default_capturing_generic_lambda_in_template ())
+	  && !parsing_default_capturing_generic_lambda ())
 	{
 	  if (DECL_P (decl)
 	      && any_dependent_type_attributes_p (DECL_ATTRIBUTES (decl)))
Index: gcc/cp/parser.c
===================================================================
--- gcc/cp/parser.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/parser.c	(.../branches/gcc-7-branch)
@@ -20486,7 +20486,7 @@
    which we ultimately want to defer to instantiation time. */
 
 bool
-parsing_default_capturing_generic_lambda_in_template (void)
+parsing_default_capturing_generic_lambda (void)
 {
   if (!processing_template_decl || !current_class_type)
     return false;
@@ -20499,12 +20499,7 @@
   if (!callop)
     return false;
 
-  return (DECL_TEMPLATE_INFO (callop)
-	  && (DECL_TEMPLATE_RESULT (DECL_TI_TEMPLATE (callop)) == callop)
-	  && ((current_nonlambda_class_type ()
-	       && CLASSTYPE_TEMPLATE_INFO (current_nonlambda_class_type ()))
-	      || ((current_nonlambda_function ()
-		   && DECL_TEMPLATE_INFO (current_nonlambda_function ())))));
+  return generic_lambda_fn_p (callop);
 }
 
 /* Parse a late-specified return type, if any.  This is not a separate
Index: gcc/cp/call.c
===================================================================
--- gcc/cp/call.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/call.c	(.../branches/gcc-7-branch)
@@ -2279,8 +2279,10 @@
 
       if (i == 0)
 	{
-	  t = implicit_conversion (totype, argtype, arg, /*c_cast_p=*/false,
-				   flags, complain);
+	  t = build_identity_conv (argtype, NULL_TREE);
+	  t = build_conv (ck_user, totype, t);
+	  /* Leave the 'cand' field null; we'll figure out the conversion in
+	     convert_like_real if this candidate is chosen.  */
 	  convert_type = totype;
 	}
       else if (parmnode == void_list_node)
@@ -6665,6 +6667,13 @@
     case ck_user:
       {
 	struct z_candidate *cand = convs->cand;
+
+	if (cand == NULL)
+	  /* We chose the surrogate function from add_conv_candidate, now we
+	     actually need to build the conversion.  */
+	  cand = build_user_type_conversion_1 (totype, expr,
+					       LOOKUP_NO_CONVERSION, complain);
+
 	tree convfn = cand->fn;
 
 	/* When converting from an init list we consider explicit
@@ -7117,13 +7126,9 @@
       /* In a template (or ill-formed code), we can have an incomplete type
 	 even after require_complete_type_sfinae, in which case we don't know
 	 whether it has trivial copy or not.  */
-      && COMPLETE_TYPE_P (arg_type))
+      && COMPLETE_TYPE_P (arg_type)
+      && !cp_unevaluated_operand)
     {
-      /* Build up a real lvalue-to-rvalue conversion in case the
-	 copy constructor is trivial but not callable.  */
-      if (!cp_unevaluated_operand && CLASS_TYPE_P (arg_type))
-	force_rvalue (arg, complain);
-
       /* [expr.call] 5.2.2/7:
 	 Passing a potentially-evaluated argument of class type (Clause 9)
 	 with a non-trivial copy constructor or a non-trivial destructor
@@ -7135,10 +7140,10 @@
 
 	 If the call appears in the context of a sizeof expression,
 	 it is not potentially-evaluated.  */
-      if (cp_unevaluated_operand == 0
-	  && (type_has_nontrivial_copy_init (arg_type)
-	      || TYPE_HAS_NONTRIVIAL_DESTRUCTOR (arg_type)))
+      if (type_has_nontrivial_copy_init (arg_type)
+	  || TYPE_HAS_NONTRIVIAL_DESTRUCTOR (arg_type))
 	{
+	  arg = force_rvalue (arg, complain);
 	  if (complain & tf_warning)
 	    warning (OPT_Wconditionally_supported,
 		     "passing objects of non-trivially-copyable "
@@ -7146,6 +7151,11 @@
 		     arg_type);
 	  return cp_build_addr_expr (arg, complain);
 	}
+      /* Build up a real lvalue-to-rvalue conversion in case the
+	 copy constructor is trivial but not callable.  */
+      else if (CLASS_TYPE_P (arg_type))
+	force_rvalue (arg, complain);
+
     }
 
   return arg;
@@ -7658,8 +7668,11 @@
     }
 
   /* N3276 magic doesn't apply to nested calls.  */
-  int decltype_flag = (complain & tf_decltype);
+  tsubst_flags_t decltype_flag = (complain & tf_decltype);
   complain &= ~tf_decltype;
+  /* No-Cleanup doesn't apply to nested calls either.  */
+  tsubst_flags_t no_cleanup_complain = complain;
+  complain &= ~tf_no_cleanup;
 
   /* Find maximum size of vector to hold converted arguments.  */
   parmlen = list_length (parm);
@@ -7841,7 +7854,7 @@
       if (flags & LOOKUP_NO_CONVERSION)
 	conv->user_conv_p = true;
 
-      tsubst_flags_t arg_complain = complain & (~tf_no_cleanup);
+      tsubst_flags_t arg_complain = complain;
       if (!conversion_warning)
 	arg_complain &= ~tf_warning;
 
@@ -8086,7 +8099,8 @@
       else if (default_ctor_p (fn))
 	{
 	  if (is_dummy_object (argarray[0]))
-	    return force_target_expr (DECL_CONTEXT (fn), void_node, complain);
+	    return force_target_expr (DECL_CONTEXT (fn), void_node,
+				      no_cleanup_complain);
 	  else
 	    return cp_build_indirect_ref (argarray[0], RO_NULL, complain);
 	}
@@ -9128,7 +9142,9 @@
 	return 0;
       else if (t1->kind == ck_user)
 	{
-	  if (t1->cand->fn != t2->cand->fn)
+	  tree f1 = t1->cand ? t1->cand->fn : t1->type;
+	  tree f2 = t2->cand ? t2->cand->fn : t2->type;
+	  if (f1 != f2)
 	    return 0;
 	}
       else
Index: gcc/cp/cp-objcp-common.c
===================================================================
--- gcc/cp/cp-objcp-common.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/cp-objcp-common.c	(.../branches/gcc-7-branch)
@@ -131,6 +131,20 @@
   return same_type_ignoring_top_level_qualifiers_p (x, y);
 }
 
+struct debug_type_hasher : ggc_cache_ptr_hash<tree_map>
+{
+  static hashval_t hash (tree_map *m) { return tree_map_hash (m); }
+  static bool equal (tree_map *a, tree_map *b) { return tree_map_eq (a, b); }
+
+  static int
+  keep_cache_entry (tree_map *&e)
+  {
+    return ggc_marked_p (e->base.from);
+  }
+};
+
+static GTY((cache)) hash_table<debug_type_hasher> *debug_type_hash;
+
 /* Return a type to use in the debug info instead of TYPE, or NULL_TREE to
    keep TYPE.  */
 
@@ -138,9 +152,36 @@
 cp_get_debug_type (const_tree type)
 {
   if (TYPE_PTRMEMFUNC_P (type) && !typedef_variant_p (type))
-    return build_offset_type (TYPE_PTRMEMFUNC_OBJECT_TYPE (type),
-			      TREE_TYPE (TYPE_PTRMEMFUNC_FN_TYPE (type)));
+    {
+      if (debug_type_hash == NULL)
+	debug_type_hash = hash_table<debug_type_hasher>::create_ggc (512);
 
+      /* We cannot simply use build_offset_type here because the function uses
+	 the type canonicalization hashtable, which is GC-ed, so its behavior
+	 depends on the actual collection points.  Since we are building these
+	 types on the fly for the debug info only, they would not be attached
+	 to any GC root and always be swept, so we would make the contents of
+	 the debug info depend on the collection points.  */
+      struct tree_map in, *h, **slot;
+
+      in.base.from = CONST_CAST_TREE (type);
+      in.hash = htab_hash_pointer (type);
+      slot = debug_type_hash->find_slot_with_hash (&in, in.hash, INSERT);
+      if (*slot)
+	return (*slot)->to;
+
+      tree t = build_offset_type (TYPE_PTRMEMFUNC_OBJECT_TYPE (type),
+				  TREE_TYPE (TYPE_PTRMEMFUNC_FN_TYPE (type)));
+
+      h = ggc_alloc<tree_map> ();
+      h->base.from = CONST_CAST_TREE (type);
+      h->hash = htab_hash_pointer (type);
+      h->to = t;
+      *slot = h;
+
+      return t;
+    }
+
   return NULL_TREE;
 }
 
Index: gcc/cp/cp-objcp-common.h
===================================================================
--- gcc/cp/cp-objcp-common.h	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/cp-objcp-common.h	(.../branches/gcc-7-branch)
@@ -94,6 +94,8 @@
 #define LANG_HOOKS_BUILTIN_FUNCTION_EXT_SCOPE cxx_builtin_function_ext_scope
 #undef	LANG_HOOKS_TYPE_HASH_EQ
 #define LANG_HOOKS_TYPE_HASH_EQ	cxx_type_hash_eq
+#undef	LANG_HOOKS_COPY_LANG_QUALIFIERS
+#define LANG_HOOKS_COPY_LANG_QUALIFIERS	cxx_copy_lang_qualifiers
 #undef LANG_HOOKS_MISSING_NORETURN_OK_P
 #define LANG_HOOKS_MISSING_NORETURN_OK_P cp_missing_noreturn_ok_p
 #undef LANG_HOOKS_BLOCK_MAY_FALLTHRU
Index: gcc/cp/cp-tree.h
===================================================================
--- gcc/cp/cp-tree.h	(.../tags/gcc_7_2_0_release)
+++ gcc/cp/cp-tree.h	(.../branches/gcc-7-branch)
@@ -6125,7 +6125,7 @@
 /* In parser.c */
 extern tree cp_convert_range_for (tree, tree, tree, tree, unsigned int, bool);
 extern bool parsing_nsdmi (void);
-extern bool parsing_default_capturing_generic_lambda_in_template (void);
+extern bool parsing_default_capturing_generic_lambda (void);
 extern void inject_this_parameter (tree, cp_cv_quals);
 
 /* in pt.c */
@@ -6703,6 +6703,7 @@
 extern tree cp_save_expr			(tree);
 extern bool cast_valid_in_integral_constant_expression_p (tree);
 extern bool cxx_type_hash_eq			(const_tree, const_tree);
+extern tree cxx_copy_lang_qualifiers		(const_tree, const_tree);
 
 extern void cxx_print_statistics		(void);
 extern bool maybe_warn_zero_as_null_pointer_constant (tree, location_t);
Index: gcc/omp-expand.c
===================================================================
--- gcc/omp-expand.c	(.../tags/gcc_7_2_0_release)
+++ gcc/omp-expand.c	(.../branches/gcc-7-branch)
@@ -4725,12 +4725,14 @@
 	      tree itype2 = TREE_TYPE (fd->loops[i - 1].v);
 	      if (POINTER_TYPE_P (itype2))
 		itype2 = signed_type_for (itype2);
+	      t = fold_convert (itype2, fd->loops[i - 1].step);
+	      t = force_gimple_operand_gsi (&gsi, t, true, NULL_TREE, true,
+					    GSI_SAME_STMT);
 	      t = build3 (COND_EXPR, itype2,
 			  build2 (fd->loops[i].cond_code, boolean_type_node,
 				  fd->loops[i].v,
 				  fold_convert (itype, fd->loops[i].n2)),
-			  build_int_cst (itype2, 0),
-			  fold_convert (itype2, fd->loops[i - 1].step));
+			  build_int_cst (itype2, 0), t);
 	      if (POINTER_TYPE_P (TREE_TYPE (fd->loops[i - 1].v)))
 		t = fold_build_pointer_plus (fd->loops[i - 1].v, t);
 	      else
@@ -4737,12 +4739,14 @@
 		t = fold_build2 (PLUS_EXPR, itype2, fd->loops[i - 1].v, t);
 	      expand_omp_build_assign (&gsi, fd->loops[i - 1].v, t);
 
+	      t = fold_convert (itype, fd->loops[i].n1);
+	      t = force_gimple_operand_gsi (&gsi, t, true, NULL_TREE, true,
+					    GSI_SAME_STMT);
 	      t = build3 (COND_EXPR, itype,
 			  build2 (fd->loops[i].cond_code, boolean_type_node,
 				  fd->loops[i].v,
 				  fold_convert (itype, fd->loops[i].n2)),
-			  fd->loops[i].v,
-			  fold_convert (itype, fd->loops[i].n1));
+			  fd->loops[i].v, t);
 	      expand_omp_build_assign (&gsi, fd->loops[i].v, t);
 	    }
 	}
Index: gcc/tree-ssa-alias.c
===================================================================
--- gcc/tree-ssa-alias.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-ssa-alias.c	(.../branches/gcc-7-branch)
@@ -2415,6 +2415,7 @@
       if (ref->ref)
 	{
 	  tree base = ref->ref;
+	  tree innermost_dropped_array_ref = NULL_TREE;
 	  if (handled_component_p (base))
 	    {
 	      tree saved_lhs0 = NULL_TREE;
@@ -2434,6 +2435,11 @@
 		  TREE_OPERAND (base, 0) = saved_base0;
 		  if (res)
 		    break;
+		  /* Remember if we drop an array-ref that we need to
+		     double-check not being at struct end.  */ 
+		  if (TREE_CODE (base) == ARRAY_REF
+		      || TREE_CODE (base) == ARRAY_RANGE_REF)
+		    innermost_dropped_array_ref = base;
 		  /* Otherwise drop handled components of the access.  */
 		  base = saved_base0;
 		}
@@ -2442,15 +2448,22 @@
 		TREE_OPERAND (lhs, 0) = saved_lhs0;
 	    }
 	  /* Finally check if the lhs has the same address and size as the
-	     base candidate of the access.  */
-	  if (lhs == base
-	      || (((TYPE_SIZE (TREE_TYPE (lhs))
-		    == TYPE_SIZE (TREE_TYPE (base)))
-		   || (TYPE_SIZE (TREE_TYPE (lhs))
-		       && TYPE_SIZE (TREE_TYPE (base))
-		       && operand_equal_p (TYPE_SIZE (TREE_TYPE (lhs)),
-					   TYPE_SIZE (TREE_TYPE (base)), 0)))
-		  && operand_equal_p (lhs, base, OEP_ADDRESS_OF)))
+	     base candidate of the access.  Watch out if we have dropped
+	     an array-ref that was at struct end, this means ref->ref may
+	     be outside of the TYPE_SIZE of its base.  */
+	  if ((! innermost_dropped_array_ref
+	       || ! array_at_struct_end_p (innermost_dropped_array_ref))
+	      && (lhs == base
+		  || (((TYPE_SIZE (TREE_TYPE (lhs))
+			== TYPE_SIZE (TREE_TYPE (base)))
+		       || (TYPE_SIZE (TREE_TYPE (lhs))
+			   && TYPE_SIZE (TREE_TYPE (base))
+			   && operand_equal_p (TYPE_SIZE (TREE_TYPE (lhs)),
+					       TYPE_SIZE (TREE_TYPE (base)),
+					       0)))
+		      && operand_equal_p (lhs, base,
+					  OEP_ADDRESS_OF
+					  | OEP_MATCH_SIDE_EFFECTS))))
 	    return true;
 	}
 
Index: gcc/dwarf2out.c
===================================================================
--- gcc/dwarf2out.c	(.../tags/gcc_7_2_0_release)
+++ gcc/dwarf2out.c	(.../branches/gcc-7-branch)
@@ -12514,6 +12514,15 @@
 
       if (qualified_type == dtype)
 	{
+	  tree origin = decl_ultimate_origin (name);
+
+	  /* Typedef variants that have an abstract origin don't get their own
+	     type DIE (see gen_typedef_die), so fall back on the ultimate
+	     abstract origin instead.  */
+	  if (origin != NULL)
+	    return modified_type_die (TREE_TYPE (origin), cv_quals, reverse,
+				      context_die);
+
 	  /* For a named type, use the typedef.  */
 	  gen_type_die (qualified_type, context_die);
 	  return lookup_type_die (qualified_type);
@@ -24346,7 +24355,7 @@
 gen_typedef_die (tree decl, dw_die_ref context_die)
 {
   dw_die_ref type_die;
-  tree origin;
+  tree type;
 
   if (TREE_ASM_WRITTEN (decl))
     {
@@ -24355,76 +24364,72 @@
       return;
     }
 
+  /* As we avoid creating DIEs for local typedefs (see decl_ultimate_origin
+     checks in process_scope_var and modified_type_die), this should be called
+     only for original types.  */
+  gcc_assert (decl_ultimate_origin (decl) == NULL);
+
   TREE_ASM_WRITTEN (decl) = 1;
   type_die = new_die (DW_TAG_typedef, context_die, decl);
-  origin = decl_ultimate_origin (decl);
-  if (origin != NULL)
-    add_abstract_origin_attribute (type_die, origin);
+
+  add_name_and_src_coords_attributes (type_die, decl);
+  if (DECL_ORIGINAL_TYPE (decl))
+    {
+      type = DECL_ORIGINAL_TYPE (decl);
+      if (type == error_mark_node)
+	return;
+
+      gcc_assert (type != TREE_TYPE (decl));
+      equate_type_number_to_die (TREE_TYPE (decl), type_die);
+    }
   else
     {
-      tree type = TREE_TYPE (decl);
-
+      type = TREE_TYPE (decl);
       if (type == error_mark_node)
 	return;
 
-      add_name_and_src_coords_attributes (type_die, decl);
-      if (DECL_ORIGINAL_TYPE (decl))
+      if (is_naming_typedef_decl (TYPE_NAME (type)))
 	{
-	  type = DECL_ORIGINAL_TYPE (decl);
+	  /* Here, we are in the case of decl being a typedef naming
+	     an anonymous type, e.g:
+		 typedef struct {...} foo;
+	     In that case TREE_TYPE (decl) is not a typedef variant
+	     type and TYPE_NAME of the anonymous type is set to the
+	     TYPE_DECL of the typedef. This construct is emitted by
+	     the C++ FE.
 
-	  if (type == error_mark_node)
-	    return;
+	     TYPE is the anonymous struct named by the typedef
+	     DECL. As we need the DW_AT_type attribute of the
+	     DW_TAG_typedef to point to the DIE of TYPE, let's
+	     generate that DIE right away. add_type_attribute
+	     called below will then pick (via lookup_type_die) that
+	     anonymous struct DIE.  */
+	  if (!TREE_ASM_WRITTEN (type))
+	    gen_tagged_type_die (type, context_die, DINFO_USAGE_DIR_USE);
 
-	  gcc_assert (type != TREE_TYPE (decl));
-	  equate_type_number_to_die (TREE_TYPE (decl), type_die);
+	  /* This is a GNU Extension.  We are adding a
+	     DW_AT_linkage_name attribute to the DIE of the
+	     anonymous struct TYPE.  The value of that attribute
+	     is the name of the typedef decl naming the anonymous
+	     struct.  This greatly eases the work of consumers of
+	     this debug info.  */
+	  add_linkage_name_raw (lookup_type_die (type), decl);
 	}
-      else
-	{
-	  if (is_naming_typedef_decl (TYPE_NAME (type)))
-	    {
-	      /* Here, we are in the case of decl being a typedef naming
-	         an anonymous type, e.g:
-	             typedef struct {...} foo;
-	         In that case TREE_TYPE (decl) is not a typedef variant
-	         type and TYPE_NAME of the anonymous type is set to the
-	         TYPE_DECL of the typedef. This construct is emitted by
-	         the C++ FE.
+    }
 
-	         TYPE is the anonymous struct named by the typedef
-	         DECL. As we need the DW_AT_type attribute of the
-	         DW_TAG_typedef to point to the DIE of TYPE, let's
-	         generate that DIE right away. add_type_attribute
-	         called below will then pick (via lookup_type_die) that
-	         anonymous struct DIE.  */
-	      if (!TREE_ASM_WRITTEN (type))
-	        gen_tagged_type_die (type, context_die, DINFO_USAGE_DIR_USE);
+  add_type_attribute (type_die, type, decl_quals (decl), false,
+		      context_die);
 
-	      /* This is a GNU Extension.  We are adding a
-		 DW_AT_linkage_name attribute to the DIE of the
-		 anonymous struct TYPE.  The value of that attribute
-		 is the name of the typedef decl naming the anonymous
-		 struct.  This greatly eases the work of consumers of
-		 this debug info.  */
-	      add_linkage_name_raw (lookup_type_die (type), decl);
-	    }
-	}
+  if (is_naming_typedef_decl (decl))
+    /* We want that all subsequent calls to lookup_type_die with
+       TYPE in argument yield the DW_TAG_typedef we have just
+       created.  */
+    equate_type_number_to_die (type, type_die);
 
-      add_type_attribute (type_die, type, decl_quals (decl), false,
-			  context_die);
+  add_alignment_attribute (type_die, TREE_TYPE (decl));
 
-      if (is_naming_typedef_decl (decl))
-	/* We want that all subsequent calls to lookup_type_die with
-	   TYPE in argument yield the DW_TAG_typedef we have just
-	   created.  */
-	equate_type_number_to_die (type, type_die);
+  add_accessibility_attribute (type_die, decl);
 
-      type = TREE_TYPE (decl);
-
-      add_alignment_attribute (type_die, type);
-
-      add_accessibility_attribute (type_die, decl);
-    }
-
   if (DECL_ABSTRACT_P (decl))
     equate_decl_number_to_die (decl, type_die);
 
@@ -24535,8 +24540,16 @@
       if (TREE_ASM_WRITTEN (type))
 	return;
 
+      tree name = TYPE_NAME (type);
+      tree origin = decl_ultimate_origin (name);
+      if (origin != NULL)
+	{
+	  gen_decl_die (origin, NULL, NULL, context_die);
+	  return;
+	}
+
       /* Prevent broken recursion; we can't hand off to the same type.  */
-      gcc_assert (DECL_ORIGINAL_TYPE (TYPE_NAME (type)) != type);
+      gcc_assert (DECL_ORIGINAL_TYPE (name) != type);
 
       /* Give typedefs the right scope.  */
       context_die = scope_die_for (type, context_die);
@@ -24543,7 +24556,7 @@
 
       TREE_ASM_WRITTEN (type) = 1;
 
-      gen_decl_die (TYPE_NAME (type), NULL, NULL, context_die);
+      gen_decl_die (name, NULL, NULL, context_die);
       return;
     }
 
@@ -24862,6 +24875,22 @@
   else
     die = NULL;
 
+  /* Avoid creating DIEs for local typedefs and concrete static variables that
+     will only be pruned later.  */
+  if ((origin || decl_ultimate_origin (decl))
+      && (TREE_CODE (decl_or_origin) == TYPE_DECL
+	  || (VAR_P (decl_or_origin) && TREE_STATIC (decl_or_origin))))
+    {
+      origin = decl_ultimate_origin (decl_or_origin);
+      if (decl && VAR_P (decl) && die != NULL)
+	{
+	  die = lookup_decl_die (origin);
+	  if (die != NULL)
+	    equate_decl_number_to_die (decl, die);
+	}
+      return;
+    }
+
   if (die != NULL && die->die_parent == NULL)
     add_child_die (context_die, die);
   else if (TREE_CODE (decl_or_origin) == IMPORTED_DECL)
@@ -26058,7 +26087,8 @@
       j = 0;
       FOR_EACH_VEC_ELT (*tmpl_value_parm_die_table, i, e)
 	{
-	  if (!tree_add_const_value_attribute (e->die, e->arg))
+	  if (!e->die->removed
+	      && !tree_add_const_value_attribute (e->die, e->arg))
 	    {
 	      dw_loc_descr_ref loc = NULL;
 	      if (! early_dwarf
Index: gcc/expr.c
===================================================================
--- gcc/expr.c	(.../tags/gcc_7_2_0_release)
+++ gcc/expr.c	(.../branches/gcc-7-branch)
@@ -6742,8 +6742,11 @@
     return const0_rtx;
 
   /* If we have nothing to store, do nothing unless the expression has
-     side-effects.  */
-  if (bitsize == 0)
+     side-effects.  Don't do that for zero sized addressable lhs of
+     calls.  */
+  if (bitsize == 0
+      && (!TREE_ADDRESSABLE (TREE_TYPE (exp))
+	  || TREE_CODE (exp) != CALL_EXPR))
     return expand_expr (exp, const0_rtx, VOIDmode, EXPAND_NORMAL);
 
   if (GET_CODE (target) == CONCAT)
Index: gcc/cfgbuild.c
===================================================================
--- gcc/cfgbuild.c	(.../tags/gcc_7_2_0_release)
+++ gcc/cfgbuild.c	(.../branches/gcc-7-branch)
@@ -442,9 +442,10 @@
   rtx_insn *end = BB_END (bb), *x;
   rtx_jump_table_data *table;
   rtx_insn *flow_transfer_insn = NULL;
+  rtx_insn *debug_insn = NULL;
   edge fallthru = NULL;
 
-  if (insn == BB_END (bb))
+  if (insn == end)
     return;
 
   if (LABEL_P (insn))
@@ -455,27 +456,49 @@
     {
       enum rtx_code code = GET_CODE (insn);
 
+      if (code == DEBUG_INSN)
+	{
+	  if (flow_transfer_insn && !debug_insn)
+	    debug_insn = insn;
+	}
       /* In case we've previously seen an insn that effects a control
 	 flow transfer, split the block.  */
-      if ((flow_transfer_insn || code == CODE_LABEL)
-	  && inside_basic_block_p (insn))
+      else if ((flow_transfer_insn || code == CODE_LABEL)
+	       && inside_basic_block_p (insn))
 	{
-	  fallthru = split_block (bb, PREV_INSN (insn));
+	  rtx_insn *prev = PREV_INSN (insn);
+
+	  /* If the first non-debug inside_basic_block_p insn after a control
+	     flow transfer is not a label, split the block before the debug
+	     insn instead of before the non-debug insn, so that the debug
+	     insns are not lost.  */
+	  if (debug_insn && code != CODE_LABEL && code != BARRIER)
+	    prev = PREV_INSN (debug_insn);
+	  fallthru = split_block (bb, prev);
 	  if (flow_transfer_insn)
 	    {
 	      BB_END (bb) = flow_transfer_insn;
 
+	      rtx_insn *next;
 	      /* Clean up the bb field for the insns between the blocks.  */
 	      for (x = NEXT_INSN (flow_transfer_insn);
 		   x != BB_HEAD (fallthru->dest);
-		   x = NEXT_INSN (x))
-		if (!BARRIER_P (x))
-		  set_block_for_insn (x, NULL);
+		   x = next)
+		{
+		  next = NEXT_INSN (x);
+		  /* Debug insns should not be in between basic blocks,
+		     drop them on the floor.  */
+		  if (DEBUG_INSN_P (x))
+		    delete_insn (x);
+		  else if (!BARRIER_P (x))
+		    set_block_for_insn (x, NULL);
+		}
 	    }
 
 	  bb = fallthru->dest;
 	  remove_edge (fallthru);
 	  flow_transfer_insn = NULL;
+	  debug_insn = NULL;
 	  if (code == CODE_LABEL && LABEL_ALT_ENTRY_P (insn))
 	    make_edge (ENTRY_BLOCK_PTR_FOR_FN (cfun), bb, 0);
 	}
@@ -498,17 +521,23 @@
   /* In case expander replaced normal insn by sequence terminating by
      return and barrier, or possibly other sequence not behaving like
      ordinary jump, we need to take care and move basic block boundary.  */
-  if (flow_transfer_insn)
+  if (flow_transfer_insn && flow_transfer_insn != end)
     {
       BB_END (bb) = flow_transfer_insn;
 
       /* Clean up the bb field for the insns that do not belong to BB.  */
-      x = flow_transfer_insn;
-      while (x != end)
+      rtx_insn *next;
+      for (x = NEXT_INSN (flow_transfer_insn); ; x = next)
 	{
-	  x = NEXT_INSN (x);
-	  if (!BARRIER_P (x))
+	  next = NEXT_INSN (x);
+	  /* Debug insns should not be in between basic blocks,
+	     drop them on the floor.  */
+	  if (DEBUG_INSN_P (x))
+	    delete_insn (x);
+	  else if (!BARRIER_P (x))
 	    set_block_for_insn (x, NULL);
+	  if (x == end)
+	    break;
 	}
     }
 
Index: gcc/opts.c
===================================================================
--- gcc/opts.c	(.../tags/gcc_7_2_0_release)
+++ gcc/opts.c	(.../branches/gcc-7-branch)
@@ -217,7 +217,7 @@
 		      unsigned int lang_mask ATTRIBUTE_UNUSED, int kind,
 		      location_t loc,
 		      const struct cl_option_handlers *handlers ATTRIBUTE_UNUSED,
-		      diagnostic_context *dc)
+		      diagnostic_context *dc, void (*) (void))
 {
   gcc_assert (dc == global_dc);
   gcc_assert (kind == DK_UNSPECIFIED);
@@ -1678,7 +1678,8 @@
 		      unsigned int lang_mask, int kind ATTRIBUTE_UNUSED,
 		      location_t loc,
 		      const struct cl_option_handlers *handlers,
-		      diagnostic_context *dc)
+		      diagnostic_context *dc,
+		      void (*target_option_override_hook) (void))
 {
   size_t scode = decoded->opt_index;
   const char *arg = decoded->arg;
@@ -1705,6 +1706,7 @@
 	undoc_mask = ((opts->x_verbose_flag | opts->x_extra_warnings)
 		      ? 0
 		      : CL_UNDOCUMENTED);
+	target_option_override_hook ();
 	/* First display any single language specific options.  */
 	for (i = 0; i < cl_lang_count; i++)
 	  print_specific_help
@@ -1724,6 +1726,7 @@
       if (lang_mask == CL_DRIVER)
 	break;
 
+      target_option_override_hook ();
       print_specific_help (CL_TARGET, CL_UNDOCUMENTED, 0, opts, lang_mask);
       opts->x_exit_after_options = true;
       break;
@@ -1850,8 +1853,11 @@
 	  }
 
 	if (include_flags)
-	  print_specific_help (include_flags, exclude_flags, 0, opts,
-			       lang_mask);
+	  {
+	    target_option_override_hook ();
+	    print_specific_help (include_flags, exclude_flags, 0, opts,
+				 lang_mask);
+	  }
 	opts->x_exit_after_options = true;
 	break;
       }
Index: gcc/opts.h
===================================================================
--- gcc/opts.h	(.../tags/gcc_7_2_0_release)
+++ gcc/opts.h	(.../branches/gcc-7-branch)
@@ -267,7 +267,8 @@
 		   const struct cl_decoded_option *decoded,
 		   unsigned int lang_mask, int kind, location_t loc,
 		   const struct cl_option_handlers *handlers,
-		   diagnostic_context *dc);
+		   diagnostic_context *dc,
+		   void (*target_option_override_hook) (void));
 
   /* The mask that must have some bit in common with the flags for the
      option for this particular handler to be used.  */
@@ -289,6 +290,9 @@
   void (*wrong_lang_callback) (const struct cl_decoded_option *decoded,
 			       unsigned int lang_mask);
 
+  /* Target option override hook.  */
+  void (*target_option_override_hook) (void);
+
   /* The number of individual handlers.  */
   size_t num_handlers;
 
@@ -333,13 +337,15 @@
 							  const char **argv, 
 							  struct cl_decoded_option **decoded_options,
 							  unsigned int *decoded_options_count);
-extern void set_default_handlers (struct cl_option_handlers *handlers);
+extern void set_default_handlers (struct cl_option_handlers *handlers,
+				  void (*target_option_override_hook) (void));
 extern void decode_options (struct gcc_options *opts,
 			    struct gcc_options *opts_set,
 			    struct cl_decoded_option *decoded_options,
 			    unsigned int decoded_options_count,
 			    location_t loc,
-			    diagnostic_context *dc);
+			    diagnostic_context *dc,
+			    void (*target_option_override_hook) (void));
 extern int option_enabled (int opt_idx, void *opts);
 extern bool get_option_state (struct gcc_options *, int,
 			      struct cl_option_state *);
@@ -384,7 +390,8 @@
 				  unsigned int lang_mask, int kind,
 				  location_t loc,
 				  const struct cl_option_handlers *handlers,
-				  diagnostic_context *dc);
+				  diagnostic_context *dc,
+				  void (*target_option_override_hook) (void));
 extern bool target_handle_option (struct gcc_options *opts,
 				  struct gcc_options *opts_set,
 				  const struct cl_decoded_option *decoded,
@@ -391,7 +398,8 @@
 				  unsigned int lang_mask, int kind,
 				  location_t loc,
 				  const struct cl_option_handlers *handlers,
-				  diagnostic_context *dc);
+				  diagnostic_context *dc,
+				  void (*target_option_override_hook) (void));
 extern void finish_options (struct gcc_options *opts,
 			    struct gcc_options *opts_set,
 			    location_t loc);
Index: gcc/ada/sysdep.c
===================================================================
--- gcc/ada/sysdep.c	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/sysdep.c	(.../branches/gcc-7-branch)
@@ -126,7 +126,7 @@
 
 */
 
-#if defined (WINNT) || defined (__CYGWIN__) || defined(__DJGPP__)
+#if defined (WINNT) || defined (__CYGWIN__) || defined (__DJGPP__)
 
 const char __gnat_text_translation_required = 1;
 
@@ -137,7 +137,7 @@
 #define WIN_SETMODE _setmode
 #endif
 
-#if defined(__DJGPP__)
+#if defined (__DJGPP__)
 #include <io.h>
 #define _setmode setmode
 #endif /* __DJGPP__ */
@@ -154,7 +154,7 @@
   WIN_SETMODE (handle, O_TEXT);
 }
 
-#ifdef __DJGPP__
+#if defined (__CYGWIN__) || defined (__DJGPP__)
 void
 __gnat_set_mode (int handle, int mode)
 {
@@ -826,7 +826,7 @@
 
 #elif defined (__APPLE__) || defined (__FreeBSD__) || defined (__linux__) \
   || defined (__GLIBC__) || defined (__DragonFly__) || defined (__OpenBSD__) \
-  || defined(__DJGPP__)
+  || defined (__DJGPP__)
 {
   localtime_r (timer, &tp);
   *off = tp.tm_gmtoff;
Index: gcc/ada/sem_ch3.adb
===================================================================
--- gcc/ada/sem_ch3.adb	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/sem_ch3.adb	(.../branches/gcc-7-branch)
@@ -21211,9 +21211,11 @@
                Error_Msg_N ("invalid subtype mark in subtype indication", S);
          end case;
 
-         --  Size and Convention are always inherited from the base type
+         --  Size, Alignment, Representation aspects and Convention are always
+         --  inherited from the base type.
 
          Set_Size_Info  (Def_Id,            (Subtype_Mark_Id));
+         Set_Rep_Info   (Def_Id,            (Subtype_Mark_Id));
          Set_Convention (Def_Id, Convention (Subtype_Mark_Id));
 
          return Def_Id;
Index: gcc/ada/sem_util.adb
===================================================================
--- gcc/ada/sem_util.adb	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/sem_util.adb	(.../branches/gcc-7-branch)
@@ -20302,6 +20302,20 @@
       end if;
    end Set_Referenced_Modified;
 
+   ------------------
+   -- Set_Rep_Info --
+   ------------------
+
+   procedure Set_Rep_Info (T1, T2 : Entity_Id) is
+   begin
+      Set_Is_Atomic               (T1, Is_Atomic (T2));
+      Set_Is_Independent          (T1, Is_Independent (T2));
+      Set_Is_Volatile_Full_Access (T1, Is_Volatile_Full_Access (T2));
+      if Is_Base_Type (T1) then
+         Set_Is_Volatile          (T1, Is_Volatile (T2));
+      end if;
+   end Set_Rep_Info;
+
    ----------------------------
    -- Set_Scope_Is_Transient --
    ----------------------------
Index: gcc/ada/sem_util.ads
===================================================================
--- gcc/ada/sem_util.ads	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/sem_util.ads	(.../branches/gcc-7-branch)
@@ -2313,6 +2313,12 @@
    --  (Referenced_As_LHS if Out_Param is False, Referenced_As_Out_Parameter
    --  if Out_Param is True) is set True, and the other flag set False.
 
+   procedure Set_Rep_Info (T1, T2 : Entity_Id);
+   pragma Inline (Set_Rep_Info);
+   --  Copies the Is_Atomic, Is_Independent and Is_Volatile_Full_Access flags
+   --  from sub(type) entity T2 to (sub)type entity T1, as well as Is_Volatile
+   --  if T1 is a base type.
+
    procedure Set_Scope_Is_Transient (V : Boolean := True);
    --  Set the flag Is_Transient of the current scope
 
Index: gcc/ada/mingw32.h
===================================================================
--- gcc/ada/mingw32.h	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/mingw32.h	(.../branches/gcc-7-branch)
@@ -59,16 +59,6 @@
 #endif
 #include <windows.h>
 
-#ifndef _O_U8TEXT
-#define _O_U8TEXT _O_TEXT
-#endif
-#ifndef _O_U16TEXT
-#define _O_U16TEXT _O_TEXT
-#endif
-#ifndef _O_WTEXT
-#define _O_WTEXT _O_TEXT
-#endif
-
 /* After including this file it is possible to use the character t as prefix
    to routines. If GNAT_UNICODE_SUPPORT is defined then the unicode enabled
    versions will be used.  */
Index: gcc/ada/ChangeLog
===================================================================
--- gcc/ada/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,75 @@
+2017-11-10  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/utils.c (convert) <RECORD_TYPE>: Add comment and do
+	not fall through to the next case.
+	<ARRAY_TYPE>: Deal specially with a dereference from another array
+	type with the same element type.
+
+2017-10-21  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/Makefile.in: Remove bogus settings for VxWorks.
+
+2017-10-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR ada/82393
+	* mingw32.h (_O_U8TEXT, _O_U16TEXT, _O_WTEXT): Delete.
+	* sysdep.c (__gnat_set_mode ): Use DJGPP version for Cygwin.
+
+2017-09-15  Martin Liska  <mliska@suse.cz>
+
+	Backport from mainline
+	2017-08-29  Martin Liska  <mliska@suse.cz>
+
+	PR other/39851
+	* gcc-interface/trans.c (Pragma_to_gnu): Set argument to NULL.
+
+2017-09-09  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/decl.c (promote_object_alignment): New function taken
+	from...
+	(gnat_to_gnu_entity) <E_Variable>: ...here.  Invoke it.
+	(gnat_to_gnu_field): If the field is Atomic or VFA, invoke it and
+	create a padding type on success before doing the atomic check.
+
+2017-09-09  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/decl.c (gnat_to_gnu_entity) <E_Variable>: Apply the
+	promotion to static memory earlier in the processing.
+
+2017-09-09  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* sem_util.ads (Set_Rep_Info): New inline procedure.
+	* sem_util.adb (Set_Rep_Info): Implement it.
+	* sem_ch3.adb (Process_Subtype): If the case of a constraint present,
+	always copy the representation aspects onto the subtype.
+	* gcc-interface/decl.c (gnat_to_gnu_entity): Only set the TYPE_ALIGN_OK
+	and TYPE_BY_REFERENCE_P flags on types after various promotions.
+	* gcc-interface/trans.c (node_has_volatile_full_access) <N_Identifier>:
+	Consider all kinds of entities.
+
+2017-09-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	PR ada/62235
+	* gcc-interface/decl.c (gnat_to_gnu_entity): Skip regular processing
+	for Itypes that are E_Record_Subtype with a cloned subtype.
+	<E_Record_Subtype>: Use the DECL of the cloned type directly, if any.
+
+2017-09-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/utils.c (unchecked_convert): When the result type is a
+	non-biased integral type with size 0, set the result to 0 directly.
+
+2017-09-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/trans.c (Call_to_gnu): If this is a function call and
+	there is no target, do not create a temporary for the return value for
+	an allocator either.
+
+2017-09-05  Eric Botcazou  <ebotcazou@adacore.com>
+
+	* gcc-interface/trans.c (pos_to_constructor): Skip conversions to an
+	unconstrained array type.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: gcc/ada/gcc-interface/utils.c
===================================================================
--- gcc/ada/gcc-interface/utils.c	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/gcc-interface/utils.c	(.../branches/gcc-7-branch)
@@ -4660,6 +4660,7 @@
       return fold (convert_to_real (type, expr));
 
     case RECORD_TYPE:
+      /* Do a normal conversion between scalar and justified modular type.  */
       if (TYPE_JUSTIFIED_MODULAR_P (type) && !AGGREGATE_TYPE_P (etype))
 	{
 	  vec<constructor_elt, va_gc> *v;
@@ -4671,9 +4672,27 @@
 	  return gnat_build_constructor (type, v);
 	}
 
-      /* ... fall through ... */
+      /* In these cases, assume the front-end has validated the conversion.
+	 If the conversion is valid, it will be a bit-wise conversion, so
+	 it can be viewed as an unchecked conversion.  */
+      return unchecked_convert (type, expr, false);
 
     case ARRAY_TYPE:
+      /* Do a normal conversion between unconstrained and constrained array
+	 type, assuming the latter is a constrained version of the former.  */
+      if (TREE_CODE (expr) == INDIRECT_REF
+	  && ecode == ARRAY_TYPE
+	  && TREE_TYPE (etype) == TREE_TYPE (type))
+	{
+	  tree ptr_type = build_pointer_type (type);
+	  tree t = build_unary_op (INDIRECT_REF, NULL_TREE,
+				   fold_convert (ptr_type,
+						 TREE_OPERAND (expr, 0)));
+	  TREE_READONLY (t) = TREE_READONLY (expr);
+	  TREE_THIS_NOTRAP (t) = TREE_THIS_NOTRAP (expr);
+	  return t;
+	}
+
       /* In these cases, assume the front-end has validated the conversion.
 	 If the conversion is valid, it will be a bit-wise conversion, so
 	 it can be viewed as an unchecked conversion.  */
@@ -5230,20 +5249,26 @@
 					? TYPE_RM_SIZE (etype)
 					: TYPE_SIZE (etype)) == 0)))
     {
-      tree base_type
-	= gnat_type_for_size (TREE_INT_CST_LOW (TYPE_SIZE (type)),
-			      type_unsigned_for_rm (type));
-      tree shift_expr
-	= convert (base_type,
-		   size_binop (MINUS_EXPR,
-			       TYPE_SIZE (type), TYPE_RM_SIZE (type)));
-      expr
-	= convert (type,
-		   build_binary_op (RSHIFT_EXPR, base_type,
-				    build_binary_op (LSHIFT_EXPR, base_type,
-						     convert (base_type, expr),
-						     shift_expr),
-				    shift_expr));
+      if (integer_zerop (TYPE_RM_SIZE (type)))
+	expr = build_int_cst (type, 0);
+      else
+	{
+	  tree base_type
+	    = gnat_type_for_size (TREE_INT_CST_LOW (TYPE_SIZE (type)),
+				  type_unsigned_for_rm (type));
+	  tree shift_expr
+	    = convert (base_type,
+		       size_binop (MINUS_EXPR,
+				   TYPE_SIZE (type), TYPE_RM_SIZE (type)));
+	  expr
+	    = convert (type,
+		       build_binary_op (RSHIFT_EXPR, base_type,
+				        build_binary_op (LSHIFT_EXPR, base_type,
+							 convert (base_type,
+								  expr),
+							 shift_expr),
+				        shift_expr));
+	}
     }
 
   /* An unchecked conversion should never raise Constraint_Error.  The code
Index: gcc/ada/gcc-interface/Makefile.in
===================================================================
--- gcc/ada/gcc-interface/Makefile.in	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/gcc-interface/Makefile.in	(.../branches/gcc-7-branch)
@@ -904,10 +904,10 @@
 
   ifeq ($(strip $(filter-out x86_64, $(target_cpu))),)
      X86CPU=x86_64
-     LIBGNAT_TARGET_PAIRS=s-atocou.adb<s-atocou-builtin.adb
+     LIBGNAT_TARGET_PAIRS=$(X86_64_TARGET_PAIRS)
   else
      X86CPU=x86
-     LIBGNAT_TARGET_PAIRS=s-atocou.adb<s-atocou-x86.adb
+     LIBGNAT_TARGET_PAIRS=$(X86_TARGET_PAIRS)
   endif
 
   LIBGNAT_TARGET_PAIRS+= \
@@ -930,10 +930,7 @@
   g-socthi.ads<g-socthi-vxworks.ads \
   g-socthi.adb<g-socthi-vxworks.adb \
   g-stsifd.adb<g-stsifd-sockets.adb \
-  $(ATOMICS_TARGET_PAIRS) \
-  $(CERTMATH_TARGET_PAIRS) \
-  $(CERTMATH_TARGET_PAIRS_SQRT_FPU) \
-  $(CERTMATH_TARGET_PAIRS_X86TRA)
+  $(ATOMICS_TARGET_PAIRS)
 
   TOOLS_TARGET_PAIRS=\
   mlib-tgt-specific.adb<mlib-tgt-specific-vxworks.adb \
@@ -1033,8 +1030,7 @@
     endif
   endif
 
-  EXTRA_GNATRTL_NONTASKING_OBJS += s-stchop.o \
-    $(CERTMATH_GNATRTL_OBJS) $(CERTMATH_GNATRTL_X86TRA_OBJS)
+  EXTRA_GNATRTL_NONTASKING_OBJS += s-stchop.o
   EXTRA_GNATRTL_TASKING_OBJS += i-vxinco.o s-vxwork.o s-vxwext.o
 
   EXTRA_LIBGNAT_OBJS+=vx_stack_info.o
@@ -1135,7 +1131,7 @@
     endif
   endif
 
-  EXTRA_GNATRTL_NONTASKING_OBJS=i-vxwork.o i-vxwoio.o $(CERTMATH_GNATRTL_OBJS) \
+  EXTRA_GNATRTL_NONTASKING_OBJS=i-vxwork.o i-vxwoio.o \
     s-stchop.o
   EXTRA_GNATRTL_TASKING_OBJS=i-vxinco.o s-vxwork.o s-vxwext.o
 
Index: gcc/ada/gcc-interface/decl.c
===================================================================
--- gcc/ada/gcc-interface/decl.c	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/gcc-interface/decl.c	(.../branches/gcc-7-branch)
@@ -229,6 +229,7 @@
 static tree validate_size (Uint, tree, Entity_Id, enum tree_code, bool, bool);
 static void set_rm_size (Uint, tree, Entity_Id);
 static unsigned int validate_alignment (Uint, Entity_Id, unsigned int);
+static unsigned int promote_object_alignment (tree, Entity_Id);
 static void check_ok_for_atomic_type (tree, Entity_Id, bool);
 static tree create_field_decl_from (tree, tree, tree, tree, tree,
 				    vec<subst_pair> );
@@ -309,11 +310,14 @@
 
   /* Since a use of an Itype is a definition, process it as such if it is in
      the main unit, except for E_Access_Subtype because it's actually a use
-     of its base type, see below.  */
+     of its base type, and for E_Record_Subtype with cloned subtype because
+     it's actually a use of the cloned subtype, see below.  */
   if (!definition
       && is_type
       && Is_Itype (gnat_entity)
-      && Ekind (gnat_entity) != E_Access_Subtype
+      && !(kind == E_Access_Subtype
+	   || (kind == E_Record_Subtype
+	       && Present (Cloned_Subtype (gnat_entity))))
       && !present_gnu_tree (gnat_entity)
       && In_Extended_Main_Code_Unit (gnat_entity))
     {
@@ -847,46 +851,8 @@
 		    && No (Renamed_Object (gnat_entity))
 		    && No (Address_Clause (gnat_entity))))
 	    && TREE_CODE (TYPE_SIZE (gnu_type)) == INTEGER_CST)
-	  {
-	    unsigned int size_cap, align_cap;
+	  align = promote_object_alignment (gnu_type, gnat_entity);
 
-	    /* No point in promoting the alignment if this doesn't prevent
-	       BLKmode access to the object, in particular block copy, as
-	       this will for example disable the NRV optimization for it.
-	       No point in jumping through all the hoops needed in order
-	       to support BIGGEST_ALIGNMENT if we don't really have to.
-	       So we cap to the smallest alignment that corresponds to
-	       a known efficient memory access pattern of the target.  */
-	    if (Is_Atomic_Or_VFA (gnat_entity))
-	      {
-		size_cap = UINT_MAX;
-		align_cap = BIGGEST_ALIGNMENT;
-	      }
-	    else
-	      {
-		size_cap = MAX_FIXED_MODE_SIZE;
-		align_cap = get_mode_alignment (ptr_mode);
-	      }
-
-	    if (!tree_fits_uhwi_p (TYPE_SIZE (gnu_type))
-		|| compare_tree_int (TYPE_SIZE (gnu_type), size_cap) > 0)
-	      align = 0;
-	    else if (compare_tree_int (TYPE_SIZE (gnu_type), align_cap) > 0)
-	      align = align_cap;
-	    else
-	      align = ceil_pow2 (tree_to_uhwi (TYPE_SIZE (gnu_type)));
-
-	    /* But make sure not to under-align the object.  */
-	    if (align <= TYPE_ALIGN (gnu_type))
-	      align = 0;
-
-	    /* And honor the minimum valid atomic alignment, if any.  */
-#ifdef MINIMUM_ATOMIC_ALIGNMENT
-	    else if (align < MINIMUM_ATOMIC_ALIGNMENT)
-	      align = MINIMUM_ATOMIC_ALIGNMENT;
-#endif
-	  }
-
 	/* If the object is set to have atomic components, find the component
 	   type and validate it.
 
@@ -1413,6 +1379,19 @@
 	    gnu_size = NULL_TREE;
 	  }
 
+	/* If this is an aggregate constant initialized to a constant, force it
+	   to be statically allocated.  This saves an initialization copy.  */
+	if (!static_flag
+	    && const_flag
+	    && gnu_expr
+	    && TREE_CONSTANT (gnu_expr)
+	    && AGGREGATE_TYPE_P (gnu_type)
+	    && tree_fits_uhwi_p (TYPE_SIZE_UNIT (gnu_type))
+	    && !(TYPE_IS_PADDING_P (gnu_type)
+		 && !tree_fits_uhwi_p (TYPE_SIZE_UNIT
+				       (TREE_TYPE (TYPE_FIELDS (gnu_type))))))
+	  static_flag = true;
+
 	/* If this is an aliased object with an unconstrained array nominal
 	   subtype, we make its type a thin reference, i.e. the reference
 	   counterpart of a thin pointer, so it points to the array part.
@@ -1463,18 +1442,6 @@
 		&& No (Address_Clause (gnat_entity))))
 	  gnu_ext_name = create_concat_name (gnat_entity, NULL);
 
-	/* If this is an aggregate constant initialized to a constant, force it
-	   to be statically allocated.  This saves an initialization copy.  */
-	if (!static_flag
-	    && const_flag
-	    && gnu_expr && TREE_CONSTANT (gnu_expr)
-	    && AGGREGATE_TYPE_P (gnu_type)
-	    && tree_fits_uhwi_p (TYPE_SIZE_UNIT (gnu_type))
-	    && !(TYPE_IS_PADDING_P (gnu_type)
-		 && !tree_fits_uhwi_p (TYPE_SIZE_UNIT
-				       (TREE_TYPE (TYPE_FIELDS (gnu_type))))))
-	  static_flag = true;
-
 	/* Deal with a pragma Linker_Section on a constant or variable.  */
 	if ((kind == E_Constant || kind == E_Variable)
 	    && Present (Linker_Section_Pragma (gnat_entity)))
@@ -3391,7 +3358,7 @@
 	{
 	  gnu_decl = gnat_to_gnu_entity (Cloned_Subtype (gnat_entity),
 					 NULL_TREE, false);
-	  maybe_present = true;
+	  saved = true;
 	  break;
 	}
 
@@ -4505,18 +4472,6 @@
 	 already defined so we cannot pass true for IN_PLACE here.  */
       process_attributes (&gnu_type, &attr_list, false, gnat_entity);
 
-      /* Tell the middle-end that objects of tagged types are guaranteed to
-	 be properly aligned.  This is necessary because conversions to the
-	 class-wide type are translated into conversions to the root type,
-	 which can be less aligned than some of its derived types.  */
-      if (Is_Tagged_Type (gnat_entity)
-	  || Is_Class_Wide_Equivalent_Type (gnat_entity))
-	TYPE_ALIGN_OK (gnu_type) = 1;
-
-      /* Record whether the type is passed by reference.  */
-      if (!VOID_TYPE_P (gnu_type) && Is_By_Reference_Type (gnat_entity))
-	TYPE_BY_REFERENCE_P (gnu_type) = 1;
-
       /* ??? Don't set the size for a String_Literal since it is either
 	 confirming or we don't handle it properly (if the low bound is
 	 non-constant).  */
@@ -4726,17 +4681,29 @@
       /* If this is not an unconstrained array type, set some flags.  */
       if (TREE_CODE (gnu_type) != UNCONSTRAINED_ARRAY_TYPE)
 	{
+	  /* Tell the middle-end that objects of tagged types are guaranteed to
+	     be properly aligned.  This is necessary because conversions to the
+	     class-wide type are translated into conversions to the root type,
+	     which can be less aligned than some of its derived types.  */
+	  if (Is_Tagged_Type (gnat_entity)
+	      || Is_Class_Wide_Equivalent_Type (gnat_entity))
+	    TYPE_ALIGN_OK (gnu_type) = 1;
+
+	  /* Record whether the type is passed by reference.  */
+	  if (Is_By_Reference_Type (gnat_entity) && !VOID_TYPE_P (gnu_type))
+	    TYPE_BY_REFERENCE_P (gnu_type) = 1;
+
+	  /* Record whether an alignment clause was specified.  */
 	  if (Present (Alignment_Clause (gnat_entity)))
 	    TYPE_USER_ALIGN (gnu_type) = 1;
 
+	  /* Record whether a pragma Universal_Aliasing was specified.  */
 	  if (Universal_Aliasing (gnat_entity) && !TYPE_IS_DUMMY_P (gnu_type))
 	    TYPE_UNIVERSAL_ALIASING_P (gnu_type) = 1;
 
 	  /* If it is passed by reference, force BLKmode to ensure that
 	     objects of this type will always be put in memory.  */
-	  if (TYPE_MODE (gnu_type) != BLKmode
-	      && AGGREGATE_TYPE_P (gnu_type)
-	      && TYPE_BY_REFERENCE_P (gnu_type))
+	  if (AGGREGATE_TYPE_P (gnu_type) && TYPE_BY_REFERENCE_P (gnu_type))
 	    SET_TYPE_MODE (gnu_type, BLKmode);
 	}
 
@@ -7114,7 +7081,15 @@
     }
 
   if (Is_Atomic_Or_VFA (gnat_field))
-    check_ok_for_atomic_type (gnu_field_type, gnat_field, false);
+    {
+      const unsigned int align
+	= promote_object_alignment (gnu_field_type, gnat_field);
+      if (align > 0)
+	gnu_field_type
+	  = maybe_pad_type (gnu_field_type, NULL_TREE, align, gnat_field,
+			    false, false, definition, true);
+      check_ok_for_atomic_type (gnu_field_type, gnat_field, false);
+    }
 
   if (Present (Component_Clause (gnat_field)))
     {
@@ -8788,6 +8763,53 @@
   return align;
 }
 
+/* Promote the alignment of GNU_TYPE corresponding to GNAT_ENTITY.  Return
+   a positive value on success or zero on failure.  */
+
+static unsigned int
+promote_object_alignment (tree gnu_type, Entity_Id gnat_entity)
+{
+  unsigned int align, size_cap, align_cap;
+
+  /* No point in promoting the alignment if this doesn't prevent BLKmode access
+     to the object, in particular block copy, as this will for example disable
+     the NRV optimization for it.  No point in jumping through all the hoops
+     needed in order to support BIGGEST_ALIGNMENT if we don't really have to.
+     So we cap to the smallest alignment that corresponds to a known efficient
+     memory access pattern, except for Atomic and Volatile_Full_Access.  */
+  if (Is_Atomic_Or_VFA (gnat_entity))
+    {
+      size_cap = UINT_MAX;
+      align_cap = BIGGEST_ALIGNMENT;
+    }
+  else
+    {
+      size_cap = MAX_FIXED_MODE_SIZE;
+      align_cap = get_mode_alignment (ptr_mode);
+    }
+
+  /* Do the promotion within the above limits.  */
+  if (!tree_fits_uhwi_p (TYPE_SIZE (gnu_type))
+      || compare_tree_int (TYPE_SIZE (gnu_type), size_cap) > 0)
+    align = 0;
+  else if (compare_tree_int (TYPE_SIZE (gnu_type), align_cap) > 0)
+    align = align_cap;
+  else
+    align = ceil_pow2 (tree_to_uhwi (TYPE_SIZE (gnu_type)));
+
+  /* But make sure not to under-align the object.  */
+  if (align <= TYPE_ALIGN (gnu_type))
+    align = 0;
+
+   /* And honor the minimum valid atomic alignment, if any.  */
+#ifdef MINIMUM_ATOMIC_ALIGNMENT
+  else if (align < MINIMUM_ATOMIC_ALIGNMENT)
+    align = MINIMUM_ATOMIC_ALIGNMENT;
+#endif
+
+  return align;
+}
+
 /* Verify that TYPE is something we can implement atomically.  If not, issue
    an error for GNAT_ENTITY.  COMPONENT_P is true if we are being called to
    process a component type.  */
Index: gcc/ada/gcc-interface/trans.c
===================================================================
--- gcc/ada/gcc-interface/trans.c	(.../tags/gcc_7_2_0_release)
+++ gcc/ada/gcc-interface/trans.c	(.../branches/gcc-7-branch)
@@ -1477,7 +1477,7 @@
 	else
 	  option_index = 0;
 
-	set_default_handlers (&handlers);
+	set_default_handlers (&handlers, NULL);
 	control_warning_option (option_index, (int) kind, arg, imply, location,
 				lang_mask, &handlers, &global_options,
 				&global_options_set, global_dc);
@@ -4058,8 +4058,6 @@
     case N_Identifier:
     case N_Expanded_Name:
       gnat_entity = Entity (gnat_node);
-      if (Ekind (gnat_entity) != E_Variable)
-	break;
       return Is_Volatile_Full_Access (gnat_entity)
 	     || Is_Volatile_Full_Access (Etype (gnat_entity));
 
@@ -4326,11 +4324,11 @@
 	  parameters.
 
        2. There is no target and the call is made for neither an object nor a
-	  renaming declaration, nor a return statement, and the return type has
-	  variable size, because in this case the gimplifier cannot create the
-	  temporary, or more generally is simply an aggregate type, because the
-	  gimplifier would create the temporary in the outermost scope instead
-	  of locally.
+	  renaming declaration, nor a return statement, nor an allocator, and
+	  the return type has variable size because in this case the gimplifier
+	  cannot create the temporary, or more generally is simply an aggregate
+	  type, because the gimplifier would then create the temporary in the
+	  outermost scope instead of locally.
 
        3. There is a target and it is a slice or an array with fixed size,
 	  and the return type has variable size, because the gimplifier
@@ -4349,6 +4347,8 @@
 	      && Nkind (Parent (gnat_node)) != N_Object_Declaration
 	      && Nkind (Parent (gnat_node)) != N_Object_Renaming_Declaration
 	      && Nkind (Parent (gnat_node)) != N_Simple_Return_Statement
+	      && !(Nkind (Parent (gnat_node)) == N_Qualified_Expression
+		   && Nkind (Parent (Parent (gnat_node))) == N_Allocator)
 	      && AGGREGATE_TYPE_P (gnu_result_type)
 	      && !TYPE_IS_FAT_POINTER_P (gnu_result_type))
 	  || (gnu_target
@@ -9702,7 +9702,14 @@
 				       gnat_component_type);
       else
 	{
-	  gnu_expr = gnat_to_gnu (gnat_expr);
+	  /* If the expression is a conversion to an unconstrained array type,
+	     skip it to avoid spilling to memory.  */
+	  if (Nkind (gnat_expr) == N_Type_Conversion
+	      && Is_Array_Type (Etype (gnat_expr))
+	      && !Is_Constrained (Etype (gnat_expr)))
+	    gnu_expr = gnat_to_gnu (Expression (gnat_expr));
+	  else
+	    gnu_expr = gnat_to_gnu (gnat_expr);
 
 	  /* Before assigning the element to the array, make sure it is
 	     in range.  */
Index: gcc/asan.c
===================================================================
--- gcc/asan.c	(.../tags/gcc_7_2_0_release)
+++ gcc/asan.c	(.../branches/gcc-7-branch)
@@ -2315,9 +2315,12 @@
   /* DECL_NAME theoretically might be NULL.  Bail out with 0 in this case.  */
   if (decl_name == NULL_TREE)
     return build_int_cst (uptr, 0);
-  size_t len = strlen (IDENTIFIER_POINTER (decl_name)) + sizeof ("__odr_asan_");
+  const char *dname = IDENTIFIER_POINTER (decl_name);
+  if (HAS_DECL_ASSEMBLER_NAME_P (decl))
+    dname = targetm.strip_name_encoding (dname);
+  size_t len = strlen (dname) + sizeof ("__odr_asan_");
   name = XALLOCAVEC (char, len);
-  snprintf (name, len, "__odr_asan_%s", IDENTIFIER_POINTER (decl_name));
+  snprintf (name, len, "__odr_asan_%s", dname);
 #ifndef NO_DOT_IN_LABEL
   name[sizeof ("__odr_asan") - 1] = '.';
 #elif !defined(NO_DOLLAR_IN_LABEL)
Index: gcc/lra-remat.c
===================================================================
--- gcc/lra-remat.c	(.../tags/gcc_7_2_0_release)
+++ gcc/lra-remat.c	(.../branches/gcc-7-branch)
@@ -684,7 +684,7 @@
 
 	if (regno2 >= FIRST_PSEUDO_REGISTER && reg_renumber[regno2] >= 0)
 	  regno2 = reg_renumber[regno2];
-	if (regno >= FIRST_PSEUDO_REGISTER)
+	if (regno2 >= FIRST_PSEUDO_REGISTER)
 	  nregs2 = 1;
 	else
 	  nregs2 = hard_regno_nregs[regno2][reg->biggest_mode];
Index: gcc/gimple-ssa-strength-reduction.c
===================================================================
--- gcc/gimple-ssa-strength-reduction.c	(.../tags/gcc_7_2_0_release)
+++ gcc/gimple-ssa-strength-reduction.c	(.../branches/gcc-7-branch)
@@ -476,7 +476,8 @@
 
   c = base_cand_from_table (base);
 
-  if (!c || c->kind != CAND_PHI)
+  if (!c || c->kind != CAND_PHI
+      || SSA_NAME_OCCURS_IN_ABNORMAL_PHI (gimple_phi_result (c->cand_stmt)))
     return 0;
 
   return c->cand_num;
@@ -515,6 +516,11 @@
 			      gimple_bb (one_basis->cand_stmt)))
 	continue;
 
+      tree lhs = gimple_assign_lhs (one_basis->cand_stmt);
+      if (lhs && TREE_CODE (lhs) == SSA_NAME
+	  && SSA_NAME_OCCURS_IN_ABNORMAL_PHI (lhs))
+	continue;
+
       if (!basis || basis->cand_num < one_basis->cand_num)
 	basis = one_basis;
     }
@@ -2044,105 +2050,105 @@
   tree target_type = TREE_TYPE (gimple_assign_lhs (c->cand_stmt));
   enum tree_code cand_code = gimple_assign_rhs_code (c->cand_stmt);
 
-  /* It is highly unlikely, but possible, that the resulting
-     bump doesn't fit in a HWI.  Abandon the replacement
-     in this case.  This does not affect siblings or dependents
-     of C.  Restriction to signed HWI is conservative for unsigned
-     types but allows for safe negation without twisted logic.  */
-  if (wi::fits_shwi_p (bump)
-      && bump.to_shwi () != HOST_WIDE_INT_MIN
-      /* It is not useful to replace casts, copies, negates, or adds of
-	 an SSA name and a constant.  */
-      && cand_code != SSA_NAME
-      && !CONVERT_EXPR_CODE_P (cand_code)
-      && cand_code != PLUS_EXPR
-      && cand_code != POINTER_PLUS_EXPR
-      && cand_code != MINUS_EXPR
-      && cand_code != NEGATE_EXPR)
+  /* It is not useful to replace casts, copies, negates, or adds of
+     an SSA name and a constant.  */
+  if (cand_code == SSA_NAME
+      || CONVERT_EXPR_CODE_P (cand_code)
+      || cand_code == PLUS_EXPR
+      || cand_code == POINTER_PLUS_EXPR
+      || cand_code == MINUS_EXPR
+      || cand_code == NEGATE_EXPR)
+    return;
+  
+  enum tree_code code = PLUS_EXPR;
+  tree bump_tree;
+  gimple *stmt_to_print = NULL;
+
+  /* If the basis name and the candidate's LHS have incompatible
+     types, introduce a cast.  */
+  if (!useless_type_conversion_p (target_type, TREE_TYPE (basis_name)))
+    basis_name = introduce_cast_before_cand (c, target_type, basis_name);
+  if (wi::neg_p (bump))
     {
-      enum tree_code code = PLUS_EXPR;
-      tree bump_tree;
-      gimple *stmt_to_print = NULL;
+      code = MINUS_EXPR;
+      bump = -bump;
+    }
 
-      /* If the basis name and the candidate's LHS have incompatible
-	 types, introduce a cast.  */
-      if (!useless_type_conversion_p (target_type, TREE_TYPE (basis_name)))
-	basis_name = introduce_cast_before_cand (c, target_type, basis_name);
-      if (wi::neg_p (bump))
+ /* It is possible that the resulting bump doesn't fit in target_type.
+    Abandon the replacement in this case.  This does not affect
+    siblings or dependents of C.  */
+  if (bump != wi::ext (bump, TYPE_PRECISION (target_type),
+		       TYPE_SIGN (target_type)))
+    return;
+
+  bump_tree = wide_int_to_tree (target_type, bump);
+
+  if (dump_file && (dump_flags & TDF_DETAILS))
+    {
+      fputs ("Replacing: ", dump_file);
+      print_gimple_stmt (dump_file, c->cand_stmt, 0, 0);
+    }
+
+  if (bump == 0)
+    {
+      tree lhs = gimple_assign_lhs (c->cand_stmt);
+      gassign *copy_stmt = gimple_build_assign (lhs, basis_name);
+      gimple_stmt_iterator gsi = gsi_for_stmt (c->cand_stmt);
+      slsr_cand_t cc = c;
+      gimple_set_location (copy_stmt, gimple_location (c->cand_stmt));
+      gsi_replace (&gsi, copy_stmt, false);
+      c->cand_stmt = copy_stmt;
+      while (cc->next_interp)
 	{
-	  code = MINUS_EXPR;
-	  bump = -bump;
+	  cc = lookup_cand (cc->next_interp);
+	  cc->cand_stmt = copy_stmt;
 	}
-
-      bump_tree = wide_int_to_tree (target_type, bump);
-
       if (dump_file && (dump_flags & TDF_DETAILS))
+	stmt_to_print = copy_stmt;
+    }
+  else
+    {
+      tree rhs1, rhs2;
+      if (cand_code != NEGATE_EXPR) {
+	rhs1 = gimple_assign_rhs1 (c->cand_stmt);
+	rhs2 = gimple_assign_rhs2 (c->cand_stmt);
+      }
+      if (cand_code != NEGATE_EXPR
+	  && ((operand_equal_p (rhs1, basis_name, 0)
+	       && operand_equal_p (rhs2, bump_tree, 0))
+	      || (operand_equal_p (rhs1, bump_tree, 0)
+		  && operand_equal_p (rhs2, basis_name, 0))))
 	{
-	  fputs ("Replacing: ", dump_file);
-	  print_gimple_stmt (dump_file, c->cand_stmt, 0, 0);
+	  if (dump_file && (dump_flags & TDF_DETAILS))
+	    {
+	      fputs ("(duplicate, not actually replacing)", dump_file);
+	      stmt_to_print = c->cand_stmt;
+	    }
 	}
-
-      if (bump == 0)
+      else
 	{
-	  tree lhs = gimple_assign_lhs (c->cand_stmt);
-	  gassign *copy_stmt = gimple_build_assign (lhs, basis_name);
 	  gimple_stmt_iterator gsi = gsi_for_stmt (c->cand_stmt);
 	  slsr_cand_t cc = c;
-	  gimple_set_location (copy_stmt, gimple_location (c->cand_stmt));
-	  gsi_replace (&gsi, copy_stmt, false);
-	  c->cand_stmt = copy_stmt;
+	  gimple_assign_set_rhs_with_ops (&gsi, code,
+					  basis_name, bump_tree);
+	  update_stmt (gsi_stmt (gsi));
+	  c->cand_stmt = gsi_stmt (gsi);
 	  while (cc->next_interp)
 	    {
 	      cc = lookup_cand (cc->next_interp);
-	      cc->cand_stmt = copy_stmt;
+	      cc->cand_stmt = gsi_stmt (gsi);
 	    }
 	  if (dump_file && (dump_flags & TDF_DETAILS))
-	    stmt_to_print = copy_stmt;
+	    stmt_to_print = gsi_stmt (gsi);
 	}
-      else
-	{
-	  tree rhs1, rhs2;
-	  if (cand_code != NEGATE_EXPR) {
-	    rhs1 = gimple_assign_rhs1 (c->cand_stmt);
-	    rhs2 = gimple_assign_rhs2 (c->cand_stmt);
-	  }
-	  if (cand_code != NEGATE_EXPR
-	      && ((operand_equal_p (rhs1, basis_name, 0)
-		   && operand_equal_p (rhs2, bump_tree, 0))
-		  || (operand_equal_p (rhs1, bump_tree, 0)
-		      && operand_equal_p (rhs2, basis_name, 0))))
-	    {
-	      if (dump_file && (dump_flags & TDF_DETAILS))
-		{
-		  fputs ("(duplicate, not actually replacing)", dump_file);
-		  stmt_to_print = c->cand_stmt;
-		}
-	    }
-	  else
-	    {
-	      gimple_stmt_iterator gsi = gsi_for_stmt (c->cand_stmt);
-	      slsr_cand_t cc = c;
-	      gimple_assign_set_rhs_with_ops (&gsi, code,
-					      basis_name, bump_tree);
-	      update_stmt (gsi_stmt (gsi));
-              c->cand_stmt = gsi_stmt (gsi);
-	      while (cc->next_interp)
-		{
-		  cc = lookup_cand (cc->next_interp);
-		  cc->cand_stmt = gsi_stmt (gsi);
-		}
-	      if (dump_file && (dump_flags & TDF_DETAILS))
-		stmt_to_print = gsi_stmt (gsi);
-	    }
-	}
-  
-      if (dump_file && (dump_flags & TDF_DETAILS))
-	{
-	  fputs ("With: ", dump_file);
-	  print_gimple_stmt (dump_file, stmt_to_print, 0, 0);
-	  fputs ("\n", dump_file);
-  	}
     }
+
+  if (dump_file && (dump_flags & TDF_DETAILS))
+    {
+      fputs ("With: ", dump_file);
+      print_gimple_stmt (dump_file, stmt_to_print, 0, 0);
+      fputs ("\n", dump_file);
+    }
 }
 
 /* Replace candidate C with an add or subtract.   Note that we only
@@ -2193,8 +2199,6 @@
 			     widest_int increment, edge e, location_t loc,
 			     bool known_stride)
 {
-  basic_block insert_bb;
-  gimple_stmt_iterator gsi;
   tree lhs, basis_type;
   gassign *new_stmt, *cast_stmt = NULL;
 
@@ -2263,39 +2267,25 @@
       }
     }
 
-  insert_bb = single_succ_p (e->src) ? e->src : split_edge (e);
-  gsi = gsi_last_bb (insert_bb);
-
-  if (!gsi_end_p (gsi) && stmt_ends_bb_p (gsi_stmt (gsi)))
+  if (cast_stmt)
     {
-      gsi_insert_before (&gsi, new_stmt, GSI_SAME_STMT);
-      if (cast_stmt)
-	{
-	  gsi_insert_before (&gsi, cast_stmt, GSI_SAME_STMT);
-	  gimple_set_location (cast_stmt, loc);
-	}
+      gimple_set_location (cast_stmt, loc);
+      gsi_insert_on_edge (e, cast_stmt);
     }
-  else
-    {
-      if (cast_stmt)
-	{
-	  gsi_insert_after (&gsi, cast_stmt, GSI_NEW_STMT);
-	  gimple_set_location (cast_stmt, loc);
-	}
-      gsi_insert_after (&gsi, new_stmt, GSI_NEW_STMT);
-    }
 
   gimple_set_location (new_stmt, loc);
+  gsi_insert_on_edge (e, new_stmt);
 
   if (dump_file && (dump_flags & TDF_DETAILS))
     {
       if (cast_stmt)
 	{
-	  fprintf (dump_file, "Inserting cast in block %d: ",
-		   insert_bb->index);
+	  fprintf (dump_file, "Inserting cast on edge %d->%d: ",
+		   e->src->index, e->dest->index);
 	  print_gimple_stmt (dump_file, cast_stmt, 0, 0);
 	}
-      fprintf (dump_file, "Inserting in block %d: ", insert_bb->index);
+      fprintf (dump_file, "Inserting on edge %d->%d: ", e->src->index,
+	       e->dest->index);
       print_gimple_stmt (dump_file, new_stmt, 0, 0);
     }
 
@@ -3217,6 +3207,23 @@
 	 that block, the earliest one will be returned in WHERE.  */
       bb = nearest_common_dominator_for_cands (c, incr, &where);
 
+      /* If the NCD is not dominated by the block containing the
+	 definition of the stride, we can't legally insert a
+	 single initializer.  Mark the increment as unprofitable
+	 so we don't make any replacements.  FIXME: Multiple
+	 initializers could be placed with more analysis.  */
+      gimple *stride_def = SSA_NAME_DEF_STMT (c->stride);
+      basic_block stride_bb = gimple_bb (stride_def);
+
+      if (stride_bb && !dominated_by_p (CDI_DOMINATORS, bb, stride_bb))
+	{
+	  if (dump_file && (dump_flags & TDF_DETAILS))
+	    fprintf (dump_file,
+		     "Initializer #%d cannot be legally placed\n", i);
+	  incr_vec[i].cost = COST_INFINITE;
+	  continue;
+	}
+
       /* If the nominal stride has a different type than the recorded
 	 stride type, build a cast from the nominal stride to that type.  */
       if (!types_compatible_p (TREE_TYPE (c->stride), c->stride_type))
@@ -3736,6 +3743,10 @@
 	  free (incr_vec);
 	}
     }
+
+  /* For conditional candidates, we may have uncommitted insertions
+     on edges to clean up.  */
+  gsi_commit_edge_inserts ();
 }
 
 namespace {
Index: gcc/fortran/trans-expr.c
===================================================================
--- gcc/fortran/trans-expr.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/trans-expr.c	(.../branches/gcc-7-branch)
@@ -4178,9 +4178,7 @@
       if (arg2 && arg2->expr_type == EXPR_CONSTANT)
 	d = mpz_get_si (arg2->value.integer) - 1;
       else
-	/* TODO: If the need arises, this could produce an array of
-	   ubound/lbounds.  */
-	gcc_unreachable ();
+	return false;
 
       if (expr->value.function.isym->id == GFC_ISYM_LBOUND)
 	{
@@ -5173,10 +5171,39 @@
 			}
 		      else
 			{
-			  gfc_add_modify (&parmse.pre, var,
-					  fold_build1_loc (input_location,
-							   VIEW_CONVERT_EXPR,
-							   type, parmse.expr));
+			  /* Since the internal representation of unlimited
+			     polymorphic expressions includes an extra field
+			     that other class objects do not, a cast to the
+			     formal type does not work.  */
+			  if (!UNLIMITED_POLY (e) && UNLIMITED_POLY (fsym))
+			    {
+			      tree efield;
+
+			      /* Set the _data field.  */
+			      tmp = gfc_class_data_get (var);
+			      efield = fold_convert (TREE_TYPE (tmp),
+					gfc_class_data_get (parmse.expr));
+			      gfc_add_modify (&parmse.pre, tmp, efield);
+
+			      /* Set the _vptr field.  */
+			      tmp = gfc_class_vptr_get (var);
+			      efield = fold_convert (TREE_TYPE (tmp),
+					gfc_class_vptr_get (parmse.expr));
+			      gfc_add_modify (&parmse.pre, tmp, efield);
+
+			      /* Set the _len field.  */
+			      tmp = gfc_class_len_get (var);
+			      gfc_add_modify (&parmse.pre, tmp,
+					      build_int_cst (TREE_TYPE (tmp), 0));
+			    }
+			  else
+			    {
+			      tmp = fold_build1_loc (input_location,
+						     VIEW_CONVERT_EXPR,
+						     type, parmse.expr);
+			      gfc_add_modify (&parmse.pre, var, tmp);
+					      ;
+			    }
 			  parmse.expr = gfc_build_addr_expr (NULL_TREE, var);
 			}
 		    }
@@ -8051,7 +8078,7 @@
     {
       /* Get the vptr from the rhs expression only, when it is variable.
 	 Functions are expected to be assigned to a temporary beforehand.  */
-      vptr_expr = re->expr_type == EXPR_VARIABLE
+      vptr_expr = (re->expr_type == EXPR_VARIABLE && re->ts.type == BT_CLASS)
 	  ? gfc_find_and_cut_at_last_class_ref (re)
 	  : NULL;
       if (vptr_expr != NULL && vptr_expr->ts.type == BT_CLASS)
@@ -8205,6 +8232,39 @@
 }
 
 
+/* Do everything that is needed for a CLASS function expr2.  */
+
+static tree
+trans_class_pointer_fcn (stmtblock_t *block, gfc_se *lse, gfc_se *rse,
+			 gfc_expr *expr1, gfc_expr *expr2)
+{
+  tree expr1_vptr = NULL_TREE;
+  tree tmp;
+
+  gfc_conv_function_expr (rse, expr2);
+  rse->expr = gfc_evaluate_now (rse->expr, &rse->pre);
+
+  if (expr1->ts.type != BT_CLASS)
+      rse->expr = gfc_class_data_get (rse->expr);
+  else
+    {
+      expr1_vptr = trans_class_vptr_len_assignment (block, expr1,
+						    expr2, rse,
+						    NULL, NULL);
+      gfc_add_block_to_block (block, &rse->pre);
+      tmp = gfc_create_var (TREE_TYPE (rse->expr), "ptrtemp");
+      gfc_add_modify (&lse->pre, tmp, rse->expr);
+
+      gfc_add_modify (&lse->pre, expr1_vptr,
+		      fold_convert (TREE_TYPE (expr1_vptr),
+		      gfc_class_vptr_get (tmp)));
+      rse->expr = gfc_class_data_get (tmp);
+    }
+
+  return expr1_vptr;
+}
+
+
 tree
 gfc_trans_pointer_assign (gfc_code * code)
 {
@@ -8223,6 +8283,7 @@
   tree desc;
   tree tmp;
   tree decl;
+  tree expr1_vptr = NULL_TREE;
   bool scalar, non_proc_pointer_assign;
   gfc_ss *ss;
 
@@ -8256,7 +8317,10 @@
       gfc_conv_expr (&lse, expr1);
       gfc_init_se (&rse, NULL);
       rse.want_pointer = 1;
-      gfc_conv_expr (&rse, expr2);
+      if (expr2->expr_type == EXPR_FUNCTION && expr2->ts.type == BT_CLASS)
+	trans_class_pointer_fcn (&block, &lse, &rse, expr1, expr2);
+      else
+	gfc_conv_expr (&rse, expr2);
 
       if (non_proc_pointer_assign && expr1->ts.type == BT_CLASS)
 	{
@@ -8268,12 +8332,12 @@
       if (expr1->symtree->n.sym->attr.proc_pointer
 	  && expr1->symtree->n.sym->attr.dummy)
 	lse.expr = build_fold_indirect_ref_loc (input_location,
-					    lse.expr);
+						lse.expr);
 
       if (expr2->symtree && expr2->symtree->n.sym->attr.proc_pointer
 	  && expr2->symtree->n.sym->attr.dummy)
 	rse.expr = build_fold_indirect_ref_loc (input_location,
-					    rse.expr);
+						rse.expr);
 
       gfc_add_block_to_block (&block, &lse.pre);
       gfc_add_block_to_block (&block, &rse.pre);
@@ -8319,7 +8383,6 @@
     {
       gfc_ref* remap;
       bool rank_remap;
-      tree expr1_vptr = NULL_TREE;
       tree strlen_lhs;
       tree strlen_rhs = NULL_TREE;
 
@@ -8354,26 +8417,8 @@
 	  rse.byref_noassign = 1;
 
 	  if (expr2->expr_type == EXPR_FUNCTION && expr2->ts.type == BT_CLASS)
-	    {
-	      gfc_conv_function_expr (&rse, expr2);
-
-	      if (expr1->ts.type != BT_CLASS)
-		rse.expr = gfc_class_data_get (rse.expr);
-	      else
-		{
-		  expr1_vptr = trans_class_vptr_len_assignment (&block, expr1,
-								expr2, &rse,
-								NULL, NULL);
-		  gfc_add_block_to_block (&block, &rse.pre);
-		  tmp = gfc_create_var (TREE_TYPE (rse.expr), "ptrtemp");
-		  gfc_add_modify (&lse.pre, tmp, rse.expr);
-
-		  gfc_add_modify (&lse.pre, expr1_vptr,
-				  fold_convert (TREE_TYPE (expr1_vptr),
-						gfc_class_vptr_get (tmp)));
-		  rse.expr = gfc_class_data_get (tmp);
-		}
-	    }
+	    expr1_vptr = trans_class_pointer_fcn (&block, &lse, &rse,
+						  expr1, expr2);
 	  else if (expr2->expr_type == EXPR_FUNCTION)
 	    {
 	      tree bound[GFC_MAX_DIMENSIONS];
@@ -10019,12 +10064,16 @@
      NOTE: This relies on having the exact dependence of the length type
      parameter available to the caller; gfortran saves it in the .mod files.
      NOTE ALSO: The concatenation operation generates a temporary pointer,
-     whose allocation must go to the innermost loop.  */
+     whose allocation must go to the innermost loop.
+     NOTE ALSO (2): A character conversion may generate a temporary, too.  */
   if (flag_realloc_lhs
       && expr2->ts.type == BT_CHARACTER && expr1->ts.deferred
       && !(lss != gfc_ss_terminator
-	   && expr2->expr_type == EXPR_OP
-	   && expr2->value.op.op == INTRINSIC_CONCAT))
+	   && ((expr2->expr_type == EXPR_OP
+		&& expr2->value.op.op == INTRINSIC_CONCAT)
+	       || (expr2->expr_type == EXPR_FUNCTION
+		   && expr2->value.function.isym != NULL
+		   && expr2->value.function.isym->id == GFC_ISYM_CONVERSION))))
     gfc_add_block_to_block (&block, &rse.pre);
 
   /* Nullify the allocatable components corresponding to those of the lhs
Index: gcc/fortran/trans-array.c
===================================================================
--- gcc/fortran/trans-array.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/trans-array.c	(.../branches/gcc-7-branch)
@@ -1441,6 +1441,17 @@
 	    }
 	}
     }
+  else if (GFC_CLASS_TYPE_P (TREE_TYPE (se->expr))
+	   && !GFC_CLASS_TYPE_P (gfc_get_element_type (TREE_TYPE (desc))))
+    {
+      /* Assignment of a CLASS array constructor to a derived type array.  */
+      if (expr->expr_type == EXPR_FUNCTION)
+	se->expr = gfc_evaluate_now (se->expr, pblock);
+      se->expr = gfc_class_data_get (se->expr);
+      se->expr = build_fold_indirect_ref_loc (input_location, se->expr);
+      se->expr = fold_convert (TREE_TYPE (tmp), se->expr);
+      gfc_add_modify (&se->pre, tmp, se->expr);
+    }
   else
     {
       /* TODO: Should the frontend already have done this conversion?  */
Index: gcc/fortran/decl.c
===================================================================
--- gcc/fortran/decl.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/decl.c	(.../branches/gcc-7-branch)
@@ -1383,8 +1383,28 @@
   symbol_attribute attr;
   gfc_symbol *sym;
   int upper;
+  gfc_symtree *st;
 
-  if (gfc_get_symbol (name, NULL, &sym))
+  /* Symbols in a submodule are host associated from the parent module or
+     submodules. Therefore, they can be overridden by declarations in the
+     submodule scope. Deal with this by attaching the existing symbol to
+     a new symtree and recycling the old symtree with a new symbol...  */
+  st = gfc_find_symtree (gfc_current_ns->sym_root, name);
+  if (st != NULL && gfc_state_stack->state == COMP_SUBMODULE
+      && st->n.sym != NULL
+      && st->n.sym->attr.host_assoc && st->n.sym->attr.used_in_submodule)
+    {
+      gfc_symtree *s = gfc_get_unique_symtree (gfc_current_ns);
+      s->n.sym = st->n.sym;
+      sym = gfc_new_symbol (name, gfc_current_ns);
+
+
+      st->n.sym = sym;
+      sym->refs++;
+      gfc_set_sym_referenced (sym);
+    }
+  /* ...Otherwise generate a new symtree and new symbol.  */
+  else if (gfc_get_symbol (name, NULL, &sym))
     return false;
 
   /* Check if the name has already been defined as a type.  The
Index: gcc/fortran/ChangeLog
===================================================================
--- gcc/fortran/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,153 @@
+2017-11-06  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/78641
+	* resolve.c (resolve_ordinary_assign): Do not add the _data
+	component for class valued array constructors being assigned
+	to derived type arrays.
+	* trans-array.c (gfc_trans_array_ctor_element): Take the _data
+	of class valued elements for assignment to derived type arrays.
+
+2017-11-06  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/69739
+	* trans-expr.c (gfc_map_intrinsic_function): Return false for
+	bounds without the DIM argument instead of ICEing.
+
+2017-11-04  Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	PR fortran/82796
+	* resolve.c (resolve_equivalence): An entity in a common block within
+ 	a module cannot appear in an equivalence statement if the entity is
+	with a pure procedure.
+
+2017-11-04  Andre Vehreschild  <vehre@gcc.gnu.org>
+
+	* trans-expr.c (gfc_trans_assignment_1): Character kind conversion may
+	create a loop variant temporary, too.
+	* trans-intrinsic.c (conv_caf_send): Treat char arrays as arrays and
+	not as scalars.
+	* trans.c (get_array_span): Take the character kind into account when
+	doing pointer arithmetic.
+
+2017-11-03  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/81735
+	* trans-decl.c (gfc_trans_deferred_vars): Correct case where
+	'tmp' can be used unititialized.
+
+2017-11-01  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/80554
+	* decl.c (build_sym): In a submodule allow overriding of host
+	associated symbols from the ancestor module with a new
+	declaration.
+
+2017-11-01  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/80850
+	* trans_expr.c (gfc_conv_procedure_call): When passing a class
+	argument to an unlimited polymorphic dummy, it is wrong to cast
+	the passed expression as unlimited, unless it is unlimited. The
+	correct way is to assign to each of the fields and set the _len
+	field to zero.
+
+2017-10-28  Andre Vehreschild  <vehre@gcc.gnu.org>
+
+	* check.c (gfc_check_co_reduce): Clarify error message.
+
+2017-10-28  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backported from trunk
+	PR fortran/81758
+	* trans-expr.c (trans_class_vptr_len_assignment): 'vptr_expr'
+	must only be set if the right hand side expression is of type
+	class.
+
+2017-10-21  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/82312
+	* resolve.c (gfc_resolve_code): Simplify condition for class
+	pointer assignments becoming regular assignments by asserting
+	that only class valued targets are permitted.
+	* trans-expr.c (trans_class_pointer_fcn): New function using a
+	block of code from gfc_trans_pointer_assignment.
+	(gfc_trans_pointer_assignment): Call the new function. Tidy up
+	a minor whitespace issue.
+
+2017-10-20  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/79795
+	* resolve.c (resovle_symbol): Change gcc_assert to
+	sensible error message.
+
+2017-10-16  Paul Thomas  <pault@gcc.gnu.org>
+
+	PR fortran/52832
+	* match.c (gfc_match_associate): Before failing the association
+	try again, allowing a proc pointer selector.
+
+	PR fortran/80120
+	PR fortran/81903
+	PR fortran/82121
+	* primary.c (gfc_match_varspec): Introduce 'tgt_expr', which
+	points to the associate selector, if any. Go through selector
+	references, after resolution for variables, to catch any full
+	or section array references. If a class associate name does
+	not have the same declared type as the selector, resolve the
+	selector and copy the declared type to the associate name.
+	Before throwing a no implicit type error, resolve all allowed
+	selector expressions, and copy the resulting typespec.
+
+	PR fortran/67543
+	* resolve.c (resolve_assoc_var): Selector must cannot be the
+	NULL expression and it must have a type.
+
+	PR fortran/78152
+	* resolve.c (resolve_symbol): Allow associate names to be
+	coarrays.
+
+2017-10-16  Paul Thomas  <pault@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/81048
+	* resolve.c (resolve_symbol): Ensure that derived type array
+	results get default initialization.
+
+2017-10-03  Thomas Koenig  <tkoenig@gcc.gnu.org>
+	    Steven G. Kargl  <kargl@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/80118
+	* expr.c (gfc_get_full_arrayspec_from_expr): If there is
+	no symtree, set array spec to NULL.
+
+2017-09-02  Janus Weil  <janus@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/81770
+	* expr.c (gfc_check_pointer_assign): Improve the check whether pointer
+	may outlive pointer target.
+
+2017-08-22  Jerry DeLisle  <jvdelisle@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/81296
+	* trans-io.c (get_dtio_proc): Add check for format label and set
+	formatted flag accordingly. Reorganize the code a little.
+
+2017-08-18  Jerry DeLisle  <jvdelisle@gcc.gnu.org>
+
+	Backport from trunk
+	PR fortran/80164
+	* trans-stmt.c (gfc_trans_call): If no code expr, use code->loc
+	as warning/error locus.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: gcc/fortran/trans-stmt.c
===================================================================
--- gcc/fortran/trans-stmt.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/trans-stmt.c	(.../branches/gcc-7-branch)
@@ -452,7 +452,10 @@
 	 subscripts.  This could be prevented in the elemental case
 	 as temporaries are handled separatedly
 	 (below in gfc_conv_elemental_dependencies).  */
-      gfc_conv_loop_setup (&loop, &code->expr1->where);
+      if (code->expr1)
+	gfc_conv_loop_setup (&loop, &code->expr1->where);
+      else
+	gfc_conv_loop_setup (&loop, &code->loc);
       gfc_mark_ss_chain_used (ss, 1);
 
       /* Convert the arguments, checking for dependencies.  */
Index: gcc/fortran/expr.c
===================================================================
--- gcc/fortran/expr.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/expr.c	(.../branches/gcc-7-branch)
@@ -3806,7 +3806,8 @@
   if (warn_target_lifetime
       && rvalue->expr_type == EXPR_VARIABLE
       && !rvalue->symtree->n.sym->attr.save
-      && !attr.pointer && !rvalue->symtree->n.sym->attr.host_assoc
+      && !rvalue->symtree->n.sym->attr.pointer && !attr.pointer
+      && !rvalue->symtree->n.sym->attr.host_assoc
       && !rvalue->symtree->n.sym->attr.in_common
       && !rvalue->symtree->n.sym->attr.use_assoc
       && !rvalue->symtree->n.sym->attr.dummy)
@@ -4514,7 +4515,11 @@
   if (expr->expr_type == EXPR_VARIABLE
       || expr->expr_type == EXPR_CONSTANT)
     {
-      as = expr->symtree->n.sym->as;
+      if (expr->symtree)
+	as = expr->symtree->n.sym->as;
+      else
+	as = NULL;
+
       for (ref = expr->ref; ref; ref = ref->next)
 	{
 	  switch (ref->type)
Index: gcc/fortran/trans.c
===================================================================
--- gcc/fortran/trans.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/trans.c	(.../branches/gcc-7-branch)
@@ -342,7 +342,14 @@
 	  || TREE_CODE (decl) == FUNCTION_DECL
 	  || DECL_CONTEXT (TYPE_MAXVAL (TYPE_DOMAIN (type)))
 					== DECL_CONTEXT (decl)))
-    span = TYPE_MAXVAL (TYPE_DOMAIN (type));
+    {
+      span = fold_convert (gfc_array_index_type,
+			   TYPE_MAX_VALUE (TYPE_DOMAIN (type)));
+      span = fold_build2 (MULT_EXPR, gfc_array_index_type,
+			  fold_convert (gfc_array_index_type,
+					TYPE_SIZE_UNIT (TREE_TYPE (type))),
+			  span);
+    }
   else
     span = NULL_TREE;
 
Index: gcc/fortran/resolve.c
===================================================================
--- gcc/fortran/resolve.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/resolve.c	(.../branches/gcc-7-branch)
@@ -8294,11 +8294,23 @@
 	sym->attr.subref_array_pointer = 1;
     }
 
+  if (target->expr_type == EXPR_NULL)
+    {
+      gfc_error ("Selector at %L cannot be NULL()", &target->where);
+      return;
+    }
+  else if (target->ts.type == BT_UNKNOWN)
+    {
+      gfc_error ("Selector at %L has no type", &target->where);
+      return;
+    }
+
   /* Get type if this was not already set.  Note that it can be
      some other type than the target in case this is a SELECT TYPE
      selector!  So we must not update when the type is already there.  */
   if (sym->ts.type == BT_UNKNOWN)
     sym->ts = target->ts;
+
   gcc_assert (sym->ts.type != BT_UNKNOWN);
 
   /* See if this is a valid association-to-variable.  */
@@ -10112,7 +10124,8 @@
 
   /* Assign the 'data' of a class object to a derived type.  */
   if (lhs->ts.type == BT_DERIVED
-      && rhs->ts.type == BT_CLASS)
+      && rhs->ts.type == BT_CLASS
+      && rhs->expr_type != EXPR_ARRAY)
     gfc_add_data_component (rhs);
 
   bool caf_convert_to_send = flag_coarray == GFC_FCOARRAY_LIB
@@ -11005,11 +11018,8 @@
 
 	    /* Assigning a class object always is a regular assign.  */
 	    if (code->expr2->ts.type == BT_CLASS
+		&& code->expr1->ts.type == BT_CLASS
 		&& !CLASS_DATA (code->expr2)->attr.dimension
-		&& !(UNLIMITED_POLY (code->expr2)
-		     && code->expr1->ts.type == BT_DERIVED
-		     && (code->expr1->ts.u.derived->attr.sequence
-			 || code->expr1->ts.u.derived->attr.is_bind_c))
 		&& !(gfc_expr_attr (code->expr1).proc_pointer
 		     && code->expr2->expr_type == EXPR_VARIABLE
 		     && code->expr2->symtree->n.sym->attr.flavor
@@ -11824,6 +11834,7 @@
   if (sym->ts.deferred
       && !(sym->attr.pointer
 	   || sym->attr.allocatable
+	   || sym->attr.associate_var
 	   || sym->attr.omp_udr_artificial_var))
     {
       gfc_error ("Entity %qs at %L has a deferred type parameter and "
@@ -13288,6 +13299,9 @@
   if (c->attr.artificial)
     return true;
 
+  if (sym->attr.vtype && sym->attr.use_assoc)
+    return true;
+
   /* F2008, C442.  */
   if ((!sym->attr.is_class || c != sym->components)
       && c->attr.codimension
@@ -13847,6 +13861,20 @@
   if (!resolve_typebound_procedures (sym))
     return false;
 
+  /* Generate module vtables subject to their accessibility and their not
+     being vtables or pdt templates. If this is not done class declarations
+     in external procedures wind up with their own version and so SELECT TYPE
+     fails because the vptrs do not have the same address.  */
+  if (gfc_option.allow_std & GFC_STD_F2003
+      && sym->ns->proc_name
+      && sym->ns->proc_name->attr.flavor == FL_MODULE
+      && sym->attr.access != ACCESS_PRIVATE
+      && !(sym->attr.use_assoc || sym->attr.vtype))
+    {
+      gfc_symbol *vtab = gfc_find_derived_vtab (sym);
+      gfc_set_sym_referenced (vtab);
+    }
+
   return true;
 }
 
@@ -14231,7 +14259,23 @@
 
   if (as)
     {
-      gcc_assert (as->type != AS_IMPLIED_SHAPE);
+      /* If AS_IMPLIED_SHAPE makes it to here, it must be a bad
+	 specification expression.  */
+      if (as->type == AS_IMPLIED_SHAPE)
+	{
+	  int i;
+	  for (i=0; i<as->rank; i++)
+	    {
+	      if (as->lower[i] != NULL && as->upper[i] == NULL)
+		{
+		  gfc_error ("Bad specification for assumed size array at %L",
+			     &as->lower[i]->where);
+		  return;
+		}
+	    }
+	  gcc_unreachable();
+	}
+
       if (((as->type == AS_ASSUMED_SIZE && !as->cp_was_assumed)
 	   || as->type == AS_ASSUMED_SHAPE)
 	  && !sym->attr.dummy && !sym->attr.select_type_temporary)
@@ -14609,6 +14653,7 @@
   if (class_attr.codimension
       && !(class_attr.allocatable || sym->attr.dummy || sym->attr.save
 	   || sym->attr.select_type_temporary
+	   || sym->attr.associate_var
 	   || (sym->ns->save_all && !sym->attr.automatic)
 	   || sym->ns->proc_name->attr.flavor == FL_MODULE
 	   || sym->ns->proc_name->attr.is_main_program
@@ -14793,7 +14838,12 @@
 
       if ((!a->save && !a->dummy && !a->pointer
 	   && !a->in_common && !a->use_assoc
-	   && !a->result && !a->function)
+	   && a->referenced
+	   && !((a->function || a->result)
+		&& (!a->dimension
+		    || sym->ts.u.derived->attr.alloc_comp
+		    || sym->ts.u.derived->attr.pointer_comp))
+	   && !(a->function && sym != sym->result))
 	  || (a->dummy && a->intent == INTENT_OUT && !a->pointer))
 	apply_default_init (sym);
       else if (a->function && sym->result && a->access != ACCESS_PRIVATE
@@ -15626,9 +15676,22 @@
 	  && sym->ns->proc_name->attr.pure
 	  && sym->attr.in_common)
 	{
-	  gfc_error ("Common block member %qs at %L cannot be an EQUIVALENCE "
-		     "object in the pure procedure %qs",
-		     sym->name, &e->where, sym->ns->proc_name->name);
+	  /* Need to check for symbols that may have entered the pure
+	     procedure via a USE statement.  */
+	  bool saw_sym = false;
+	  if (sym->ns->use_stmts)
+	    {
+	      gfc_use_rename *r;
+	      for (r = sym->ns->use_stmts->rename; r; r = r->next)
+		if (strcmp(r->use_name, sym->name) == 0) saw_sym = true;
+	    }
+	  else
+	    saw_sym = true;
+
+	  if (saw_sym)
+	    gfc_error ("COMMON block member %qs at %L cannot be an "
+		       "EQUIVALENCE object in the pure procedure %qs",
+		       sym->name, &e->where, sym->ns->proc_name->name);
 	  break;
 	}
 
Index: gcc/fortran/trans-decl.c
===================================================================
--- gcc/fortran/trans-decl.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/trans-decl.c	(.../branches/gcc-7-branch)
@@ -4499,7 +4499,10 @@
 		    && sym->ts.u.cl->passed_length)
 		tmp = gfc_null_and_pass_deferred_len (sym, &init, &loc);
 	      else
-		gfc_restore_backend_locus (&loc);
+		{
+		  gfc_restore_backend_locus (&loc);
+		  tmp = NULL_TREE;
+		}
 
 	      /* Deallocate when leaving the scope. Nullifying is not
 		 needed.  */
Index: gcc/fortran/match.c
===================================================================
--- gcc/fortran/match.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/match.c	(.../branches/gcc-7-branch)
@@ -1882,8 +1882,15 @@
       if (gfc_match (" %n => %e", newAssoc->name, &newAssoc->target)
 	    != MATCH_YES)
 	{
-	  gfc_error ("Expected association at %C");
-	  goto assocListError;
+	  /* Have another go, allowing for procedure pointer selectors.  */
+	  gfc_matching_procptr_assignment = 1;
+	  if (gfc_match (" %n => %e", newAssoc->name, &newAssoc->target)
+ 	      != MATCH_YES)
+ 	    {
+ 	      gfc_error ("Expected association at %C");
+ 	      goto assocListError;
+ 	    }
+	  gfc_matching_procptr_assignment = 0;
 	}
       newAssoc->where = gfc_current_locus;
 
Index: gcc/fortran/trans-io.c
===================================================================
--- gcc/fortran/trans-io.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/trans-io.c	(.../branches/gcc-7-branch)
@@ -2214,19 +2214,25 @@
   bool formatted = false;
   gfc_dt *dt = code->ext.dt;
 
-  if (dt && dt->format_expr)
+  if (dt)
     {
-      char *fmt;
-      fmt = gfc_widechar_to_char (dt->format_expr->value.character.string,
-				  -1);
-      if (strtok (fmt, "DT") != NULL)
+      char *fmt = NULL;
+
+      if (dt->format_label == &format_asterisk)
+	{
+	  /* List directed io must call the formatted DTIO procedure.  */
+	  formatted = true;
+	}
+      else if (dt->format_expr)
+	fmt = gfc_widechar_to_char (dt->format_expr->value.character.string,
+				      -1);
+      else if (dt->format_label)
+	fmt = gfc_widechar_to_char (dt->format_label->format->value.character.string,
+				      -1);
+      if (fmt && strtok (fmt, "DT") != NULL)
 	formatted = true;
+
     }
-  else if (dt && dt->format_label == &format_asterisk)
-    {
-      /* List directed io must call the formatted DTIO procedure.  */
-      formatted = true;
-    }
 
   if (ts->type == BT_CLASS)
     derived = ts->u.derived->components->ts.u.derived;
Index: gcc/fortran/check.c
===================================================================
--- gcc/fortran/check.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/check.c	(.../branches/gcc-7-branch)
@@ -1731,7 +1731,7 @@
 
   if (!gfc_compare_types (&a->ts, &sym->result->ts))
     {
-      gfc_error ("A argument at %L has type %s but the function passed as "
+      gfc_error ("The A argument at %L has type %s but the function passed as "
 		 "OPERATOR at %L returns %s",
 		 &a->where, gfc_typename (&a->ts), &op->where,
 		 gfc_typename (&sym->result->ts));
Index: gcc/fortran/primary.c
===================================================================
--- gcc/fortran/primary.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/primary.c	(.../branches/gcc-7-branch)
@@ -1890,6 +1890,7 @@
   gfc_ref *substring, *tail, *tmp;
   gfc_component *component;
   gfc_symbol *sym = primary->symtree->n.sym;
+  gfc_expr *tgt_expr = NULL;
   match m;
   bool unknown;
   char sep;
@@ -1918,6 +1919,9 @@
 	}
     }
 
+  if (sym->assoc && sym->assoc->target)
+    tgt_expr = sym->assoc->target;
+
   /* For associate names, we may not yet know whether they are arrays or not.
      If the selector expression is unambiguously an array; eg. a full array
      or an array section, then the associate name must be an array and we can
@@ -1929,20 +1933,28 @@
       && sym->ts.type != BT_CLASS
       && !sym->attr.dimension)
     {
-      if ((!sym->assoc->dangling
-	   && sym->assoc->target
-	   && sym->assoc->target->ref
-	   && sym->assoc->target->ref->type == REF_ARRAY
-	   && (sym->assoc->target->ref->u.ar.type == AR_FULL
-	       || sym->assoc->target->ref->u.ar.type == AR_SECTION))
-	  ||
-	   (!(sym->assoc->dangling || sym->ts.type == BT_CHARACTER)
-	    && sym->assoc->st
-	   && sym->assoc->st->n.sym
-	    && sym->assoc->st->n.sym->attr.dimension == 0))
+      gfc_ref *ref = NULL;
+
+      if (!sym->assoc->dangling && tgt_expr)
 	{
-    sym->attr.dimension = 1;
-	  if (sym->as == NULL && sym->assoc
+	   if (tgt_expr->expr_type == EXPR_VARIABLE)
+	     gfc_resolve_expr (tgt_expr);
+
+	   ref = tgt_expr->ref;
+	   for (; ref; ref = ref->next)
+	      if (ref->type == REF_ARRAY
+		  && (ref->u.ar.type == AR_FULL
+		      || ref->u.ar.type == AR_SECTION))
+		break;
+	}
+
+      if (ref || (!(sym->assoc->dangling || sym->ts.type == BT_CHARACTER)
+		  && sym->assoc->st
+		  && sym->assoc->st->n.sym
+		  && sym->assoc->st->n.sym->attr.dimension == 0))
+	{
+	  sym->attr.dimension = 1;
+	  if (sym->as == NULL
 	      && sym->assoc->st
 	      && sym->assoc->st->n.sym
 	      && sym->assoc->st->n.sym->as)
@@ -1949,6 +1961,15 @@
 	    sym->as = gfc_copy_array_spec (sym->assoc->st->n.sym->as);
 	}
     }
+  else if (sym->ts.type == BT_CLASS
+	   && tgt_expr
+	   && tgt_expr->expr_type == EXPR_VARIABLE
+	   && sym->ts.u.derived != tgt_expr->ts.u.derived)
+    {
+      gfc_resolve_expr (tgt_expr);
+      if (tgt_expr->rank)
+	sym->ts.u.derived = tgt_expr->ts.u.derived;
+    }
 
   if ((equiv_flag && gfc_peek_ascii_char () == '(')
       || gfc_peek_ascii_char () == '[' || sym->attr.codimension
@@ -2008,10 +2029,31 @@
       && gfc_get_default_type (sym->name, sym->ns)->type == BT_DERIVED)
     gfc_set_default_type (sym, 0, sym->ns);
 
+  /* See if there is a usable typespec in the "no IMPLICIT type" error.  */
   if (sym->ts.type == BT_UNKNOWN && m == MATCH_YES)
     {
-      gfc_error ("Symbol %qs at %C has no IMPLICIT type", sym->name);
-      return MATCH_ERROR;
+      bool permissible;
+
+      /* These target expressions can ge resolved at any time.  */
+      permissible = tgt_expr && tgt_expr->symtree && tgt_expr->symtree->n.sym
+		    && (tgt_expr->symtree->n.sym->attr.use_assoc
+			|| tgt_expr->symtree->n.sym->attr.host_assoc
+			|| tgt_expr->symtree->n.sym->attr.if_source
+								== IFSRC_DECL);
+      permissible = permissible
+		    || (tgt_expr && tgt_expr->expr_type == EXPR_OP);
+
+      if (permissible)
+	{
+	  gfc_resolve_expr (tgt_expr);
+	  sym->ts = tgt_expr->ts;
+	}
+
+      if (sym->ts.type == BT_UNKNOWN)
+	{
+	  gfc_error ("Symbol %qs at %C has no IMPLICIT type", sym->name);
+	  return MATCH_ERROR;
+	}
     }
   else if ((sym->ts.type != BT_DERIVED && sym->ts.type != BT_CLASS)
            && m == MATCH_YES)
@@ -2948,7 +2990,7 @@
      expression here.  */
   if (gfc_in_match_data ())
     gfc_reduce_init_expr (e);
- 
+
   *result = e;
   return MATCH_YES;
 }
@@ -3662,7 +3704,7 @@
 	implicit_ns = gfc_current_ns;
       else
 	implicit_ns = sym->ns;
-	
+
       old_loc = gfc_current_locus;
       if (gfc_match_member_sep (sym) == MATCH_YES
 	  && sym->ts.type == BT_UNKNOWN
Index: gcc/fortran/trans-intrinsic.c
===================================================================
--- gcc/fortran/trans-intrinsic.c	(.../tags/gcc_7_2_0_release)
+++ gcc/fortran/trans-intrinsic.c	(.../branches/gcc-7-branch)
@@ -1872,12 +1872,21 @@
   gfc_init_se (&lhs_se, NULL);
   if (lhs_expr->rank == 0)
     {
-      symbol_attribute attr;
-      gfc_clear_attr (&attr);
-      gfc_conv_expr (&lhs_se, lhs_expr);
-      lhs_type = TREE_TYPE (lhs_se.expr);
-      lhs_se.expr = gfc_conv_scalar_to_descriptor (&lhs_se, lhs_se.expr, attr);
-      lhs_se.expr = gfc_build_addr_expr (NULL_TREE, lhs_se.expr);
+      if (lhs_expr->ts.type == BT_CHARACTER && lhs_expr->ts.deferred)
+	{
+	  lhs_se.expr = gfc_get_tree_for_caf_expr (lhs_expr);
+	  lhs_se.expr = gfc_build_addr_expr (NULL_TREE, lhs_se.expr);
+	}
+      else
+	{
+	  symbol_attribute attr;
+	  gfc_clear_attr (&attr);
+	  gfc_conv_expr (&lhs_se, lhs_expr);
+	  lhs_type = TREE_TYPE (lhs_se.expr);
+	  lhs_se.expr = gfc_conv_scalar_to_descriptor (&lhs_se, lhs_se.expr,
+						       attr);
+	  lhs_se.expr = gfc_build_addr_expr (NULL_TREE, lhs_se.expr);
+	}
     }
   else if ((lhs_caf_attr.alloc_comp || lhs_caf_attr.pointer_comp)
 	   && lhs_caf_attr.codimension)
Index: gcc/BASE-VER
===================================================================
--- gcc/BASE-VER	(.../tags/gcc_7_2_0_release)
+++ gcc/BASE-VER	(.../branches/gcc-7-branch)
@@ -1 +1 @@
-7.2.0
+7.2.1
Index: gcc/langhooks.h
===================================================================
--- gcc/langhooks.h	(.../tags/gcc_7_2_0_release)
+++ gcc/langhooks.h	(.../branches/gcc-7-branch)
@@ -123,6 +123,10 @@
      FUNCTION_TYPE or METHOD_TYPE.  */
   bool (*type_hash_eq) (const_tree, const_tree);
 
+  /* If non-NULL, return TYPE1 with any language-specific modifiers copied from
+     TYPE2.  */
+  tree (*copy_lang_qualifiers) (const_tree, const_tree);
+
   /* Return TRUE if TYPE uses a hidden descriptor and fills in information
      for the debugger about the array bounds, strides, etc.  */
   bool (*get_array_descr_info) (const_tree, struct array_descr_info *);
Index: gcc/tree-if-conv.c
===================================================================
--- gcc/tree-if-conv.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-if-conv.c	(.../branches/gcc-7-branch)
@@ -2198,7 +2198,7 @@
       gimple *stmt;
       int index;
 
-      if (is_true_predicate (cond) || is_false_predicate (cond))
+      if (is_true_predicate (cond))
 	continue;
 
       swap = false;
@@ -2211,96 +2211,107 @@
       vect_sizes.truncate (0);
       vect_masks.truncate (0);
 
-      for (gsi = gsi_start_bb (bb); !gsi_end_p (gsi); gsi_next (&gsi))
-	if (!gimple_assign_single_p (stmt = gsi_stmt (gsi)))
-	  continue;
-	else if (gimple_plf (stmt, GF_PLF_2))
-	  {
-	    tree lhs = gimple_assign_lhs (stmt);
-	    tree rhs = gimple_assign_rhs1 (stmt);
-	    tree ref, addr, ptr, mask;
-	    gimple *new_stmt;
-	    gimple_seq stmts = NULL;
-	    int bitsize = GET_MODE_BITSIZE (TYPE_MODE (TREE_TYPE (lhs)));
-	    ref = TREE_CODE (lhs) == SSA_NAME ? rhs : lhs;
-	    mark_addressable (ref);
-	    addr = force_gimple_operand_gsi (&gsi, build_fold_addr_expr (ref),
-					     true, NULL_TREE, true,
-					     GSI_SAME_STMT);
-	    if (!vect_sizes.is_empty ()
-		&& (index = mask_exists (bitsize, vect_sizes)) != -1)
-	      /* Use created mask.  */
-	      mask = vect_masks[index];
-	    else
-	      {
-		if (COMPARISON_CLASS_P (cond))
-		  mask = gimple_build (&stmts, TREE_CODE (cond),
-				       boolean_type_node,
-				       TREE_OPERAND (cond, 0),
-				       TREE_OPERAND (cond, 1));
-		else
-		  {
-		    gcc_assert (TREE_CODE (cond) == SSA_NAME);
-		    mask = cond;
-		  }
+      for (gsi = gsi_start_bb (bb); !gsi_end_p (gsi);)
+	{
+	  if (!gimple_assign_single_p (stmt = gsi_stmt (gsi)))
+	    ;
+	  else if (is_false_predicate (cond)
+		   && gimple_vdef (stmt))
+	    {
+	      unlink_stmt_vdef (stmt);
+	      gsi_remove (&gsi, true);
+	      release_defs (stmt);
+	      continue;
+	    }
+	  else if (gimple_plf (stmt, GF_PLF_2))
+	    {
+	      tree lhs = gimple_assign_lhs (stmt);
+	      tree rhs = gimple_assign_rhs1 (stmt);
+	      tree ref, addr, ptr, mask;
+	      gimple *new_stmt;
+	      gimple_seq stmts = NULL;
+	      int bitsize = GET_MODE_BITSIZE (TYPE_MODE (TREE_TYPE (lhs)));
+	      ref = TREE_CODE (lhs) == SSA_NAME ? rhs : lhs;
+	      mark_addressable (ref);
+	      addr = force_gimple_operand_gsi (&gsi, build_fold_addr_expr (ref),
+					       true, NULL_TREE, true,
+					       GSI_SAME_STMT);
+	      if (!vect_sizes.is_empty ()
+		  && (index = mask_exists (bitsize, vect_sizes)) != -1)
+		/* Use created mask.  */
+		mask = vect_masks[index];
+	      else
+		{
+		  if (COMPARISON_CLASS_P (cond))
+		    mask = gimple_build (&stmts, TREE_CODE (cond),
+					 boolean_type_node,
+					 TREE_OPERAND (cond, 0),
+					 TREE_OPERAND (cond, 1));
+		  else
+		    {
+		      gcc_assert (TREE_CODE (cond) == SSA_NAME);
+		      mask = cond;
+		    }
 
-		if (swap)
-		  {
-		    tree true_val
-		      = constant_boolean_node (true, TREE_TYPE (mask));
-		    mask = gimple_build (&stmts, BIT_XOR_EXPR,
-					 TREE_TYPE (mask), mask, true_val);
-		  }
-		gsi_insert_seq_before (&gsi, stmts, GSI_SAME_STMT);
+		  if (swap)
+		    {
+		      tree true_val
+			= constant_boolean_node (true, TREE_TYPE (mask));
+		      mask = gimple_build (&stmts, BIT_XOR_EXPR,
+					   TREE_TYPE (mask), mask, true_val);
+		    }
+		  gsi_insert_seq_before (&gsi, stmts, GSI_SAME_STMT);
 
-		mask = ifc_temp_var (TREE_TYPE (mask), mask, &gsi);
-		/* Save mask and its size for further use.  */
-	        vect_sizes.safe_push (bitsize);
-		vect_masks.safe_push (mask);
-	      }
-	    ptr = build_int_cst (reference_alias_ptr_type (ref),
-				 get_object_alignment (ref));
-	    /* Copy points-to info if possible.  */
-	    if (TREE_CODE (addr) == SSA_NAME && !SSA_NAME_PTR_INFO (addr))
-	      copy_ref_info (build2 (MEM_REF, TREE_TYPE (ref), addr, ptr),
-			     ref);
-	    if (TREE_CODE (lhs) == SSA_NAME)
-	      {
-		new_stmt
-		  = gimple_build_call_internal (IFN_MASK_LOAD, 3, addr,
-						ptr, mask);
-		gimple_call_set_lhs (new_stmt, lhs);
-		gimple_set_vuse (new_stmt, gimple_vuse (stmt));
-	      }
-	    else
-	      {
-		new_stmt
-		  = gimple_build_call_internal (IFN_MASK_STORE, 4, addr, ptr,
+		  mask = ifc_temp_var (TREE_TYPE (mask), mask, &gsi);
+		  /* Save mask and its size for further use.  */
+		  vect_sizes.safe_push (bitsize);
+		  vect_masks.safe_push (mask);
+		}
+	      ptr = build_int_cst (reference_alias_ptr_type (ref),
+				   get_object_alignment (ref));
+	      /* Copy points-to info if possible.  */
+	      if (TREE_CODE (addr) == SSA_NAME && !SSA_NAME_PTR_INFO (addr))
+		copy_ref_info (build2 (MEM_REF, TREE_TYPE (ref), addr, ptr),
+			       ref);
+	      if (TREE_CODE (lhs) == SSA_NAME)
+		{
+		  new_stmt
+		    = gimple_build_call_internal (IFN_MASK_LOAD, 3, addr,
+						  ptr, mask);
+		  gimple_call_set_lhs (new_stmt, lhs);
+		  gimple_set_vuse (new_stmt, gimple_vuse (stmt));
+		}
+	      else
+		{
+		  new_stmt
+		    = gimple_build_call_internal (IFN_MASK_STORE, 4, addr, ptr,
 						  mask, rhs);
-		gimple_set_vuse (new_stmt, gimple_vuse (stmt));
-		gimple_set_vdef (new_stmt, gimple_vdef (stmt));
-		SSA_NAME_DEF_STMT (gimple_vdef (new_stmt)) = new_stmt;
-	      }
+		  gimple_set_vuse (new_stmt, gimple_vuse (stmt));
+		  gimple_set_vdef (new_stmt, gimple_vdef (stmt));
+		  SSA_NAME_DEF_STMT (gimple_vdef (new_stmt)) = new_stmt;
+		}
 
-	    gsi_replace (&gsi, new_stmt, true);
-	  }
-	else if (gimple_vdef (stmt))
-	  {
-	    tree lhs = gimple_assign_lhs (stmt);
-	    tree rhs = gimple_assign_rhs1 (stmt);
-	    tree type = TREE_TYPE (lhs);
+	      gsi_replace (&gsi, new_stmt, true);
+	    }
+	  else if (gimple_vdef (stmt))
+	    {
+	      tree lhs = gimple_assign_lhs (stmt);
+	      tree rhs = gimple_assign_rhs1 (stmt);
+	      tree type = TREE_TYPE (lhs);
 
-	    lhs = ifc_temp_var (type, unshare_expr (lhs), &gsi);
-	    rhs = ifc_temp_var (type, unshare_expr (rhs), &gsi);
-	    if (swap)
-	      std::swap (lhs, rhs);
-	    cond = force_gimple_operand_gsi_1 (&gsi, unshare_expr (cond),
-					       is_gimple_condexpr, NULL_TREE,
-					       true, GSI_SAME_STMT);
-	    rhs = fold_build_cond_expr (type, unshare_expr (cond), rhs, lhs);
-	    gimple_assign_set_rhs1 (stmt, ifc_temp_var (type, rhs, &gsi));
-	    update_stmt (stmt);
-	  }
+	      lhs = ifc_temp_var (type, unshare_expr (lhs), &gsi);
+	      rhs = ifc_temp_var (type, unshare_expr (rhs), &gsi);
+	      if (swap)
+		std::swap (lhs, rhs);
+	      cond = force_gimple_operand_gsi_1 (&gsi, unshare_expr (cond),
+						 is_gimple_condexpr, NULL_TREE,
+						 true, GSI_SAME_STMT);
+	      rhs = fold_build_cond_expr (type, unshare_expr (cond), rhs, lhs);
+	      gimple_assign_set_rhs1 (stmt, ifc_temp_var (type, rhs, &gsi));
+	      update_stmt (stmt);
+	    }
+	  gsi_next (&gsi);
+	}
     }
 }
 
Index: gcc/gimplify.c
===================================================================
--- gcc/gimplify.c	(.../tags/gcc_7_2_0_release)
+++ gcc/gimplify.c	(.../branches/gcc-7-branch)
@@ -5434,7 +5434,12 @@
      side as statements and throw away the assignment.  Do this after
      gimplify_modify_expr_rhs so we handle TARGET_EXPRs of addressable
      types properly.  */
-  if (zero_sized_type (TREE_TYPE (*from_p)) && !want_value)
+  if (zero_sized_type (TREE_TYPE (*from_p))
+      && !want_value
+      /* Don't do this for calls that return addressable types, expand_call
+	 relies on those having a lhs.  */
+      && !(TREE_ADDRESSABLE (TREE_TYPE (*from_p))
+	   && TREE_CODE (*from_p) == CALL_EXPR))
     {
       gimplify_stmt (from_p, pre_p);
       gimplify_stmt (to_p, pre_p);
Index: gcc/lra-constraints.c
===================================================================
--- gcc/lra-constraints.c	(.../tags/gcc_7_2_0_release)
+++ gcc/lra-constraints.c	(.../branches/gcc-7-branch)
@@ -4222,8 +4222,9 @@
 	      reg = SUBREG_REG (*loc);
 	      byte = SUBREG_BYTE (*loc);
 	      if (REG_P (reg)
-		  /* Strict_low_part requires reload the register not
-		     the sub-register.	*/
+		  /* Strict_low_part requires reloading the register and not
+		     just the subreg.  Likewise for a strict subreg no wider
+		     than a word for WORD_REGISTER_OPERATIONS targets.  */
 		  && (curr_static_id->operand[i].strict_low
 		      || (GET_MODE_SIZE (mode)
 			  <= GET_MODE_SIZE (GET_MODE (reg))
@@ -4235,7 +4236,11 @@
 			  && (goal_alt[i] == NO_REGS
 			      || (simplify_subreg_regno
 				  (ira_class_hard_regs[goal_alt[i]][0],
-				   GET_MODE (reg), byte, mode) >= 0)))))
+				   GET_MODE (reg), byte, mode) >= 0)))
+		      || (GET_MODE_PRECISION (mode)
+			  < GET_MODE_PRECISION (GET_MODE (reg))
+			  && GET_MODE_SIZE (GET_MODE (reg)) <= UNITS_PER_WORD
+			  && WORD_REGISTER_OPERATIONS)))
 		{
 		  /* An OP_INOUT is required when reloading a subreg of a
 		     mode wider than a word to ensure that data beyond the
@@ -4284,7 +4289,13 @@
 	}
       else if (curr_static_id->operand[i].type == OP_IN
 	       && (curr_static_id->operand[goal_alt_matched[i][0]].type
-		   == OP_OUT))
+		   == OP_OUT
+		   || (curr_static_id->operand[goal_alt_matched[i][0]].type
+		       == OP_INOUT
+		       && (operands_match_p
+			   (*curr_id->operand_loc[i],
+			    *curr_id->operand_loc[goal_alt_matched[i][0]],
+			    -1)))))
 	{
 	  /* generate reloads for input and matched outputs.  */
 	  match_inputs[0] = i;
@@ -4295,9 +4306,14 @@
 			[goal_alt_number * n_operands + goal_alt_matched[i][0]]
 			.earlyclobber);
 	}
-      else if (curr_static_id->operand[i].type == OP_OUT
+      else if ((curr_static_id->operand[i].type == OP_OUT
+		|| (curr_static_id->operand[i].type == OP_INOUT
+		    && (operands_match_p
+			(*curr_id->operand_loc[i],
+			 *curr_id->operand_loc[goal_alt_matched[i][0]],
+			 -1))))
 	       && (curr_static_id->operand[goal_alt_matched[i][0]].type
-		   == OP_IN))
+		    == OP_IN))
 	/* Generate reloads for output and matched inputs.  */
 	match_reload (i, goal_alt_matched[i], outputs, goal_alt[i], &before,
 		      &after, curr_static_id->operand_alternative
Index: gcc/calls.c
===================================================================
--- gcc/calls.c	(.../tags/gcc_7_2_0_release)
+++ gcc/calls.c	(.../branches/gcc-7-branch)
@@ -1220,32 +1220,38 @@
 		  else if (!strcasecmp (end, "KiB") || strcmp (end, "KB"))
 		    unit = 1024;
 		  else if (!strcmp (end, "MB"))
-		    unit = 1000LU * 1000;
+		    unit = HOST_WIDE_INT_UC (1000) * 1000;
 		  else if (!strcasecmp (end, "MiB"))
-		    unit = 1024LU * 1024;
+		    unit = HOST_WIDE_INT_UC (1024) * 1024;
 		  else if (!strcasecmp (end, "GB"))
-		    unit = 1000LU * 1000 * 1000;
+		    unit = HOST_WIDE_INT_UC (1000) * 1000 * 1000;
 		  else if (!strcasecmp (end, "GiB"))
-		    unit = 1024LU * 1024 * 1024;
+		    unit = HOST_WIDE_INT_UC (1024) * 1024 * 1024;
 		  else if (!strcasecmp (end, "TB"))
-		    unit = 1000LU * 1000 * 1000 * 1000;
+		    unit = HOST_WIDE_INT_UC (1000) * 1000 * 1000 * 1000;
 		  else if (!strcasecmp (end, "TiB"))
-		    unit = 1024LU * 1024 * 1024 * 1024;
+		    unit = HOST_WIDE_INT_UC (1024) * 1024 * 1024 * 1024;
 		  else if (!strcasecmp (end, "PB"))
-		    unit = 1000LU * 1000 * 1000 * 1000 * 1000;
+		    unit = HOST_WIDE_INT_UC (1000) * 1000 * 1000 * 1000 * 1000;
 		  else if (!strcasecmp (end, "PiB"))
-		    unit = 1024LU * 1024 * 1024 * 1024 * 1024;
+		    unit = HOST_WIDE_INT_UC (1024) * 1024 * 1024 * 1024 * 1024;
 		  else if (!strcasecmp (end, "EB"))
-		    unit = 1000LU * 1000 * 1000 * 1000 * 1000 * 1000;
+		    unit = HOST_WIDE_INT_UC (1000) * 1000 * 1000 * 1000 * 1000
+			   * 1000;
 		  else if (!strcasecmp (end, "EiB"))
-		    unit = 1024LU * 1024 * 1024 * 1024 * 1024 * 1024;
+		    unit = HOST_WIDE_INT_UC (1024) * 1024 * 1024 * 1024 * 1024
+			   * 1024;
 		  else
 		    unit = 0;
 		}
 
 	      if (unit)
-		alloc_object_size_limit
-		  = build_int_cst (ssizetype, limit * unit);
+		{
+		  wide_int w = wi::uhwi (limit, HOST_BITS_PER_WIDE_INT + 64);
+		  w *= unit;
+		  if (wi::ltu_p (w, alloc_object_size_limit))
+		    alloc_object_size_limit = wide_int_to_tree (ssizetype, w);
+		}
 	    }
 	}
     }
Index: gcc/gimple-fold.c
===================================================================
--- gcc/gimple-fold.c	(.../tags/gcc_7_2_0_release)
+++ gcc/gimple-fold.c	(.../branches/gcc-7-branch)
@@ -1236,7 +1236,7 @@
 		 the NUL.
 		 Set *FLEXP to true if the array whose bound is being
 		 used is at the end of a struct.  */
-	      if (array_at_struct_end_p (arg, true))
+	      if (array_at_struct_end_p (arg))
 		*flexp = true;
 
 	      arg = TREE_OPERAND (arg, 1);
@@ -6439,7 +6439,6 @@
   gcc_assert (init);
   if (init == error_mark_node)
     {
-      gcc_assert (in_lto_p);
       /* Pass down that we lost track of the target.  */
       if (can_refer)
 	*can_refer = false;
Index: gcc/tree-ssa-pre.c
===================================================================
--- gcc/tree-ssa-pre.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-ssa-pre.c	(.../branches/gcc-7-branch)
@@ -2090,8 +2090,9 @@
      ANTIC_OUT[BLOCK] = phi_translate (ANTIC_IN[succ(BLOCK)])
 
    ANTIC_IN[BLOCK] = clean(ANTIC_OUT[BLOCK] U EXP_GEN[BLOCK] - TMP_GEN[BLOCK])
-*/
 
+   Note that clean() is deferred until after the iteration.  */
+
 static bool
 compute_antic_aux (basic_block block, bool block_has_abnormal_pred_edge)
 {
@@ -2190,7 +2191,8 @@
     bitmap_value_insert_into_set (ANTIC_IN (block),
 				  expression_for_id (bii));
 
-  clean (ANTIC_IN (block));
+  /* clean (ANTIC_IN (block)) is defered to after the iteration converged
+     because it can cause non-convergence, see for example PR81181.  */
 
   if (!was_visited || !bitmap_set_equal (old, ANTIC_IN (block)))
     changed = true;
@@ -2424,6 +2426,12 @@
       gcc_checking_assert (num_iterations < 500);
     }
 
+  /* We have to clean after the dataflow problem converged as cleaning
+     can cause non-convergence because it is based on expressions
+     rather than values.  */
+  FOR_EACH_BB_FN (block, cfun)
+    clean (ANTIC_IN (block));
+
   statistics_histogram_event (cfun, "compute_antic iterations",
 			      num_iterations);
 
Index: gcc/po/es.po
===================================================================
--- gcc/po/es.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/es.po	(.../branches/gcc-7-branch)
@@ -39,7 +39,7 @@
 msgstr ""
 "Project-Id-Version: gcc 7.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2017-07-26 08:25+0200\n"
 "Last-Translator: Antonio Ceballos <aceballos@gmail.com>\n"
 "Language-Team: Spanish <es@tp.org.es>\n"
@@ -227,13 +227,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "constante de coma flotante mal usada"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -519,62 +519,62 @@
 " automáticamente a los varios subprocesos invocados por %s.  Para pasar\n"
 " otras opciones a estos procesos se deben usar las opciones -W<letra>.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Se procesa la especificación (%s), la cual es '%s'\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Objetivo: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Configurado con: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Modelo de hilos: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc versión %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "controlador gcc versión %s %sejecutando gcc versión %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr "El error no es repetible, por lo que probablemente sea un problema de hardware o de S.O.\n"
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr "Fuente preprocesada almacenada en el fichero %s; por favor, adjúntelo a su informe de errores.\n"
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "instalar: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "programas: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "bibliotecas: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -583,16 +583,16 @@
 "\n"
 "Para instrucciones de informe de errores, por favor vea:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "(C)"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -603,7 +603,7 @@
 "PARTICULAR\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -616,7 +616,7 @@
 "======================\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -623,7 +623,7 @@
 "\n"
 msgstr "Utilice \"-Wl,OPCIÓN\" para pasar la \"OPCIÓN\" al enlazador.\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -634,7 +634,7 @@
 "=======================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -648,16 +648,16 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr "  merge [opciones] <dir1> <dir2>        Mezcla el contenido del fichero de cobertura\n"
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "    -o, --output <dir>                  Directorio de salida\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "    -v, --verbose                       Modo expresivo\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "    -o, --output <dir>                  Directorio de salida\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -673,16 +673,16 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr "  rewrite [opciones] <dir>              Reescribe el contenido del fichero de cobertura\n"
 
+#: gcov-tool.c:270
+#, c-format
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgstr "    -n, --normalize <int64_t>         Normaliza el perfil\n"
+
 #: gcov-tool.c:272
 #, c-format
 msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr "    -s, --scale <float o frac-simple>   Escala los contadores de perfil\n"
 
-#: gcov-tool.c:273
-#, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
-msgstr "    -n, --normalize <int64_t>         Normaliza el perfil\n"
-
 #: gcov-tool.c:290
 #, c-format
 msgid "Rewrite subcommand usage:"
@@ -708,27 +708,27 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr "  overlap [opciones] <dir1> <dir2>      Calcula el solapamiento de dos perfiles\n"
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "    -h, --hotonly                       Solo imprime información sobre objetos y funciones calientes\n"
-
-#: gcov-tool.c:422
-#, c-format
 msgid "    -f, --function                      Print function level info\n"
 msgstr "    -f, --function                      Imprime información sobre el nivel de funciones\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:421
 #, c-format
 msgid "    -F, --fullname                      Print full filename\n"
 msgstr "    -F, --fullname                      Imprime el nombre de fichero completo\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:422
 #, c-format
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr "    -h, --hotonly                       Solo imprime información sobre objetos y funciones calientes\n"
+
+#: gcov-tool.c:423
+#, c-format
 msgid "    -o, --object                        Print object level info\n"
 msgstr "    -o, --object                        Imprime información sobre el nivel de objetos\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr "    -t <float>, --hot_threshold <float> Establece el umbral de calentura\n"
@@ -815,20 +815,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Muestra esta información, y finaliza\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Muestra información por cada bloque básico\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Incluye las probabilidades de ramificación en la salida\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -837,16 +832,21 @@
 "  -c, --branch-counts             Se muestra el número de ramificaciones\n"
 "                                    en lugar de los porcentajes\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          Muestra información de progreso\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Muestra sumarios para cada función\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Muestra esta información, y finaliza\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1031,82 +1031,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s:no se puede resolver el grafo para '%s'\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Líneas ejecutadas:%s de %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "No hay líneas de código ejecutables\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s '%s'\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Ramificaciones ejecutadas:%s de %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "Se visitaron al menos una vez:%s de %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "No hay ramificaciones\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Llamadas ejecutadas:%s de %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "No hay llamadas\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s:no hay líneas para '%s'\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "la llamada %2d devuelve %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "la llamada %2d nunca se ejecuta\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "ramificación %2d tomada %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "la ramificacion %2d nunca se ejecuta\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "el incondicional %2d tomado %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "el incondicional %2d nunca se ejecuta\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "No se puede abrir el fichero fuente %s\n"
@@ -1213,89 +1213,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr "Los usos de esta opción están diagnosticados."
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr "predeterminado %d mínimo %d máximo %d"
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr "Igual que %s.  Utilice, en cambio, la última opción."
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s  Igual que %s."
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[por defecto]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[activado]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[desactivado]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " No se encontraron opciones con las características deseadas\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " No se encontró ninguna.  Use --help=%s para mostrar *todas* las opciones admitidas por el frente %s.\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr "Ya se mostraron todas las opciones con las características deseadas\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "Las siguientes opciones son específicas del objetivo"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "Las siguientes opciones controlan los mensajes de aviso del compilador"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "Las siguientes opciones controlan las optimizaciones"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "Las siguientes opciones son independientes del lenguaje"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "La opción --param reconoce los parámetros a continuación"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "Las siguientes opciones son específicas sólo para el lenguaje "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "Las siguientes opciones se admiten en el lenguaje "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "Las siguientes opciones no están documentadas"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "Las siguientes opciones toman argumentos separados"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "Las siguientes opciones toman argumentos conjuntos"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "Las siguientes opciones son relacionadas al lenguaje"
 
@@ -2833,8 +2833,8 @@
 msgid "<command-line>"
 msgstr "<línea-de-orden>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "No se admite el operando para el código '%c'"
@@ -2853,7 +2853,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "coma flotante incompatible / operando de registro de vector para '%%%c'"
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "falta un operando"
@@ -2873,8 +2873,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "prefijo de operando no válido '%%%c'"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "se usó '%%&' sin ninguna referencia TLS dinámica local"
@@ -2890,18 +2890,18 @@
 msgstr "valor %%r no válido"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "valor %%R no válido"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "valor %%N no válido"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "valor %%P no válido"
@@ -2911,7 +2911,7 @@
 msgid "invalid %%h value"
 msgstr "valor %%h no válido"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "valor %%L no válido"
@@ -2932,7 +2932,7 @@
 msgstr "valor %%U no válido"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "valor %%s no válido"
@@ -2942,7 +2942,7 @@
 msgid "invalid %%C value"
 msgstr "valor %%C no válido"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "valor %%E no válido"
@@ -2953,7 +2953,7 @@
 msgstr "reubicación unspec desconocida"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "código %%xn no válido"
@@ -3016,7 +3016,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "operando no válido en el código de salida"
@@ -3026,29 +3026,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC no válido como operando: %d"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "operando de desplazamiento no válido"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instrucción de predicado Thumb"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instrucción de predicado en una secuencia condicional"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3056,101 +3056,101 @@
 msgid "invalid operand for code '%c'"
 msgstr "operando no válido para el código '%c'"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "la instrucción nunca se ejecuta"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "código de formato Maverick obsoleto '%c'"
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "el operando de dirección requiere una restricción para los registros X, Y, o Z"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "los operandos para %T/%t deben ser reg + const_int:"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr "dirección errónea, no es una dirección de E/S:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr "dirección errónea, no es una constante:"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "dirección errónea, no (reg+disp):"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "dirección errónea, no hay post_inc o pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "error interno del compilador.  Dirección errónea:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Código '%c' no admitido para coma fija:"
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "error interno del compilador.  Modo desconocido:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "insn no válida:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "insn incorrecta:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "insn move desconocida:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "insn shift errónea:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "error interno del compilador.  Desplazamiento incorrecto:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 msgid "unsupported fixed-point conversion"
 msgstr "conversión de coma fija no admitida"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr "variable"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 msgid "function parameter"
 msgstr "parámetro de función"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 msgid "structure field"
 msgstr "campo de estructura"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 msgid "return type of function"
 msgstr "tipo de retorno de función"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr "puntero"
 
@@ -3174,7 +3174,7 @@
 msgstr "operando const_double no válido"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3396,87 +3396,87 @@
 msgid "bad output_condmove_single operand"
 msgstr "operando output_condmove_single erróneo"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC no válido como operando"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "tipo no válido de la salida del indicador asm"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "tamaño de operando no válido para el código de operando 'O'"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "tamaño de operando no válido para el código de operando 'z'"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "se usó un tipo de operando no válido con el código de operando 'Z'"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "tamaño de operando no válido para el código de operando 'Z'"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "el operando no es un código de condición, código de operando 'Y' no válido"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "el operando no es un código de condición, código de operando 'D' no válido"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "el operando no es un código de condición, código de operando '%c' no válido"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "el operando no es una referencia de memoria desplazable, código de operando 'H' no válido"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "el operando no es un entero, código de operando 'K' no válido"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "el operando no es un entero concreto, código de operando 'r' no válido"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "el operando no es un entero, código de operando 'R' no válido"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "el operando no es un entero concreto, código de operando 'R' no válido"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "código de operando '%c' no válido"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "restricciones no válidas para el operando"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "modo insn desconocido"
 
@@ -3513,7 +3513,7 @@
 msgid "invalid %%P operand"
 msgstr "operando %%P no válido"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "valor %%p no válido"
@@ -3567,7 +3567,7 @@
 msgstr "la dirección de post-incremento no es un registro"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "dirección errónea"
 
@@ -3600,7 +3600,7 @@
 msgstr "¡ La insn contiene una dirección no válida !"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "dirección no válida"
 
@@ -3691,277 +3691,277 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Pruebe ejecutar '%s' en el intérprete de órdenes para elevar su límite.\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le no permitida para destinos big-endian"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx requiere coma flotante de hardware"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx y -mpaired son incompatibles"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx necesita direccionamiento indizado"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx y -mno-altivec son incompatibles"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec desactiva vsx"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory requiere modo de 64 bits"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic requiere modo de 64 bits"
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory no está disponible en modo little endian"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mtoc-fusion requiere 64 bits"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion requiere modelo de código medio/grande"
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr "move erróneo"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr "Movimiento de 128 bits erróneo"
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, c-format
 msgid "invalid %%e value"
 msgstr "valor %%e no válido"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "valor %%f no válido"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "valor %%F no válido"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "valor %%G no válido"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "código %%j no válido"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "código %%J no válido"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "valor %%k no válido"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "valor %%K no válido"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "valor %%O no válido"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "valor %%q no válido"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "valor %%T no válido"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "valor %%u no válido"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "valor %%v no válido"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "valor %%x no válido"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valor %%y no válido, pruebe usando la restricción 'Z'"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 y __ibm128 no pueden utilizarse en la misma expresión"
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 y long double no pueden utilizarse en la misma expresión"
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 y long double no pueden utilizarse en la misma expresión"
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Se pasó un argumento Altivec a una función sin prototipo"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 msgid "Could not generate addis value for fusion"
 msgstr "No se ha podido generar valor addis para fusión"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 msgid "Unable to generate load/store offset for fusion"
 msgstr "No se puede generar desplazamiento de carga/almacenamiento para fusión"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr "Fusión GPR errónea"
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, reg #1 erróneo"
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, reg #2 erróneo"
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load no MEM"
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, reg #1 erróneo"
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, reg #2 erróneo"
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store no MEM"
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "las referencias a memoria simbólica sólo se admiten en z10 o posterior"
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "no se puede descomponer la dirección"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "operador de comparación no válido para el modificador de salida 'E'"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "referencia no válida para el modificador de salida 'J'"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "dirección no válida para el modificador de salida 'O'"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "dirección no válida para el modificador de salida 'R'"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "se esperaba una referencia de memoria para el modificador de salida 'S'"
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "dirección no válida para el modificador de saida 'S'"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "se esperaba un registro o expresión de memoria para el modificador de salida 'N'"
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "se esperaba un registro o expresión de memoria para el modificador de salida 'M'"
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "constante no válida para el modificador de salida '%c'"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "constante no válida - pruebe usar un modificador de salida"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "vector constante no válido para el modificador de salida '%c'"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "expresión no válida - pruebe usar un modificador de salida"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "expresión no válida para el modificador de salida '%c'"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 msgid "vector argument passed to unprototyped function"
 msgstr "se pasó un argumento vector a una función sin prototipo"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 msgid "types differ in signedness"
 msgstr "los tipos difieren en el signo"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr "el operador binario no admite dos operadores bool vector"
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr "el operador binario no admite operador bool vector"
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "el operador binario no admite que se mezclen operandos bool vector y vector de coma flotante"
 
@@ -3987,43 +3987,43 @@
 msgid "created and used with different endianness"
 msgstr "creado y usado con diferente orden de bits"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "operando %%Y no válido"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "operando %%A no válido"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "operando %%B no válido"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "operando %%C no válido"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "operando %%D no válido"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "operando %%f no válido"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "operando %%s no válido"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "la constante de coma flotante no es un operando inmediato válido"
@@ -4185,30 +4185,30 @@
 msgid "bad test"
 msgstr "prueba errónea"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "valor %%D no válido"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "máscara no válida"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "valor %%d no válido"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "valor %%t%%b no válido"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "no hay registro en la dirección"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "el desplazamiento de dirección no es una constante"
 
@@ -4229,8 +4229,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "se esperaba %<;%>"
@@ -4252,14 +4252,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "se esperaba %<(%>"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "se esperaba %<,%>"
@@ -4290,7 +4290,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "se esperaba %<)%>"
@@ -4298,7 +4298,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "se esperaba %<]%>"
@@ -4308,7 +4308,7 @@
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "se esperaba %<}%>"
@@ -4315,7 +4315,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "se esperaba %<{%>"
@@ -4325,7 +4325,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "se esperaba %<:%>"
@@ -4338,24 +4338,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "La notaicón de array de Cilk no puede utilizarse para expresiones throw"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr "La notación de array de Cilk no puede utilizarse para sentencias switch"
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr "La notaicón de array de Cilk no puede utilizarse para sentencias while"
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "se esperaba %<while%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr "La notaicón de array de Cilk no puede utilizarse para sentencias do-while"
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr "La notaicón de array de Cilk no puede utilizarse para sentencias do-while"
 
@@ -4363,18 +4363,18 @@
 msgid "expected %<.%>"
 msgstr "se esperaba %<.%>"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "se esperaba %<@end%>"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "se esperaba %<>%>"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "se esperaba %<,%> o %<)%>"
@@ -4382,17 +4382,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "se esperaba %<=%>"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "se esperaba %<[%>"
@@ -4401,7 +4401,7 @@
 msgid "(anonymous)"
 msgstr "(anónimo)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "se esperaba %<<%>"
@@ -4410,11 +4410,11 @@
 msgid "expected label"
 msgstr "se esperaba etiqueta"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "candidato 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "candidato 2:"
 
@@ -4633,11 +4633,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%r%s:%d:%R   en la expansión de la expresión constante de %qs"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "los candidatos son:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "el candidato es:"
@@ -4808,80 +4808,80 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "argumento actual de INTENT = OUT/INOUT"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "Se requieren una anchura positiva"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "Se requiere una anchura que no sea negativa"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Elemento %qc inesperado en la cadena de formato en %L"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "Cadena de fin de formato inesperada"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr "Anchura cero en el descriptor de formato"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "Falta el paréntesis izquierdo inicial"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 msgid "Left parenthesis required after %<*%>"
 msgstr "Se requiere paréntesis izquierdo después de %<*%>"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "Se esperaba un descriptor de edición P"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "El descriptor P requiere un factor de escala inicial"
 
-#: fortran/io.c:726
-#, c-format
-msgid "Right parenthesis expected at %C"
-msgstr "Se seperaba paréntesis derecho en %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr "Se requiere una coma antes del descriptor P"
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr "Se requieren una anchura positiva con el descriptor T"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "No se permite el especificador E con el descriptor g0"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "Se requiere anchura del exponente positiva"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, c-format
+msgid "Right parenthesis expected at %C"
+msgstr "Se seperaba paréntesis derecho en %C"
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr "Se requiere un punto en el especificador de formato"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr "etiqueta %s"
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr "unidad interna en WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "etiqueta %s con INQUIRE"
@@ -4891,75 +4891,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "Error sintáctico en la expresión en %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Fin de fichero inesperado"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Desbordamiento entero"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "Nombre demasiado largo"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Nombre erróneo"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Se esperaba un nombre"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "Se esperaba un paréntesis izquierdo"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "Se esperaba un paréntesis derecho"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Se esperaba un entero"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Se esperaba una cadena"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum(): No se encontró el enumerador"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "Se esperaba un nombre de atributo de bit"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Se esperaba una cadena entera"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "Error al convertir el entero"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Se esperaba una cadena real"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "Se esperaba un tipo de expresión"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "Operador erróneo"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "Tipo erróneo en la expresión constante"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "Fin de módulo inesperado"
 
@@ -5204,12 +5204,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longitud de la cadena actual es más corta que la declarada para el argumento dummy '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "El objetivo del remapeo de rango es demasiado pequeño (%ld < %ld)"
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr "Asignación de escalar a un array sin espacio asignado"
 
@@ -5554,7 +5554,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "no se pueden usar -m32 y -m64 al mismo tiempo"
 
@@ -8437,7 +8437,7 @@
 msgstr "Especifica el tamaño de bit para los desplazamientos TLS inmediatos."
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr "Código de planificador para el CPU dado."
@@ -8658,7 +8658,7 @@
 msgid "target the software simulator."
 msgstr "destina al simulador software."
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr "Usa la LRA en lugar de recarga."
 
@@ -8875,12 +8875,12 @@
 msgid "Use 80-bit long double."
 msgstr "Usa long doubles de 80 bits."
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 msgid "Use 64-bit long double."
 msgstr "Usa long doubles de 64 bits."
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr "Usa long doubles de 128 bits."
@@ -9895,87 +9895,87 @@
 msgid "64 bit ABI."
 msgstr "ABI de 64 bit."
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr "Mantiene el puntero a la cadena hacia atrás."
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr "Impresiones adicionales de depuración."
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr "Arquitectura ESA/390."
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 msgid "Enable decimal floating point hardware support."
 msgstr "Admite la coma flotante decimal de hardware."
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 msgid "Enable hardware floating point."
 msgstr "Activa coma flotante de hardware."
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 msgid "Use hardware transactional execution instructions."
 msgstr "Usa instrucciones de ejecución transaccional por hardware."
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "Usa las instrucciones de operaciones con vectores por hardware y activa el vector ABI."
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr "Usa la disposición de pila empacada."
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr "Usa bras para el ejecutable < 64k."
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 msgid "Disable hardware floating point."
 msgstr "Desactiva la coma flotante de hardware."
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "Establece el número máximo de bytes que se deben dejar en el tamaño de la pila antes de que se active una instrucción trap."
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr "Desactiva la opción -mstack-guard=."
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "Emite código extra en el prólogo de la función para atrapar en caso de que el tamaño de la pila exceda el límite dado."
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr "Desactiva la opción -mstack-size= ."
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 msgid "Use the mvcle instruction for block moves."
 msgstr "Utiliza la instrucción mvcle para movimiento de bloques."
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr "Activa la extensión de lenguaje de vector z que ofrece la macro de vector sensible al contexto y activa los internos de estilo Altivec en vecintrin.h."
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "Avisa si una función usa alloca o crea una matriz de tamaño dinámico."
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "Avisa si el tamaño de marco de una sola función excede el tamaño de marco dado."
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr "z/Architecture."
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr "Establece los costos de ramificación para las instrucciones de ramificación condicional.  Los valores razonables son enteros pequeños que no son negativos.  El costo de ramificación por defecto es 1."
 
@@ -10027,11 +10027,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr "CPUs ARM conocidos (para usar con las opciones -mcpu= y -mtune=):"
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr "Arquitecturas ARM conocidas (para usar con la opción -march=):"
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr "FPUs ARM conocidos (para usar con la opción -mfpu=):"
 
@@ -10257,78 +10257,102 @@
 msgstr "Usa las extensiones del Conjunto de Instrucciones Visuales de UltraSPARC versión 4.0."
 
 #: config/sparc/sparc.opt:86
+#, fuzzy
+#| msgid "Use vector and scalar instructions added in ISA 2.07."
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr "Usa las instrucciones de vectores y escalares añadidas en ISA 2.07."
+
+#: config/sparc/sparc.opt:90
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "Usa las extensiones Comparación-y-Ramificación de UltraSPARC."
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "Usa las extensiones Multiplicación-Adición de Corto Circuito de UltraSPARC."
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+#, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Genera instrucciones multiply-add de coma flotante"
+
+#: config/sparc/sparc.opt:102
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "Usa la instrucción Población-Cuenta de UltraSPARC."
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "Usa la instrucción Resta-Extendida-con-Llevada de UltraSPARC."
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 msgid "Pointers are 64-bit."
 msgstr "Los punteros son de 64-bit."
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 msgid "Pointers are 32-bit."
 msgstr "Los punteros son de 32-bit."
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 msgid "Use 64-bit ABI."
 msgstr "Usa la ABI de 64-bit."
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 msgid "Use 32-bit ABI."
 msgstr "Usa la ABI de 32-bit."
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr "Usa la tendencia de la pila."
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Usa structs en la alineación más fuerte para copias double-word."
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Optimiza las instrucciones de la llamada del extremo en el ensamblador y el enlazador."
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr "No genera código que solo pueda correr en modo supervisor (predeterminado)."
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr "Usa las características y el código de planificador para el CPU dado."
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr "Usa el modelo de código del SPARC-V9 dado."
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 msgid "Enable debug output."
 msgstr "Activa la salida de depuración."
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "Permite la revisión de devolución de struct psABI de 32 bits estricta."
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr "Activa evitar el error único del procesador AT697F (corresponde al error #13 del procesador AT697E)."
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr "Activa evitar el error único del procesador UT699."
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+#, fuzzy
+#| msgid "Enable workarounds for the errata of the UT699 processor."
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr "Activa evitar el error único del procesador UT699."
+
+#: config/sparc/sparc.opt:250
+#, fuzzy
+#| msgid "Enable workarounds for the errata of the UT699 processor."
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr "Activa evitar el error único del procesador UT699."
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr "Especifica el modelo de memoria en efecto para el programa."
 
@@ -14676,7 +14700,9 @@
 msgstr "Detecta rutas que disparan comportamiento erróneo o indefinido debido a desreferencia de puntero nulo.  Aisla esas rutas del flujo de control principal y convierte la sentencia con comportamiento erróneo o indefinido en una trampa."
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+#, fuzzy
+#| msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detecta rutas que disparan comportamiento erróneo o indefinido debido a un uso indebido de un valor nuloen un atributo returns_nonnull o nonnull.  Aisla esas rutas del flujo de control principal y convierte la sentencia con comportamiento erróneo o indefinido en una trampa."
 
 #: common.opt:2502
@@ -15079,7 +15105,7 @@
 msgstr "se esperaba un tipo booleano"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "se esperaba un entero"
@@ -15357,125 +15383,125 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr "la cláusula de rango debe tener tipo matriz, rebanada, cadena, mapa o canal"
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 msgid "invalid comparison of non-ordered type"
 msgstr "comparación no válida de tipo que no es ordenado"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr "la rebanada sólo se puede comparar con nil"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr "el mapa sólo se puede comparar con nil"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr "la función sólo se puede comparar con nil"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, c-format
 msgid "invalid operation (%s)"
 msgstr "operación no válida (%s)"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 msgid "invalid comparison of non-comparable type"
 msgstr "comparación no válida de tipo que no es comparable"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 msgid "invalid comparison of generated struct"
 msgstr "comparación no válida de struct generado"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr "comparación no válida de struct que no es comparable"
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 msgid "invalid comparison of generated array"
 msgstr "comparación no válida de matriz generada"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr "comparación no válida de matriz que no es comparable"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr "llamada a función de valor múltiple en un contexto de un solo valor"
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr "necesita conversión implícita"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr "no se puede usar el tipo %s como tipo %s"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr "tipos de receptor diferentes"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr "número diferente de parámetros"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr "tipos de parámetro diferentes"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr "varargs diferentes"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr "número diferente de resultados"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr "tipos de resultado diferentes"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "se necesita conversión explícita; falta el método %s%s%s"
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "tipo incompatible para el método %s%s%s"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "tipo incompatible para el método %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr "el puntero a tipo de interfaz no tiene métodos"
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr "el tipo no tiene métodos"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "método ambiguo %s%s%s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "falta el método %s%s%s"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "el método %s%s%s requiere un receptor de puntero"
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "el método %s%s%s está marado go:nointerface"
@@ -15650,7 +15676,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr "el límite %wu especificado es igual al tamaño del destino"
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "faltan argumentos para la función %<va_start%>"
@@ -15712,27 +15738,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "modelo de memoria no válido para %<__atomic_load%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "modelo de memoria no válido para %<__atomic_store%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "el argumento 1 para __atomic_always_lock_free no es una constante"
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "el argumento 1 para __atomic_is_lock_free no es un entero"
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "no se admite __builtin_thread_pointer en este objetivo"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "no se admite __builtin_set_thread_pointer en este objetivo"
@@ -15739,7 +15765,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kuso no válido de %<__builtin_va_arg_pack ()%>"
@@ -15746,12 +15772,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kuso no válido de %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "el segundo argumento de %<__builtin_longjump%> debe ser 1"
@@ -15758,62 +15784,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Su plataforma objetivo no soporta -fcheck-pointer-bounds"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "el formato objetivo no soporta infinito"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "se usó %<va_start%> en una función con argumentos fijos"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "número erróneo argumentos para la función %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "se llamó a %<__builtin_next_arg%> sin un argumento"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "número erróneo de argumentos para la función %<__builtin_next_arg%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "el segundo parámetro de %<va_start%> no es el último argumento nombrado"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "la conducta es indefinida cuando el segundo parámetro de %<va_start%> se declara con almacenamiento %<register%>"
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%Kel primer argumento de %D debe ser un puntero, el segundo una constante entera"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%Kel último argumento de %D no es una constante entera entre 0 y 3"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kse intenta liberar un objeto %qD que no es de pila"
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kse intenta liberar un objeto que no es de pila"
@@ -16721,12 +16747,12 @@
 msgstr "se descarta el atributo %<weakref%> porque ya se inicializó la variable"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "se usa %q+F pero nunca se define"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
@@ -16821,12 +16847,12 @@
 msgid "cannot find '%s'"
 msgstr "no se puede encontrar '%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "falló pex_init: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -16836,7 +16862,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "se debe definir COLLECT_LTO_WRAPPER"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17047,7 +17073,7 @@
 msgid "error writing %qs"
 msgstr "error al escribir %qs"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "no se puede abrir %s"
@@ -17127,17 +17153,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr "se descarta la opción posiblemente conflictiva %<-fopt-info-%s%>"
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "sólo se admiten múltiples personalidades EH con ensambladores que admiten la directiva cfi.personality"
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "se encontró UNSPEC %s (%d) que no está delegitimado la ubicación de variable"
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17247,12 +17273,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kla llamada a %qs se redeclaró con error de atributo: %s"
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kla llamada a %qs se redecló con aviso de atributo: %s"
@@ -17267,12 +17293,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "el tamaño de marco de %wd bytes es mayor que %wd bytes"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "no se puede abrir el fichero de volcado de insn final %qs: %m"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "no se puede cerrar el fichero de volcado de insn final %qs: %m"
@@ -17287,7 +17313,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparación siempre es %d debido a la anchura del campo de bit"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "se asume que el desbordamiento con signo no sucede al simplificar la prueba de rango"
@@ -17317,7 +17343,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "se asume que el desbordamiento con signo no sucede cuando se combinan constantes alrededor de una comparación"
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold check: el árbol original cambió por un pliegue"
@@ -17327,7 +17353,7 @@
 msgid "total size of local objects too large"
 msgstr "el tamaño total de los objetos locales es demasiado grande"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "restricción imposible en %<asm%>"
@@ -17427,62 +17453,68 @@
 msgid "input file %qs is the same as output file"
 msgstr "el fichero de entrada %qs es el mismo que el de salida"
 
-#: gcc.c:4498
+#: gcc.c:4476
+#, fuzzy, gcc-internal-format
+#| msgid "output file not specified"
+msgid "output filename may not be empty"
+msgstr "no se ha especificado el fichero de salida"
+
+#: gcc.c:4501
 #, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "se descarta -pipe porque se especificó -save-temps"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "%<-x %s%> después del último fichero de entrada no tiene efecto"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr "no se puede localizar el guión de enlazador por defecto %qs en las rutas de búsqueda de bibliotecas"
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "la opción %qs no inicia con %<-%>"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr "la opción generada de especificación sólo es %<-%>"
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "no se puede abrir el fichero de respuesta temporal %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "no se puede escribir en el fichero de respuesta temporal %s"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "no se puede cerrar el fichero de respuesta temporal %s"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "la especificación %qs es no válida"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "la especificación %qs tiene un %<%%0%c%> no válido"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "la especificación %qs tiene un %<%%W%c%> no válido"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "la especificación %qs tiene un %<%%x%c%> no válido"
@@ -17490,228 +17522,228 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "falla de especificación: %<%%*%> no ha sido inicializado por coincidencia de patrón"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "falla de especificación: no se reconoce la opción de especificación %qc"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "función de especificación %qs desconocida"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "error en los argumentos para la función de especificación %qs"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "nombre de la función de especificación malformado"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "no hay argumentos para la función de especificación"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "argumentos de la función de especificación malformados"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "la especificación entre llaves %qs es no válida en %qc"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "el cuerpo de la especificación entre llaves %qs es no válido"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s: no se puede determinar la longitud del fichero para comparar depuración %s"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr "%s: falló -fcompare-debug (longitud)"
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s: no se puede abrir el fichero para comparar depuración %s"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "%s: falló -fcompare-debug"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "falla de especificación: más de un argumento para SYSROOT_SUFFIX_SPEC"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "falla de especificación: más de un argumento para SYSROOT_HEADERS_SUFFIX_SPEC"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "no se reconoce la opción de línea de órdenes %<-%s%>; ¿quería decir %<-%s%>?"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "no se reconoce la opción de línea de órdenes %<-%s%>"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "no se configuró con el sufijo de encabezados sysroot"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "no hay ficheros de entrada"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "no se puede especificar -o con -c, -S o -E y con múltiples ficheros"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: el compilador %s no está instalado en este sistema"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "se recompila con -fcompare-debug"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr "durante la recompilación -fcompare-debug"
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr "se comparan volcados finales de insns"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "-fuse-linker-plugin, pero no se encontró %s"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: no se usó el fichero de entrada del enlazador porque no se hizo enlace"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "no se reconoce el lenguaje %s"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "la especificación multilib %qs es no válida"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "las exclusiones multilib %qs son no válidas"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "la selección multilib %qs %qs no es válida"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "la selección multilib %qs es no válida"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "la exclusión multilib %qs es no válida"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "no se definió la variable de entorno %qs"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "número de versión %qs no válido"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "faltan argumentos para %%:version-compare"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "demasiados argumentos para %%:version-compare"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "operador %qs desconocido en %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "demasiados argumentos para %%:compare-debug-dump-opt"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "demasiados argumentos para %%:compare-debug-self-opt"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "faltan argumentos para %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "demasiados argumentos para %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr "el argumento para %%:compare-debug-auxbase-opt no termina en .gk"
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "faltan argumentos para %%:replace-extension"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "número erróneo de argumentos para %%:debug-level-gt"
@@ -17856,9 +17888,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "se declara aquí"
@@ -18273,227 +18305,227 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr "el atributo %<fallthrough%> no antecede una etiqueta case o default"
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "se usa el resultado de una función que devuelve %<void%>"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "l-valor no válido en la salida asm %d"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "la entrada que no es de memoria %d debe permanecer en memoria"
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "la entrada de memoria %d no es directamente direccionable"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "se usó la variable threadprivate %qE en una región objetivo"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "región objetivo contenedora"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "se usó la variable threadprivate %qE en una tarea sin atar"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "tarea contenedora"
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "no se especificó %qE en el %qs que lo contiene"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "%qs contenedora"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "no se especificó %qE en la construcción OpenACC %qs que lo contiene"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "construcción OpenACC %qs que lo contiene"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE con cláusula %<link%> usada en la función %<routine%>"
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE requiere una directiva %<declare%> para poder usarse en una función%<routine%>"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "la variable %qE se declaró en la región %<host_data%> que la contiene"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD referenciada en la región de destino no tiene un tipo al que asociarla"
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "la variable de iteración %qE se predetermina lineal"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "la variable de iteración %qE debe ser private"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "la variable de iteración %qE no debe ser firstprivate"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "la variable de iteración %qE no debe ser reduction"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "la variable de iteración %qE no debe ser lineal"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "la variable de iteración %qE no debe ser lastprivate"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "la variable de iteración %qE no debe ser private"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "cláusula %<linear%> para una variable que no es iterador de bucle especificada en una construcción combinada con %<distribute%>"
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "se asocia el campo %qE de una estructura de longitud variable"
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE aparece más de una vez en las cláusulas map"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "la variable copyprivate %qE no es threadprivate o private en el contexto externo"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "la variable %s %qE es private en el contexto externo"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "se esperaba el modificador de cláusula %qs %<if%> en vez de %qs"
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD en cláusula %<map%> implícita"
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> implícita en una construcción %<target%>"
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD en cláusula %<firstprivate%> en una construcción %<target%>"
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "se ha usado la misma variable en cláusulas %<firstprivate%> y %<lastprivate%> en una construcción %<distribute%>"
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr "cláusula de datos incompatible con reducción en %qE; se promociona a present_or_copy"
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "reducción privada no válida en %qE"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "la construcción %<ordered%> con cláusula %<depend%> debe estar bien anidada dentro de un bucle con una cláusula %<ordered%> con un parámetro"
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "la variable %qE no es una iteración del bucle más externo %d; se esperaba %qE"
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "el número de variables en la cláusula %<depend(sink)%> no coincide con el número de variables de iteración"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr "más de una cláusula %<depend(source)%> en una construcción %<ordered%>"
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr "cláusula %<depend(source)%> especificada junto con cláusulas %<depend(sink:)%> en la misma construcción"
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "se esperaba %<_Cilk_spawn%> antes de %<_Cilk_sync%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "falló la gimplificación"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT se promueve a %qT cuando pasa a través de %<...%>"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(así que debe pasar %qT y no %qT a %<va_arg%>)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si se alcanza este código, el programa abortará"
@@ -18725,8 +18757,9 @@
 msgstr "tipos con número de parámetros diferentes"
 
 #: ipa-devirt.c:1229
-#, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+#, fuzzy, gcc-internal-format
+#| msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "el propio tipo %qT viola la regla de una sola definición de C++"
 
 #: ipa-devirt.c:1235
@@ -18825,8 +18858,9 @@
 msgstr "hay un campo con el mismo nombre pero distinto tipo definido en otra unidad de traducción"
 
 #: ipa-devirt.c:1576
-#, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+#, fuzzy, gcc-internal-format
+#| msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr "los campos tienen distinta disposición en otra unidad de translación"
 
 #: ipa-devirt.c:1599
@@ -19208,198 +19242,198 @@
 msgid "multiple loop axes specified for routine"
 msgstr "se especificaron múltiples ejes de bucle para la rutina"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr "%<seq%> ignora otros especificadores de bucle OpenACC"
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr "%<auto%> está en conflicto con otros especificadores de bucle OpenACC"
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr "el bucle interno usa el mismo paralelismo OpenACC que el bucle que lo contiene"
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr "argumento no permitido en la cláusula %qs en OpenACC %<parallel%>"
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr "construcción no OpenACC dentro de rutina OpenACC"
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr "construcción no OpenACC dentro de región OpenACC"
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr "%<ordered simd threads%> debe estar estar bien anidada dentro de la región %<for simd%>"
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr "Las construcciones OpenACC distintas de %<#pragma omp ordered simd%> pueden no estar anidadas dentro de la región %<simd%>"
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr "solamente a las regiones %<distribute%> o %<parallel%> se les permite estar estrictamente anidadas dentro de la región %<teams%>"
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr "las regiones %<distribute%> deben estar estrictamente anidadas dentro de construcciones %<teams%>"
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr "la directiva de bucle OpenACC debe estar asociada a una región de cómputo OpenACC"
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr "construcción %qs huérfana"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr "%<#pragma omp cancel for%> dentro de %<nowait%> para construcción"
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr "%<#pragma omp cancel for%> dentro de %<ordered%> para construcción"
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<#pragma omp cancel section%> dentro de contrucción de secciones %<nowait%>"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr "la construcción %<%s taskgroup%> no está bien anidada dentro de la región %<taskgroup%>"
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, gcc-internal-format
 msgid "invalid arguments"
 msgstr "argumentos no válidos"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr "la construcción %<%s %s%> no está bien anidada dentro de %qs"
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "la región de barrera puede no estar bien anidada dentro de la región de trabajo compartido, %<critical%>, %<ordered%>, %<master%>, %<task%> explícita o región %<taskloop%>"
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "la región de trabajo compartido puede no estar bien anidada dentro de la región de trabajo compartido, %<crítical%>, %<ordered%>, %<master%>, %<task%> explícita o región %<taskloop%>"
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr "la región %<master%> puede no estar bien anidada dentro de la región de trabajo compartido, de %<task%> explícita o de región %<taskloop%>"
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr "%<depend(%s)%> solo se permite en %<omp ordered%>"
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr "la construcción %<ordered%> con la cláusula %<depend%> debe estar bien anidada dentro de un bucle %<ordered%>"
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr "%<ordered%> %<simd%> debe estar bien anidada dentro de una región %<simd%>"
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr "la región %<ordered%> puede no estar bien anidada dentro de la región %<critical%>, %<ordered%>, explicit %<task%> o %<taskloop%>"
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr "la región %<ordered%> debe estar bien anidada dentro de una región de bucle con una cláusula %<ordered%>"
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr "la región %<critical%> puede no estar bien anidada dentro de una región %<critical%> con el mismo nombre"
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr "construcción %<teams%> no bien anidada dentro de construcción %<target%>"
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr "región OpenACC dentro de rutina OpenACC; el paralelismo anidado aún no se permite"
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr "construcción OpenACC dentro de región no OpenACC"
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr "construcción %s %qs dentro de región %s %qs"
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr "construcción %qs dentro de región %qs"
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr "setjmp/longjmp dentro de construcción simd"
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr "se hace caso omiso de cláusula sumidero con desplazamiento que no es múltiplo del paso del bucle"
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr "el primer desplazamiento debe estar en dirección opuesta a las iteraciones del bucle"
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "salida no válida de un bloque estructurado %s"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "entrada no válida a un bloque estructurado %s"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "ramificación no válida desde/para un bloque estructurado %s"
@@ -19485,7 +19519,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "la opción de línea de órdenes %qs no se admite en esta configuración"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "faltan argumentos para %qs"
@@ -19641,127 +19675,139 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr "-fsanitize-address-use-after-scope requiere -fstack-reuse=none option"
 
-#: opts.c:1410
+#: opts.c:1012
+#, fuzzy, gcc-internal-format
+#| msgid "transactional memory is not supported with non-call exceptions"
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "la memoria transaccional no se admite con excepciones que no son llamada"
+
+#: opts.c:1015
+#, fuzzy, gcc-internal-format
+#| msgid "transactional memory is not supported with non-call exceptions"
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "la memoria transaccional no se admite con excepciones que no son llamada"
+
+#: opts.c:1417
 #, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr "no se reconocen las include_flags 0x%x pasadas a print_specific_help"
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr "la opción -fsanitize=all no es válida"
 
-#: opts.c:1642
+#: opts.c:1649
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "no se reconoce el argumento para la opción -f%ssanitize%s=: %q.*s; ¿quiso decir %qs?"
 
-#: opts.c:1649
+#: opts.c:1656
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "no se reconoce el argumento para la opción -f%ssanitize%s=: %q.*s"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "el argumento %q.*s de --help es ambiguo, por favor sea más específico"
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "no se reconoce el argumento para la opción --help=: %q.*s"
 
-#: opts.c:2078
+#: opts.c:2085
 #, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr "HSA no se activó durante la configuración"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr "la opción -foffload-abi solo puede especificarse para compilador de descarga"
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "la alineación de la estructura debe ser una potencia pequeña de dos, no %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "parámetro de revisión de pila desconocido %qs"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr "%<-gdwarf%s%> es ambiguo; use %<-gdwarf-%s%> para la versión DWARF o %<-gdwarf -g%s%> para nivel de depuración"
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "no se admite dwarf versión %d"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: los argumentos --param deben ser de la forma NOMBRE=VALOR"
 
-#: opts.c:2371
+#: opts.c:2378
 #, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "nombre de --param %qs no válido; ¿quiso decir %qs?"
 
-#: opts.c:2374
+#: opts.c:2381
 #, gcc-internal-format
 msgid "invalid --param name %qs"
 msgstr "nombre de --param %qs no válido"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "valor de --param %qs no válido"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "el sistema objetivo no admite salida de depuración"
 
-#: opts.c:2513
+#: opts.c:2520
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "el formato de depuración %qs genera un conflicto con una selección previa"
 
-#: opts.c:2531
+#: opts.c:2538
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "no se reconoce el nivel de salida de depuración %qs"
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "el nivel de salida de depuración %qs es demasiado elevado"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "obteniendo el límite del tamaño máximo del fichero core: %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "estableciendo el límite del tamaño máximo del fichero core: %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "no se reconoce la opción de depuración de gcc: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: no existe la opción -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr "-Werror=%s: -%s no es una opción para controlar avisos"
@@ -20107,7 +20153,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "se usó el registro de %qD para múltiples variables de registro globales"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "genera un conflicto con %qD"
@@ -20709,12 +20755,12 @@
 msgid "error closing %s: %m"
 msgstr "error al cerrar %s: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr "self-tests es incompatible con -E"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "self-tests no están activadas en este build"
@@ -21625,47 +21671,47 @@
 msgid "in expansion of macro %qs"
 msgstr "en expansión de macro %qs"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "el BB %i tiene múltiples bordes EH"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr "el BB %i no puede hacer throw pero tiene un borde EH"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "la última sentencia del BB %i tiene establecido incorrectamente lp"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "al BB %i le falta un borde EH"
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "Borde EH %i->%i incorrecto"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "al BB %i le falta un borde"
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "BB %i demasiados bordes de respaldo"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "BB %i tiene un borde incorrecto"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "BB %i tiene un borde de respaldo incorrecto"
@@ -21766,32 +21812,32 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr "el objetivo no admite actualización de perfil atómica; se selecciona el modo sencillo"
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr "argumento %u nulo donde se esperaba no nulo"
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "en una llamada a la función interna %qD"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "en una llamada a la función %qD declarada aquí"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "faltó optimizar el bucle, el contador de bucles se puede desbordar"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr "la iteración %s invoca comportamiento indefinido"
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr "dentro de este bucle"
@@ -22145,11 +22191,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -23116,7 +23162,7 @@
 msgid "type was previously declared %qE"
 msgstr "el tipo se declaró previamente %qE"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> solo se puede especificar para funciones virtuales"
@@ -23391,7 +23437,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "el compilador puede asumir que la dirección de %qD siempre se evaluará como %<true%>"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "se sugieren paréntesis alrededor de la asignación usada como valor verdadero"
@@ -24010,62 +24056,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "calificadores de tipo extra en el argumento de formato (argumento %d)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> espera un argumento de tipo %<%s%s%>, pero el argumento %d es de tipo %qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> espera un argumento %<%s%s%> coincidente"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> espera un argumento de tipo %<%T%s%>, pero el argumento %d es de tipo %qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> espera un argumento %<%T%s%> coincidente"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> no se define como un tipo"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> no se define como %<long%> o %<long long%>"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> no se define como un tipo"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> no se define como un tipo"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> no se define como un tipo"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> no se define como un tipo puntero"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "los argumentos que recibirán formato no son %<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "los formatos de strftime no pueden dar formato a los argumentos"
@@ -24166,7 +24212,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "%<@%> repetida antes de la cadena Objective-C"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "no se admite la concatenación no estándar de literales de cadena"
@@ -24196,7 +24242,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> usa dos variables diferentes para la memoria"
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipo no válido para la variable de iteración %qE"
@@ -24211,22 +24257,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE no está inicializado"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "falta el predicado controlador"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predicado controlador no válido"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "falta la expresión de incremento"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expresión de incremento no válida"
@@ -24771,8 +24817,8 @@
 msgid "wrong type argument to %s"
 msgstr "argumento de tipo erróneo para %s"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "desbordamiento en la expresión constante"
@@ -25449,7 +25495,7 @@
 msgid "this condition has identical branches"
 msgstr "esta condición tiene bifurcaciones idénticas"
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "%<_Cilk_spawn%> sólo se puede usar dentro de una función"
@@ -25611,7 +25657,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr "-march=%s: subcadena ISA %qs no válida"
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "interruptor -mdebug-%s desconocido"
@@ -25938,7 +25984,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "el %Kargumento %d debe ser un inmediato constante"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "el índice %Klane debe ser un inmediato constante"
@@ -26025,7 +26071,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "valor %qs desconocido para -mtune"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "la opción -mcpu=%s genera un conflicto con la opción -march=%s"
@@ -26112,9 +26158,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "el objetivo %s %s=%s no es válido"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -26202,7 +26248,7 @@
 msgstr "valor %qs erróneo para -mmemory-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26379,235 +26425,235 @@
 msgid "insn addresses not freed"
 msgstr "direcciones de insn no liberadas"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "this builtin is not supported for this target"
 msgstr "no se admiten funciones anidadas en este objetivo"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr "Debe activar las instrucciones NEON (e.g. -mfloat-abi=softfp -mfpu=neon) para usar estos intrínsecos."
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Debe activar las instrucciones VFP para usar estos intrínsecos."
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr "Debe activar las instrucciones crypto (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) para usar estos intrínsecos."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "el selector debe ser un inmediato"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "el rango del selector debe estar entre 0 y 7"
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "el rango del selector debe estar entre 0 y 3"
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "el rango del selector debe estar entre 0 y 1"
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "la máscara debe ser un inmediato"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "el rango de la máscara debe estar entre 0 y 255"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt y NEON son incompatibles"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "el CPU objetivo no tiene soporte para el modo ARM"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "habilitar el soporte de rastreo hacia atrás sólo tiene significado cuando se compila para el Thumb"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "habilitar el soporte de trabajo interno de llamado sólo tiene significado cuando se compila para el Thumb"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g con -mno-apcs-frame no permite una depuración sensible"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "no se puede usar -mtp=cp15 con Thumb de 16-bit"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "El PIC de RTP es incompatible con Thumb"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr "-mpure-code solo admite código no pic en los objetivos armv7-m"
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "el CPU objetivo no admite las instrucciones THUMB"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "el CPU objetivo no admite accesos sin alinear"
@@ -26614,141 +26660,141 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mfpu=auto no se admite actualmente sin una CPU explícita."
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "el CPU objetivo no admite trabajo interno"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check es incompatible con -mno-apcs-frame"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic y -mapcs-reent son incompatibles"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "no se admite el código reentrante APCS.  Descartado"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "las opciones fp16 seleccionadas son incompatibles"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt requiere una ABI compatible con AAPCS para una operación adecuada"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "el abi iwmmxt requiere un cpu capaz de iwmmxt"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS no admite -mcaller-super-interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS no admite -mcallee-super-interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 sin ldrh"
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard: el procesador seleccionado carece de FPU"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard y VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "el límite del tamaño de la estructura sólo se puede establecer a 8, 32 o 64"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "el límite del tamaño de la estructura sólo se puede establecer a 8 o 32"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "El PIC de RTP es incompatible con -msingle-pic-base"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= es inútil sin -fpic"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "no se puede usar '%s' para registro PIC"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "no se admite -freorder-blocks-and-partition en esta arquitectura"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "la CPU objetivo no admite las instrucciones de seguridad ARMv8-M"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "variante PCS derivada de un no AAPCS"
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "las funciones variadic debe usar la variante AAPCS base"
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "variante PCS"
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "ABI de VFP de coma flotante dura de Thumb-1"
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "el paso de parámetro para argumentos de tipo %qT ha cambiado en GCC 7.1"
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -26756,73 +26802,78 @@
 msgid "%qE attribute only applies to functions"
 msgstr "el atributo %qE se aplica solamente a funciones"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "el atributo %qE no está disponible para funciones con argumentos pasados en la pila"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "el atributo %qE no está disponible para funciones con un número variable de argumentos"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "el atributo %qE no está disponible para funciones que devuelven valor en la pila"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "se descarta el atributo %qE sin la opción -mcmse."
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "el atributo %qE no tiene efecto en funciones con enlazado estático"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "el atributo %qE se aplica solamente al tipo base de un puntero a función"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd fuera de rango %wd - %wd"
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd fuera de rango %wd - %wd"
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "no se puede calcular la ubicación real del parámetro apilado"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Fin de módulo inesperado"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "no hay registros inferiores disponibles para extraer registros superiores"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "no se pueden codificar las Rutinas de Servicios de Interrupción en el modo Thumb"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr "-fstack-check=specific para Thumb-1"
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr "fpu no válida para el atributo(objetivo(\"%s\"))"
@@ -26830,13 +26881,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "selección automática de fpu actualmente no permitida aquí"
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "se desconoce attribute(target(\"%s\"))"
@@ -26933,163 +26984,176 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr "los atributos de función %qs y %qs no tienen efecto en funciones %qs"
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la función %qs no puede tener argumentos"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la función %qs no puede devolver un valor"
 
-#: config/avr/avr.c:1084
-#, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+#: config/avr/avr.c:1085
+#, fuzzy, gcc-internal-format
+#| msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs parece ser un manejador %s mal escrito; falta el prefijo __vector"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> sólo contiene 2 bytes de dirección"
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "el desplazamiento del puntero desde el símbolo tal vez es incorrecto"
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "se accede a memoria de datos con dirección de memoria de programa"
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "se accede a memoria de programa con dirección de memoria de datos"
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "se usó el registro fijo %s para pasar un parámetro a la función"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "no se admite escribir al espacio de direcciones %qs"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "el atributo %qE se aplica solamente a variables en almacenamiento estático"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "solo se admite el atributo %qE núcleos Tiny reducidos"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "el atributo %qE solamente se aplica a variables"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "el atributo %qE sólo permite una constante entera como argumento"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr "la dirección del atributo %qE está fuera de rango"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "tanto el atributo %s como el %qE proporcionan dirección"
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "atributo %qE en variable no volátil"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "no se admiten espacios de direcciones para dispositivos Tiny reducidos"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "no se admite el espacio de direcciones %qs para dispositivos con tamaño de flash de hasta %d KiB"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "el espacio de direcciones %qs que apuntan a punteros debe ser const en %qT"
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "el espacio de direcciones %qs que apuntan a punteros debe ser const en %s %q+D"
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "la variable %q+D debe ser const para que se ponga en la sección de sólo lectura a través de %qs"
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr "la declaración de ES estática para %q+D necesita una dirección"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr "la definición de ES para %q+D necesita una dirección"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "Sólo las variables sin inicializar se pueden colocar en la sección .noinit"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
+#, fuzzy, gcc-internal-format
+#| msgid "uninitialized variable %q+D put into program memory area"
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "se colocó la variable %q+D sin inicializar en el área de memoria del programa"
+
+#: config/avr/avr.c:10160
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "se colocó la variable %q+D sin inicializar en el área de memoria del programa"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D tiene atributos incompatibles %qs y %qs"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "la arquitectura %qs sólo se admite para ensamblador"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "vonversión del espacio de direcciones %qs al espacio de direcciones %qs"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s expera una constante entera en tiempo de compilación"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s espera una constante entera long en tiempo de compilación como primer argumento"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "redondear a %d bits no tiene ningún efecto en valores de coma fija con %d bits de fracción"
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "el resultado del redondeo será siempre 0"
@@ -27372,12 +27436,12 @@
 msgid "invalid IACC argument"
 msgstr "argumento IACC no válido"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs espera una constante como argumento"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "el argumento constante está fuera de rango para %qs"
@@ -27555,7 +27619,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "el modelo de código %qs no se admite en modo x32"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "el modelo de código %s no admite el modo PIC"
@@ -27685,287 +27749,287 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "se descarta %<target(\"rtd\")%> en el modo de 64bit"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "no se admite -mpreferred-stack-boundary en este objetivo"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d no está entre %d y %d"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d no está entre %d y 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount no es compatible con este objetivo"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount no está implementada para -fPIC"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "se usó %<-msseregparm%> sin SSE activado"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "se usó %<target(\"ssseregparm\")%> sin SSE activado"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "el conjunto de instrucciones SSE está desactivado, usando la aritmética 387"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "el conjunto de instrucciones 387 está desactivado, usando la aritmética SSE"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "la prueba de pila requiere %<-maccumulate-outgoing-args%> para ser correcta"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "la prueba de pila requiere %<target(\"accumulate-outgoing-args\"%> para ser correcta"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "el registro ebp fijo requiere %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "el registro ebp fijo requiere %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry no se admite para 32-bit en combinación con -fpic"
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry no es compatible con SEH"
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "opción desconocida para -mrecip=%s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "ya se había especificado option(\"%s\")"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Solo se admite el formato de depuración DWARF para la rutina de servicio de interrupciones."
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "las instrucciones %s no se permiten en la rutina de servicio %s"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "Las instrucciones %s no están permitidas en funciones con el atributo no_caller_saved_registers"
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "los atributos fastcall y regparm no son compatibles"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "los atributos regparam y thiscall no son compatibles"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "el atributo %qE requiere un argumento constante entero"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "los atributos fastcall y cdecl no son compatibles"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "los atributos fastcall y stdcall no son compatibles"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "los atributos fastcall y thiscall no son compatibles"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "los atributos stdcall y cdecl no son compatibles"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "los atributos stdcall y fastcall no son compatibles"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "los atributos stdcall y thiscall no son compatibles"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "los atributos cdecl y thiscall no son compatibles"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "se usó el atributo %qE para método no de clase"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qD con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "se llama a %qT con el atributo sseregparm sin activar SSE/SSE2"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 no admite el atributo ms_abi"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue no es compatible con la función anidada"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "el argumento de vector AVX512F sin AVX512F activado cambia la ABI"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "el retorno de vector AVX512F sin AVX512F activado cambia la ABI"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "el argumento de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "el retorno de vector AVX sin AVX activado cambia la ABI"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "el argumento de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "la devolución de vector SSE sin SSE activado cambia la ABI"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "el argumento de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "la devolución de vector MMX sin MMX activado cambia la ABI"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "la ABI para pasar un struct con un miembro de matriz flexible cambió en GCC 4.4"
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "la ABI para pasar un union con long double cambió en GCC 4.4"
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "se devuelve el registro SSE con SSE desactivado"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumento de registro SSE con SSE desactivado"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "se devuelve el registro x87 con x87 desactivado"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "se llama a %qD con el convenio de llamadas SSE sin activar SSE/SSE2"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "esto es un error de GCC que se puede sortear añadiendo el atributo usado a la función llamada"
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "La ABI para pasar parámetros con alineación de %d-bytes cambió en GCC 4.6"
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "el atributo ms_hook_prologue no es compatible con -mfentry para 32-bit"
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "No se admite Puntero de Argumento de Realineamiento Dinámico (DRAP) en la rutina de servicio de interrupciones.  Esto puede sortearse evitando funciones con retorno agregado."
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack no admite fastcall con funciones anidadas"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack no admite 2 parámetros de registro para una función anidada"
@@ -27972,297 +28036,297 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack no admite 3 parámetros de registro"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "no se admite el tamaño para registro de enteros"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "los registros extendidos no tiene mitades superiores"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "no se admite el tamaño de operando para el registro extendido"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "se usó un operando que no es entero con el código de operando 'z'"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "no se puede llamar directamente a la rutina de servicio de interrupciones"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "No se ha encontrado despachador para los atributos de versión"
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "No se encontró despachador para %s"
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "No se encontró despachador para los atributos de versión : %s"
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Las versiones de funciones no pueden marcarse como gnu_inline; hay que generar cuerpos"
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "No se admiten versiones múltiples de funciones virtuales"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr "falta el atributo %<target%> para %D multiversionado"
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "declaración previa de %D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "el versionado múltiple necesita ifunc, que no se admite en este objetivo"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "El parámetro para la función interna debe ser una cadena constante o literal"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "El parámetro para la función interna no es válido: %s"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 2-bit"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "el quinto argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 3-bit"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 4-bit"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 1-bit"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "el tercer argumento debe ser un inmediato de 5-bit"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "el penúltimo argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "el tercer argumento debe ser una constante de comparación"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "modo de comparación incorrecto"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "operando de redondeo incorrecto"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 4-bit"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 5-bit"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "el argumento inmediato debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "el último argumento debe ser un inmediato de 32-bit"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "el selector debe ser una constante entera en el rango 0..%wi"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE necesita la opción isa desconocida"
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE necesita la opción isa %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "el último argumento debe ser un inmediato"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "el último argumento debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "el argumento delantero debe ser un escalar 1, 2, 4, 8"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "operando de pista incorrecto"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "el argumento de xabort debe ser un inmediato de 8-bit"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "el atributo %qE solamente está disponible para 64-bit"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "el argumento del atributo %qE no es cero ni uno"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "los atributos ms_abi y sysv_abi no son compatibles"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "se descarta el atributo incompatible %qE"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la rutina de servicio de interrupciones debería tener un puntero como primer argumento"
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la rutina de servicio de interrupciones solo puede tener un argumento puntero y un argumento entero opcional"
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "ls rutina de servicio de interrupción no puede tener valor de retorno que no sea void"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "no se permiten alternativas en la salida del indicador asm"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "salida del indicador asm %qs desconocida"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "tipo no válido para la salida del indicador asm"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "Modelo de memoria específico de la arquitectura desconocido"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE no se usa con ACQUIRE o modelos de memoria más fuertes"
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE no se usa con RELEASE o modelos de memoria más fuertes"
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen %d no admitido"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr "no se admite el tipo de retorno %qT para simd\n"
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "no se admite el tipo de argumento %qT para simd\n"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "El Comprobador de Punteros requiere suporte MPX en este objetivo. Utilice las opciones -mmpx para activar MPX."
@@ -28382,7 +28446,7 @@
 msgid "argument %qd is not a constant"
 msgstr "el argumento %qd no es una constante"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, puntero nulo"
@@ -28392,7 +28456,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: Puntuación desconocida '%c'"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND puntero nulo"
@@ -28493,7 +28557,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread sólo está disponible en fido"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "no se admite la expresión del límite de la pila"
@@ -28999,8 +29063,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr "las funciones internas de MSP430 solo funcionan dentro de manejadores de interrupciones"
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr "código interno erróneo"
@@ -29253,27 +29317,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr "PTX no admite declaraciones débiles (solamente definiciones débiles)"
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "el atributo %qE requiere tipo de retorno void"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "no se permite el atributo %qE con una clase de auto almacenamiento"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr "se usa vector_length (%d); se hace caso omiso de %d"
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr "se usa vector_length (%d); se hace caso omiso de la configuración de tiempo de ejecución"
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "se usa num_workers (%d); se hace caso omiso de %d"
@@ -29298,7 +29362,7 @@
 msgid "-g option disabled"
 msgstr "opción -g desactivada"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "la alineación (%u) para %s excede la alineación máxima para los datos comunes globales.  Se usará %u"
@@ -29433,157 +29497,157 @@
 msgid "junk at end of #pragma longcall"
 msgstr "basura al final de #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr está obsoleta para little endian; utilize asignación para cargas y almacenajes no alineados"
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_mul sólo acepta 2 argumentos"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_cmpne sólo acepta 2 argumentos"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_adde sólo acepta 3 argumentos"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_addec sólo acepta 3 argumentos"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s sólo acepta %d argumentos"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s sólo acepta 1 argumento"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s sólo acepta 2 argumentos"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract sólo acepta 2 argumentos"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert sólo acepta 3 argumentos"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "el paso del argumento %d de %qE descarta los calificadores del tipo del destino del puntero"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "No se admite la función interna %s en esta configuración del compilador"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "combinación de parámetros no válida para el intrínseco AltiVec %s"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr "-recip requiere -ffinite-math o -ffast-math"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr "-mrecip requiere -fno-trapping-math o -ffast-math"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr "-mrecip requiere -freciprocal-math o -ffast-math"
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 requiere la arquitectura PowerPC64, activando"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "no se admite -malign-power para Darwin de 64-bit; es incompatible con las bibliotecas C y C++ instaladas"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr "no generará instrucciones power9 porque el ensamblador no las admite"
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr "no generará instrucciones power8 porque el ensamblador no las admite"
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr "no generará instrucciones power7 porque el ensamblador no las admite"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr "no generará instrucciones power6 porque el ensamblador no las admite"
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr "no generará instrucciones power5 porque el ensamblador no las admite"
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr "no se configuró para ABI SPE"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr "no configurado para el conjunto de instrucciones SPE"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "el atributo o pragma target cabia la ABI SPE"
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "no se admite AltiVec en este objetivo"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "no se admite SPE en este objetivo"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "no se admite -mmultiple en sistemas little endian"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "no se admite -mstring en sistemas little endian"
@@ -29590,67 +29654,67 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "-mpower9-minmax es incompatible con las opciones desactivadas explícitamente"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr "la opción del objetivo Power9 es incompatible con -mcpu=<xxx> para <xxx> menor que power9"
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr "-mcrypto requiere -maltivec"
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr "-mdirect-move requiere -mvsx"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr "-mpower8-vector requiere -maltivec"
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr "-mpower8-vector requiere -mvsx"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr "-mvsx-timode requiere -mvsx"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "-mhard-dfp requiere -mhard-float"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "-mupper-regs-df requiere -mvsx"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "-mupper-regs-di requiere -mvsx"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr "-mupper-regs-sf requiere -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr "-mpower8-fusion-sign requiere -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr "-mtoc-fusion requiere -mpower8-fusion"
@@ -29659,244 +29723,244 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "-mpower9-fusion requiere -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr "-mpower9-vector requiere -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr "-mpower9-dform requiere -mpower9-vector"
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar requieren -mdirect-move"
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr "-mpower9-dform requiere -mupper-regs-df"
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr "-mpower9-dform requiere -mupper-regs-sf"
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "el atributo o pragma target cambia el tamaño de double long"
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, fuzzy, gcc-internal-format
 #| msgid "-mrecip requires -mfused-madd"
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr "-mrecip requiere -mfused-madd"
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, fuzzy, gcc-internal-format
 #| msgid "-mrecip requires -mfused-madd"
 msgid "-mfloat128-hardware requires -m64"
 msgstr "-mrecip requiere -mfused-madd"
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr "tipo de ABI de biblioteca de vectorización desconocida (%s) para la opción -mveclibabi="
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "el atributo o pragma target cambia la ABI Altivec"
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "el atributo o pragma target cambia la ABI darwin64"
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "el atributo o pragma target cambia la coma flotante de precisión sencilla"
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "el atributo o pragma target cambia la coma flotante de precisión doble"
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs no es una opción válida para el preprocesador"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "La ABI para pasar parámetros con alineación de %d-bytes cambió en GCC 4.6"
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "Se devolvió un vector GCC por referencia: extensión de ABI no estándar sin garantía de compatibilidad"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "no se puede devolver un valor en el registro vector porque las instrucciones altivec están desactivadas, use -maltivec para activarlas"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "La ABI para pasar parámetros con alineación de %d-bytes cambió en GCC 4.6"
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "no se puede pasar argumentos en el registro vector porque las instrucciones altivec están desactivadas, use -maltivec para activarlas"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "la ABI para pasar una estructura con un miembro de coma flotante compleja cambió en GCC 4.4"
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vector GCC pasado por referencia: extensión ABI que no es estándar sin garantía de compatibilidad"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "error interno: la función interna %s ya se procesó"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "el argumento 1 debe ser una literal con signo de 5-bit"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "el argumento 1 debe ser una literal con signo de 5-bit"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "el argumento 2 debe ser una literal sin signo de 5-bit"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "el argumento 2 debe ser una literal sin signo de 5-bit"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "el argumento 2 debe ser una literal sin signo de 5-bit"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "el argumento 1 de __builtin_altivec_predicate debe ser una constante"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "el argumento 1 de __builtin_altivec_predicate está fuera de rango"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "se descarta %srtd%s en el modo de 64bit"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "el argumento 2 debe ser una literal sin signo de 5-bit"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "el argumento 1 de __builtin_spe_predicate está fuera de rango"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %s only accepts a string argument"
@@ -29903,7 +29967,7 @@
 msgstr "%s sólo acepta 1 argumento"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "cpu %s is an invalid argument to builtin %s"
@@ -29910,79 +29974,84 @@
 msgstr "%qs es un argumento no válido para -mcpu="
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "%qs es un argumento no válido para -mcpu="
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 4-bit"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 2-bit"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 1-bit"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a map"
 msgid "argument 1 must be 0 or 2"
 msgstr "el argumento 1 debe ser un mapa"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "el argumento 3 debe ser una literal sin signo de 1-bit"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "el argumento 2 debe ser una literal sin signo de 5-bit"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "el número debe ser 0 ó 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range 0..15"
 msgstr "el argumento %d de %qE debe estar dentro del rango %d...%d"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "el argumento para %qs debe ser una literal sin signo de 2-bit"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "sobrecarga sin resolver para el interno Altivec %qF"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "el argumento para dss debe ser una literal sin signo de 2-bit"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, fuzzy, gcc-internal-format
 #| msgid "second argument to %<__builtin_expect%> must be a constant"
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr "el segundo argumento de %<__builtin_expect%> debe ser una constante"
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
@@ -29989,218 +30058,218 @@
 msgstr "el tercer argumento de %<__builtin_prefetch%> debe ser una constante"
 
 # continuar aqui
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "el argumento 1 de __builtin_paired_predicate debe ser una constante"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "el argumento 1 de __builtin_paired_predicate está fuera de rango"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "el argumento 1 de __builtin_spe_predicate debe ser una constante"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "el argumento 1 de __builtin_spe_predicate está fuera de rango"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "La función interna %s sólo es válida para el procesador cell"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "La función interna %s requiere la opción -mvsx"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "La función interna %s requiere la opción -mvsx"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "La función interna %s requiere la opción -maltivec"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "La función interna %s requiere la opción -mpaired"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "La función interna %s requiere la opción -mspe"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "La función interna %s requiere la opción -mpaired"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "La función interna %s requiere la opción -mpaired"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mspe option"
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "La función interna %s requiere la opción -mspe"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mspe option"
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "La función interna %s requiere la opción -mspe"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mspe option"
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "La función interna %s requiere la opción -mspe"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -maltivec option"
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "La función interna %s requiere la opción -maltivec"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "La función interna %s requiere la opción -mpaired"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -maltivec option"
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "La función interna %s requiere la opción -maltivec"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "La función interna %s no se admite con las opciones actuales"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "error interno: la función interna %s tiene un tipo de devolución inesperado %s"
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "error interno: función interna %s, el argumento %d tiene el tipo de argumento inesperado %s"
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "marco de pila demasiado grande"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 3 register parameters"
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack no admite 3 parámetros de registro"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "No se admite #pragma GCC target en este objetivo"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "no hay análisis de perfil del código de 64-bit para esta ABI"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "No se puede tomar la dirección de una función anindada si se usa la opción -mno-pointers-to-nested-functions."
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "el uso de %<long double%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "el uso de tipos booleanos en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "el uso de %<complex%> en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "el uso de tipos de coma flotante decimal en tipos AltiVec es no válido"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "el uso de %<long%> en tipos AltiVec es no válido para código de 64 bit sin -mvsx"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "el uso de %<long%> en tipos AltiVec es obsoleto; use %<int%>"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "el uso de %<long long%> en tipos AltiVec es no válido sin -mvsx"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "el uso de %<double%> en tipos AltiVec es no válido sin -mvsx"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "se emite el insn de microcódigo %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "se emite el insn de microcódigo condicional %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "cpu \"%s\" no válido para %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s no está definido"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s es no válido"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -30391,6 +30460,7 @@
 msgstr "-mas100-syntax es incompatible con -gdwarf"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 requiere un procesador PowerPC64"
@@ -30483,7 +30553,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -30511,9 +30581,10 @@
 msgstr "--resource requiere -o"
 
 #: config/s390/s390-c.c:889
-#, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
-msgstr ""
+#, fuzzy, gcc-internal-format
+#| msgid "--resource requires -o"
+msgid "%qF requires z14 or higher"
+msgstr "--resource requiere -o"
 
 #: config/s390/s390-c.c:903
 #, gcc-internal-format
@@ -30533,9 +30604,10 @@
 msgstr "sobrecarga ambigua para %qs en %<%s %E%>"
 
 #: config/s390/s390-c.c:966
-#, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
-msgstr ""
+#, fuzzy, gcc-internal-format
+#| msgid "%qs is deprecated"
+msgid "%qs matching variant requires z14 or higher"
+msgstr "%qs es obsoleto"
 
 #: config/s390/s390-c.c:972
 #, fuzzy, gcc-internal-format
@@ -30549,162 +30621,162 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "el argumento constante está fuera de rango para %qs"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "el argumento constante está fuera de rango para %qs."
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "el argumento constante está fuera de rango para %qs"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<tipo de función sobrecargada sin resolver>"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "icode interno erróneo"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument %qs for %<instanceof%>"
 msgid "invalid argument %d for builtin %qF"
 msgstr "Argumento %qs no válido para %<instanceof%>"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "el tamaño total de las variables locales excede el límite de la arquitectura"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "el tamaño de marco de la función %qs de %wd bytes excede el límite de pila definido por el usuario de %d bytes.  Se agrega una trampa incondicional."
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "el tamaño de marco de la función %qs de %wd bytes es mayor que la mitad del tamaño de la pila. La revisión dinámica no será confiable. No se emitirá revisión para esta función."
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "el tamaño de marco de %qs es de %wd bytes"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs utiliza alojamiento dinámico de pila"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<mwords-little-endian%> is deprecated and will be removed in a future release"
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr "%<mwords-little-endian%> es obsoleto y se eliminará en una versión futura"
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<mwords-little-endian%> is deprecated and will be removed in a future release"
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr "%<mwords-little-endian%> es obsoleto y se eliminará en una versión futura"
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "no se admite el modo z/Architecture en %s"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "no se admite la ABI de 64-bit en el modo ESA/390"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en %s"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en %s"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "las instrucciones de coma flotante decimal de hardware no están disponibles en el modo ESA/390"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp no se puede usar en conjunción con -msoft-float"
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "no se admiten -mbackchain -mpacked-stack -mhard-float en combinación"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "el tamaño de la pila debe ser mayor que el valor de la guardia de pila"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "el tamaño de la pila no debe ser mayor a 64k"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard implica el uso de -mstack-size"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "el argumento para %qs debe ser un entero no negativo"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
@@ -30711,7 +30783,7 @@
 msgstr "el argumento para el atributo %qE es más grande que %d"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -30769,27 +30841,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax sólo se admite pare el PIC de RTP"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s no se admite en esta configuración"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "no se permite -mlong-double-64 con -m64"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "valor erróneo (%s) para el interruptor -mcmodel="
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= no se admite en sistemas de 32 bit"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "no se admite -fcall-saved-REG para registros de salida"
@@ -31077,22 +31150,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "constante no válida en %<#pragma pack%> - se descarta"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "se requieren registros booleanos para la opción de coma flotante"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "no se admite -f%s con instrucciones CONST16"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "se requiere PIC pero no se admite con instrucciones CONST16"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "sólo las variables sin inicializar se pueden colocar en una sección .bss"
@@ -31182,7 +31255,7 @@
 msgid "could not read the BRIG file"
 msgstr "no se puede abrir el fichero %s"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -31595,9 +31668,9 @@
 msgstr "la etiqueta %qD se define aquí"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD se declara aquí"
@@ -31731,7 +31804,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "no se permite %<[*]%> en otro lugar que no sea el ámbido de prototipo de función"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -32793,7 +32866,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "dos o más tipos de datos en los especificadores de la declaración"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> es demasiado largo para GCC"
@@ -32942,17 +33015,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C no admite %<complex%> simples que significan %<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C no admite tipos enteros complejos"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -33005,7 +33078,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "se esperaba fin de línea"
@@ -33047,7 +33120,7 @@
 msgstr "nombre de tipo %qE desconocido"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "se esperaban especificadores de declaración"
@@ -33063,7 +33136,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "se esperaba %<;>, identificador o %<(%>"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "se descartan los atributos de prefijo para los métodos"
@@ -33078,8 +33151,8 @@
 msgid "unexpected attribute"
 msgstr "atributo inesperado"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "getter/setter attribute must be followed by %<=%>"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -33122,7 +33195,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> sólo se puede especificar para variables o declaraciones de función"
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "se esperaba %<,%> o %<;%>"
@@ -33150,7 +33223,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 no admite %<_Static_assert%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "se esperaba una cadena literal"
@@ -33218,14 +33291,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "se esperaba un identificador"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "coma al final de la lista de enumeradores"
@@ -33361,7 +33434,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "se esperaba %<}%> antes de %<else%>"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> sin un %<if%> previo"
@@ -33387,12 +33460,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr "una etiqueta sólo puede ser parte de una declaración y una declaración no es un enunciado"
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -33406,17 +33479,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "se esperaba una declaración"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<if%>"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "se sugieren llaves alrededor del cuerpo vacío en una declaración %<else%>"
@@ -33426,7 +33499,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "se sugieren llaves explícitas para evitar un %<else%> ambiguo"
@@ -33446,7 +33519,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "variable de iteración no válida en la enumeración rápida"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -33636,17 +33709,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "los operandos de %<__builtin_complex%> son de tipos diferentes"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -33701,64 +33774,64 @@
 msgid "no type or storage class may be specified here,"
 msgstr "ninguna clase de almacenamiento o tipo se puede especificar aquí,"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "atributo de propiedad desconocido"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<getter%>)"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "falta un %<=%> (después del atributo %<setter%>)"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "el atributo %<setter%> sólo se puede especificar una vez"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "el nombre del setter debe terminar con %<:%>"
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "el atributo %<getter%> sólo se puede especificar una vez"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC option%> is not a string"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC option%> no es una cadena"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> sólo se puede usar en construcciones %<#pragma omp sections%>"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
@@ -33774,12 +33847,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -33796,59 +33869,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD no es una variable"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<none%>"
 msgstr "se esperaba %<new%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "se esperaba %<none%> o %<shared%>"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "se esperaba %<;%>, %<,%> o %<)%>"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "se esperaba %<catch%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "demasiadas cláusulas %qs"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -33878,25 +33951,25 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%<priority%> value must be non-negative"
 msgstr "'%s' en %L debe ser no negativo"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "se esperaba %<throw%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>"
 msgid "expected %<scalar%>"
@@ -33908,65 +33981,65 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "demasiados argumentos"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected attribute"
 msgid "unexpected argument"
 msgstr "atributo inesperado"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "el argumento del atributo %qE no es una constante entera"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "el argumento de collapse necesita una expresión entera constante positiva"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "se esperaba %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> o %<max%>"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "se usaron al mismo tiempo %<long%> y %<void%> en los especificadores de declaración"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<runtime%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "el planificador %<auto%> no toma un parámetro %<chunk_size%>"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "género de planificador no válido"
@@ -33983,19 +34056,19 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -34019,19 +34092,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "género de planificador no válido"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "máscara no válida"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -34043,76 +34116,76 @@
 msgid "invalid proc_bind kind"
 msgstr "género de planificador no válido"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs no es válido para %qs"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs se debe usar con %qs"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, fuzzy, gcc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "Sección de matriz en la llamada '%s' en %L"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "uso no válido de %<--%> en la variable booleana %qD"
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "invalid OpenACC clause at file scope"
 msgstr "tipo no válido en la declaración"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "declaración de la variable %<extern%> %qD en la declaración inicial del bucle %<for%>"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "uso no válido de %<--%> en la variable booleana %qD"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is used more than once in the argument list of method %qs"
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "La variable %qs se usa más de una vez en la lista de argumentos del método %qs"
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "se esperaba una cadena después de %<#pragma message%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC option%> is not a string"
 msgid "%<#pragma acc %s data%> has no data movement clause"
@@ -34129,7 +34202,7 @@
 msgid "expected function name"
 msgstr "se esperaba función"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -34141,46 +34214,46 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "no se puede usar el especificador %<constexpr%> en una declaración de función que no es una definición"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, fuzzy, gcc-internal-format
 #| msgid "the %<constexpr%> specifier cannot be used in a function declaration that is not a definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "no se puede usar el especificador %<constexpr%> en una declaración de función que no es una definición"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma GCC pch_preprocess%> debe ser primero"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forma no válida de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operador no válido para %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
@@ -34191,28 +34264,28 @@
 msgid "expected %<(%> or end of line"
 msgstr "se esperaba %<(%> o fin de línea"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "se esperaba una declaración for"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "se esperaba una declaración de iteración o una inicialización"
@@ -34222,76 +34295,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "no hay suficientes bucles perfectamente anidados"
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "los bucles colapsados no están perfectamente anidados"
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable de iteración %qD no debe ser firstprivate"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "no se puede calificar %<void%> si es el único parámetro"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> sólo se puede usar en declaraciones compuestas"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "se esperaba %<operator%>"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "se esperaba %<using%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -34307,7 +34380,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> debe aparecer antes de la declaración de %D, se descarta"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -34317,34 +34390,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "se esperaba %<try%>"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "se esperaba %<decltype%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -34405,23 +34478,23 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "se esperaba %<#pragma omp section%> o %<}%>"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE se declaró %<threadprivate%> después del primer uso"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automática %qE no puede ser %<threadprivate%>"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE tiene tipo incompleto"
@@ -34437,57 +34510,57 @@
 msgid "pragma simd must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 #| msgid "end bit in POS must be an integer constant"
 msgid "vectorlength must be an integer constant"
 msgstr "el bit final en POS debe ser una constante entera"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 #| msgid "text length must be greater than 0"
 msgid "vectorlength must be a power of 2"
 msgstr "la longitud de texto debe ser más grande que 0"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "el selector debe ser una constante entera en el rango 0..%wi"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "se esperaba una cláusula %<#pragma omp%>"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> no se permite aquí"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sin activar el soporte para memoria transaccional"
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> dentro de un %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> más externo no está dentro del %<__transaction_atomic%> más externo"
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  o una función %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> no está dentro de %<__transaction_atomic%>"
@@ -34498,7 +34571,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<:%> or numeral"
@@ -35244,7 +35317,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la inicialización puede ser un candidato para un atributo de formato"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "el tipo de devolución puede ser un candidato para un atributo de formato"
@@ -35573,7 +35646,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C prohíbe %<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la función declarada %<noreturn%> tiene una declaración %<return%>"
@@ -35584,7 +35657,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "se usó una expresión coma para inicializar el valor de devolución"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -35611,7 +35684,7 @@
 msgid "function returns address of label"
 msgstr "la función devuelve la dirección de una variable local"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "la cantidad de switch no es un entero"
@@ -35626,7 +35699,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "la etiqueta de case no es una expresion constante entera"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "la etiqueta case no se encuentra dentro de una declaración switch"
@@ -35646,17 +35719,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "la declaración break no está dentro de un bucle o switch"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "la declaración continue no está dentro de un bucle"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "se usó la declaración break en un bucle for de OpenMP"
@@ -35667,7 +35740,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "la declaración break no está dentro de un bucle o switch"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
@@ -35774,12 +35847,12 @@
 msgid "used vector type where scalar is required"
 msgstr "se usa un tipo vector cuando se requiere un escalar"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -35790,27 +35863,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%Hdemasiadas cláusulas %qs"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD no es una función plantilla miembro"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -35823,19 +35896,19 @@
 msgstr "%Hdemasiadas cláusulas %qs"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -35842,58 +35915,58 @@
 msgstr "el tamaño de la matriz nueva debe tener un tipo integral"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "zero length array section in %qs clause"
 msgstr "Sección de matriz en la llamada '%s' en %L"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for pointer type length expression must be specified"
 msgstr "la expresión de incremento for no tiene efecto"
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Copia las secciones de matriz en un bloque contiguo en la entrada de procedimiento"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qE does not have pointer or array type"
@@ -35915,7 +35988,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE tiene tipo no válido para %<reduction(%s)%>"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
@@ -35927,17 +36000,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "se usó la matriz de longitud variable"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE debe ser %<threadprivate%> para %<copin%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -35957,18 +36030,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -35981,33 +36054,33 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE no es una variable en la cláusula %<firstprivate%>"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE no es una variable en la cláusula %<lastprivate%>"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -36031,64 +36104,64 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "No se permite una sección de matriz en la llamada '%s' en %L"
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE aparece más de una vez en las cláusulas de datos"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -36100,32 +36173,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE está predeterminado como %qs para %qs"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -36716,163 +36789,163 @@
 msgid "use of multiversioned function without a default"
 msgstr "función definida por defecto %q+D con argumento por defecto"
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "pasar %qT como el argumento %<this%> de %q#D descarta a los calificadores"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  en la llamada a %qD"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT no es una base inaccesible de %qT"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "se deduce %qT como %qT"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (puede desactivar esto con -fno-deduce-init-list)"
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "demasiados argumentos para el constructor %q#D"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "la constante se refiere a sí misma"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "llamada a %qD que no es función"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "no se puede llamar directamente al constructor %<%T::%D%>"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, fuzzy, gcc-internal-format
 #| msgid "  for a function-style cast, remove the redundant %<::%D%>"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  para una conversión de estilo de función, borre el %<::%D%> redundante"
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "no se encontró una función coincidente para la llamada a %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "no hay una función coincidente para la llamada a %<%D(%A)%>"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "la llamada del %<%s(%A)%> sobrecargado es ambigua"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "los inicializadores de los datos miembro no son estáticos"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "virtual abstracto `%#D' llamado desde un constructor"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "abstract virtual `%#D' called from destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "virtual abstracto `%#D' llamado desde un destructor"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "no se puede llamar a la función miembro %qD sin un objeto"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "al pasar %qT se escoge %qT sobre %qT"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "se escoge %qD sobre %qD"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  para la conversión de %qT a %qT"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  porque la secuencia de conversión para el argumento es mejor"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "no coincide el argumento por defecto en la resolución de sobrecarga"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " candidato 1: %q+#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " candidato 2: %q+#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ dice que estos son ambiguos, aún cuando la peor conversión para el primero es mejor que la peor conversión para el segundo:"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "no se puede convertir %qE de %qT a %qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "un enlace temporal a %qD sólo persiste hasta que el constructor termina"
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "inicialización no válida de una referencia que no es constante de tipo %qT desde un r-valor de tipo %qT"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "inicialización no válida de la referencia de tipo %qT desde una expresión de tipo %qT"
@@ -36980,297 +37053,297 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "no se puede derivar de la base %<final%> %qT al tipo derivado %qT"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "todos las funciones miembros en la clase %qT son privadas"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T solamente define un destructor privado y no tiene friends"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T solamente define constructores privados y no tiene friends"
 
 # Ojo, no es impostor, sino impositor, el que impone. cfuga
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "no hay un impositor único final para %qD en %qT"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "no se puede sobrecargar %q+#D"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D marked final, but is not virtual"
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "se marca %q+#D como final, pero no es virtual"
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D marked override, but does not override"
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D se marca como override, pero no hace override"
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D estaba escondido"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  por %q+D"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D no válido; un union anónimo sólo puede tener miembros con datos no estáticos"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D no válido; un struct anónimo sólo puede tener miembros con datos no estáticos"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "miembro privado %q+#D en union anónima"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous struct"
 msgid "private member %q#D in anonymous struct"
 msgstr "miembro privado %q+#D en struct anónimo"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous struct"
 msgid "protected member %q#D in anonymous struct"
 msgstr "miembro protegido %q+#D en struct anónimo"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "campo de bits %q+#D con tipo no entero"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "la anchura del campo de bits %q+D no es una constante entera"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "anchura negativa en el campo de bits %q+D"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "anchura cero para el campo de bits %q+D"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "la anchura de %q+D excede su tipo"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D es demasiado pequeño para contener todos los valores de %q#T"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "no se permite el miembro %q+#D con constructor en la union"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "no se permite el miembro %q+#D con destructor en la union"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "no se permite el miembro %q+#D con operador de asignación de copia en la union"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D no debe ser static porque es el miembro de una unión"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "el dato miembro que no es estático %qD tiene un tipo de clase Java"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "el campo %q+D no válidamente se declara como un tipo de función"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "el campo %q+D no válidamente se declara como un tipo de método"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "se descartan los atributos packed por el campo %q+#D sin empacar que no es POD"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "el no-miembro %qs no se puede declarar %<mutable%>"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "múltiples campos inicializados en la unión %qT"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "campo %q+#D con el mismo nombre que la clase"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T tiene miembros punteros a datos"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  pero no se impone a %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  o a %<operator=(cont %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  pero no se impone a %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "la alineación de %qD es más grande que la declaración original"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "se especificó un inicializador para el método %q+D que no es virtual"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "el método anula tanto %<transaction_pure%> como los métodos %qE"
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "el método declarado como %qE anula el método %qE"
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "la clase envolvente de la función miembro que no es estática constexpr %q+#D no es un tipo literal"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T no es literal porque:"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T tiene un destructor que no es trivial"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr "  %q+T no es un agregado, no tiene un constructor trivial por defecto y no tiene un constructor constexpr que no es un constructor copy o move"
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  la clase base %qT de %q+T no es literal"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has volatile type"
 msgstr "  el dato miembro que no es estático %q+D tiene un tipo que no es literal"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "la clase base %q#T tiene un destructor no virtual"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "referencia %q+#D que no es static en una clase sin un constructor"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -37278,165 +37351,165 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "se declaró %q+D para tomar referencia const, pero la declaración implícita tomaría algo que no es const"
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "base directa %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "base virtual %qT inaccesible en %qT debido a ambigüedad"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "el desplazamiento de %q+D no cumple con la ABI y puede cambiar en una versión futura de GCC"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "el tamaño de la matriz %qE es demasiado grande"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "uso no válido de %<...%> con algo que no es rebanada"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "uso no válido de una estructura con un miembro de matriz flexible"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "redefinición de %q#T"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "el miembro de matriz flexible no está al final del struct"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "el miembro de matriz flexible sería de otra manera un struct vacío"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D se declaró aquí"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinición de %q#T"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T tiene funciones virtuales y destructor no virtual accesible"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 #| msgid "type transparent class %qT does not have any fields"
 msgid "type transparent %q#T does not have any fields"
 msgstr "la clase transparente tipo %qT no tiene ningún campo"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "la clase transparente tipo %qT tiene clases base"
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "la clase transparente tipo %qT tiene funciones virtuales"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "se trató de terminar struct, pero fue sacado debido a errores previos de decodificación"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "no se reconoce la cadena de lenguaje %<\"%E\"%>"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "no se puede resolver la función sobrecargada %qD basándose en la conversión al tipo %qT"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "no hay coincidencias al convertir la función %qD al tipo %q#T"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "la conversión de la función sobrecargada %qD al tipo %q#T es ambigua"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "asumiendo el puntero a miembro %qD"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un puntero a miembro solamente se puede formar con %<&%E%>)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "no hay suficiente información de tipo"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "no se puede convertir %qE desde el tipo %qT al tipo %qT"
@@ -37446,12 +37519,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "la declaración de %q#D"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -37484,366 +37557,366 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "tipo de devolución %qT no válido para la función constexpr %q+D"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T tiene clases base virtuales"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr "el constructor constexpr no tiene cuerpo vacío"
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "el constructor %<constexpr%> para union %qT debe inicializar exactamente un dato miembro que no es static"
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "el cuerpo de la función constexpr %qD no es una declaración de devolución"
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not usable as a constexpr function because:"
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%q+D no se puede usar como una función constexpr porque:"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E no es una expresión constante"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function %qE"
 msgstr "función interna"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "la expresión %qE no designa una función constexpr"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "llamada a la función %qD que no es constexpr"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 #| msgid "%qD called in a constant expression"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "se llamó %qD en una expresión constante"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "se llamó %qD en una expresión constante"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "se usó %qD antes de su definición"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "la llamada tiene una dependencia circular"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on calls to these functions"
 msgid "constexpr call flows off the end of the function"
 msgstr "Avisa en las llamadas a estas funciones"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "la cuenta de desplazamiento a la derecha es negativa"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "el operador del lado izquierdo de la expresión coma no tiene efecto"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "el subíndice de la matriz está fuera de los límites de la matriz"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD mutable no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "se accede al miembro %qD  en lugar del miembro inicializado %qD en la expresión constante"
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "falta el inicializador para el miembro %qD"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "deferenciando el puntero %<void *%>"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "se accede al valor de %qE a través de glvalue %qT en una expresión constante"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "el valor de %qD no se puede usar en una expresión constante"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "se usó %qD en su propio inicializador"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D no es const"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D es volatile"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD no se inicializó con una expresion constante"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD no se declaró %<constexpr%>"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "la profundidad de evaluación de constexpr excede el máximo de %d (use -fconstexpr-depth= para incrementar el máximo)"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "expression %qE is not a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "el elemento inicializador no es una expresión constante"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "expresión %qE inesperada de género %s"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT no puede ser el tipo de una expresión constante completa porque tiene sub-objetos mutables"
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversión del tipo puntero %qT al tipo aritmético %qT en una expresión constante"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "la expresión %qE tiene efectos colaterales"
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast no válido del tipo `%T' al tipo `%T'"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "la dirección de un objeto %qE con hilo local o almacenamiento automático no es una expresión constante"
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "la expresión id de tipo no es una expresión constante porque %qE es de tipo polimórfico"
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "temporal del tipo %qT que no es literal en una expresión constante"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F se declaró %<static%> pero nunca se define"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qE no se declaró aquí (no en una función)"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "miembro %qD sin inicializar en el constructor %<constexpr%>"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "la división entre cero no es una expresión constante"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "inicialización de una matriz que no es constante"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE no es una expresión constante"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "AST inesperado de género %s"
@@ -38687,7 +38760,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  salta la inicialización de %q+#D"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "salida no válida de un bloque estructurado OpenMP"
@@ -38702,7 +38775,7 @@
 msgid "%qD is not a type"
 msgstr "%qD no es un tipo"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "se usa %qD sin parámetros de plantilla"
@@ -40429,7 +40502,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "el parámetro se declaró %<auto%>"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "uso no válido del nombre-de-plantilla %qE sin una lista de argumentos"
@@ -40900,13 +40973,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD tiene el mismo nombre que la clase en la cual se declaró"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT no es una plantilla"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -40917,8 +40990,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la referencia a %qD es ambigua"
@@ -40971,7 +41044,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "no coinciden scoped/unscoped en el enum %q#T"
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "la definición previa está aquí"
@@ -41038,7 +41111,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> debe devolver una referencia a %<*this%>"
@@ -41054,7 +41127,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "no hay una declaración de devolución en la función que no devuelve void"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
@@ -41218,28 +41291,28 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "la anchura del campo de bits %qD es del tipo %qT que no integral"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a static data member of a class template"
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "struct anónimo no está dentro de un tipo nombrado"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "los agregados anónimos de alcance de espacio de nombres deben ser static"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "union anónima sin miembros"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> debe devolver el tipo %qT"
@@ -41248,71 +41321,71 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "el primer parámetro de %<operator new%> no puede tener un argumento por defecto"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> toma el tipo %<size_t%> (%qT) como primer argumento"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> debe devolver el tipo %qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> toma el tipo %qT como primer argumento"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT tiene un campo %qD cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT se declaró con mayor visibilidad que el tipo de su campo %qD"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT tiene una base %qT cuyo tipo usa el espacio de nombres anónimo"
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT se declaró con mayor visibilidad que su base %qT"
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -41322,52 +41395,52 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la variable %q#D sin enlace"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "se usó un tipo anónimo sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D no se refiere al tipo sin calificar, así que no se usa para el enlace"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, declarada usando el tipo local %qT, se usa pero nunca se define"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la variable %q#D con enlace"
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "se usó el tipo %qT sin enlace para declarar la función %q#D con enlace"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "se usa la función inline %q+D pero nunca se define"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "falta el argumento por defecto para el parámetro %P de %q+#D"
@@ -41374,12 +41447,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "se convierte lambda la cual usa %<...%> a un puntero de función"
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "se usó la función borrada %q+D"
@@ -41699,19 +41772,19 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "inicializador no válido para la matriz miembro %q#D"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "miembro const sin inicializar en %q#T"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
 msgid "%q#D should be initialized"
 msgstr "%qD se debe inicializar"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "miembro referencia sin inicializar en %q#T"
@@ -41813,7 +41886,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "la matriz se debe inicializar con un inicializador dentro de llaves"
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT no es un tipo de clase"
@@ -41833,7 +41906,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "uso no válido de la función miembro no static %qD"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "uso no válido del dato miembro no static %qD"
@@ -42042,23 +42115,23 @@
 msgid "because the array element type %qT has variable size"
 msgstr "la literal compuesta tiene tamaño variable"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "no se puede capturar %qE por referencia"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete type %q#T"
 msgid "capture by copy of incomplete type %qT"
 msgstr "uso no válido del tipo incompleto %q#T"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "ya se capturó %qD en la expresión lambda"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "no se capturó %<this%> para esta función lambda"
@@ -42113,121 +42186,121 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(si utiliza %<-fpermissive%>, G++ aceptará su código, pero permitir el uso de un nombre sin declarar es obsoleto)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "se decodifica typeof, utilice decltype en su lugar"
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "se decodifica __underlying_type"
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "se decodifica el tipo de coma fija desconocido"
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "decodificando %C"
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "se omitió el operando de enmedio de %<?%>: no se puede revolver el operando"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "literal de cadena en la firma de plantilla de función"
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "-fabi-version=6 (or =0) avoids this error with a change in mangling"
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (o =0) evita este error con un cambio en la decodificación"
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "el nombre revuelto de %qD cambiará en una versión futura de GCC"
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "el miembro const %q#D que no es static, no puede usar el operador de asignación por defecto"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "el miembro de referencia %q#D que no es static, no puede usar el operador de asignación por defecto"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr "se requirió primero el método sintetizado %qD aquí "
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "miembro union %q+D con %qD que no es trivial"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted constructor calls non-constexpr %q+D"
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "un constructor por defecto llama a %q+D que no es constexpr"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %q+#D is invalid"
 msgid "initializer for %q#D is invalid"
 msgstr "el inicializador para %q+#D es no válido"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted default constructor does not initialize %q+#D"
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "el constructor por defecto en efecto no inicializa %q+#D"
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "copying non-static data member %q#D of rvalue reference type"
@@ -42234,79 +42307,79 @@
 msgstr "el dato miembro que no es estático %qD tiene un tipo de clase Java"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "el constructor por defecto en efecto no inicializa ningún dato miembro que no es static"
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "un tipo de conclusión lambda tiene un constructor por defecto borrado"
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "un tipo de conclusión lambda tiene un operador de asignación por copia borrado"
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q+#D se declara implícitamente como deleted porque %qT declara un constructor move o un operador de asignación move"
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is implicitly deleted because the default definition would be ill-formed:"
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q+#D es implícitamente deleted por que la definición por defecto estaría mal formada:"
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "declaración definida por defecto %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr "no coincide la firma esperada %qD"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 #, fuzzy
 #| msgid "function %q+D defaulted on its first declaration with an exception-specification that differs from the implicit declaration %q#D"
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr "la función %q+D definida por defecto en su primera declaración tiene una excepción de especificación que difiere de la declaración implícita %q#D"
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr "la función %q+D explícitamente por defecto no se puede declarar como constexpr porque la declaración implícita no es constexpr:"
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "una plantilla no se puede definir por defecto"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD no se puede definir por defecto"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "función definida por defecto %q+D con argumento por defecto"
@@ -42506,97 +42579,97 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nombra al constructor en %qT"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "no hay miembros que coincidan con %<%T::%D%> en %q#T"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la declaración de %qD no está en un espacio de nombres alrededor de %qD"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "calificación explícita en la declaración de %qD"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %D"
 msgstr "%qE no se ha declarado"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a friend"
 msgstr "%q+D se declaró como friend"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD se debería declarar dentro de %qD"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "el atributo %qD no tiene signifcado porque los miembros del espacio de nombres anónimo tiene símbolos locales"
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "se descarta la directiva de atributo %qD"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "no se permite aquí el alias del espacio de nombres %qD, se asume que es %qD"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "Esta opción es obsoleta; utilice en su lugar -fsanitize-recover=."
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "el uso de strong solamente tiene significado en el ámbito de espacio de nombres"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "el espacio de nombres actual %qD no contiene al espacio de nombres %qD usado con frecuencia"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "límite máximo de %d espacios de nombres buscados para %qE"
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "suggested alternative:"
 #| msgid_plural "suggested alternatives:"
@@ -42603,7 +42676,7 @@
 msgid "suggested alternative: %qs"
 msgstr "alternativa sugerida:"
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -42610,28 +42683,28 @@
 msgstr[0] "alternativa sugerida:"
 msgstr[1] "alternativas sugeridas:"
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr "la búsqueda dependiente del argumento encuentra %q+D"
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX entrando a pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX saliendo de pop_everything ()\n"
@@ -42651,7 +42724,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -42676,7 +42749,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "solicitud por el miembro %qE en el tipo %qT que no es clase"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> no se ha declarado"
@@ -42736,698 +42809,698 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(tal vez falta un punto y coma después de la definición de %qT)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a template"
 msgid "%qE is not a class template"
 msgstr "%qE no es una plantilla"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE no es una plantilla"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "id-de-plantilla no válido"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 #| msgid "floating-point literal cannot appear in a constant-expression"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "una literal de coma flotante no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "una conversión a un tipo diferente de un tipo integral o de enumeración no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "el operador %<typeid%> no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "las literales compuestas que no son constantes no pueden aparecer en una expresión constante"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "una llamada a función no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "un incremento no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "un decremento no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "una referencia a matriz no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "la dirección de una etiqueta no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "las llamadas a operadores sobrecargados no pueden aparecer en una expresión constante"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "una asignación no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "un operador coma no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "una llamada a un constructor no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "una expresión de transacción no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%qs no puede aparecer en una expresión constante"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "uso no válido del destructor %qD como un tipo"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "combinación no válida de especificadores de tipo múltiples"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE no nombra a un tipo"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE no nombra a un tipo"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<concept%> only available with -fconcepts"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(tal vez intentó %<typename %T::%E%>)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in namespace %qE does not name a type"
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE en el espacio de nombres %qE no nombra un tipo"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE en el espacio de nombres %qE no nombra un tipo"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%E%> nombra el constructor, no el tipo"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "y %qT no tiene constructores de plantilla"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr "se necesita %<typename%> antes de %<%T::%E%> porque %qT es un ámbito dependiente"
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in %q#T does not name a type"
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE en %q#T no nombra un tipo"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE en %q#T no nombra un tipo"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr "se esperaba una cadena literal"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr "los sufijos de literal %qD y %qD definidos por el usuario son inconsistentes en la cadena literal"
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr "una cadena ancha es no válida en este contexto"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr "no se puede encontrar el operador de carácter literal %qD con argumento %qT"
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "integer literal exceeds range of %qT type"
 msgstr "la constante de coma flotante excede el rango de %qT"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "floating literal exceeds range of %qT type"
 msgstr "la constante de coma flotante excede el rango de %qT"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant truncated to zero"
 msgid "floating literal truncated to zero"
 msgstr "se truncó la constante de coma flotante a cero"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr "no se puede encontrar un operador literal numérico %qD"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "no se puede encontrar un operador literal de cadena %qD con argumentos %qT, %qT"
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "se esperaba una declaración"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "expected operator"
 msgid "expected binary operator"
 msgstr "operador inesperado"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<...%>"
 msgid "expected ..."
 msgstr "se esperaba %<...%>."
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "binary expression in operand of fold-expression"
 msgstr "se trata la lista de expresiones como una expresión compuesta %s"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "conditional expression not allowed inside parentheses"
 msgid "conditional expression in operand of fold-expression"
 msgstr "no se permiten expresiones condicionales dentro de paréntesis"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in vector shift expression"
 msgid "mismatched operator in fold-expression"
 msgstr "los tipos de datos no coinciden en la expresión shift de vector"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "no se admiten tipos de coma fija en C++"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ prohíbe grupos de llaves dentro de expresiones"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "las expresiones-de-declaraciones no se permiten fuera de funciones ni en listas de argumentos-plantilla"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "se esperaba una expresión primaria"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "no se puede usar %<this%> en este contexto"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "una declaración de plantilla no puede aparecer en el ámbito de bloque"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "la variable local %qD no puede aparecer en este contexto"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "se esperaba una expresión id"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "el ámbito %qT antes de %<~%> no es un nombre-de-clase"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "declaración de %<~%T%> como miembro de %qT"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "se usa el nombre-de-definición-de-tipo %qD como un declarador de destructor"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "los sufijos de operador literal que no están precedidos por %<_%> están reservados para estandarización futura"
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "se esperaba un id sin calificar"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "se encontró %<:%> en un especificador de nombre anidado, se esperaba %<::%>"
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "el tipo de declaración evalúa a %qT, el cual no es una clase o un tipo enumerado"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "se utilizó el tipo incompleto %qT en un especificador de nombre anidado"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 #| msgid "expected nested-name-specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "se esperaban especificadores de nombre anidados"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD no es una plantilla"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "se esperaban especificadores de nombre anidados"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "los tipos no se pueden definir en conversiones"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "no se pueden definir tipos en una expresión %<typeid%>"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "número erróneo de argumentos para %<__builtin_shuffle%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "número erróneo de argumentos para %<__builtin_complex%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ prohíbe las literales compuestas"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "braced list index is not allowed with array notation"
 msgstr "no se permite -client_name con -dynamiclib"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "uso no válido de %qD"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> no es un miembro clase"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "tipo que no es escalar"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ no permite %<alignof%> con algo que no es tipo"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<noexcept%>"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "no se pueden definir tipos en una expresión new"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "se prohíbe el límite de matriz después del id-de-tipo entre paréntesis"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "intente borrar los paréntesis alrededor del id-de-tipo"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Se esperaba un tipo de expresión"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "no se pueden definir tipos en un id-tipo-nuevo"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "la expresión en el declarador-new debe tener un tipo integral o de enumeración"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "uso de conversión de estilo antiguo"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "el operador %<>>%> se tratará como dos en llaves en ángulo derechas en C++11"
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "se sugieren paréntesis alrededor de la expresión %<>>%>"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ no permite ?: con el operando medio omitido"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "expresión lambda en un contexto sin evaluar"
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in unevaluated context"
 msgid "lambda-expression in template-argument"
 msgstr "expresión lambda en un contexto sin evaluar"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "se esperaba el fin de la lista-de-captura"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "la captura por copia explícita de %<this%> es redundante con la captura por copia por defecto"
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer for lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "captura de %qD que no es variable "
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here"
 msgstr "%q+#D se declaró aquí"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "captura de la variable %qD con duración de almacenamiento que no es automática"
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "la captura por copia explícita de %qD es redundante con la captura por copia por defecto"
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "la captura por referencia explícita de %qD es redundate con la captura por referencia por defecto"
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "las plantillas variadic sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C90 no admite tipos complejos"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "se especificó un argumento por defecto para el parámetro lambda"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "%<volatile%> duplicado"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "se esperaba una declaración etiquetada"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "la etiqueta case %qE no está dentro de una declaración switch"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "se necesita %<typename%> antes de %qE porque %qT es un ámbito dependiente"
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nombra el constructor, no el tipo"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr "declaración compuesta en una función constexpr"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "%<constexpr%> de C++11 sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "se esperaba una declaración de selección"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "no se pueden definir tipos en condiciones"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "la expresión %<for%> basada en rango de tipo %qT es de tipo incompleto"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr "la expresión %<for%> basada en rango de tipo %qT tiene un miembro %<end%> pero no tiene %<begin%>"
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr "la expresión %<for%> basada en rango de tipo %qT tiene un miembro %<begin%> pero no tiene %<end%>"
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "tipos begin/end inconsistentes para la declaración %<for%> basada en rango: %qT y %qT"
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "se esperaba una declaración de iteración"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "las uniones sin restricción sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 #| msgid "break statement used with OpenMP for loop"
 msgid "break statement used with Cilk Plus for loop"
 msgstr "se usó la declaración break en un bucle for de OpenMP"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<goto%> in %<constexpr%> function"
@@ -43434,72 +43507,78 @@
 msgstr "declaración compuesta en una función constexpr"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ prohíbe los gotos calculados"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "se esperaba una declaración de salto"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "<;%> extra"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label%> no está al inicio de un bloque"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "se prohíbe mezclar declaraciones y definiciones-de-función"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in range-based for loops"
 msgid "initializer in range-based %<for%> loop"
 msgstr "no se pueden definir tipos en bucles for basados en rango"
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "declaraciones múltiples `%T' y `%T'"
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "declaración vacía"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+#| msgid "invalid initializer for bit string"
+msgid "invalid initializer for structured binding declaration"
+msgstr "inicializador no válido para la cadena de bits"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "se usó %<friend%> fuera de la clase"
@@ -43506,502 +43585,502 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> cambiará su significado en C++11; por favor bórrelo"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "especificador-decl no válido en la condición"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 #| msgid "%qD invalid in %qT"
 msgid "%qD invalid in lambda"
 msgstr "%qD no válido en %qT"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la definición de clase no se puede declarar como friend"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "las plantillas no pueden ser %<virtual%>"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "especificación de enlace no válida"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "no se pueden definir tipos en expresiones %<decltype%>"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-type-id"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "no se pueden definir tipos en un id-tipo-nuevo"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "solamente los constructores toman inicializadores miembro"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "no se puede expandir el inicializador para el miembro %<%D%>"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "inicializador mem para %qD después de una delegación de constructor"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "delegación de constructor después de un inicializador mem para %qD"
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "inicializador de clase base de estilo antiguo anacrónico"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (un inicializador de miembro calificado es implícitamente un tipo)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, fuzzy, gcc-internal-format
 #| msgid "missing space between %<\"\"%> and suffix identifier"
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "falta un espacio entre %<\"\"%> y el identificador sufijo"
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "se esperaba un identificador sufijo"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "se esperaba una cadena vacía después de la palabra clave %<operator%>"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in ternary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operandos no válidos en la operación terniaria"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operador inesperado"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "no se admite la palabra clave %<export%>, y se descartará"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "invalid constrained type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "parámetro de captura no válido"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros plantilla %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "los paquetes de parámetro de plantilla no pueden tener argumentos por defecto"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "se esperaba un id de plantilla"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> no puede iniciar una lista de argumentos de plantilla"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> es una forma alternativa para %<[%>. Inserte espacios en blanco entre %<<%> y %<::%>"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si utiliza %<-fpermissive%>, G++ aceptará su código)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "error de decodificación en la lista de argumentos de plantilla"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "se esperaba un nombre de plantilla"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilice %<%T::template %D%> para indicar que es una plantilla"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "se esperaba un argumento de plantilla"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argumento de plantilla que no es tipo no válido"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<inline%>"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "la instanciación explícita no debe usar el especificador %<constexpr%>"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "especialización de plantilla con enlace C"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "se esperaba un specificador de tipo"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "las funciones por defecto y borradas sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C prohíbe declaraciones adelantadas de parámetros"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "se esperaba un id de plantilla para el tipo"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "se esperaba un nombre de tipo"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "el especificador de tipo elaborado para un ámbito enumerado no debe usar la palabra clave %<%D%>"
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la declaración %qD no declara nada"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "se descartan los atributos en el tipo sin instanciar"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "se descartan los atributos en la instanciación de una plantilla"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "se descartan los atributos en un especificador de tipo elaborado que no es una declaración adelantada"
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD es una plantilla de enumeración"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD no tiene tipo integral o de enumeración"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "se esperaba %<;%> o %<{%>"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "no se puede agregar una lista de enumerador a una instanciación de plantilla"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "la declaración de %qD en el espacio de nombres %qD el cual no incluye a %qD"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "la declaración de %qD en %qD la cual no incluye a %qD"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "no se permite la calificación extra"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "definición múltiple de %q#T"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ prohíbe incrementar un enum"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "especificador enumerador opaco sin nombre"
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "el especificador enumerador opaco debe usar un identificador simple"
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD no es un nombre-de-espacio-de-nombres"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "se esperaba un nombre de espacio"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "El enumerador no puede tener atributos %C"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "los nombres de espacio incluidos en línea sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "varargs function cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "la función varargs no puede ser inline"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "nested identifier required"
 msgstr "se esperaba un identificador"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 #| msgid "namespace %qT undeclared"
 msgid "namespace %qD entered"
 msgstr "espacio de nombres %qT sin declarar"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la definición %<namespace%> no se permite aquí"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un id-de-plantilla no puede aparecer en una declaración-using"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "las expresiones lambda sólo están disponibles con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "las declaraciones access son obsoletas en favor de las declaraciones using: sugerencia: use la palabra clave %<using%>"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "no se pueden definir tipos en declaraciones de plantilla alias"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "declaración compuesta en una función constexpr"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "una definición de función no se permite aquí"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "no se permite una especificación-asm en una definición-de-función"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "no se permiten atributos en una definición-de-función"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "se esperaba un constructor, un destructor, o una conversión de tipo"
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "se esperaba un inicializador"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "se proporcionó un inicializador para la función"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "se descartan los atributos después del inicializador entre paréntesis"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "se redeclara la función %q+D como inline"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "el límite de la matriz no es una constante entera"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "no se puede definir el miembro de la definición de tipo dependiente %qT"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> no es un tipo"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "uso no válido del constructor como una plantilla"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "use %<%T::%D%> en lugar de %<%T::%D%> para nombrar el constructor en un nombre calificado"
@@ -44010,7 +44089,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "declarador no válido"
@@ -44017,354 +44096,356 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "qualified-id in declaration"
 msgstr "tipo no válido en la declaración"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "se esperaba un declarador"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD es un espacio de nombres"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "no se puede formar un puntero al miembro de %q#T que no es clase"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "se esperaba un operador puntero"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "calificador-cv duplicado"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "especificadores `virtual' múltiples"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "especificador-virt duplicado"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments after %qT"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "uso no válido de %qT"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "no se pueden definir tipos en argumentos de plantilla"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of '%E' as a non-type template-argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "uso no válido de '%E' como un argumento de plantilla que no es tipo"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "se esperaba un especificador de tipo"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "se esperaba %<,%> o %<...%>"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "no se pueden definir tipos en tipos de parámetro"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "los argumentos por defecto sólo se permiten para parámetros de función"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "el paquete de parámetros %qD no puede tener un argumento por defecto"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros plantilla no puede tener un argumento por defecto"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "el paquete de parámetros no puede tener un argumento por defecto"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ no permite inicializadores designados"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ no permite inicializadores designados de C99"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "se esperaba un nombre de clase"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "se esperaba %<;%> después de la definición de clase"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "se esperaba %<;%> después de la definición de struct"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "se esperaba %<;%> después de la definición de union"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "se esperaba %<{%> o %<:%>"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "no se puede especificar %<override%> para una clase"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la calificación global del nombre de clase es no válida"
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "el nombre calificado no nombra una clase"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nombre de clase no válido en la declaración de %qD"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "una especialización explícita se debe preceder con %<template <>%>"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "la plantilla de función %qD se redeclaró commo una plantilla de clase"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "no se puede resolver el tipo typename"
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "definición previa de %q+#T"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "se esperaba una llave de clase"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03 se debe usar una llave-clase cuando se declara un friend"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la declaración friend no nombra una clase o función"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "especificador-pure en la definición-de-función"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "se esperaba %<;%> al final de la declaración miembro"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "especificador pure no válido (sólo se permite %<= 0%>)"
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "un inicializador dentro de llaves no se permite aquí"
 
-#: cp/parser.c:23680
-#, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+#: cp/parser.c:23703
+#, fuzzy, gcc-internal-format
+#| msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "se especificó %<virtual%> más de una vez en la base especificada"
 
-#: cp/parser.c:23700
-#, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+#: cp/parser.c:23723
+#, fuzzy, gcc-internal-format
+#| msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr "más de un especificador de acceso en la base especificada"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "no se permite la palabra clave %<typename%> fuera de las plantillas"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "no se permite la palabra clave %<typename%> en este contexto (la clase base es implícitamente un tipo)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "no se pueden definir tipos en una especificación de excepción"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "debido a diferentes especificaciones de excepciones"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, fuzzy, gcc-internal-format
 #| msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "las especificaciones de excepción dinámicas son obsoletas en C++0x; utilice %<noexcept%> en su lugar"
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "uso no válido de %<auto%> en el operador de conversión"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not %<constexpr%>"
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%qD no es %<constexpr%>"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "no se pueden definir tipos en declaraciones de excepción"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "El atributo %qE genera un conflicto con el atributo %s"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "se esperaba un identificador o %<(%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "se esperaba el parámetro pack antes de %<...%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++0x automático sólo está disponible con -std=c++11 o -std=gnu++11"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, fuzzy, gcc-internal-format
 #| msgid "%<@required%> is not available in Objective-C 1.0"
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<@required%> no está disponible en Objective-C 1.0"
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, fuzzy, gcc-internal-format
 #| msgid "a transaction expression cannot appear in a constant-expression"
 msgid "a requires expression cannot appear outside a template"
 msgstr "una expresión de transacción no puede aparecer en una expresión constante"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "el miembro especializado %<%T::%E%> requiere sintaxis %<template<>%>"
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "declaración no válida de %<%T::%E%>"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "faltan listas-de-parámetros-de-plantilla"
@@ -44373,438 +44454,438 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "demasiadas listas-de-parámetros-de-plantilla"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "ya no se admiten los valores de devolución nombrados"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "la plantilla de operador literal %qD tiene una lista de parámetros no válida.  Se esperaba un paquete de argumentos de plantilla que no sean de tipo <char...>"
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "Activa las instrucciones multiply"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "declaración no válida de plantilla miembro en la clase local"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "plantilla con enlace C"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "especialización explícita no válida"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "declaración plantilla de %<typedef%>"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "la declaración no declara nada"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "la especialización de plantilla explícita no puede tener una clase de almacenamiento"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> debe ser %<> >%> dentro de una lista de argumentos de plantilla anidada"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%<>>%> sobrante, use %<>%> para terminar una lista de argumentos de plantilla"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "uso no válido de %qD en la especificación de enlace"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> antes de %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 no admite %<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "se usaron al mismo tiempo %<_Sat%> y %<char%> en los especificadores de declaración"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE duplicado"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs duplicado"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "se esperaba %<new%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "se esperaba %<delete%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "se esperaba %<return%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "se esperaba %<extern%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "se esperaba %<static_assert%>"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "se esperaba %<decltype%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "se esperaba %<operator%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "se esperaba %<class%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "se esperaba %<template%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "se esperaba %<namespace%>"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "se esperaba %<using%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "se esperaba %<asm%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "se esperaba %<try%>"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "se esperaba %<catch%>"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "se esperaba %<throw%>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "se esperaba %<__label__%>"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "se esperaba %<@try%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "se esperaba %<@synchronized%>"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "se esperaba %<@throw%>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "se esperaba %<__transaction_atomic%>"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "se esperaba %<__transaction_relaxed%>"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "se esperaba %<::%>"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "se esperaba %<...%>"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "se esperaba %<*%>"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "se esperaba %<~%>"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "se esperaba %<:%> o %<::%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "se esperaba %<class%>, %<typename%> o %<template%>"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "se usó la etiqueta %qs al nombrar a %q#T"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T se declaró previamente aquí"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD se redeclaró con acceso diferente"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (como desambiguador) sólo se permite dentro de plantillas"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "el fichero termina en el argumento por defecto"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construct Objective-C++ %<@%D%> mal ubicado"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "se esperaba(n) argumento(s) de mensaje de objective-c++"
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> debe especificar un tipo como un argumento"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nombre de selector Objective-C++ no válido"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "se esperaba una declaración de método de objective-c++"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "los atributos de método se deben especificar al final"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs sobrante después de los métodos Objective-C++"
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "tipo no válido para la variable de de instancia"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "se esperaba un identificador después de %<@protocol%>"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "los atributos no se pueden especificar antes de la palabra clave de Objective-C++ %<@%D%>"
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "se descartan los atributos de prefijo antes de %<@%D%>"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "tipo no válido para la propiedad"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%> en OpenMP"
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "no se permite la inicialización entre paréntesis para el bucle %<for%> en OpenMP"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable de iteración %qD no debe ser reduction"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "no hay suficientes bucles DO para los !$OMP DO colapsados en %L"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "no se permiten atributos en una definición-de-función"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "inicializador no válido"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "se esperaba una expresión id"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "no se pueden definir tipos nuevos en un tipo de devolución"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -44811,73 +44892,73 @@
 msgstr "%qD no es una función plantilla miembro"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sin activar el soporte de memoria transaccional"
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "basura al final de %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "restricciones no válidas para el operando"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "no se permite #pragma GCC optimize dentro de funciones"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "no se han implementado las optimizaciones intermódulos para C++"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "se esperaba un nombre variable en %C"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "se esperaba %<,%> o %<)%>"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
@@ -44973,7 +45054,7 @@
 msgid "candidate is: %#D"
 msgstr "el candidato es: %+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
@@ -45585,126 +45666,144 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+#| msgid "  variable-sized array type %qT is not a valid template argument"
+msgid "the address of %qD is not a valid template argument"
+msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+#| msgid "  variable-sized array type %qT is not a valid template argument"
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "  el tipo matriz de tamaño variable %qT no es un argumento de plantilla válido"
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+#| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%qE no es un argumento válido de plantilla de tipo %qT porque %qD no tiene enlace externo"
+
+#: cp/pt.c:6672
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT debido a conflictos en la calificación cv"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un l-valor"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D no es un argumento válido de plantilla para el tipo %qT porque una referencia variable no tiene una dirección constante"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque no es un objeto con enlace externo"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE no es un argumento válido de plantilla para el tipo %qT porque el objeto %qD no tiene enlace externo"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es un puntero"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "intente utilizar %qE en su lugar"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE no es un argumento de plantilla válido para el tipo %qT porque es de tipo %qT"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "no se permiten las conversiones estándar en este contexto"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attributes in template argument %qE"
 msgstr "se descartan los atributos en el argumento de plantilla %qT"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "se usó el nombre-de-clase-inyectada %qD como un argumento de plantilla plantilla"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "uso no válido del destructor %qE como un tipo"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "para hacer referencia a un tipo miembro de un parámetro de plantilla, use %<typename %E%>"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  se esperaba una constante de tipo %qT, se obtuvo %qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  se esperaba un tipo, se obtuvo %qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  se esperaba un tipo, se obtuvo %qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  se esperaba una plantilla de clase, se obtuvo %qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  se esperaba una plantilla de tipo %qD, se obtuvo %qT"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "no coincide el tipo/valor en el argumento %d en la lista de parámetros de plantilla para %qD"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
@@ -45712,110 +45811,110 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "los tipos no coinciden en el parámetro pack que no es de tipo"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "no se puede convertir el argumento de plantilla %qE a %qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "el argumento de plantilla %d es no válido"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "número erróneo de argumentos de plantilla (%d, debe ser %d)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "provisto por %q+D"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argumento por defecto para el parámetro de plantilla para la clase incluyente %qD"
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumento por defecto dado para el parámetro %d de %q#D"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "provisto por %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D no es una plantilla de función"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "se usa el tipo %qT que no es plantilla como una plantilla"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "para la declaración de plantilla %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "falla interna de consistencia"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d (use -ftemplate-depth= para incrementar el máximo) al sustituir %qS"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%T%>"
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "no coinciden las longitudes de los paquetes de argumentos al expandir %<%E%>"
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -45834,280 +45933,280 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD tiene tipo de función"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipo de parámetro %qT no válido"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "en la declaración %q+D"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "la función devuelve una matriz"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "la función devuelve una función"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "se crea un puntero a función miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "se forma la referencia a void"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "se forma un puntero para referenciar al tipo %qT"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "se forma una referencia para referenciar al tipo %qT"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "no se puede declarar el puntero para el tipo de función calificado %qT"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "no se puede declarar la referencia para el tipo de función calificado %qT"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "se crea un puntero al miembro del tipo %qT que no es clase"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "se crea un puntero al miembro de referencia de tipo %qT"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "se crea un puntero al miembro de tipo void"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "se crea la matriz de %qT"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT no es de tipo clase, struct o union"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo enumerado"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT resuelve a %qT, el cual no es un tipo de clase"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "inicializador no-vacío para una matriz de elementos vacíos"
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "uso de %qs en la plantilla"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificador %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "el nombre dependiente %qE se decodifica como un no tipo, pero la instanciación genera un tipo"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "escriba %<typename %E%> si quiere un tipo"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "se usa el campo no válido %qD"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "uso no válido de la expresión de expansión de paquete"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "use %<...%> para expandir el paquete de argumentos"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD no se declaró en este ámbito, y no se encontraron declaraciones en la búsqueda dependiente de argumentos en el punto de la instanciación"
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "no se encontraron declaraciones en la base dependiente %qT pur la búsqueda no calificada"
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "use %<this->%D%> en su lugar"
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "use %<%T::%D%> en su lugar"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D se declaró aquí, después en la unidad de translación"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT no es una clase o un espacio de nombres"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD no es una clase o un espacio de nombres"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT es/usa un tipo anónimo"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "el argumento de plantilla para %qD usa el tipo local %qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT es un tipo modificado variablemente"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "la expresión integral %qE no es una constante"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  se trata de instanciar %qD"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciación de plantilla clase ambigua para %q#T"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciación explícita de %q#D que no es plantilla"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD no es un dato miembro static de una plantilla de clase"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "no se encontró una plantilla coincidente para %qD"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "el tipo %qT para la instanciación explícita %qD no coincide con el tipo declarado %qT"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciación explícita de %q#D"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciación explícita duplicada de %q#D"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 prohíbe el uso de %<extern%> en instanciaciones explícitas"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "clase de almacenamiento %qD aplicada a la instanciación de una plantilla"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciación explícita de la plantilla %qD que no es clase"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciación explícita del tipo %qT que no es plantilla"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciación explícita de %q#T antes de la definición de la plantilla"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ prohíbe el uso de %qE en las instanciaciones explícitas"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciación explícita duplicada de %q#T"
@@ -46119,98 +46218,98 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciación explícita de %qD pero no hay una definición disponible"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profundidad de instanciación de la plantilla excede el máximo de %d al instanciar %q+D, posiblemente de la generación de tabla virtual (use -ftemplate-depth= para incrementar el máximo)"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "parámetro que no es tipo plantilla no válido"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T no es un tipo válido para un parámetro que no es tipo plantilla"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "la deducción de una lista inicializadora encerrada entre llaves requiere #include <initializer_list>"
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "se usó %qD que no es plantilla como plantilla"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction failed:"
 msgstr "  falló la deducción/sustitución del argumento de plantilla:"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "la función no se consideró para la inclusión en línea"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "no se puede deducir %qT de %qE"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "la insn no satisface sus restricciones:"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -46373,504 +46472,504 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  ya que se declaró %q+#D en la clase base"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "se sugieren llaves explícitas alrededor del cuerpo vacío en la declaración %<do%>"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "no se puede determinar el tipo del operando asm %qE"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "las declaraciones __label__ sólo se permiten en ámbitos de función"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "uso no válido del miembro %q+D en la función miembro static"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "no se permiten argumentos para el destructor"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> no está disponible para funciones miembro static"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "uso no válido de %<this%> en la función que no es miembro"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "uso no válido de %<this%> en el nivel principal"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ámbito calificador no válido en el nombre del seudo-destructor"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "el tipo calificado %qT no coincide con el nombre del destructor ~%qT"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE no es de tipo %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "la literal compuesta del tipo %qT que no es objeto"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "los parámetros de tipo plantilla debe usar la palabra clave %<class%> o %<typename%>"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "uso no válido del tipo %qT como un valor por defecto para una plantilla de parámetro de plantilla"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argumento por defecto no válido para una plantilla de parámetro de plantilla"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "la definición de %q#T dentro de la lista de parámetros de plantilla"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "definición no válida del tipo calificado %qT"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "especificación de clase base no válida"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "miembro protegido %q+#D en union anónima"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD no se capturó"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "uso de la variable %<auto%> desde la función contenedora"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "uso de parámetro desde la función contenedora"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter %qD outside function body"
 msgid "use of parameter outside function body"
 msgstr "se usó el parámetro %qD fuera del cuerpo de la función"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments"
 msgstr "en el argumento de plantilla para el tipo %qT "
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "no se permite el parámetro de plantilla %qD de tipo %qT en una expresión integral constante porque no es de tipo integral o de enumeración"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "uso del espacio de nombres %qD como expresión"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "uso de la plantilla de clase %qT como expresión"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "la petición por el miembro %qD es ambigua en la red de herencia múltiple"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD no puede aparecer en una expresion constante"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "el tipo de %qE es desconocido"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT no es un tipo de enumeración"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Los paquetes de parámetros __bases sólo son válidos en la declaración de plantilla"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "no se puede aplicar %<offsetof%> al destructor %<~%T%>"
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "no se puede aplicar %<offsetof%> a la función miembro %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la referencia a %qD es ambigua"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE tiene tipo no válido para %<reduction%>"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD no es una variable en la cláusula %<firstprivate%>"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD no es una variable en la cláusula %<lastprivate%>"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hel argumento de collapse necesita ser una expresión entera constante positiva"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<device%> id must be integral"
 msgstr "el final de la rebanada debe ser entero"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD aparece más de una vez en las cláusulas de datos"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "la expresión schedule chunk size debe ser integral"
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD no es una variable en la cláusula %qs"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "demasiadas cláusulas %qs"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "la expresión num_threads debe ser integral"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "el tipo de vector delete no es del tipo puntero ni matriz"
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "el valor de %<num_threads%> debe ser positivo"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD no es un fichero, espacio de nombres o variable de ámbito de bloque"
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directiva %<threadprivate%> %qE no está en la definición %qT"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la diferencia entre %qE y %qD no tiene tipo entero"
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> usa dos variables diferentes para la memoria"
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "falló la aserción estática: %E"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "falló la aserción estática: %s"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condición que no es constante para una aserción estática"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "el argumento para decltype debe ser una expresión"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "el tipo de declaración no puede resolver la dirección de la función sobrecargada"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 #| msgid "third operand of conditional expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "el tercer operando de la expresión condicional no tiene efecto"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "el argumento de plantilla %qE involucra a el(los) parámetro(s) de plantilla"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -46887,121 +46986,121 @@
 msgid "lambda-expression in a constant expression"
 msgstr "la expresión %qE no es una expresión constante"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "se descarta el atributo %qE en tipos"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "el atributo %qE sólo se puede aplicar a definiciones de clase"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "la init_priority solicitada no es una constante entera"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "solo se puede usar el atributo %qE en definiciones de rango de fichero de objetos de tipo class"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "la init_priority solicitada está fuera de rango"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "la init_priority solicitada está reservada para uso interno"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "el atributo %qE no se admite en esta plataforma"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "declaración de %qD como miembro de %qT"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "el atributo %qD requiere un solo argumento NTBS"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "el argumento del atributo %qE no es una cadena constante"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 #| msgid "%.*s is not a valid universal character"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%.*s no es un carácter universal válido"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> no es un declarador válido"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "se descarta el atributo %qE en tipos que no son clases"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "se descartan los atributos aplicados al %qT después de la definición"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "el atributo %qE se aplica solamente a funciones, no a %s"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "El atributo %s se aplica a %s %s en %L"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "cero como constante de puntero nulo"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "revisión lang_*: falló en %s, en %s:%d"
@@ -47700,107 +47799,107 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversión no válida del tipo %qT a partir del tipo %qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "no se puede convertir %qT a %qT para el argumento %qP para %qD"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "no se puede convertir %qT a %qT en el argumento por defecto"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "no se puede convertir %qT a %qT en el paso de argumentos"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "no se puede convertir %qT a %qT"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "no se puede convertir %qT a %qT en la inicialización"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "no se puede convertir %qT a %qT en la devolución"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "no se puede convertir %qT a %qT en la asignación"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "el tipo de devolución %q#T es un tipo de dato incompleto"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "el parámetro %qP de %qD puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "el parámetro puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "el objetivo de conversión puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "el objetivo de inicialización puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "el lado izquierdo de la asignación puede ser un candidato para un atributo de formato"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "al pasar el argumento %P de %q+D"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "se devuelve la referencia al temporal"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "se devolvió una referencia a un valor que no es l-valor"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "se devolvió una referencia a la variable local %q+D"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "se devolvió la dirección de la variable local %q+D"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "se devuelve un valor de un destructor"
@@ -47807,57 +47906,57 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "no se puede regresar de un manejador de una función-intenta-bloque de un constructor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "se devuelve un valor de un constructor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "declaración return sin valores, en una función que devuelve %qT"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 #| msgid "<brace-enclosed initializer list>"
 msgid "returning initializer list"
 msgstr "<lista inicializador dentro de llaves>"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "se deducen los tipos inconsistentes %qT y %qT para el tipo de devolución lambda"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "deducción inconsistente para %qT: %qT y después %qT"
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "declaración return con un valor, en una función que devuelve 'void'"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> no debe regresar NULL a menos que se declare %<throw()%> (o -fcheck-new esté en efecto)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "se usa el temporal como l-valor"
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "se usa xvalue (referencia a r-valor) como l-valor"
@@ -52205,99 +52304,99 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "El objetivo de inicialización de puntero a procedimiento en %L tal vez no es un puntero a procedimiento"
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Funciones puntero en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Expresión que no es variable en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in variable definition context (%s) at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "'%s' en el contexto de definición variable (%s) en %L no es una variable"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Uno que no es POINTER en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Constante nombrada '%s' en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE en el contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in pointer association context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in variable definition context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Argumento dummy '%s' con INTENT(IN) en el contexto de definición de variable (%s) en %L"
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de asociación de puntero (%s) en %L"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "La variable '%s' es PROTECTED y no puede aparecer en un contexto de definición variable (%s) en %L"
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "La variable '%s' no puede aparecer en un contexto de definición variable (%s) en %L en el procedimiento PURE"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado al objetivo con índice vectorial en un contexto de definición variable (%s)"
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "No se puede usar '%s' en %L asociado a una expresión en un contexto de definición variable (%s)"
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "El nombre asociado '%s' no puede aparecer en un contexto de definición variable (%s) en %L porque su obtetivo en %L tampoco puede aparecer"
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
@@ -52500,12 +52599,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la asignación definida en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "El primer argumento de la interfaz de operador en %L debe ser INTENT(IN)"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "El segundo argumento de la interfaz de operador en %L debe ser INTENT(IN)"
@@ -53403,545 +53502,563 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "Fortran 2003: no se permite el especificador de formato DP en %C"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: X descriptor requires leading space count at %L"
 msgid "X descriptor requires leading space count at %L"
 msgstr "Extensión: El descriptor X requiere una cuenta de espacios iniciales en %L"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: $ descriptor at %L"
 msgid "$ descriptor at %L"
 msgstr "Extensión: Descriptor $ en %L"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ debe ser el último especificador del formato en %L"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %L"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Extensión: Falta una anchura positiva después del descriptor L en %L"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %L"
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Extensión: Falta una anchura positiva después del descriptor L en %L"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %L"
 msgid "%<G0%> in format at %L"
 msgstr "%s en la cadena de formato en %L"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr "Se requiere anchura positiva en el especificador de formato %s en %L"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "Se requiere un punto en el especificador de formato %s en %L"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "Se requiere un punto en el especificador de formato en %L"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr "El especificador de formato H en %L es una característica eliminada de Fortran 95"
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing comma at %L"
 msgid "Missing comma at %L"
 msgstr "Extensión: Falta una coma en %L"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s en la cadena de formato en %L"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr "Caracteres ajenos el formato en %L"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr "Declaración de formato en el módulo bloque principal en %C"
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un INTERFACE"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Falta la etiqueta de formato en %C"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "Valor no válido para la especificación %s en %C"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "Especificación %s duplicada en %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "La variable %s no puede ser INTENT(IN) en %C"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "La variable %s no se puede asignar en el procedimiento PURE en %C"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "Especifición de etiqueta %s duplicada en %C"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "La expresión constante en la etiqueta FORMAT en %L debe ser del tipo por defecto CHARACTER"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "La etiqueta FORMAT en %L debe ser de tipo con género por defecto CHARACTER o INTEGER"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: ASSIGNED variable in FORMAT tag at %L"
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "Característica eliminada: Variable ASSIGNED en la etiqueta FORMAT en %L"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L has not been assigned a format label"
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "No se ha asignado una etiqueta de formato a la variable '%s' en %L"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar '%s' in FORMAT tag at %L is not an ASSIGNED variable"
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr "El escalar '%s' en la etiqueta FORMAT en %L no es una variable ASSIGNED"
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Non-character in FORMAT tag at %L"
 msgid "Non-character in FORMAT tag at %L"
 msgstr "Extensión: Elemento que no es carácter en la etiqueta FORMAT en %L"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "Elemento de matriz de forma asumida que no es carácter en la etiqueta FORMAT en %L"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "Elemento de matriz de tamaño asumido que no es carácter en la etiqueta FORMAT en %L"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "Elemento de matriz de puntero que no es carácter en la etiqueta FORMAT en %L"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "La etiqueta %s en %L debe ser de tipo %s"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "La etiqueta %s en %L debe ser una cadena de caracteres del género por defecto"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "La etiqueta %s en %L debe ser escalar"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: IOMSG tag at %L"
 msgid "IOMSG tag at %L"
 msgstr "Fortran 2003: Etiqueta IOMSG en %L"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Fortran 95 requiere un INTEGER por defecto en la etiqueta %s en %L"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Nondefault LOGICAL in %s tag at %L"
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr "Fortran 2008: LOGICAL que no es por defecto en la etiqueta %s en %L"
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT not specified at %L"
 msgid "NEWUNIT specifier at %L"
 msgstr "No se especificó UNIT en %L"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: CONVERT tag at %L"
 msgid "CONVERT tag at %L"
 msgstr "Extensión: etiqueta CONVERT en %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: %s specifier in %s statement at %C has value '%s'"
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Fortran 2003: el especificador %s en la declaración %s en %C tiene el valor '%s'"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 #| msgid "%s specifier in %s statement at %C has invalid value '%s'"
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "El especificador %s en la declaración %s en %C tiene el valor no válido '%s'"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: %s specifier in %s statement at %C has value '%s'"
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "Extensión: el especificador %s en la declaración %s en %C tiene el valor '%s'"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "%s specifier in %s statement at %C has invalid value '%s'"
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "El especificador %s en la declaración %s en %C tiene el valor no válido '%s'"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "No se permite una declaración OPEN en el procedimiento PURE en %C"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr "No se permite el especificador UNIT con NEWUNIT en %C"
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr "El especificador NEWUNIT debe tener FILE= o STATUS='scratch' en %C"
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "La declaración OPEN en %C debe tener especificado UNIT o NEWUNIT"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite ASYNCHRONOUS= en %C en Fortran 95"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite BLANK= en %C en Fortran 95"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite DECIMAL= en %C en Fortran 95"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENCODING= at %C not allowed in Fortran 95"
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite ENCODING= en %C en Fortran 95"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ROUND= at %C not allowed in Fortran 95"
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: No se permite ROUND= en %C en Fortran 95"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: SIGN= at %C not allowed in Fortran 95"
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite SIGN= en %C en Fortran 95"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "No se permite una declaración CLOSE en el procedimiento PURE en %C"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "La declaración CLOSE en %L requiere un número UNIT"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "El número UNIT en la declaración CLOSE en %L debe ser no negativo"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "No se permite una declaración %s en el procedimiento PURE en %C"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number missing in statement at %L"
 msgstr "El número UNIT en la declaración en %L debe ser no negativo"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "El número UNIT en la declaración en %L debe ser no negativo"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003: Declaración FLUSH en %C"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing format with default unit at %C"
 msgstr "Falta la etiqueta de formato en %C"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Especificación UNIT duplicada en %C"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Especificación de formato duplicada en %C"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "El símbolo '%s' en la lista de nombres '%s' es INTENT(IN) en %C"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Especificación NML duplicada en %C"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "El símbolo '%s' en %C debe ser un nombre de grupo NAMELIST"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "No se permite la etiqueta END en %C en la declaración de salida"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "No se especificó UNIT en %L"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "La especificación UNIT en %L debe ser una expresión INTEGER o una variable CHARACTER"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Forma no válida de la declaración WRITE en %L, se requiere UNIT"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Unidad interna con subíndice vectorial en %L"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Un IO UNIT externo no puede ser una matriz en %L"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST '%s' in READ statement at %L contains the symbol '%s' which may not appear in a variable definition context"
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "NAMELIST '%s' en la declaración READ en %L contiene el símbolo '%s' el cual puede no aparecer en un contexto de definición de variable"
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, fuzzy, gcc-internal-format
+#| msgid "NAMELIST object '%s' in namelist '%s' at %L is polymorphic and requires a defined input/output procedure"
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L es polimórfico y requiere un procedimiento de entrada/salida definido"
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, fuzzy, gcc-internal-format
+#| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr "Fortran 2003: El objeto NAMELIST '%s' en la lista de nombres '%s' en %L con componentes ALLOCATABLE o POINTER"
+
+#: fortran/io.c:3317
+#, fuzzy, gcc-internal-format
+#| msgid "NAMELIST object '%s' in namelist '%s' at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L tiene componentes ALLOCATABLE o POINTER y por lo tanto requere un procedimiento de entrada/salida definido"
+
+#: fortran/io.c:3328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Comma before i/o item list at %L"
 msgid "Comma before i/o item list at %L"
 msgstr "Extensión: Una coma antes de una lista de elementos de e/s en %L"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "La etiqueta ERR %d en %L no está definida"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "La etiqueta END %d en %L no está definida"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "La etiqueta EOR %d en %L no está definida"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "La etiqueta FORMAT %d en %L no está definida"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Error sintáctico en el iterador de E/S en %C"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Se esperaba una variable en la declaración READ en %C"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Se esperaba una expresión en la declaración %s en %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Error sintáctico en la declaración %s en %C"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Internal file at %L with namelist"
 msgid "Internal file at %L with namelist"
 msgstr "Fortran 2003: Fichero interno en %L con lista de nombres"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "El especificador ASYNCHRONOUS= en %L debe ser una expresión de inicialización"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: No se permite PAD= en %C en Fortran 95"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DELIM= at %C not allowed in Fortran 95"
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: no se permite DELIM= en %C en Fortran 95"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "La lista de nombres PRINT en %C es una extensión"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Se esperaba una coma en la lista E/S en %C"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "No se permite la declaración PRINT en %C dentro un procedimiento PURE"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "No se permite la declaración INQUIRE en el procedimiento PURE en %C"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "La etiqueta IOLENGHT es no válida en la declaración INQUIRE en %C"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "La declaración INQUIRE en %L no puede contener especificadores FILE y UNIT al mismo tiempo"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "La declaración INQUIRE en %L requiere un especificador FILE o UNIT"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "El número UNIT en la declaración en %L debe ser no negativo"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "La declaración INQUIRE en %L requiere un especificador PENDING= con el especificador ID="
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: WAIT at %C not allowed in Fortran 95"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: No se permite WAIT en %C en Fortran 95"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "No se permite una declaración WAIT en un procedimiento PURE en %C"
@@ -54916,265 +55033,265 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "Falta la especificación genérica en la declaración USE en %C"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr "Se renombran operadores en declaraciones USE en %C"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 #| msgid "The name %qs at %C has already been used as an external module name."
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "El nombre %qs en %C ya se está usando como un nombre de módulo externo."
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "declaración SUBMODULE en %C"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "La declaración ENTRY en %C no puede aparecer dentro de un subprograma contenido"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Error sintáctico en la sentencia SUBMODULE en %C"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "Leyendo el módulo %qs en la línea %d columna %d: %s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "Escribiendo el módulo %qs en la línea %d columna %d: %s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr "Módulo %qs en la línea %d columna %d: %s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr "require_atom(): tipo de átomo requerido incorrecto"
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Error al escribir el fichero de módulos: %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr "write_atom(): Escribiendo entero negativo"
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr "write_atom(): Intentando escribir átomo incorrecto"
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr "unquote_string(): cadena incorrecta"
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr "mio_array_ref(): Referencia de array desconocido"
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "!$OMP DECLARE REDUCTION ambiguo en el módulo %s en %L"
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "!$OMP DECLARE REDUCTION anterior en el módulo %s en %L"
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%qs del módulo %qs, importado en %C, es también el nombre de la unidad de programa actual"
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "El símbolo %qs referenciado en %L no se encontró en el módulo %qs"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "El operador de usuario %qs referenciado en %L no se encontró en el módulo %qs"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "El operador intrínseco %qs referenciado en %L no se encontró en el módulo %qs"
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): símbolo de módulo %qs incorrecto"
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Símbolo no escrito"
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "No se puede abrir el fichero de módulo %qs para escritura en %C: %s"
 
 # El mensaje de error seguramente está mal redactado. cfuga
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Error al escribir al fichero de módulo %qs para escritura: %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "No se puede borrar el fichero de módulo %qs: %s"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "No se puede renombrar el fichero de módulo %qs a %qs: %s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "No se puede borrar el fichero de módulo temporal %qs: %s"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "El símbolo %qs en %C ya se había declarado"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Imposible crear símbolo para %s"
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "El símbolo %qs referenciado en %L, no está en el estándar seleccionado"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "El símbolo %qs referenciado en %L no se encontró en el módulo intrínseco ISO_C_BINDING"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "El símbolo %qs ya se había declarado"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "El uso del módulo intrínseco %qs en %C tiene conflictos con un nombre de módulo no intrínseco usado previamente"
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "El uso de la constante nombrada NUMERIC_STORAGE_SIZE del módulo intrínseco ISO_FORTRAN_ENV en %L es incompatible con la opción %s"
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "El uso de la constante nombrada NUMERIC_STORAGE_SIZE del módulo intrínseco ISO_FORTRAN_ENV en %C es incompatible con la opción %s"
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "El símbolo '%s' referenciado en %L no se encontró en el módulo intrínseco ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CLOSE statement at %L requires a UNIT number"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "La declaración CLOSE en %L requiere un número UNIT"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003: Módulo intrínseco ISO_FORTRAN_ENV en %C"
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_C_BINDING module at %C"
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003: Módulo ISO_C_BINDING en %C"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "No se puede encontrar un módulo intrínseco llamado '%s' en %C"
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "No se puede abrir el fichero de módulo '%s' para lectura en %C: %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "El uso del módulo '%s' que no es intrínseco en %C tiene conflictos con el nombre del módulo intrínseco usado previamente"
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "El fichero '%s' abierto en %C no es un fichero de módulo GFORTRAN"
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
 # No se puede hacer el mismo juego de palabras que en inglés. cfuga
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building!"
@@ -57816,7 +57933,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "No se puede resolver la función específica '%s' en %L"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -59454,507 +59571,495 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: El nombre genérico '%s' de la función '%s' en %L tiene el mismo nombre que el tipo derivado en %L"
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "No se permite la matriz de tamaño asumido '%s' en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: Objeto de matriz NAMELIST '%s' con forma asumida en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con forma que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: El objeto de matriz NAMELIST '%s' con longitud de carácter que no es constante en la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, fuzzy, gcc-internal-format
-#| msgid "NAMELIST object '%s' in namelist '%s' at %L is polymorphic and requires a defined input/output procedure"
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L es polimórfico y requiere un procedimiento de entrada/salida definido"
-
-#: fortran/resolve.c:13924
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "Fortran 2003: El objeto NAMELIST '%s' en la lista de nombres '%s' en %L con componentes ALLOCATABLE o POINTER"
-
-#: fortran/resolve.c:13942
-#, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' se declaró PRIVATE y no puede ser miembro de una lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE asociados a uso y no puede ser miembro de la lista de nombres '%s' en %L"
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "El objeto NAMELIST '%s' tiene componentes PRIVATE y no puede ser un miembro de la lista de nombres PUBLIC '%s' en %L"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo NAMELIST en '%s' en %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "La matriz de parámetro '%s' en %L no puede ser automática ni de forma diferida"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "El PARAMETER de tipo implícito '%s' en %L no coincide con un tipo IMPLICIT posterior"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipo derivado incompatible en PARAMETER en %L"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "El bloque COMMON '%s' en %L no puede tener el atributo EXTERNAL"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "El atributo PROTECTED genera un conflicto con el atributo EXTERNAL en %L"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "El atributo PROCEDURE genera un conflicto con el atributo PROTECTED en %L"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "La matriz de tamaño asumido en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "La matriz de forma asumida en %L debe ser un argumento de prueba"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "El símbolo en %L no es una variable DUMMY"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' en %L no puede tener el atributo VALUE porque no es un argumento dummy"
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable dummy de carácter '%s' en %L con atributo VALUE debe tener longitud constante"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable dummy de carácter interoperable con C '%s' en %L con atributo VALUE debe ser de longitud uno"
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "El tipo derivado '%s' en %L es de tipo '%s', el cual no se ha definido"
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' en %L tiene el atributo CONTIGUOUS pero no es un puntero de matriz o una matriz de forma asumida"
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "No se permite la matriz de forma asumida '%s' en %L en una expresión de inicialización"
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos ALLOCATABLE y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable '%s' en %L no puede tener los atributos POINTER y BIND(C) al mismo tiempo"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de bucle en %C no puede ser una comatriz"
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable '%s' en %L no puede ser BIND(C) porque no es un bloque COMMON ni se declaró en el ámbito de nivel de módulo"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: La función PUBLIC %s '%s' en %L es de tipo derivado PRIVATE '%s'"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s en %L de tipo LOCK_TYPE o con un subcomponente de tipo LOCK_TYPE debe ser una comatriz"
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "El argumento dummy INTENT(OUT) '%s' en %L es ASSUMED SIZE y por lo tanto no puede tener un inicializador por defecto"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "El argumento dummy '%s' en %L de LOCK_TYPE no puede ser INTENT(OUT)"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "El resultado de la función '%s' en %L no puede ser una comatriz o tener un componente comatriz"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable '%s' en %L de TYPE(C_PTR) o TYPE(C_FUNPTR) no debe ser una comatriz"
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable '%s' en %L con componente de comatriz debe ser un escalar que no sea puntero alojable"
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable '%s' en %L es una comatriz y no es ALLOCATABLE, SAVE ni un argumento dummy"
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable de comatriz '%s' en %L no debe tener codimensiones con forma diferida"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable comatriz allocatable '%s' en %L debe tener forma diferida"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable '%s' en %L es INTENT(OUT) y por lo tanto no puede ser una comatriz allocatable o tener componentes comatriz"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "No se permite la variable dummy comatriz '%s' en %L en el procedimiento BIND(C) '%s'"
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "La lista de nombres %s no se puede renombrar por asociación de USE a %s"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "No se guarda (SAVE) el threadprivate en %L"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "El elemento BLOCK DATA '%s' en %L debe estar en COMMON"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "La matriz DATA '%s' en %L se debe especificar en una declaración previa"
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "El elemento DATA '%s' en %L no puede tener un coíndice"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "El elemento DATA '%s' en %L es un puntero y entonces debe ser una matriz completa"
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Sección de matriz no constante en %L en la declaración DATA"
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "La declaración DATA en %L tiene más variables que valores"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el inicio del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el final del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "el paso del bucle do implícito en %L no se puede simplificar a un valor constante"
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "La declaración DATA en %L tiene más valores que variables"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Se define la etiqueta %d en %L pero no se usa"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Se define la etiqueta %d en %L pero no se puede usar"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L debe tener el atributo SEQUENCE para ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L no puede tener componentes ALLOCATABLE que sean un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de tipo derivado '%s' en %L con inicializadores por defecto no puede ser un objeto EQUIVALENCE con una variable en COMMON"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de tipo derivado '%s' en %L con componente(s) de puntero no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Error sintáctico en la declaración EQUIVALENCE en %L"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Todos o ninguno de los objetos en el conjunto EQUIVALENCE en %L deben tener el atributo PROTECTED"
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "El miembro de bloque común '%s' en %L no puede ser un objeto EQUIVALENCE en el procedimiento puro '%s'"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nombrada '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "La matriz '%s' en %L con límites que no son constantes no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "El componente de estructura '%s' en %L no puede ser un objeto EQUIVALENCE"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La subcadena en %L tiene longitud cero"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "La función PUBLIC '%s' en %L no puede ser del tipo PRIVATE '%s'"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' en %L no tiene tipo IMPLICIT"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe ser FUNCTION"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "El procedimiento de operador de usuario '%s' en %L no puede ser de longitud de carácter asumido"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "El procedimiento de operador de usuario '%s' en %L debe tener al menos un argumento"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "El primer argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "El segundo argumento de la interfaz de operador en %L no puede ser opcional"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "La interfaz de operador en %L debe tener, cuando mucho, dos argumentos"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -61133,12 +61238,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "El objeto puntero en %C no debe tener un coíndice"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "Tipo base ES erróneo (%d)"
@@ -63474,11 +63579,6 @@
 #~ msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 #~ msgstr "Aún no se admite la matriz polimórfica en %C"
 
-#, fuzzy
-#~| msgid "NAMELIST object '%s' in namelist '%s' at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
-#~ msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
-#~ msgstr "El objeto NAMELIST '%s' en la lista de nombres '%s' en %L tiene componentes ALLOCATABLE o POINTER y por lo tanto requere un procedimiento de entrada/salida definido"
-
 #~ msgid "bad method signature"
 #~ msgstr "firma de método errónea"
 
@@ -63937,9 +64037,6 @@
 #~ msgid "Put jumps in call delay slots"
 #~ msgstr "Pone saltos en ranuras de retardo de llamadas"
 
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "Genera instrucciones multiply-add de coma flotante"
-
 #~ msgid "Support Green Hills ABI"
 #~ msgstr "Soporte para el ABI Green Hills"
 
@@ -70024,9 +70121,6 @@
 #~ msgid "control may reach end of non-void function %qD being inlined"
 #~ msgstr "el control puede alcanzar el final de la función %qD que no es void al ser inlined"
 
-#~ msgid "invalid initializer for bit string"
-#~ msgstr "inicializador no válido para la cadena de bits"
-
 #~ msgid "volatile register variables don%'t work as you might wish"
 #~ msgstr "las variables de registro volatile no funcionan como usted quisiera"
 
Index: gcc/po/fr.po
===================================================================
--- gcc/po/fr.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/fr.po	(.../branches/gcc-7-branch)
@@ -130,10 +130,10 @@
 #
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 7.1.0\n"
+"Project-Id-Version: gcc 7.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
-"PO-Revision-Date: 2017-07-31 21:23+0200\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
+"PO-Revision-Date: 2017-08-16 09:16+0200\n"
 "Last-Translator: Frédéric Marchal <fmarchal@perso.be>\n"
 "Language-Team: French <traduc@traduc.org>\n"
 "Language: fr\n"
@@ -141,7 +141,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8-bit\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
-"Plural-Forms: nplurals=2; plural=(n > 1);\n"
+"Plural-Forms: nplurals=2; plural=(n >= 2);\n"
 
 #: cfgrtl.c:2661
 msgid "flow control insn inside a basic block"
@@ -319,13 +319,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "constante flottante mal utilisée"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -611,62 +611,62 @@
 " passées aux divers sous-processus invoqués par %s.  Afin de passer\n"
 " les autres options à ces processus l'option -W<lettre> doit être utilisé.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Traitement du spec (%s), lequel est « %s »\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Cible : %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Configuré avec: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Modèle de thread: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc version %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "pilote gcc version %s %sexécutant gcc version %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr "Le bogue n'est pas reproductible, donc c'est probablement un problème matériel ou dans l'OS.\n"
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr "La source convertie par le préprocesseur a été stockée dans le fichier %s, veuillez l'attacher à votre rapport d'anomalie.\n"
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "installés: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "programmes: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "bibliothèques: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -675,16 +675,16 @@
 "\n"
 "Pour les instructions afin de rapporter des anomalies, consultez :\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "©"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -694,7 +694,7 @@
 "AUCUNE GARANTIE, pas même pour la COMMERCIALISATION ni L'ADÉQUATION À UNE TÂCHE PARTICULIÈRE.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -707,7 +707,7 @@
 "=============================\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -716,7 +716,7 @@
 "Utilisez « -Wl,OPTION » pour passer « OPTION » à l'éditeur de liens.\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -727,7 +727,7 @@
 "=======================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -741,16 +741,16 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr "  merge [options] <rép1> <rép2>         Fusionner les contenus des fichiers de couverture\n"
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "    -o, --output <rép>                  Répertoire de sortie\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "    -v, --verbose                       Mode verbeux\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "    -o, --output <rép>                  Répertoire de sortie\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -766,16 +766,16 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr "  rewrite [options] <rép>               Réécrire le contenu des fichiers de couverture\n"
 
+#: gcov-tool.c:270
+#, c-format
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgstr "    -n, --normalize <int64_t>           Normaliser le profil\n"
+
 #: gcov-tool.c:272
 #, c-format
 msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr "    -s, --scale <décimal ou frac simple> Met à l'échelle les compteurs de profils\n"
 
-#: gcov-tool.c:273
-#, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
-msgstr "    -n, --normalize <int64_t>           Normaliser le profil\n"
-
 #: gcov-tool.c:290
 #, c-format
 msgid "Rewrite subcommand usage:"
@@ -801,27 +801,27 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr "  overlap [options] <rép1> <rép2>       Calcule le recouvrement de deux profils\n"
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "    -h, --hotonly                       Afficher seulement les informations sur les fonctions/objets chargés (hot)\n"
-
-#: gcov-tool.c:422
-#, c-format
 msgid "    -f, --function                      Print function level info\n"
 msgstr "    -f, --function                      Afficher les informations au niveau de la fonction\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:421
 #, c-format
 msgid "    -F, --fullname                      Print full filename\n"
 msgstr "    -F, --fullname                      Afficher le nom complet du fichier\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:422
 #, c-format
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr "    -h, --hotonly                       Afficher seulement les informations sur les fonctions/objets chargés (hot)\n"
+
+#: gcov-tool.c:423
+#, c-format
 msgid "    -o, --object                        Print object level info\n"
 msgstr "    -o, --object                        Afficher les informations au niveau de l'objet\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr "    -t <décimal>, --hot_threshold <décimal> Changer le seuil pour déclarer une fonction ou objet « hot »\n"
@@ -908,20 +908,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Afficher cette aide puis quitter\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Afficher l'information pour chaque bloc de base\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Inclure les probabilités de branchement dans la sortie\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -930,16 +925,21 @@
 "  -c, --branch-counts             Afficher le décompte des branchements pris\n"
 "                                    plutôt que les pourcentages\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          Afficher les informations de progression\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Produire des résumés pour chaque fonction\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Afficher cette aide puis quitter\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1125,82 +1125,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s: le graphe n'a pas de solution pour « %s »\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Lignes exécutées: %s sur %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Aucune ligne exécutable\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s « %s »\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Branchements exécutés: %s sur %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "Pris au moins une fois: %s sur %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Pas de branchement\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Appels exécutés: %s sur %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Pas d'appel\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s: pas de ligne pour « %s »\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "appel  %2d a retourné %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "appel  %2d jamais exécuté\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "branchement %2d pris %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "branchement %2d jamais exécuté\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "inconditionnel %2d pris %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "inconditionnel %2d jamais exécuté\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "N'a pu ouvrir le fichier source %s\n"
@@ -1308,89 +1308,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr "Les utilisations de cette option sont diagnostiquées."
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr "par défaut %d minimum %d maximum %d"
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr "Comme %s. Utilisez plutôt cette dernière option."
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s  Comme %s."
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[par défaut]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[activé]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[désactivé]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Aucune option avec les caractéristiques désirées a été trouvée\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Aucune trouvée.  Utilisez --help=%s pour voir *toutes* les options acceptées par l'interface %s.\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Toutes les options avec les caractéristiques désirées ont déjà été affichées\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "Les options suivantes sont spécifiques à la cible"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "Les options suivantes contrôlent les messages d’avertissement du compilateur"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "Les options suivantes contrôlent les optimisations"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "Les options suivantes sont indépendantes du langage"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "L'option --param reconnaît les paramètres suivant"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "Les options suivantes sont uniquement spécifiques au langage "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "Les options suivantes sont prises en charge par le langage "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "Les options suivantes ne sont pas documentées"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "Les options suivantes prennent des arguments séparées"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "Les options suivantes prennent des arguments groupés"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "Les options suivantes concernent des langages"
 
@@ -2923,8 +2923,8 @@
 msgid "<command-line>"
 msgstr "<ligne-de-commande>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Opérande non supporté pour le code « %c »"
@@ -2943,7 +2943,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "opérande en virgule flottante ou registre vecteur incompatible pour « %%%c »"
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "opérande manquant"
@@ -2963,8 +2963,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "préfixe d'opérande invalide « %%%c »"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "« %%& » utilisé sans référence à un TLS dynamique local"
@@ -2980,18 +2980,18 @@
 msgstr "valeur %%r invalide"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "valeur %%R invalide"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "valeur %%N invalide"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "valeur %%P invalide"
@@ -3001,7 +3001,7 @@
 msgid "invalid %%h value"
 msgstr "valeur %%h invalide"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "valeur %%L invalide"
@@ -3022,7 +3022,7 @@
 msgstr "valeur %%U invalide"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "valeur %%s invalide"
@@ -3032,7 +3032,7 @@
 msgid "invalid %%C value"
 msgstr "valeur %%C invalide"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "valeur %%E invalide"
@@ -3043,7 +3043,7 @@
 msgstr "relocalisation unspec inconnue"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "valeur %%xn invalide"
@@ -3106,7 +3106,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "opérande invalide pour le code de sortie"
@@ -3116,29 +3116,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC invalide comme opérande : %d"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "opérande shift invalide"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruction Thumb établie"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruction établie dans la séquence conditionnelle"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3146,101 +3146,101 @@
 msgid "invalid operand for code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "instruction jamais exécutée"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "code de format Maverick « %c » obsolète"
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "l'opérande d'adresse requiert une contrainte sur le registre X, Y ou Z"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "les opérandes de %T/%t doivent être reg + const_int:"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr "mauvaise adresse, pas une adresse E/S:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr "mauvaise adresse, pas une constante:"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "mauvaise adresse, pas (reg+disp):"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "mauvaise adresse, pas post_inc ou pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "erreur interne du compilateur. Mauvaise adresse:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Code « %c » non supporté en virgule fixe:"
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "erreur interne du compilateur. Mode inconnu:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "insn invalide :"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "insn incorrecte :"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "insn de déplacement inconnue :"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "insn de décalage erronée :"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "erreur interne du compilateur. Décalage incorrect:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 msgid "unsupported fixed-point conversion"
 msgstr "conversion en virgule fixe non supportée"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr "variable"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 msgid "function parameter"
 msgstr "paramètre de fonction"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 msgid "structure field"
 msgstr "champ de structure"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 msgid "return type of function"
 msgstr "type de retour d'une fonction"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr "pointeur"
 
@@ -3264,7 +3264,7 @@
 msgstr "opérande const_double invalide"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3486,87 +3486,87 @@
 msgid "bad output_condmove_single operand"
 msgstr "mauvais opérande output_condmove_single"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC invalide comme opérande"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "utilisation invalide de la sortie du fanion asm"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "taille d'opérande invalide pour le code d'opérande « 0 »"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "taille d'opérande invalide pour le code d'opérande « z »"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "type opérande invalide utilisé avec le code d'opérande « Z »"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "taille d'opérande invalide pour le code d'opérande « Z »"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « Y » invalide"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « D » invalide"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "l'opérande n'est pas du code de condition, code d'opérande « %c » invalide"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "l'opérande n'est pas une référence mémoire avec décalage, code d'opérande « H » invalide"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "l'opérande n'est pas un entier, code d'opérande « K » invalide"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "l'opérande n'est pas un entier spécifique, code d'opérande « r » invalide"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "l'opérande n'est pas un entier, code d'opérande « R » invalide"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "l'opérande n'est pas un entier spécifique, code d'opérande « R » invalide"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "opérande invalide pour « %c »"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "contrainte invalide pour l'opérande"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "mode insn inconnu"
 
@@ -3603,7 +3603,7 @@
 msgid "invalid %%P operand"
 msgstr "opérande %%P invalide"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "valeur %%p invalide"
@@ -3657,7 +3657,7 @@
 msgstr "le post-incrément d'adresse n'est pas un registre"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "mauvaise adresse"
 
@@ -3690,7 +3690,7 @@
 msgstr "insn contient une adresse invalide !"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "adresse invalide"
 
@@ -3781,277 +3781,277 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Essayez d'exécuter « %s » dans le shell pour augmenter sa limite.\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le pas permis pour des cibles gros-boutistes"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx nécessite une unité matérielle en virgule flottante"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx et -mpaired sont incompatibles"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx nécessite l'adressage indexé"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx et -mno-altivec sont incompatibles"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec désactive vsx"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory requiert le mode 64 bits"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic requiert le mode 64 bits"
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory n'est pas disponible en mode petit-boutiste"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mtoc-fusion requiert le mode 64 bits"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion requiert le modèle de code moyen/large"
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr "mauvais déplacement"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr "Mauvais déplacement sur 128 bits"
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, c-format
 msgid "invalid %%e value"
 msgstr "valeur %%e invalide"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "valeur %%f invalide"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "valeur %%F invalide"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "valeur %%G invalide"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "valeur %%j invalide"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "valeur %%J invalide"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "valeur %%k invalide"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "valeur %%K invalide"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "valeur %%O invalide"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "valeur %%q invalide"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "valeur %%T invalide"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "valeur %%u invalide"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "valeur %%v invalide"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "valeur %%x invalide"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "valeur %%y invalide, essayez d'utiliser la contrainte « Z »"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 et __ibm128 ne peuvent pas être utilisés dans la même expression"
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 et long double ne peuvent pas être utilisés dans la même expression"
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 et long double ne peuvent pas être utilisés dans la même expression"
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argument AltiVec passé à une fonction sans prototype"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 msgid "Could not generate addis value for fusion"
 msgstr "N'a pu générer de valeur addis pour la fusion"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Impossible de générer un offset load/store pour la fusion"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr "Mauvaise fusion GPR"
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, mauvais reg #1"
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, mauvais reg #2"
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load pas MEM"
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, mauvais reg #1"
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, mauvais reg #2"
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store pas MEM"
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "les références mémoire symboliques sont uniquement supportées sur z10 ou ultérieur"
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "adresse indécomposable"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "opérateur de comparaison invalide pour le modificateur de sortie « E »"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "référence invalide pour le modificateur de sortie « J »"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « O »"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « R »"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "référence mémoire attendue pour le modificateur de sortie « S »"
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "adresse invalide pour le modificateur de sortie « S »"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "registre ou expression mémoire attendue pour le modificateur de sortie « N »"
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "registre ou expression mémoire attendue pour le modificateur de sortie « M »"
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "constante invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "constante invalide - essayez un modificateur de sortie"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "vecteur constant invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "expression invalide - essayez un modificateur de sortie"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "expression invalide pour le modificateur de sortie « %c »"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 msgid "vector argument passed to unprototyped function"
 msgstr "vecteur passé en argument à une fonction sans prototype"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 msgid "types differ in signedness"
 msgstr "les types diffèrent sur le type signé/non-signé"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr "l'opérateur binaire ne supporte pas deux opérandes booléens vectoriels"
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr "l'opérateur binaire ne supporte pas l'opérande booléen vectoriel"
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "l'opérateur binaire ne supporte pas le mélange d'un booléen vectoriel avec un vecteur en virgule flottante"
 
@@ -4077,43 +4077,43 @@
 msgid "created and used with different endianness"
 msgstr "créé et utilisé avec des boutismes différents"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "opérande %%Y invalide"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "opérande %%A invalide"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "opérande %%B invalide"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "opérande %%C invalide"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "opérande %%D invalide"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "opérande %%f invalide"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "opérande %%s invalide"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "la constante en virgule flottante n'est pas un opérande immédiat valide"
@@ -4275,30 +4275,30 @@
 msgid "bad test"
 msgstr "mauvais test"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "valeur %%D invalide"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "masque invalide"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "valeur %%d invalide"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "valeur %%t/%%b invalide"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "pas de registre dans l'adresse"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "le décalage d'adresse n'est pas une constante"
 
@@ -4319,8 +4319,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> attendu"
@@ -4342,14 +4342,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> attendu"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> attendu"
@@ -4380,7 +4380,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> attendu"
@@ -4388,7 +4388,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> attendu"
@@ -4398,7 +4398,7 @@
 msgstr "%<;%>, %<,%> ou %<)%> attendu"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> attendu"
@@ -4405,7 +4405,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> attendu"
@@ -4415,7 +4415,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> attendu"
@@ -4428,24 +4428,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "La notation Cilk d'un tableau ne peut pas être utilisée comme expression pour déclencher une exception"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr "La notation Cilk d'un tableau ne peut pas être utilisée comme condition d'un switch"
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr "La notation Cilk d'un tableau ne peut pas être utilisée comme condition d'un while"
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> attendu"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr "La notation Cilk d'un tableau ne peut pas être utilisée comme condition d'un do-while"
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr "La notation Cilk d'un tableau ne peut pas être utilisée comme condition d'une boucle for"
 
@@ -4453,18 +4453,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> attendu"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> attendu"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> attendu"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> ou %<)%> attendu"
@@ -4472,17 +4472,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> attendu"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> ou %<}%> attendu"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> attendu"
@@ -4491,7 +4491,7 @@
 msgid "(anonymous)"
 msgstr "(anonyme)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> attendu"
@@ -4500,11 +4500,11 @@
 msgid "expected label"
 msgstr "étiquette attendue"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "candidat 1 :"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "candidat 2 :"
 
@@ -4723,11 +4723,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%r%s:%d:%R   dans l'expansion de constexpr de %qs"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "les candidats sont :"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "le candidat est :"
@@ -4898,80 +4898,80 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "argument actuel de INTENT = OUT/INOUT"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "Largeur positive requise"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "Largeur non négative requise"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Élément %qc inattendu dans la chaîne de format à %L"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "Fin inattendue de la chaîne de format"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr "Largeur zéro dans le descripteur de format"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "Parenthèse gauche d'ouverture manquante"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 msgid "Left parenthesis required after %<*%>"
 msgstr "Parenthèse gauche requise après %<*%>"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "Descripteur d'édition P attendu"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "Le descripteur P doit être annoncé par un facteur d'échelle"
 
-#: fortran/io.c:726
-#, c-format
-msgid "Right parenthesis expected at %C"
-msgstr "Parenthèse droite attendue à %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr "Virgule requise après le descripteur P"
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr "Largeur positive requise avec le descripteur T"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "Spécificateur E pas permis avec le descripteur g0"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "Largeur d'exposant positive requise"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, c-format
+msgid "Right parenthesis expected at %C"
+msgstr "Parenthèse droite attendue à %C"
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr "Point requis dans le spécificateur de format"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr "étiquette %s"
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr "unité interne dans WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "étiquette %s avec INQUIRE"
@@ -4981,75 +4981,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "Erreur de syntaxe dans l'exception à %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Fin de fichier inattendue"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Débordement d'entier"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "Nom trop long"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Mauvais nom"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Nom attendu"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "Parenthèse gauche attendue"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "Parenthèse droite attendue"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Entier attendu"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Chaîne attendue"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum(): Énumération introuvable"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "Nom de bit d'attribut attendu"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Chaîne contenant un entier attendue"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "Erreur de conversion de l'entier"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Chaîne contenant un réel attendue"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "Type d'expression attendue"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "Mauvais opérateur"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "Mauvais type dans l'expression constante"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "Fin de module inattendue"
 
@@ -5294,12 +5294,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "La longueur réelle de la chaîne est plus courte que celle déclarée pour l'argument fictif « %s » (%ld/%ld)"
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "La cible du remappage de rang est trop petite (%ld < %ld)"
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr "Assignation d'un scalaire à un tableau non alloué"
 
@@ -5644,7 +5644,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "ne peut utiliser -m32 et -m64 ensemble"
 
@@ -8523,7 +8523,7 @@
 msgstr "Spécifier la taille en bits des décalages TLS immédiats."
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr "Ordonnancer le code pour le processeur donné."
@@ -8744,7 +8744,7 @@
 msgid "target the software simulator."
 msgstr "cible le simulateur logiciel."
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr "Utiliser LRA au lieu d'un rechargement."
 
@@ -8961,12 +8961,12 @@
 msgid "Use 80-bit long double."
 msgstr "Utiliser un long double de 80 bits."
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 msgid "Use 64-bit long double."
 msgstr "Utiliser un long double de 64 bits."
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr "Utiliser un long double de 128 bits."
@@ -9978,87 +9978,87 @@
 msgid "64 bit ABI."
 msgstr "ABI de 64 bits."
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr "Tenir à jour une liste inversée de pointeurs."
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr "Imprimer des informations additionnelles de débogage."
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr "Architecture ESA/390."
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 msgid "Enable decimal floating point hardware support."
 msgstr "Activer le support matériel pour les nombres décimaux en virgule flottante."
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 msgid "Enable hardware floating point."
 msgstr "Activer l'unité matérielle en virgule flottante."
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr "Prends deux nombres entiers non-négatifs séparés par une virgule. Le premier nombre indique le nombre d'instructions Nop de deux octets à ajouter avant l'étiquette de la fonction. Le second nombre indique le nombre d'instructions Nop d'un demi-mot à ajouter après l'étiquette. Des instructions Nop de la taille la plus grande possible sont utilisées (six, quatre ou deux octets) en commençant par la taille la plus grande possible. Si les deux valeurs sont à zéro, la correction à chaud est désactivée."
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 msgid "Use hardware transactional execution instructions."
 msgstr "Utiliser des instructions transactionnelles matérielles."
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "Utiliser des instructions d'assistance vectorielles matérielles et activer l'ABI vectorielle."
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr "Utiliser une disposition de pile compacte."
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr "Utiliser « bras » pour les exécutables < 64k."
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 msgid "Disable hardware floating point."
 msgstr "Désactiver l'unité matérielle en virgule flottante."
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "Définir le nombre maximum d'octets qui doivent rester sur la pile avant qu'une instruction de déroutement soit déclenchée."
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr "Arrêter l'option -mstack-guard=."
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "Générer du code supplémentaire dans le prologue de la fonction pour intercepter si la taille de la pile dépasse la limite donnée."
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr "Arrêter l'option -mstack-size=."
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 msgid "Use the mvcle instruction for block moves."
 msgstr "Utiliser les instructions mvcle pour les déplacements de blocs."
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr "Activer l'extension du langage vecteur z qui fourni la macro sensible au contexte « vector » et activer les fonctions internes dans le style Altivec dans vecintrin.h."
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "Avertir si une fonction utilise alloca ou crée un tableau avec une taille dynamique."
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "Avertir si la taille de trame d'une seule fonction excède la taille de trame donnée."
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr "z/Architecture."
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr "Définir le coût du branchement dans des instructions de branchements conditionnels. Les valeurs raisonnables sont de petits entiers positifs ou nuls. Le coût par défaut est 1."
 
@@ -10110,11 +10110,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr "Processeurs ARM connus (à utiliser avec les options -mcpu= et -mtune=):"
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr "Architectures ARM connues (à utiliser avec l'option -march=):"
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr "Unités en virgule flottante ARM connues (à utiliser avec l'option -mfpu=):"
 
@@ -10343,78 +10343,94 @@
 msgstr "Utiliser les extensions UltraSPARC Visual Instruction Set version 4.0."
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr "Utiliser les instructions VIS additionnelles ajoutées dans OSA2017."
+
+#: config/sparc/sparc.opt:90
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "Utiliser les extensions UltraSPARC Compare-and-Branch."
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "Utiliser les extensions UltraSPARC Fused Multiply-Add."
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Utiliser l'instruction de multiplication en virgule flottante simple vers double (FsMULd)."
+
+#: config/sparc/sparc.opt:102
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "Utiliser les extensions UltraSPARC Population-Count."
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "Utiliser l'instruction de soustraction étendue avec une retenue de l'UltraSPARC."
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 msgid "Pointers are 64-bit."
 msgstr "Les pointeurs sont de 64 bits."
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 msgid "Pointers are 32-bit."
 msgstr "Les pointeurs sont de 32 bits."
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 msgid "Use 64-bit ABI."
 msgstr "Utiliser l'ABI 64 bits."
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 msgid "Use 32-bit ABI."
 msgstr "Utiliser l'ABI 32 bits."
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr "Utiliser un biais de la pile."
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Utiliser des structs avec un alignement plus fort pour les copies de mots-doubles."
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Optimiser les instructions d'appel en fin de fonction (tail call) avec l'assembleur et l'éditeur de liens."
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr "Ne pas générer du code qui ne peut tourner qu'en mode superviseur (par défaut)."
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr "Utiliser les options et ordonnancer le code pour le processeur donné."
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr "Utiliser le modèle de code SPARC-V9 donné."
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 msgid "Enable debug output."
 msgstr "Activer la sortie de débogage."
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "Activer la vérification stricte du retour d'une structure selon l'ABI 32 bits spécifique au processeur."
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr "Activer le contournement du seul errata du processeur AT697F (qui correspond à l'errata #13 du processeur AT697E)."
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr "Activer les contournements des erratas du processeur UT699."
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr "Activer les contournements des erratas des processeurs UT699E/UT700."
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr "Activer les contournements des erratas du processeur GR712RC."
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr "Spécifier le modèle mémoire actif pour le programme."
 
@@ -14767,7 +14783,7 @@
 msgstr "Détecter les chemins qui déclenchent un comportement erroné ou indéfini dû au déréférencement d'un pointeur nul. Isoler ces chemins du flux de contrôle principal et transformer les instructions avec un comportement erroné ou indéfini en instructions de déroutement."
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Détecter les chemins qui déclenchent un comportement erroné ou indéfini dû à une valeur nulle utilisée d'une manière interdite par l'attribut returns_nonnull ou nonnull. Isoler ces chemins du flux de contrôle principal et transformer l'instruction avec un comportement erroné ou indéfini en une instruction de déroutement."
 
 #: common.opt:2502
@@ -15169,7 +15185,7 @@
 msgstr "type booléen attendu"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "entier attendu"
@@ -15447,125 +15463,125 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr "l'instruction « range » doit avoir un type tableau, tranche, chaîne, tableau associatif ou canal"
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 msgid "invalid comparison of non-ordered type"
 msgstr "comparaison invalide d'un type non ordonné"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr "une tranche peut uniquement être comparée à nul"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr "un tableau associatif peut uniquement être comparé à nul"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr "une fonction peut uniquement être comparée à nul"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, c-format
 msgid "invalid operation (%s)"
 msgstr "opération invalide (%s)"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 msgid "invalid comparison of non-comparable type"
 msgstr "comparaison invalide d'un type non comparable"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 msgid "invalid comparison of generated struct"
 msgstr "comparaison invalide d'une structure générée"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr "comparaison invalide d'une structure non comparable"
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 msgid "invalid comparison of generated array"
 msgstr "comparaison invalide d'un tableau généré"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr "comparaison invalide d'un tableau non comparable"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr "appel de fonction à valeur multiple dans un contexte à valeur unique"
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr "conversion explicite nécessaire"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr "impossible d'utiliser le type %s comme type %s"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr "types de récepteurs différents"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr "nombre de paramètres différents"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr "types de paramètres différents"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr "varargs différents"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr "nombre de résultats différents"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr "types de résultats différents"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "conversion explicite nécessaire, méthode %s%s%s manquante"
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "type incompatible pour la méthode %s%s%s"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "type incompatible pour la méthode %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr "le pointeur vers le type d'interface n'a pas de méthode"
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr "le type n'a pas de méthode"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "méthode ambiguë %s%s%s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "méthode manquante %s%s%s"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "la méthode %s%s%s exige un récepteur pointeur"
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "la méthode %s%s%s est marquée comme go:nointerface"
@@ -15740,7 +15756,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr "la limite spécifiée (%wu) est égale à la taille de la destination"
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "trop peu d'arguments pour la fonction %<va_start%>"
@@ -15802,27 +15818,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "modèle mémoire invalide pour %<__atomic_load%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "modèle mémoire invalide pour %<__atomic_store%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "argument 1 non constant pour __atomic_always_lock_free"
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "argument 1 non entier pour __atomic_is_lock_free"
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_thread_pointer n'est pas supporté sur cette cible"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_set_thread_pointer n'est pas supporté sur cette cible"
@@ -15829,7 +15845,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kutilisation invalide de %<__builtin_va_arg_pack ()%>"
@@ -15836,12 +15852,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kutilisation invalide de %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "le deuxième argument de %<__builtin_longjmp%> doit être 1"
@@ -15848,62 +15864,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Votre plateforme cible ne supporte pas -fcheck-pointer-bounds"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "le format cible ne supporte pas l'infini"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> utilisé dans une fonction ayant des arguments fixes"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "nombre erroné d'arguments pour la fonction %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> appelé sans argument"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "nombre erroné d'arguments pour la fonction %<__builtin_next_arg%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "le deuxième paramètre de %<va_start%> n'est pas le dernier argument nommé"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "le comportement est indéfini quand le second paramètre de %<va_start%> est déclaré avec le stockage %<register%>"
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%Kle premier argument de %D doit être un pointeur et le second une constante entière"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%Kle dernier argument de %D n'est pas une constante entière entre 0 et 3"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Ktentative de libérer un objet %qD qui n'est pas sur le tas"
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Ktentative de libérer un objet qui n'est pas sur le tas"
@@ -16812,12 +16828,12 @@
 msgstr "l'attribut %<weakref%> est ignoré car la variable est initialisée"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F utilisé mais jamais défini"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F déclaré %<static%> mais jamais défini"
@@ -16912,12 +16928,12 @@
 msgid "cannot find '%s'"
 msgstr "« %s » introuvable"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "échec de pex_init: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -16927,7 +16943,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER  doit être défini"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17142,7 +17158,7 @@
 msgid "error writing %qs"
 msgstr "erreur d'écriture dans %qs"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "ne peut ouvrir %s"
@@ -17222,17 +17238,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr "ignore l'option %<-fopt-info-%s%> qui entre peut-être en conflit"
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "les personnalités EH multiples sont uniquement supportées avec les assembleurs qui supportent la directive .cfi_personality"
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "UNSPEC non délégitimisé %s (%d) trouvé à l'emplacement de la variable"
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr "-feliminate-dwarf2-dups ne fonctionne pas en C++, il est ignoré"
@@ -17342,12 +17358,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "écriture de %wu bits de données hors des limites de l'objet de destination, les données ont été tronquées dans %wu bits"
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kappel à %qs déclaré avec une erreur d'attribut: %s"
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kappel à %qs déclaré avec un avertissement d'attribut: %s"
@@ -17362,12 +17378,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "la taille de trame de %wd octets est plus grande que %wd octets"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "n'a pu ouvrir le fichier de vidange des insn finales %qs: %m"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "n'a pu fermer le fichier de vidange des insn finales %qs: %m"
@@ -17382,7 +17398,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "la comparaison est toujours %d en raison de la largeur du champ de bits"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "suppose qu'un débordement signé n'a pas lieu quand le test de la plage est simplifié"
@@ -17412,7 +17428,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "suppose qu'un débordement signé n'a pas lieu lorsque des constantes sont combinées autour d'une comparaison"
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vérification fold: arbre originale modifié par fold"
@@ -17422,7 +17438,7 @@
 msgid "total size of local objects too large"
 msgstr "la taille totale des objets locaux est trop grande"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "contrainte impossible dans %<asm%>"
@@ -17523,62 +17539,67 @@
 msgid "input file %qs is the same as output file"
 msgstr "le fichier d'entrée %qs est le même que le fichier de sortie"
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, gcc-internal-format
+msgid "output filename may not be empty"
+msgstr "le nom du fichier de sortie ne peut pas être vide"
+
+#: gcc.c:4501
+#, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "-pipe est ignoré parce que -save-temps est spécifié"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "%<-x %s%> n'a pas d'effet après le dernier fichier d'entrée"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr "impossible de trouver le script d'édition de liens par défaut %qs dans les chemins de recherche des bibliothèques"
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "le commutateur %qs ne débute pas par %<-%>"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr "le commutateur généré par la spec est un simple %<-%>"
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "impossible d'ouvrir le fichier de réponse temporaire %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "impossible d'écrire dans le fichier de réponse temporaire %s"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "impossible de fermer le fichier de réponse temporaire %s"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "spec %qs invalide"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "la spec %qs a un %<%%0%c%> invalide"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "la spec %qs a un %<%%W%c%> invalide"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "la spec %qs a un %<%%x%c%> invalide"
@@ -17586,229 +17607,229 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "échec du spec: %<%%*%> n'a pas été initialisé par concordance du patron"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "échec de spec: option de spec %qc non reconnue"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "fonction de spec %qs inconnue"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "erreur dans les arguments de la fonction de spec %qs"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "nom de fonction de spec mal composé"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "aucun argument pour la fonction de spec"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "arguments pour la fonction de spec mal composés"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "la spec entre accolades %qs est invalide à %qc"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "le contenu de la spec entre accolades %qs est invalide"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s: impossible de déterminer la longueur du fichier de comparaison pour le débogage %s"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr "%s: échec de -fcompare-debug (longueur)"
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s: ne peut ouvrir le fichier de comparaison pour le débogage %s"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "%s: échec de -fcompare-debug"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "échec de spec: plus d'un argument à SYSROOT_SUFFIX_SPEC"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "échec de spec: plus d'un argument à SYSROOT_HEADERS_SUFFIX_SPEC"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "option %<-%s%> non reconnue sur la ligne de commande, aviez-vous l'intention d'utiliser %<-%s%> ?"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "option %<-%s%> non reconnue sur la ligne de commande"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "pas configuré avec le suffixe d'en-têtes sysroot"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "pas de fichier à l'entrée"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "ne peut spécifier -o avec -c, -S ou -E et de multiples fichiers"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: le compilateur %s n'est pas installé sur ce système"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "recompilation avec -fcompare-debug"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr "pendant la recompilation avec -fcompare-debug"
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr "comparaison des vidanges des insns finales"
 
 # I18N
-#: gcc.c:8261
+#: gcc.c:8264
 #, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "-fuse-linker-plugin, mais %s introuvable"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: le fichier d'entrée de l'édition de liens n'est pas utilisé parce que l'édition de liens n'a pas été faite"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr "impossible d'utiliser %<-%> comme nom de fichier d'entrée pour un en-tête précompilé"
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "le langage %s n'est pas reconnu"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "la spec multilib %qs est invalide"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "les exclusions multilib %qs sont invalides"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "le sélecteur multilib %qs %qs est invalide"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "le sélecteur multilib %qs est invalide"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "l'exclusion multilib %qs est invalide"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "variable d'environnement %qs non définie"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "numéro de version %qs invalide"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "trop peu d'arguments pour %%:version-compare"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "trop d'arguments pour %%:version-compare"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "opérateur %qs inconnu dans %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "trop d'arguments pour %%:compare-debug-dump-opt"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "trop d'arguments pour %%:compare-debug-self-opt"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "trop peu d'arguments pour %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "trop d'arguments pour %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr "l'argument de %%:compare-debug-auxbase-opt n'est pas terminé par .gk"
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "trop peu d'arguments pour %%:replace-extension"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "mauvais nombre d'arguments pour %%:debug-level-gt"
@@ -17953,9 +17974,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "déclaré ici"
@@ -18371,230 +18392,230 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr "l'attribut %<fallthrough%> ne précède pas un « case » ou un « default »"
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "utilisation du résultat d'une fonction qui retourne %<void%>"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "l-valeur invalide dans la sortie asm %d"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "l'entrée %d qui n'est pas une zone mémoire doit rester en mémoire"
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "l'entrée mémoire %d n'est pas directement adressable"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "la variable privée au thread %qE est utilisée dans la région cible"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "région cible englobante"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "la variable privée au thread %qE est utilisée dans une tâche non liée"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "tâche englobante"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE non spécifié dans la région %qs englobante"
 
 # le %qs est un nom de région non traduit tel que « parallel », « task », « teams ».
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "région %qs englobante"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE non spécifié dans la construction OpenACC %qs englobante"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "construction OpenACC %qs englobante"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE avec une clause %<link%> utilisée dans une fonction %<routine%>"
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE requiert une directive %<declare%> pour l'utilisation dans une fonction %<routine%>"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "la variable %qE est déclarée dans une région %<host_data%> englobante"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD est référencé dans une région cible qui n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "la variable d'itération %qE est prédéterminée linéaire"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "la variable d'itération %qE devrait être privée"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "la variable d'itération %qE ne devrait pas être « firstprivate »"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "la variable d'itération %qE ne devrait pas être une réduction"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "la variable d'itération %qE ne devrait pas être linéaire"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "la variable d'itération %qE ne devrait pas être « lastprivate »"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "la variable d'itération %qE ne devrait pas être privée"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "la clause %<linear%> pour une variable autre qu'un itérateur de boucle est spécifiée sur une construction combinée avec %<distribute%>"
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "champ de correspondance %qE d'une structure de longueur variable"
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE apparaît plus d'une fois dans la clause de correspondance (map)"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "la variable « copyprivate » %qE n'est pas « threadprivate » ou privée dans le contexte extérieur"
 
 # le %s est remplacé par des mots-clé non traduits tels que « firstprivate », « lastprivate »,…
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "la variable « %s » %qE est privée dans le contexte extérieur"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "modificateur de clause %qs %<if%> attendu au lieu de %qs"
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD dans la clause implicite %<map%>"
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD dans la clause implicite %<firstprivate%> dans la construction %<target%>"
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD dans la clause %<firstprivate%> dans la construction %<target%>"
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "la même variable est utilisée dans les clauses %<firstprivate%> et %<lastprivate%> dans la construction %<distribute%>"
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr "clause de données avec réduction sur %qE incompatible; promu en present_or_copy"
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "réduction privée invalide sur %qE"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "une construction %<ordered%> avec une clause %<depend%> doit être étroitement imbriquée dans une boucle avec une clause %<ordered%> avec un paramètre"
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "la variable %qE n'est pas une itération de la boucle %d la plus à l'extérieur, %qE attendu"
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "le nombre de variables dans la clause %<depend(sink)%> ne correspond pas au nombre de variables d'itérations"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr "plus d'une clause %<depend(source)%> sur une construction %<ordered%>"
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr "une clause %<depend(source)%> a été spécifiée avec des clauses %<depend(sink:)%> sur la même construction"
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<_Cilk_spawn%> attendu avant %<_Cilk_sync%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "la gimplification a échoué"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT a été promu en %qT lors du passage à travers %<...%>"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(vous devriez donc passer %qT et non %qT à %<va_arg%>)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "si ce code est atteint, le programme s'arrêtera"
@@ -18827,7 +18848,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "le type %qT enfreint lui-même la règle de la définition unique du C++"
 
 #: ipa-devirt.c:1235
@@ -18927,8 +18948,8 @@
 
 #: ipa-devirt.c:1576
 #, gcc-internal-format
-msgid "fields has different layout in another translation unit"
-msgstr "le champ a un agencement différent dans une autre unité de traduction"
+msgid "fields have different layout in another translation unit"
+msgstr "les champs ont un agencement différent dans une autre unité de traduction"
 
 #: ipa-devirt.c:1599
 #, gcc-internal-format
@@ -19308,198 +19329,198 @@
 msgid "multiple loop axes specified for routine"
 msgstr "axes de boucles multiples spécifiés pour la routine"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr "%<seq%> écrase d'autres spécificateurs de boucle de OpenACC"
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr "%<auto%> entre en conflit avec d'autres spécificateurs de boucle de OpenACC"
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr "la boucle intérieure utilise le même parallélisme OpenACC que la boucle qui la contient"
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr "argument pas permis dans la clause %qs dans %<parallel%> de OpenACC"
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr "construction non OpenACC à l'intérieur d'une routine OpenACC"
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr "construction non OpenACC à l'intérieur d'une région OpenACC"
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr "%<ordered simd threads%> doit être étroitement imbriquée à l'intérieur d'une région %<for simd%>"
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr "les constructions OpenMP autres que %<#pragma omp ordered simd%> ne peuvent pas être imbriquées à l'intérieur d'une région %<simd%>"
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr "seules les régions %<distribute%> ou %<parallel%> sont autorisées à être strictement imbriquées à l'intérieur d'une région %<teams%>"
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr "une région %<distribute%> doit être strictement imbriquées à l'intérieur d'une construction %<teams%>"
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr "une directive de boucle OpenACC doit être associée avec une région de calcul de OpenACC"
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr "construction %qs orpheline"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr "%<#pragma omp cancel for%> à l'intérieur de %<nowait%> pour la construction"
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr "%<#pragma omp cancel for%> à l'intérieur de %<ordered%> pour la construction"
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<#pragma omp cancel sections%> à l'intérieur d'une construction de sections %<nowait%>"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr "la construction %<%s taskgroup%> n'est pas étroitement imbriquée à l'intérieur de la région %<taskgroup%>"
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, gcc-internal-format
 msgid "invalid arguments"
 msgstr "arguments invalides"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr "construction %<%s %s%> pas étroitement imbriquée à l'intérieur de %qs"
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "une région barrière ne peut pas être étroitement imbriquée à l'intérieur d'une région de partage de tâche, %<critical%>, %<ordered%>, %<master%>, %<task%> explicite ou %<taskloop%>"
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "la région qui partage une tâche ne peut pas être étroitement imbriquée à l'intérieur d'une région de partage de tâche, %<critical%>, %<ordered%>, %<master%>, %<task%> explicite ou %<taskloop%>"
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr "une région %<master%> ne peut pas être étroitement imbriquée à l'intérieur d'un partage de tâche, un %<task%> explicite ou une région %<taskloop%>"
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr "%<depend(%s)%> est uniquement autorisé dans %<omp ordered%>"
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr "une construction %<ordered%> avec une clause %<depend%> doit être étroitement imbriquée à l'intérieur d'une boucle %<ordered%>"
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr "sous-type dépendant invalide dans omp %<ordered%> %<depend%>"
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr "%<ordered%> %<simd%> doit être étroitement imbriquée à l'intérieur d'une région %<simd%>"
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr "une région %<ordered%> ne peut pas être étroitement imbriquée à l'intérieur d'une région %<critical%>, %<ordered%>, %<task%> explicite ou %<taskloop%>"
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr "une région %<ordered%> doit être étroitement imbriquée à l'intérieur d'une région de boucle avec la clause %<ordered%>"
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr "une région %<critical%> ne peut pas être imbriquée à l'intérieur d'une région %<critical%> portant le même nom"
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr "la construction %<teams%> n'est pas étroitement imbriquée dans une construction %<target%>"
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr "une région OpenACC est à l'intérieur d'une routine OpenACC, le parallélisme imbriqué n'est pas encore supporté"
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr "construction OpenACC à l'intérieur d'une région qui n'est pas OpenACC"
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr "une construction %s %qs est à l'intérieur d'une région %s %qs"
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr "la construction %qs est à l'intérieur de la région %qs"
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr "setjmp/longjmp à l'intérieur d'une construction simd"
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr "la clause « sink » est ignorée car elle a un offset qui n'est pas un multiple du pas de la boucle"
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr "le premier offset doit être dans la direction opposée des itérations de la boucle"
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "sortie invalide hors du bloc structuré %s"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "entrée invalide dans le bloc structuré %s"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "branchement invalide vers/depuis le bloc structuré %s"
@@ -19584,7 +19605,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "l'option %qs en ligne de commande n'est pas supportée par cette configuration"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "argument manquant à %qs"
@@ -19740,127 +19761,137 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr "-fsanitize-address-use-after-scope requiert l'option -fstack-reuse=none"
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "la mémoire transactionnelle n'est pas supportée avec %<-fsanitize=address%>"
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "la mémoire transactionnelle n'est pas supportée avec %<-fsanitize=kernel-address%>"
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr "include_flags 0x%x non reconnu passé à print_specific_help"
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr "l'option -fsanitize-all n'est pas valide"
 
-#: opts.c:1642
+#: opts.c:1649
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "argument non reconnu pour l'option -f%ssanitize%s=: %q.*s; vouliez-vous utiliser %qs ?"
 
-#: opts.c:1649
+#: opts.c:1656
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "argument non reconnu pour l'option -f%ssanitize%s=: %q.*s"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "l'argument %q.*s de --help est ambigu, veuillez être plus précis"
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "argument non reconnu pour l'option --help=: %q.*s"
 
-#: opts.c:2078
+#: opts.c:2085
 #, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr "HSA n'a pas été activé durant la configuration"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr "l'option -foffload-abi ne peut être spécifiée qu'avec un compilateur pour le délestage"
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "l'alignement de la structure doit être une petite puissance de 2, pas %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "paramètre de contrôle de la pile %qs inconnu"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr "%<-gdwarf%s%> est ambigu; utilisez %<-gdwarf-%s%> pour la version DWARF ou %<-gdwarf -g%s%> pour le niveau de débogage"
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "la version dwarf %d n'est pas supportée"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: les arguments de --param devraient être de la forme NOM=VALEUR"
 
-#: opts.c:2371
+#: opts.c:2378
 #, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "nom de --param %qs invalide; vouliez vous utiliser %qs ?"
 
-#: opts.c:2374
+#: opts.c:2381
 #, gcc-internal-format
 msgid "invalid --param name %qs"
 msgstr "nom de --param %qs invalide"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "valeur de --param %qs invalide"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "le système cible ne supporte pas la sortie de débogage"
 
-#: opts.c:2513
+#: opts.c:2520
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "le format de débogage %qs entre en conflit avec une sélection précédente"
 
-#: opts.c:2531
+#: opts.c:2538
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "niveau de sortie de débogage %qs non reconnu"
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "le niveau de sortie de débogage %qs est trop élevé"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "obtention de la limite maximale de la taille du fichier de vidange (core file): %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "initialisation de la limite maximale de la taille du fichier de vidange (core file): %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "option gcc de débogage non reconnue: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: pas d'option -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr "-Werror=%s: -%s n'est pas une option qui contrôle les avertissements"
@@ -20207,7 +20238,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "le registre de %qD est utilisé pour plusieurs variables-registre globales"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "en conflit avec %qD"
@@ -20808,12 +20839,12 @@
 msgid "error closing %s: %m"
 msgstr "erreur de fermeture de %s: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr "auto-tests incompatibles avec -E"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "les auto-tests ne sont pas activés dans cet exécutable"
@@ -21724,47 +21755,47 @@
 msgid "in expansion of macro %qs"
 msgstr "dans l'expansion de la macro %qs"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "le BB %i a plusieurs arêtes de gestion des exceptions"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr "le BB %i ne peut pas produire d'exception mais il a une arête pour la gestion des exceptions"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "la dernière instruction du BB %i a défini incorrectement la zone d'atterrissage des exceptions"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "le BB %i n'a pas d'arête de gestion des exceptions"
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "arête incorrecte de gestions des exceptions %i->%i"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "il manque une arête dans le BB %i"
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "le BB %i a trop d'arêtes falltrhu"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "le BB %i a une arête incorrecte"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "le BB %i a une arête fallthru incorrecte"
@@ -21866,32 +21897,32 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr "la cible ne supporte pas la mise à jour atomique du profilage, le mode simple est sélectionné"
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr "argument %u nul où un non-nul est attendu"
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "dans un appel à la fonction interne %qD"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "dans un appel à la fonction %qD déclarée ici"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "optimisation de boucle manquée, le compteur de boucle peut déborder"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr "l'itération %s invoque un comportement indéfini"
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr "dans cette boucle"
@@ -22245,11 +22276,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -23219,7 +23250,7 @@
 msgid "type was previously declared %qE"
 msgstr "le type a été précédemment déclaré %qE"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> ne peut être spécifié que pour une fonction virtuelle"
@@ -23494,7 +23525,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "le compilateur peut supposer que l'adresse de %qD sera toujours évaluée à %<true%>"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "parenthèses suggérées autour de l'affectation utilisée comme valeur dans une condition"
@@ -24114,62 +24145,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "qualificatif de type supplémentaire dans l'argument du format (argument %d)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> attend un argument de type %<%s%s%> mais l'argument %d a le type %qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> attend un argument %<%s%s%> correspondant"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> attend un argument de type %<%T%s%> mais l'argument %d a le type %qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> attend un argument %<%T%s%> correspondant"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> n'est pas défini comme un type"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> n'est pas défini comme %<long%> ou %<long long%>"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> n'est pas défini comme un type"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> n'est pas défini comme un type"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> n'est pas défini comme un type"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> n'est pas défini comme un type pointeur"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "les arguments devant être formatés ne sont pas %<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "les formats de strftime ne peuvent pas formater d'arguments"
@@ -24271,7 +24302,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "%<@%> répété avant la chaîne Objective-C"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "concaténation non standard de chaînes littérales non supportée"
@@ -24301,7 +24332,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> utilise deux variables différentes pour la mémoire"
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "type invalide pour la variable d'itération %qE"
@@ -24316,22 +24347,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE n'est pas initialisé"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "prédicat de contrôle manquant"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "prédicat de contrôle invalide"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "expression d'incrémentation manquante"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "expression d'incrémentation invalide"
@@ -24876,8 +24907,8 @@
 msgid "wrong type argument to %s"
 msgstr "argument de type erroné pour %s"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "débordement dans l'expression constante"
@@ -25545,7 +25576,7 @@
 msgid "this condition has identical branches"
 msgstr "cette condition a des branches identiques"
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "%<_Cilk_spawn%> ne peut être utilisé qu'à l'intérieur d'une fonction"
@@ -25705,7 +25736,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr "-march=%s: sous-chaîne ISA %qs non supportée"
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "option -mdebug-%s inconnue"
@@ -26028,7 +26059,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%Kl'argument %d doit être une constante immédiate"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%Kl'index de l'avenue doit être une constante immédiate"
@@ -26108,7 +26139,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "valeur %qs inconnue pour -mtune"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "l'option -mcpu=%s est en conflit avec l'option -march=%s"
@@ -26193,9 +26224,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "la cible %s %s=%s n'est pas valable"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "l'argument %<target%> de l'attribut n'est pas une chaîne"
@@ -26281,7 +26312,7 @@
 msgstr "valeur %qs erronée pour -mmemory-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26455,234 +26486,234 @@
 msgid "insn addresses not freed"
 msgstr "les adresses des insn ne sont pas libérées"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "cette fonction interne n'est pas supportée pour cette cible"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr "Vous devez activer les instructions NEON (par ex. -mfloat-abi=softfp -mfpu=neon) pour utiliser ces intrinsèques."
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Vous devez activer les instructions VFP pour utiliser ces intrinsèques."
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr "Vous devez activer les instructions crypto (par ex. inclure -mfloat-abi=softfp -mfpu=crypto-neon…) pour utiliser ces intrinsèques."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "sélecteur doit être un immédiat"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "la plage du sélecteur doit être entre 0 et 7"
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "la plage du sélecteur doit être entre 0 et 3"
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "la plage du sélecteur doit être entre 0 et 1"
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "le masque doit être un immédiat"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "la plage du masque doit être entre 0 et 255"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_rori_pi16 dans le code."
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_rori_pi32 dans le code."
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_ror_pi16 dans le code."
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "la plage du décompte doit être entre 0 et 32. Veuillez vérifier l'intrinsèque _mm_ror_pi32 dans le code."
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "la plage du décompte doit être entre 0 et 64. Veuillez vérifier l'intrinsèque _mm_rori_si64 dans le code."
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "la plage du décompte doit être entre 0 et 64. Veuillez vérifier l'intrinsèque _mm_ror_si64 dans le code."
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srli_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_slli_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srai_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_srl_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sll_si64 dans le code"
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_pi16 dans le code"
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_pi32 dans le code"
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "le décompte ne devrait pas être inférieur à 0. Veuillez vérifier l'intrinsèque _mm_sra_si64 dans le code"
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt et NEON sont incompatibles"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "le processeur cible ne supporte pas ARM"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "activer le support de la trace de débogage n'a de sens qu'en compilant pour le Thumb"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "activer le support pour l'interopérabilité de l'appelé n'a de sens qu'en compilant pour le Thumb"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g avec -mno-apcs-frame peut ne pas donner un débogage pertinent"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr "iWMMXt non supporté en mode Thumb"
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "-mtp=cp15 ne peut pas être utilisé avec un Thumb 16 bits"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC est incompatible avec Thumb"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr "-mslow-flash-data ne supporte que du code non pic sur les cibles armv7-m"
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr "-mpure-code ne supporte que du code non pic sur les cibles armv7-m"
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "le processeur cible ne supporte pas les instructions THUMB"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "le processeur cible ne supporte pas les accès non alignés"
@@ -26689,141 +26720,141 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mfpu=auto n'est actuellement pas supporté sans un processeur explicite."
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "le processeur cible ne supporte pas l'interopérabilité"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check incompatible avec -mno-apcs-frame"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic et -mapcs-reent sont incompatibles"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "Le code réentrant APCS n'est pas supporté.  Ignoré"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "les options fp16 sélectionnées sont incompatibles"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt exige une ABI compatible AAPCS pour fonctionner correctement"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "l'abi iwmmxt requiert un processeur avec iwmmxt"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS ne supporte pas -mcaller-super-interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS ne supporte pas -mcallee-super-interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 et pas de ldrh"
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard: le processeur sélectionné n'a pas de FPU"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard et VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "la frontière de la taille de la structure peut seulement être 8, 32 ou 64"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "la frontière de la taille de la structure peut seulement être 8 ou 32"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "RTP PIC est incompatible avec -msingle-pic-base"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= est inutile sans -fpic"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "incapable d'utiliser « %s » pour un registre PIC"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition n'est pas supporté sur cette architecture"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "le processeur cible ne supporte pas les extensions de sécurité ARMv8-M"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "variante PCS qui n'est pas dérivée de AAPCS"
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "les fonctions variadiques doivent utiliser la variante du AAPCS de base"
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "variante PCS"
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "ABI VFP en virgule flottante matérielle du Thumb-1"
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "le passage de paramètre pour l'argument de type %qT a changé dans GCC 7.1"
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -26831,72 +26862,77 @@
 msgid "%qE attribute only applies to functions"
 msgstr "l'attribut %qE s'applique uniquement aux fonctions"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "l'attribut %qE n'est pas disponible pour les fonctions avec des arguments passés sur la pile"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "l'attribut %qE n'est pas disponible pour les fonctions avec un nombre variable d'arguments"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "l'attribut %qE n'est pas disponible pour les fonctions qui retournent une valeur sur la pile"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "l'attribut %qE est ignoré sans l'option -mcmse."
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "l'attribut %qE n'a pas d'effet sur les fonctions statiques"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "l'attribut %qE ne s'applique qu'au type de base d'un pointeur vers une fonction"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr "l'accès à un stockage local au thread n'est actuellement pas supporté avec -mpure-code ou -mslow-flash-data"
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd hors des limites %wd - %wd"
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd hors des limites %wd - %wd"
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "incapable de calculer la position réelle des paramètres sur la pile"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Saut lointain thumb1 inattendu"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "pas de registre bas disponible pour dépiler les registres hauts"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "les routines du service d'interruption ne peuvent pas être codées en mode Thumb"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr "-fstack-check=specific pour Thumb-1"
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr "fpu invalide pour attribute(target(\"%s\"))"
@@ -26904,13 +26940,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "la sélection automatique du fpu n'est actuellement pas permise ici"
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) est inconnu"
@@ -27004,99 +27040,104 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr "les attributs de fonction %qs et %qs n'ont pas d'effet sur la fonction %qs"
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "la fonction avec l'attribut %qs ne peut pas avoir d'argument"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "la fonction avec l'attribut %qs ne peut pas retourner une valeur"
 
 # %s est « interrupt » ou « signal » non traduit.
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
-msgstr "%qs semble être un gestionnaire avec l'attribut « %s » mal orthographié, il manque le préfixe __vector"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
+msgstr "%qs semble être un gestionnaire avec l'attribut %qs mal orthographié, il manque le préfixe %<__vector%>"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr "%qs est un identificateur réservé de AVR-LibC. Envisagez %<#include <avr/interrupt.h>%> avant d'utiliser la macro %qs"
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> ne contient que 2 octets d'adresse"
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "l'offset du pointeur par rapport au symbole peut être incorrect"
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "accès à la mémoire des données avec une adresse mémoire du programme"
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "accès à la mémoire du programme avec une adresse mémoire des données"
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "registre fixe %s utilisé pour passer un paramètre à la fonction"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "l'écriture dans l'espace d'adresses %qs n'est pas supportée"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "l'attribut %qE ne s'applique qu'aux variables statiques"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "l'attribut %qE n'est supporté que par les cœurs Tiny réduits"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "l'attribut %qE ne s'applique qu'aux variables"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "l'attribut %qE n'accepte qu'une constante entière comme argument"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr "l'adresse de l'attribut %qE est hors limites"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "les attributs %s et %qE fournissent tous les deux une adresse"
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "attribut %qE sur une variable non volatile"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "les espaces d'adresses ne sont pas supportés pour les périphériques Tiny réduits"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "l'espace d'adresses %qs n'est pas supporté pour les périphériques avec une taille de flash jusqu'à %d Kio"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "un pointeur visant l'espace d'adresses %qs doit être « const » dans %qT"
@@ -27103,67 +27144,73 @@
 
 # %s est un texte non traduit tel que « variable », « function parameter », « structure field »,…
 # J'ai soumis le bug 79453 pour demander de créer des messages spécifiques à chaque cas.
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "un pointeur visant l'espace d'adresses %qs doit être const dans le/la %s %q+D"
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "la variable %q+D doit être « const » pour être placée dans une section en lecture seule à l'aide de %qs"
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr "la déclaration IO statique pour %q+D a besoin d'une adresse"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr "la définition IO pour %q+D a besoin d'une adresse"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "seules les variables non initialisées peuvent être placées dans la section .noinit"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "variable %q+D avec une initialisation dynamique placée dans la zone mémoire du programme"
+
+#: config/avr/avr.c:10160
+#, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "variable non initialisée %q+D placée dans la zone mémoire du programme"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D a les attributs incompatibles %qs et %qs"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "l'architecture %qs n'est supportée que par l'assembleur"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "conversion depuis l'espace d'adresses %qs vers l'espace d'adresses %qs"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s attend une constante entière à la compilation"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s attend une constante sous forme d'entier long à la compilation comme premier argument"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "arrondir à %d bits n'a pas d'effet pour une valeur en virgule fixe avec %d bits fractionnels"
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "le résultat de l'arrondi sera toujours 0"
@@ -27446,12 +27493,12 @@
 msgid "invalid IACC argument"
 msgstr "argument IACC invalide"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs attend un argument constant"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "argument constant hors limite pour %qs"
@@ -27629,7 +27676,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "le modèle de code %qs n'est pas supporté en mode x32"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "le modèle de code %s ne supporte pas le mode PIC"
@@ -27759,288 +27806,288 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> est ignoré en mode 64 bits"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary n'est pas supporté pour cette cible"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d n'est pas entre %d et %d"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d n'est pas entre %d et 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount n'est pas compatible avec cette cible"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount n'est pas implémenté pour -fPIC"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> utilisé sans que SSE soit activé"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "jeu d'instructions SSE désactivé, l'arithmétique 387 est utilisée"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "jeu d'instructions 387 désactivé, l'arithmétique SSE est utilisée"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "le sondage de la pile requiert %<-maccumulate-outgoing-args%> pour être correcte"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "le sondage de la pile requiert %<target(\"accumulate-outgoing-args\")%> pour être correcte"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "le registre ebp fixé requiert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "le registre ebp fixé requiert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry n'est pas supporté en 32 bits en combinaison avec -fpic"
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry n'est pas compatible avec SEH (gestionnaire d'exceptions structuré)"
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "option inconnue pour -mrecip=%s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") a déjà été spécifié"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Seul le format de débogage DWARF est supporté pour les routines de service d'interruptions."
 
 # Le dernier %s est le texte non traduit « exception » ou « interrupt ».
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "les instructions %s ne sont pas autorisées dans la routine de service de type « %s »"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "les instructions %s ne sont pas autorisées dans la fonction avec l'attribut no_caller_saved_registers"
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "les attributs fastcall et regparm sont incompatibles"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "les attributs regparam et thiscall sont incompatibles"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "l'attribut %qE requiert un argument de type constante entière"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "l'argument pour l'attribut %qE est plus grand que %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "les attributs fastcall et cdecl sont incompatibles"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "les attributs fastcall et stdcall sont incompatibles"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "les attributs fastcall et thiscall sont incompatibles"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "les attributs stdcall et cdecl sont incompatibles"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "les attributs stdcall et fastcall sont incompatibles"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "les attributs stdcall et thiscall sont incompatibles"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "les attributs cdecl et thiscall sont incompatibles"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "l'attribut %qE est utilisé pour une méthode qui n'est pas une classe"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "appel de %qD avec l'attribut sseregparm sans que SSE/SSE2 soit activé"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "appel de %qT avec l'attribut sseregparm sans que SSE/SSE2 soit activé"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 ne supporte pas l'attribut ms_abi"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue n'est pas compatible avec les fonctions imbriquées"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "l'argument vectoriel AVX512F sans activer AVX512F change l'ABI"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "le retour vectoriel AVX512F sans activer AVX512F change l'ABI"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "l'argument vectoriel AVX sans activer AVX change l'ABI"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "le retour vectoriel AVX sans activer AVX change l'ABI"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "l'argument vectoriel SSE sans activer SSE modifie l'ABI"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "le retour vectoriel SSE sans activer SSE change l'ABI"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "l'argument vectoriel MMX sans activer MMX modifie l'ABI"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "le retour vectoriel MMX sans activer MMX change l'ABI"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "l'ABI pour passer une structure possédant un tableau flexible comme membre a changé dans GCC 4.4"
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "l'ABI pour passer une union avec un double long a changé dans GCC 4.4"
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "l'ABI pour passer une structure possédant un nombre décimal complexe comme membre a changé dans GCC 4.4"
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "retour d'un registre SSE alors que SSE est désactivé"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argument dans un registre SSE alors que SSE est désactivé"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "retour d'un registre x87 alors que x87 est désactivé"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "appel de %qD avec la convention d'appel SSE sans avoir activé SSE/SSE2"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "ceci est un bogue de GCC qui peut être contourné en ajoutant l'attribut utilisé à la fonction appelée"
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "L'ABI pour passer des paramètres avec un alignement de %d octets a changé dans GCC 4.6"
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "l'attribut ms_hook_prologue est incompatible avec -mfentry pour 32 bits"
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "DRAP (Dynamic Realign Argument Pointer) n'est pas supporté dans une routine de service d'interruption. Ceci peut être contourné en évitant les fonctions avec un retour agrégé."
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack ne supporte pas fastcall avec des fonctions imbriquées"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack ne supporte pas deux paramètres registres pour une fonction imbriquée"
@@ -28047,297 +28094,297 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack ne supporte pas trois paramètres registres"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "taille non supportée pour un registre entier"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "les registres étendus n'ont pas de moitié haute"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "taille d'opérande non supportée pour un registre étendu"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "opérande non entier utilise avec le code d'opérande « z »"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "une routine de service d'interruption ne peut pas être appelée directement"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Pas de répartiteur trouvé pour les attributs de version"
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Pas de répartiteur trouvé pour %s"
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Pas de répartiteur trouvé pour les attributs de version : %s"
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Les versions de fonctions ne peuvent pas être marquées avec gnu_inline, des corps de fonctions doivent être générés"
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Des versions multiples de fonctions virtuelles ne sont pas supportées"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr "attribut %<target%> manquant pour %D avec plusieurs versions"
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "déclaration précédente de %D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "les versions multiples requièrent ifunc qui n'est pas supporté sur cette cible"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Le paramètre à une fonction interne doit être une chaîne sous forme constante ou littérale"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Le paramètre à la fonction interne n'est pas valable: %s"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 2 bits"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "le cinquième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "le troisième argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 3 bits"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 1 bit"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "l'avant dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "le troisième argument doit être une constante de comparaison"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "mode de comparaison incorrect"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "opérande d'arrondi incorrect"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 4 bits"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 5 bits"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "l'argument immédiat doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "le dernier argument doit être une valeur immédiate sur 32 bits"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "le sélecteur doit être une constante entière dans la plage 0..%wi"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE a besoin d'une option isa inconnue"
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE a besoin de l'option isa %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "le dernier argument doit être une valeur immédiate"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "le dernier argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "le quatrième argument doit être une échelle 1, 2, 4, 8"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "opérande d'indice incorrect"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "l'argument de xabort doit être une valeur immédiate sur 8 bits"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "l'attribut %qE est uniquement disponible en 32 bits"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "l'argument de l'attribut %qE n'est ni zéro ni un"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "les attributs ms_abi et sysv_abi sont incompatibles"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "l'attribut incompatible %qE est ignoré"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "la routine de service d'interruption devrait avoir un pointeur comme premier argument"
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "la routine de service d'interruption devrait avoir un « unsigned %sint » comme deuxième argument"
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "la routine de service d'interruption ne peut avoir qu'un argument de type pointeur et un argument entier optionnel"
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "la routine de service d'interruption ne peut pas avoir une valeur de retour non void"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "les alternatives ne sont pas autorisées dans la sortie du fanion asm"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "sortie du fanion asm %qs inconnue"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "type invalide pour la sortie du fanion asm"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "Modèle mémoire spécifique à l'architecture inconnu"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE n'est pas utilisé avec le modèle mémoire ACQUIRE ou un autre plus contraignant"
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE n'est pas utilisé avec le modèle mémoire RELEASE ou un autre plus contraignant"
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen %d non supportée"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr "type de retour %qT non supporté pour simd\n"
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "type d'argument %qT non supporté pour simd\n"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Le contrôleur de pointeurs requiert le support MPX sur cette cible. Utilisez les options -mmpx pour activer MPX."
@@ -28457,7 +28504,7 @@
 msgid "argument %qd is not a constant"
 msgstr "l'argument %qd n'est pas une constante"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, pointeur nul"
@@ -28467,7 +28514,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: Ponctuation « %c » inconnue"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND pointeur nul"
@@ -28568,7 +28615,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread est disponible uniquement sur fido"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "l'expression limitant la pile n'est pas supportée"
@@ -29075,8 +29122,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr "les fonctions internes du MSP430 ne fonctionnent qu'à l'intérieur des gestionnaires d'interruptions"
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr "code interne erroné"
@@ -29327,27 +29374,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr "PTX ne supporte pas les déclarations faibles (uniquement les définitions faibles)"
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "l'attribut %qE requiert un type de retour « void »"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "l'attribut %qE n'est pas permis avec une classe de stockage auto"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr "utilisation de vector_length (%d), %d est ignoré"
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr "utilisation de vector_length (%d), le paramètre à l'exécution est ignoré"
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "utilisation de num_workers (%d), %d est ignoré"
@@ -29372,7 +29419,7 @@
 msgid "-g option disabled"
 msgstr "option -g désactivée"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "l'alignement (%u) pour %s excède l'alignement maximum pour les données communes globales. Utilisation de %u"
@@ -29507,157 +29554,157 @@
 msgid "junk at end of #pragma longcall"
 msgstr "rebut à la fin de #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr est déprécié pour les petits boutistes; utilisation d'une affectation pour des chargements et des stockages non alignés"
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_mul accepte uniquement 2 arguments"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_cmpne accepte uniquement 2 arguments"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_adde accepte uniquement 3 arguments"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_addec accepte uniquement 3 arguments"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s accepte uniquement %d arguments"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s accepte uniquement 1 argument"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s accepte uniquement 2 arguments"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract accepte uniquement 2 arguments"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert accepte uniquement 3 arguments"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "le passage de l'argument %d de %qE abandonne les qualificatifs du type cible du pointeur"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "La fonction interne %s n'est pas supportée dans cette configuration du compilateur"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "combinaison invalide de paramètres pour l'intrinsèque Altivec %s"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr "-mrecip requiert -ffinite-math ou -ffast-math"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr "-mrecip requiert -fno-trapping-math ou -ffast-math"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr "-mrecip requiert -freciprocal-math ou -ffast-math"
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 requiert une architecture PowerPC64, elle est maintenant activée"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power n'est pas supporté sur Darwin 64 bits; il est incompatible avec les bibliothèques C et C++ installées"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr "ne générera pas d'instructions power9 car l'assembleur ne supporte pas power9"
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr "ne générera pas d'instructions power8 car l'assembleur ne supporte pas power8"
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr "ne générera pas d'instructions power7 car l'assembleur ne supporte pas power7"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr "ne générera pas d'instructions power6 car l'assembleur ne supporte pas power6"
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr "ne générera pas d'instructions power5 car l'assembleur ne supporte pas power5"
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr "pas configuré pour l'ABI SPE"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr "pas configuré pour le jeu d'instructions SPE"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI SPE"
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec pas supporté par cette cible"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "SPE pas supporté par cette cible"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple n'est pas supporté sur des systèmes petits boutistes"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring n'est pas supporté sur des systèmes petits boutistes"
@@ -29664,67 +29711,67 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "-mpower9-minmax est incompatible avec les options explicitement désactivées"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr "L'option de la cible power9 est incompatible avec -mcpu=<xxx> pour <xxx> inférieur à power9"
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr "-mcrypto requiert -maltivec"
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr "-mdirect-move requiert -mvsx"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr "-mpower8-vector requiert -maltivec"
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr "-mpower8-vector requiert -mvsx"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr "-mvsx-timode requiert -mvsx"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "-mhard-dfp requiert -mhard-float"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "-mupper-regs-df requiert -mvsx"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "-mupper-regs-di requiert -mvsx"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr "-mupper-regs-sf requiert -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr "-mpower8-fusion-sign requiert -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr "-mtoc-fusion requiert -mpower8-fusion"
@@ -29733,514 +29780,519 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "-mpower9-fusion requiert -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr "-mpower9-vector requiert -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr "-mpower9-dform requiert -mpower9-vector"
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar requièrent -mdirect-move"
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr "-mpower9-dform requiert -mupper-regs-df"
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr "-mpower9-dform requiert -mupper-regs-sf"
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr "-mvsx-timode pourrait nécessiter -mlra"
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr "-mallow-movmisalign requiert -mvsx"
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr "-mefficient-unaligned-vsx requiert -mvsx"
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr "-mefficient-unaligned-vsx requiert -mallow-movmisalign"
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr "-mvsx-small-integer requiert -mpower8-vector, -mupper-regs-di et -mdirect-move"
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "l'attribut cible ou le pragma change la taille du double long"
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr "-mfloat128 requiert le support VSX"
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr "-mfloat128-type requiert le support VSX"
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr "-mfloat128 requiert -mfloat128-type"
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr "-mfloat128-hardware requiert -mfloat128-type"
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr "-mfloat128-hardware requiert le support ISA 3.0 complet"
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr "-mfloat128-hardware requiert -m64"
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr "type d'ABI de la bibliothèque de vectorisation (%s) inconnu pour l'option -mveclibabi="
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI AltiVec"
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "l'attribut cible ou le pragma change l'ABI darwin64"
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "l'attribut cible ou le pragma change la virgule flottante simple précision"
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "l'attribut cible ou le pragma change la virgule flottante double précision"
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs n'est pas un nombre valable dans -mstack-protector-guard-offset="
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs n'est pas un décalage valable dans -mstack-protector-guard-offset="
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs n'est pas un registre de base valable dans -mstack-protector-guard-reg="
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr "-mstack-protector-guard=tls a besoin d'un registre de base valable"
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "l'agencement des agrégats contenant des vecteurs alignés sur %d octets a changé avec GCC 5"
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vecteur GCC retourné par référence: extension ABI non standard sans aucune garantie de compatibilité"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "la valeur ne peut être retournée dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez -maltivec pour les autoriser"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "l'ABI pour passer des agrégats avec un alignement sur %d octets a changé avec GCC 5"
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "l'argument ne peut pas être passé dans le registre vectoriel parce que les instructions altivec sont désactivées, utilisez -maltivec pour les autoriser"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "l'ABI pour passer des agrégats de flottants homogènes a changé avec GCC 5"
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "vecteur GCC passé par référence: extension ABI non standard sans aucune garantie de compatibilité"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "erreur interne: fonction interne %s déjà traitée"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "l'argument 1 doit être une valeur de champ sur 8 bits"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "l'argument 1 doit être un littéral signé de 5 bits"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 5 bits"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "l'argument 1 doit être un littéral non signé de 6 bits"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 7 bits"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "argument 1 de « __builtin_altivec_predicate » doit être une constante"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "argument 1 de « __builtin_altivec_predicate » est hors limite"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "la fonction interne %s est uniquement valable en mode 64 bits"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "l'argument %d doit être un littéral non signé"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "l'argument %d est un littéral non signé qui est hors limite"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr "la fonction interne %s n'accepte qu'une chaîne comme argument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr "le processeur %s est un argument invalide pour la fonction interne %s"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "le hwcap %s est un argument invalide pour la fonction interne %s"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr "%s requiert GLIBC (2.23 ou plus récent) qui exporte des bits de capacité matérielle"
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 4 bits"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 2 bits"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "l'argument 3 doit être un littéral non signé de 1 bit"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "l'argument 1 doit être 0 ou 2"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "l'argument 1 doit être un littéral non signé de 1 bit"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "l'argument 2 doit être un littéral non signé de 6 bits"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "l'argument 1 doit être 0 ou 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "l'argument 3 doit être dans la plage 0..15"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "l'argument de %qs doit être un littéral non signé de 2 bits"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "surcharge non résolue pour la fonction Altivec interne %qF"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "argument de dss doit être un littéral non signé de 2 bits"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr "le deuxième argument de vec_vextract4b doit être 0..12"
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, gcc-internal-format
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "le troisième argument de « vec_vinsert4b » doit être 0..12"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "l'argument 1 de « __builtin_paired_predicate » doit être une constante"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "l'argument 1 de « __builtin_paired_predicate » est hors limite"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "l'argument 1 de « __builtin_spe_predicate » doit être une constante"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "l'argument 1 de « __builtin_spe_predicate » est hors limite"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "La fonction interne %s est uniquement valable pour le processeur cell"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "La fonction interne %s requiert l'option -mvsx"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "La fonction interne %s requiert l'option -mhtm"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "La fonction interne %s requiert l'option -maltivec"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "La fonction interne %s requiert l'option -mpaired"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "La fonction interne %s requiert l'option -mspe"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "La fonction interne %s requiert les options -mhard-dfp et -mpower8-vector"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "La fonction interne %s requiert l'option -mhard-dfp"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "La fonction interne %s requiert l'option -mpower8-vector"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "La fonction interne %s requiert les options -mcpu=power9 et -m64"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "La fonction interne %s requiert l'option -mcpu=power9"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "La fonction interne %s requiert les options -mhard-float et -mlong-double-128"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "La fonction interne %s requiert l'option -mhard-float"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "La fonction interne %s requiert l'option -mfloat128"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "La fonction interne %s n'est pas supportée avec les options actuelles"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "erreur interne: la fonction interne %s a un type de retour %s inattendu"
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "erreur interne: pour la fonction interne %s, l'argument %d a le type %s inattendu"
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "trame de pile trop grande"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack utilise le registre r29"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "Une trame de pile plus grande que 2G n'est pas supportée par -fsplit-stack"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "pas de profilage du code 64 bits pour cette ABI"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Vous ne pouvez pas prendre l'adresse d'une fonction imbriquée si vous utilisez l'option -mno-pointers-to-nested-functions."
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<long double%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "l'utilisation des types booléens dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "l'utilisation de %<complex%> dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "l'utilisation de types décimaux en virgule flottante dans les types AltiVec est invalide"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "l'utilisation de %<long%> dans les types AltiVec est invalide pour du code 64 bits sans -mvsx"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "l'utilisation de %<long%> dans les types Altivec est obsolète; utilisez %<int%>"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "l'utilisation de %<long long%> dans les types AltiVec est invalide sans -mvsx"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "l'utilisation de %<double%> dans les types AltiVec est invalide sans -mvsx"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "production d'une insn microcode %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "production d'une insn microcode conditionnelle %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "processeur « %s » invalide pour %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s n'est pas permis"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s est invalide"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr "-mno-%s désactive -m%s"
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr "-mno-power9-vector désactive -mpower9-dform"
@@ -30427,6 +30479,7 @@
 msgstr "-mcall-aixdesc incompatible avec -mabi=elfv2"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 requiert un processeur PowerPC64"
@@ -30518,7 +30571,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr "la fonction interne vec_step peut uniquement être utilisée sur des types vectoriels."
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "valeur constante requise pour l'argument %2$d de la fonction interne %1$qF"
@@ -30545,8 +30598,8 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
-msgstr "%qF requiert -march=arch12 ou supérieur"
+msgid "%qF requires z14 or higher"
+msgstr "%qF requiert z14 ou supérieur"
 
 #: config/s390/s390-c.c:903
 #, gcc-internal-format
@@ -30565,8 +30618,8 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
-msgstr "la variante correspondant à %qs requiert -march=arch12 ou supérieur"
+msgid "%qs matching variant requires z14 or higher"
+msgstr "la variante correspondant à %qs requiert z14 ou supérieur"
 
 #: config/s390/s390-c.c:972
 #, gcc-internal-format
@@ -30578,160 +30631,160 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite pour le type cible"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite (0.."
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "l'argument constant %d de la fonction interne %qF est hors limite ("
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr "la fonction interne %qF n'est pas supportée sans -mhtm (par défaut avec -march=zEC12 et supérieur)."
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr "la fonction interne %qF requiert -mvx (par défaut avec -march=z13 et supérieur)."
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
-msgstr "La fonction interne %qF requiert arch12 ou supérieur."
+msgid "Builtin %qF requires z14 or higher."
+msgstr "La fonction interne %qF requiert z14 ou supérieur."
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "fonction interne surchargée non résolue"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "icode de fonction interne erroné"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "argument %d invalide pour la fonction interne %qF"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "l'attribut %qE demandé n'est pas une paire de constantes entières non négatives séparées par une virgule ou est trop grand (max. %d)"
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "la taille totale des variables locales excède la limite de l'architecture"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "la taille de la trame de la fonction %qs est de %wd octets. Elle dépasse la limite de %d octets de la pile fournie par l'utilisateur. Un déroutement inconditionnel est ajouté."
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "la taille de la trame de la fonction %qs est de %wd octets. C'est plus que la moitié de la taille de la pile. Le contrôle dynamique ne serait pas fiable. Aucun contrôle n'est généré pour cette fonction."
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "la taille de la trame de %qs est de %wd octets"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs utilise l'allocation de pile dynamique"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr "les processeurs plus vieux que le z900 ne sont pas supportés par -fsplit-stack"
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr "%sarch=%s%s est déprécié et sera supprimé dans les versions futures; utilisez au moins %sarch=z900%s"
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr "%stune=%s%s est déprécié et sera supprimé dans les versions futures; utilisez au moins %stune=z900%s"
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Le mode d'architecture n'est pas supporté sur %s"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "l'ABI 64 bits n'est pas supportée en mode ESA/390"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "le support des vecteurs matériels n'est pas disponible sur %s"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr "le support des vecteurs matériels n'est pas disponible avec -msoft-float"
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "les instructions décimales en virgule flottante matérielles ne sont pas disponibles sur %s"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "les instructions décimales en virgule flottante matérielles ne sont pas disponibles en mode ESA/390"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp ne peut être utilisé en conjonction avec -msoft-float"
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float ne sont pas supportés en combinaison"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "la taille de la pile doit être plus grande que la valeur de la protection de la pile"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "la taille de la pile ne peut pas être plus grande que 64k"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard implique l'utilisation de -mstack-size"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "les arguments de %qs doivent être des entiers non négatifs"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "l'argument de %qs est trop grand (max. %d)"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "la valeur %qs n'est pas supportée par l'attribut %<target%>"
@@ -30788,27 +30841,27 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax est uniquement supporté pour le PIC RTP"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s n'est pas supporté par cette configuration"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 n'est pas permis avec -m64"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "valeur erronée (%s) pour l'option -mcmodel="
 
-#: config/sparc/sparc.c:1425
+#: config/sparc/sparc.c:1541
 #, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= n'est pas supporté sur les systèmes 32 bits"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "-fcall-saved-REG n'est pas supporté pour les registres de sortie"
@@ -31093,22 +31146,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "constante invalide dans %<#pragma %s%>"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "registres booléens requis pour l'option de virgule flottante"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "-f%s n'est pas supporté avec les instructions CONST16"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "PIC est requis mais non supporté avec des instructions CONST16"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "seules les variables non initialisées peuvent être placées dans une section .bss"
@@ -31194,7 +31247,7 @@
 msgid "could not read the BRIG file"
 msgstr "n'a pu lire le fichier BRIG"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -31596,9 +31649,9 @@
 msgstr "l'étiquette %qD est définie ici"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD déclaré ici"
@@ -31731,7 +31784,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> n'est pas permis ailleurs que dans la portée du prototype d'une fonction"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D dans la directive de déclaration de cible n'a pas de type pour lequel une correspondance peut être établie (mappable type)"
@@ -32777,7 +32830,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "deux types de données ou plus dans le spécificateur de déclaration"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> est trop long pour GCC"
@@ -32917,17 +32970,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "le C ISO ne supporte pas un simple %<complex%> signifiant %<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "le C ISO interdit les types entiers complexes"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "le combinateur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_out%> ni %<omp_in%>"
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "l'initialiseur %<#pragma omp declare reduction%> fait référence à la variable %qD qui n'est ni %<omp_priv%> ni %<omp_orig%>"
@@ -32977,7 +33030,7 @@
 msgid "version control conflict marker in file"
 msgstr "marqueur de conflit de contrôle de version dans le fichier"
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "fin de ligne attendue"
@@ -33018,7 +33071,7 @@
 msgstr "nom de type %qE inconnu"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "spécificateurs de déclaration attendus"
@@ -33033,7 +33086,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identificateur ou %<(%> attendu"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "les attributs de préfixes sont ignorés pour les méthodes"
@@ -33048,8 +33101,8 @@
 msgid "unexpected attribute"
 msgstr "attribut inattendu"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "l'attribut %<fallthrough%> n'est pas suivi par %<;%>"
@@ -33087,7 +33140,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> peut uniquement être utilisé avec un seul déclarateur"
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> ou %<;%> attendu"
@@ -33115,7 +33168,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "le C90 ISO ne supporte pas %<_Static_assert%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "chaîne littérale attendue"
@@ -33179,14 +33232,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identificateur attendu"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "virgule à la fin de la liste d'énumerateurs"
@@ -33321,7 +33374,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> attendu avant %<else%>"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> sans %<if%> précédent"
@@ -33346,12 +33399,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr "une étiquette peut uniquement faire partie d'une instruction or une déclaration n'est pas une instruction"
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr "-fcilkplus doit être activé pour utiliser %<_Cilk_for%>"
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr "-fcilkplus doit être activé pour utiliser %<_Cilk_sync%>"
@@ -33365,17 +33418,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "instruction attendue"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<if%>"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "accolades suggérées autour du corps vide d'une instruction %<else%>"
@@ -33385,7 +33438,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr "une instruction « if » ne peut pas contenir %<Cilk_spawn%>"
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "des accolades explicites sont suggérées pour éviter toute ambiguïté sur le %<else%>"
@@ -33405,7 +33458,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "variable d'itération invalide dans l'énumération rapide"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "condition de boucle manquante dans la boucle avec le pragma %<GCC ivdep%>"
@@ -33581,17 +33634,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "opérandes de %<__builtin_complex%> de types différents"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_shuffle%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr "-fcilkplus doit être activé pour utiliser %<_Cild_spawn%>"
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr "des mots-clés %<_Cilk_spawn%> consécutifs ne sont pas permis"
@@ -33646,61 +33699,61 @@
 msgid "no type or storage class may be specified here,"
 msgstr "aucun type ni classe de stockage ne peut être spécifié ici,"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "attribut de propriété inconnu"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<=%> manquant (après l'attribut %<getter%>)"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<=%> manquant (après l'attribut %<setter%>)"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "l'attribut %<setter%> ne peut être spécifié qu'une seule fois"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "le nom du « setter » doit être terminé par %<:%>"
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "l'attribut %<getter%> ne peut être spécifié qu'une seule fois"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> ne peut être utilisé que dans des instructions composées"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> doit être dans la portée au niveau du fichier"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> ne peut être utilisé que dans une construction %<#pragma omp sections%>"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "instruction « for », « while » ou « do » attendue"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> doit être le premier"
@@ -33715,12 +33768,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "%<#pragma grainsize%> doit être à l'intérieur d'une fonction"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "trop de clauses %qs"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "expression entière attendue avant « ) »"
@@ -33735,53 +33788,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD n'est pas une variable"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD n'est pas une variable pointeur"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "l'argument « collapse » a besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, gcc-internal-format
 msgid "expected %<none%>"
 msgstr "%<none%> attendu"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> ou %<shared%> attendu"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> ou %<exit%> attendu"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> attendu"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "trop de %<if%> avec le modificateur %qs"
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "trop de clauses %<if%>"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "trop de clauses %<if%> sans modificateur"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "si une clause %<if%> a un modificateur, alors toutes les clauses %<if%> doivent utiliser un modificateur"
@@ -33809,22 +33862,22 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "la valeur de %<num_tasks%> doit être positive"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "la valeur de %<grainsize%> doit être positive"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "la valeur de %<priority%> doit être positive ou nulle"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "%<tofrom%> attendu"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "%<scalar%> attendu"
@@ -33834,57 +33887,57 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "la valeur de %<num_workers%> doit être positive"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "trop d'arguments pour %<static%>"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "argument inattendu"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "la valeur de %qs doit être positive"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "l'argument %<tile%> a besoin d'une constante entière positive"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "les arguments ordonnés ont besoin d'une expression entière constante positive"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> ou identificateur attendu"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "les deux modificateurs %<monotonic%> et %<nonmonotonic%> sont spécifiés"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<runtime%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "schedule %<auto%> ne prend pas de paramètre %<chunk_size%>"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "la taille du fragment doit être positive"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "type d'ordonnancement invalide"
@@ -33899,17 +33952,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "la valeur de %<num_teams%> doit être positive"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "la valeur de %<thread_limit%> doit être positive"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "l'expression d'alignement %<aligned%> doit être une expression entière constante positive"
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr "utiliser des paramètres pour le pas %<linear%> n'est pas encore supporté"
@@ -33929,17 +33982,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "l'expression %<simdlen%> doit être une expression entière constante positive"
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "type de « depend » invalide"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "type de « map » invalide"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "type de « dist_schedule » invalide"
@@ -33949,67 +34002,67 @@
 msgid "invalid proc_bind kind"
 msgstr "type de « proc_bind » invalide"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "clause %<#pragma acc%> attendue"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs n'est pas valide pour %qs"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs doit être la première clause de %qs"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "clause %<#pragma omp%> attendue"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "pas de clause valide spécifiée dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "section de tableau dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD doit être une variable globale dans %<#pragma acc declare link%>"
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "clause OpenACC invalide au niveau global du fichier"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<extern%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "utilisation invalide de la variable %<globale%> %qD dans %<#pragma acc declare%>"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variable %qD utilisée plus d'une fois avec %<#pragma acc declare%>"
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> attendu après %<#pragma acc %s%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> n'a pas clause de mouvement de données"
@@ -34024,7 +34077,7 @@
 msgid "expected function name"
 msgstr "nom de fonction attendu"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD ne fait pas référence à une fonction"
@@ -34034,42 +34087,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une déclaration ou d'une définition de fonction"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> n'est pas immédiatement suivi d'une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> déjà appliqué à %qD"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> doit être appliqué avant l'utilisation"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> doit être appliqué avant la définition"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> doit contenir au moins une clause %<device%> ou %<host%> ou %<self%>"
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "forme invalide de %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "opération invalide pour %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> utilise deux expressions différentes pour la mémoire"
@@ -34079,27 +34132,27 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> ou fin de ligne attendue"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "le paramètre de la clause %<ordered%> est plus petit que %<collapse%>"
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "la clause %<linear%> ne peut pas être spécifiée avec la clause %<ordered%> comportant un paramètre"
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "instruction « for » attendue"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "instruction « _Cilk_for » attendue"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "déclaration ou initialisation d'itération attendue"
@@ -34109,72 +34162,72 @@
 msgid "not enough perfectly nested loops"
 msgstr "pas assez de boucles parfaitement imbriquées"
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "boucles coalescées imparfaitement imbriquées"
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "la variable d'itération %qD ne devrait pas être « firstprivate »"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "la clause %<ordered%> avec un paramètre ne devrait pas être spécifiée sur la construction %qs"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> avec une clause %<depend%> peut uniquement être utilisé dans des instructions composées"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> attendu après %qs"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> attendu"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur un clause %<map%>"
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> doit contenir au moins une clause %<from%> ou %<to%>"
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> avec un type avec correspondance autre que %<to%> ou %<alloc%> sur une clause %<map%>"
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> avec un type « map » autre que %<from%>, %<release%> ou %<delete%> sur une clause %<map%>"
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> doit contenir au moins une clause %<map%>"
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> avec un type avec correspondance autre que %<to%>, %<from%>, %<tofrom%> ou %<alloc%> sur une clause %<map%>"
@@ -34189,7 +34242,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> doit être suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr "%<#pragma omp declare simd%> ou l'attribut %<simd%> ne peuvent pas être utilisés dans la même fonction marquée comme une fonction Cilk Plus avec SIMD activé"
@@ -34199,32 +34252,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> pas immédiatement suivi d'une déclaration ou une définition de fonction"
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> pas immédiatement suivi par une seule déclaration ou définition de fonction"
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> avec des clauses entre %<#pragma omp declare target%> sans clauses et %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD est spécifié à la fois dans les clauses declare target %<link%> et %<to%>"
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> attendu"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> attendu"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> sans %<#pragma omp declare target%> correspondant"
@@ -34279,22 +34332,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<&omp_priv%>"
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> ou %<reduction%> ou %<target%> attendu"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE est déclaré %<threadprivate%> après la première utilisation"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "la variable automatique %qE ne peut être %<threadprivate%>"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE a un type incomplet"
@@ -34309,52 +34362,52 @@
 msgid "pragma simd must be inside a function"
 msgstr "le pragma simd doit être à l'intérieur de la fonction"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "vectorlength doit être une constante entière"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "vectorlength doit être une puissance de 2"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "la taille du pas doit être une expression constante entière ou une variable entière"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "clause %<#pragma simd%> attendue"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma cilk grainsize%> n'est pas suivi de %<_Cilk_for%>"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> à l'intérieur de %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "le %<__transaction_cancel%> extérieur n'est pas à l'intérieur d'un %<__transaction_atomic%> extérieur"
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  ou une fonction %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> pas à l'intérieur de %<__transaction_atomic%>"
@@ -34364,7 +34417,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "la base de la section des tableaux doit être d'un type pointeur ou tableau"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "%<:%> ou nombre attendu"
@@ -35079,7 +35132,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'initialisation pourrait être un candidat pour un attribut de format"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "le type de retour pourrait être un candidat pour un attribut de format"
@@ -35407,7 +35460,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "le C ISO interdit %<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "la fonction est déclarée avec %<noreturn%> mais elle utilise l'instruction %<return%>"
@@ -35417,7 +35470,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "une expression avec la notation de tableau ne peut pas être utilisée comme valeur retournée"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr "l'utilisation de %<_Cilk_spawn%> dans une instruction de retour n'est pas permise"
@@ -35442,7 +35495,7 @@
 msgid "function returns address of label"
 msgstr "la fonction retourne l'adresse d'une étiquette"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "la quantité du switch n'est pas un entier"
@@ -35457,7 +35510,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "l'étiquette du « case » doit être une expression constante entière"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "étiquette « case » en dehors de tout « switch »"
@@ -35477,17 +35530,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr "désaccord de rang entre la condition de l'instruction « if » et le bloc « else »"
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "mot-clé « break » à l'extérieur de toute boucle ou « switch »"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "mot-clé « continue » à l'extérieur de toute boucle"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "mot-clé « break » utilisé dans une boucle OpenMP"
@@ -35497,7 +35550,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "mot-clé « break » à l'intérieur du corps d'une boucle %<#pragma simd%>"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "mot-clé « continue » à l'intérieur du corps d'une boucle %<#pragma simd%>"
@@ -35603,12 +35656,12 @@
 msgid "used vector type where scalar is required"
 msgstr "valeur de type « vector » utilisée là où un scalaire est requis"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> doit spécifier l'une des clauses %<parallel%>, %<for%>, %<sections%> ou %<taskgroup%>"
@@ -35618,25 +35671,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE dans la clause %qs"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "champ de bits %qE dans la clause %qs"
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE est un membre d'une union"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE n'est pas une variable dans la clause %qs"
@@ -35647,70 +35700,70 @@
 msgstr "%<_Atomic%> %qD dans la clause %qs"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD est une variable « threadprivate » dans la clause %qs"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "la borne inférieure %qE de la section du tableau n'a pas un type entier"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "la longueur %qE de la section du tableau n'a pas un type entier"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "section de tableau ayant une longueur nulle dans la clause %qs"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type tableau dont la limite est inconnue"
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "limite inférieure négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "longueur négative dans la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "limite inférieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "longueur %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "limite supérieure %qE au delà de la taille de la section du tableau dans la clause %qs"
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "l'expression de longueur doit être spécifiée pour un type pointeur"
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "la section du tableau n'est pas contigüe dans la clause %qs"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE n'a pas un type pointeur ou tableau"
@@ -35730,7 +35783,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE a un type invalide pour %<reduction(%s)%>"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "réduction définie par l'utilisateur pas trouvée pour %qE"
@@ -35740,17 +35793,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "type d'élément de longueur variable dans la table de la clause %<reduction%>"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "la clause %<nowait%> ne doit pas être utilisée avec %<copyprivate%>"
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE doit être %<threadprivate%> pour %<copyin%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "le modificateur ne devrait pas être spécifié dans la clause %<linear%> sur des constructions %<simd%> ou %<for%>"
@@ -35770,18 +35823,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD dans la clause %<linear%>"
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "le pas %qE de la clause %<linear%> n'est ni une constante ni un paramètre"
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE n'est pas une variable dans la clause %qs"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de réduction"
@@ -35793,32 +35846,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de données"
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD apparaît à la fois dans les clauses « data » et « map »"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<firstprivate%>"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE n'est pas une variable dans la clause %<lastprivate%>"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<aligned%>"
@@ -35838,55 +35891,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE apparaît plus d'une fois dans les clause %<aligned%>"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE n'est pas une variable dans la clause %<depend%>"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "la section du tableau n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses de mouvement"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<map%>"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE n'a pas un type pour lequel une correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD n'a pas un type pour lequel la correspondance peut être établie (mappable type) dans la clause %qs"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE n'est ni une variable ni un nom de fonction dans la clause %qs"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE apparaît plus d'une fois dans la même directive %<declare target%>"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD n'est pas un argument dans la clause %<uniform%>"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE n'est pas un argument dans la clause %<uniform%>"
@@ -35896,33 +35949,33 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr "modificateur %<nonmonotonic%> spécifié pour le type d'ordonnancement %qs"
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "la clause %<inbranch%> est incompatible avec %<notinbranch%>"
 
 # le premier %qs est un mot non traduit tel que « private », « shared » ou « threadprivate ».
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE est prédéterminé %qs pour %qs"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "la valeur de la clause %<simdlen%> est plus grande que la valeur de la clause %<safelen%>"
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "modificateur d'ordonnancement %<nonmonotonic%> spécifié en même temps que la clause %<ordered%>"
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "le pas de la clause %<linear%> est un paramètre %qD pas spécifié dans la clause %<uniform%>"
@@ -36465,152 +36518,152 @@
 msgid "use of multiversioned function without a default"
 msgstr "utilisation d'une fonction ayant plusieurs versions sans version par défaut"
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "le passage de %qT comme argument %<this%> abandonne les qualificatifs"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dans l'appel de %qD"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT n'est pas une base accessible de %qT"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%qT est déduit comme étant %qT"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (vous pouvez désactiver ceci avec -fno-deduce-init-list)"
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "passage des arguments à l'élision du constructeur hérité %qD"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "le constructeur délègue à lui-même"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "appel à la non fonction %qD"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "ne peut appeler le constructeur %<%T::%D%> directement"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "pour un transtypage de style « fonction », enlevez le %<::%D%> redondant"
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "pas de fonction concordante pour l'appel à %<%T::%E(%A)%#V%>"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "pas de fonction concordante pour l'appel de %<%s(%A)%>"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "appel ambigu à la surcharge %<%s(%A)%>"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "appel à %q#D qui est pur virtuel depuis un initialisateur qui n'est pas un membre statique"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le constructeur"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "appel à %q#D qui est pur virtuel depuis le destructeur"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "impossible d'appeler la fonction membre %qD sans objet"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "le passage de %qT choisi %qT au lieu de %qT"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "choix de %qD à la place de %qD"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  pour la conversion de %qT vers %qT"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  parce que la séquence de conversion pour l'argument est meilleure"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "désaccord dans l'argument par défaut lors de la résolution de la surcharge"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidat 1: %q#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidat 2: %q#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "le C++ ISO indique que ceux-ci sont ambigus même si la plus mauvaise conversion pour le premier est meilleures que la plus mauvaise conversion pour le second:"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "impossible de convertir %qE de %qT vers %qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "une limite temporaire sur %qD existe uniquement jusqu'à la sortie du constructeur"
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "initialisation invalide pour une référence non constante du type %qT à partir d'une r-valeur de type %qT"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "initialisation invalide pour une référence du type %qT à partir d'une expression de type %qT"
@@ -36712,272 +36765,272 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "impossible de dériver de la classe de base %<final%> %qT dans le type dérivé %qT"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "toutes les fonctions membre de la classe %qT sont privées"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T définit uniquement un destructeur privé et n'a pas d'amis"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T définit uniquement des constructeurs privés et n'a pas d'amis"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "pas de surcharge finale unique pour %qD dans %qT"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD peut être marqué « override »"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D est marqué %<final%> mais il n'est pas virtuel"
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D est marqué %<override%> mais il ne surcharge rien"
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD était caché"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  par %qD"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q#D est invalide; une union anonyme ne peut avoir que des membres de données non statiques"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q#D est invalide; une structure anonyme ne peut avoir que des membres de données non statiques"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "membre privé %q#D dans une union anonyme"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr "membre privé %q#D dans une structure anonyme"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "membre protégé %q#D dans une union anonyme"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr "membre protégé %q#D dans une structure anonyme"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "l'élision dans %qD n'est pas héritée"
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "champ de bits %q+#D avec un type non entier"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "la largeur du champ de bits %q+D n'est pas une constante entière"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "largeur négative dans le champ de bits %q+D"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "largeur nulle pour le champ de bits %q+D"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "la largeur de %qD dépasse celle de son type"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD est trop petit pour contenir toutes les valeurs de %q#T"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "le membre %q+#D avec un constructeur n'est pas permis dans l'union"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "le membre %q+#D avec destructeur n'est pas permis dans l'union"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "le membre %q#D avec un opérateur d’affectation par copie n'est pas permis dans l'union"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "les unions sans restrictions sont disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "en C++98, %q+D ne peut pas être statique parce qu'il est un membre d'une union"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "le membre de donnée non statique %q+D dans une union ne peut pas avoir le type référencé %qT"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "le champ %q+D est incorrectement déclaré avec le type d'une fonction"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "le champ %q+D est incorrectement déclaré avec le type d'une méthode"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "attribut « packed » ignoré à cause du champ non POD non empaqueté %q#D"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "le membre %q+D ne peut pas être déclaré à la fois %<const%> et %<mutable%>"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "le membre %q+D ne peut pas être déclaré comme une référence %<mutable%>"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "champs multiples initialisés dans l'union %qT"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "champ %q#D avec le même nom que la classe"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T a des membres de données qui sont des pointeurs"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  mais il ne surcharge pas %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  ou %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  mais il ne surcharge pas %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr "l'alignement de %qD a augmenté avec -fabi-version=9 (GCC 5.2)"
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "l'alignement de %qD augmentera avec -fabi-version=9"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initialisation spécifiée pour une méthode non virtuelle %q+D"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "la méthode surcharge à la fois les méthodes %<transaction_pure%> et %qE"
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "la méthode déclarée %qE surcharge la méthode %qE"
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "la classe englobant la fonction membre non statique « constexpr » %q+#D n'est pas un type littéral"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T n'est pas littéral à cause de:"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T a un destructeur non trivial"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr "  %q+T n'est pas un agrégat, n'a pas de constructeur par défaut trivial et n'a pas de constructeur « constexpr » qui n'est pas un constructeur de copie ou par déplacement"
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  la classe de base %qT de %q+T n'est pas littérale"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  le membre de donnée non statique %qD a un type non littéral"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  le membre de donnée non statique %qD a un type volatile"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "la classe de base %q#T a un destructeur non virtuel accessible"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "la référence non statique %q#D dans la classe sans un constructeur"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "le membre constant non statique %q#D dans la classe sans un constructeur"
@@ -36984,153 +37037,153 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D est déclaré pour prendre une référence const mais la déclaration implicite prendrait un non-const"
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "la base directe %qT est inaccessible dans %qT en raison de l'ambiguïté"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "la base virtuelle %qT est inaccessible dans %qT en raison de l'ambiguïté"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "le décalage relatif de %qD n'est pas compatible avec l'ABI et peut changer dans une version future de GCC"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "la taille du type %qT est trop grande (%qE octets)"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "utilisation invalide de %q#T avec un tableau de taille nulle dans %q#D"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "utilisation invalide de %q#T avec un membre sous forme de tableau flexible dans %q#T"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "membre tableau %q#D déclaré ici"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "membre tableau de taille nulle %qD pas à la fin de %q#T"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "membre tableau de taille nulle %qD dans un %q#T par ailleurs vide"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "dans la définition de %q#T"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "le membre tableau flexible %qD n'est pas à la fin de %q#T"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "membre tableau flexible %qD dans %q#T par ailleurs vide"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "membre %q#D suivant déclaré ici"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redéfinition de %q#T"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T a des fonctions virtuelles et un destructeur non virtuel accessible"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "le type transparent %q#T n'a aucun champ"
 
 # un type transparent est un type qui est passé comme le type qu'elle manipule, par ex decimal32
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "la classe de type transparent %qT a des classes de base"
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "la classe de type transparent %qT a des fonctions virtuelles"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "le type transparent %q#T ne peut être rendu transparent car le type du premier champ a une ABI différente de la classe générale"
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "la définition de std::initializer_list ne correspond pas à #include <initializer_list>"
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "la tentative de terminer la struct a été stoppée nette en raison des erreurs précédentes dans l'analyse syntaxique"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "la chaîne de langage %<\"%E\"%> n'est pas reconnue"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ne peut résoudre la fonction surchargée %qD basé sur la conversion vers le type %qT"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "pas de correspondance pour convertir la fonction %qD vers le type %q#T"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "la conversion de la fonction surchargée %qD vers le type %q#T est ambiguë"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "on suppose un pointeur vers le membre %qD"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(un pointeur vers un membre peut seulement être formé avec %<&%E%>)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "pas assez d'informations sur le type"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "impossible de convertir %qE du type %qT vers le type %qT"
@@ -37140,13 +37193,13 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "la déclaration de %q#D"
 
 # ce message suit directement le précédent
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr "change la signification de %qD depuis %q#D"
@@ -37176,332 +37229,332 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "type retourné %qT invalide pour la fonction constexpr %q+D"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T a des classes virtuelles de base"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr "le constructeur constexpr n'a pas de corps vide"
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr "le corps du constructeur %<constexpr%> ne peut pas être un try..catch sur toute la fonction (function-try-block)"
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "le constructeur %<constexpr%> de l'union %qT doit initialiser exactement un membre de donnée non statique"
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "le membre %qD doit être initialisé par l'initialisation des membres dans le constructeur %<constexpr%>"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "le corps de la fonction constexpr %qD n'est pas une unique instruction « return »"
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%qD n'est pas utilisable comme une fonction constexpr car:"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E n'est pas une expression constante"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "appel à la fonction interne %qE"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "l'expression %qE ne désigne pas une fonction constexpr"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "appel à la fonction non constexpr %qD"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD est appelé dans une expression constante avant que sa définition soit complète"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD appelé dans une expression constante"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD utilisé avant sa définition"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "l'appel a une dépendance circulaire"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "la profondeur d'évaluation de la constexpr dépasse le maximum permis %d (utilisez -fconstexpr-depth= pour augmenter le maximum)"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr "l'appel constexpr déborde au delà de la fin de la fonction"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "l'opérande de droite de l'expression de décalage %q+E est négatif"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr "l'opérande de droite de l'expression de décalage %q+E est >= à la précision de l'opérande de gauche"
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "l'opérande de gauche de l'expression de décalage %q+E est négatif"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "l'expression de décalage %q+E déborde"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "arithmétique impliquant un pointeur nul dans %qE"
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "la valeur %qE de l'indice du tableau est hors des limites du tableau %qD du type %qT"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "la valeur %qE de l'indice du tableau est hors des limites du tableau de type %qT"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "accès à un élément non initialisé du tableau"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "déréférencement d'un pointeur nul dans %qE"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE n'est pas une expression constante"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "le mutable %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "accès au membre %qD au lieu du membre initialisé %qD dans l'expression constante"
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "accès au membre non initialisé %qD"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "déréférencement d'un pointeur nul"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "accès à la valeur de %qE au travers d'une gl-valeur %qT dans une expression constante"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "la valeur de %qD n'est pas utilisable dans une expression constante"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD utilisé dans sa propre initialisation"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D n'est pas const"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D est volatile"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD n'a pas été initialisé par une expression constante"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD n'a pas été déclaré %<constexpr%>"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD n'a pas un type entier ou énuméré"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "la modification de %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "le décompte des itérations de la boucle constexpr dépasse la limite permise %d (utilisez -fconstexpr-loop-limit= pour augmenter la limite)"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "la valeur %qE du type %qT n'est pas une expression constante"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporaire du type %qT non littéral dans une expression constante"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "un reinterpret_cast n'est pas une expression constante"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "la conversion du pointeur nul %qT vers %qT n'est pas une expression constante"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> n'est pas une expression constante"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "l'expression %qE n'est pas une expression constante"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "l'instruction n'est pas une expression constante"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "l'expression %qE du sous-type %s est inattendue"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE n'est pas une expression constante car il fait référence aux sous-objets mutables de %qT"
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE n'est pas une expression constante car il fait référence à une variable incomplètement initialisée"
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "conversion depuis le type pointeur %qT vers le type arithmétique %qT dans une expression constante"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "l'expression %qE à des effets de bord"
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast d'un entier vers un pointeur"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "prendre l'adresse avec address-of d'un objet %qE qui est local au thread ou a un stockage automatique n'est pas une expression constante"
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "utilisation de %<this%> dans une expression constante"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "l'expression typeid n'est pas une expression constante car %qE est un type polymorphique"
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "transtypage vers le type non entier %qT dans une expression constante"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%qD déclaré %<static%> dans une fonction %<constexpr%>"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qD déclaré %<thread_local%> dans une fonction %<constexpr%>"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variable %qD non initialisée dans une fonction %<constexpr%>"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "la division par zéro n'est pas une expression constante"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> n'est pas une expression constante"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "initialisation d'un tableau non constant"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> n'est pas une expression constante"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "arbre syntaxique abstrait (AST=Abstract Syntax Tree) de type %s inattendu"
@@ -38297,7 +38350,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  passe outre l'initialisation de %q#D"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "sortie invalide du bloc structuré OpenMP"
@@ -38312,7 +38365,7 @@
 msgid "%qD is not a type"
 msgstr "%qD n'est pas un type"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD utilisé sans paramètres du patron"
@@ -39949,7 +40002,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "paramètre déclaré %<auto%>"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "utilisation invalide du nom de patron %qE sans liste d'arguments"
@@ -40400,13 +40453,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD a le même nom que la classe dans laquelle il est déclaré"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT n'est pas un patron"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "déclaration précédente ici"
@@ -40416,8 +40469,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "vous voulez peut-être ajouter %<%T::%> explicitement"
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "la référence à %qD est ambiguë"
@@ -40467,7 +40520,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "non concordance entre un enum simple et un enum fortement typé pour %q#T"
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "définition précédente ici"
@@ -40531,7 +40584,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "le type retourné %q#T est incomplet"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> devrait retourner une référence à %<*this%>"
@@ -40546,7 +40599,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "« return » manquant dans une fonction retournant %qT"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "seul un type de retour %<auto%> évident peut être déduit en %<void%>"
@@ -40704,27 +40757,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "la largeur du champ de bits %qD a le type non entier %qT"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "membre de donnée statique %q+D à l'intérieur de la directive de déclaration de cible"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "struct anonyme pas à l'intérieur d'un type nommé"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "les agrégats anonymes dans la portée de l'espace de noms doivent être statiques"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "union anonyme sans aucun membre"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> doit retourner le type %qT"
@@ -40733,67 +40786,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "le premier paramètre de %<operator new%> ne peut pas avoir d'argument par défaut"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> prend le type %<size_t%> (%qT) comme premier paramètre"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> doit retourner le type %qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> prend le type %qT comme premier paramètre"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT a un champ %qD dont le type n'a pas de classe de liaison"
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT a un champ %qD dont le type dépend du type %qT qui n'a pas de classe de liaison"
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT a un champ %qD dont le type utilise l'espace de noms anonyme"
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT est déclaré avec une plus grande visibilité que le type de son champs %qD"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT a la base %qT dont le type n'a pas de classe de liaison"
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT a la base %qT dont le type dépend du type %qT qui n'a pas de classe de liaison"
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT a la base %qT dont le type utilise l'espace de noms anonyme"
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT est déclaré avec une plus grande visibilité que sa base %qT"
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q#D, déclaré avec un type non nommé, est utilisé mais jamais défini"
@@ -40802,47 +40855,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "un type non nommé sans classe de liaison est utilisé pour déclarer la variable %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "un type non nommé sans classe de liaison est utilisé pour déclarer la fonction %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D ne réfère pas au type non qualifié, aussi n'est-il pas utilisé pour la liaison"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, déclaré avec le type local %qT, est utilisé mais jamais défini"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "le type %qT sans classe de liaison est utilisé pour déclarer la variable %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "le type %qT sans classe de liaison est utilisé pour déclarer la fonction %q#D avec une classe de liaison"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "le programme devrait aussi définir %qD"
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "la fonction en ligne %qD est utilisée mais n'a jamais été définie"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "argument par défaut manquant pour le paramètre %P de %q+#D"
@@ -40849,12 +40902,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "conversion d'une fonction lambda qui utilise %<...%> en pointeur de fonction"
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "utilisation de la fonction supprimée %qD"
@@ -41163,18 +41216,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "initialisation invalide pour le membre tableau %q#D"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "membre constant non initialisé dans %q#T"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D devrait être initialisé"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "membre par référence non initialisé dans %q#T"
@@ -41274,7 +41327,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "le tableau doit être initialisé avec une initialisation entre accolades"
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT n'est pas un type de classe"
@@ -41294,7 +41347,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "utilisation invalide de la fonction membre non statique %qD"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "utilisation invalide du membre de donnée non statique %qD"
@@ -41489,22 +41542,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr "car le type %qT des éléments du tableau a une taille variable"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "ne peut capturer %qE par référence"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "capture par copie du type incomplet %qT"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "%qD déjà capturé dans l'expression lambda"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> n'a pas été capturé pour cette fonction lambda"
@@ -41559,186 +41612,186 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(si vous utilisez %<-fpermissive%>, G++ acceptera votre code, mais permettre l'utilisation d'un nom non déclaré est obsolète)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "décoration de typeof, utilisez plutôt decltype"
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "décoration de __underlying_type"
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "décoration du type en virgule fixe inconnu"
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "utilisation du trait interne %qE dans la signature de la fonction, utilisez plutôt la bibliothèque des traits"
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "décoration de %C"
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "l'opérande omis au milieu de %<?:%> ne peut pas être décoré"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "chaîne littérale dans la signature du patron de la fonction"
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "le nom décoré pour %qD changera dans le C++17 car la spécification de l'exception fait partir du type de la fonction"
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "un -fabi-version= plus récent (ou =0) évite cette erreur avec un changement de décoration"
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "le nom décoré de %qD a changé entre -fabi-version=%d (%D) et -fabi-version=%d (%D)"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "le nom décoré de %qD change entre -fabi-version=%d (%D) et -fabi-version=%d (%D)"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "le nom décoré d'un fragment pour %qD change entre -fabi-version=%d et -fabi-version=%d"
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "le nom décoré de %qD change entre -fabi-version=%d et -fabi-version=%d"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "le nom décoré de la variable de protection de l'initialisation pour %qD change entre -fabi-version=%d et -fabi-version=%d"
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "le membre constant non statique %q#D ne peut utiliser l'opérateur d'affectation par défaut"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "le membre par référence non statique %q#D ne peut utiliser l'opérateur d'affectation par défaut"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr "la méthode synthétisée %qD est requise ici pour la première fois "
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "membre d'union %q+D avec un %qD non trivial"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "le constructeur par défaut appelle %qD qui n'est pas constexpr"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "l'initialisation pour %q#D est invalide"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "le constructeur par défaut imposé par défaut n'initialise pas %q#D"
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "copie du membre de donnée non statique %q#D du type de référence d'une r-valeur"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "le constructeur par défaut imposé par défaut n'initialise aucun membre de donnée non statique"
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr "l'affectation par déplacement imposée par défaut pour %qT appelle l'opérateur d'affectation par déplacement non trivial de la base virtuelle %qT"
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "un type de fermeture lambda a un constructeur par défaut supprimé"
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "un type de fermeture lambda a un opérateur d'affectation par copie supprimé"
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q#D est implicitement déclaré comme supprimé car %qT déclare un constructeur par déplacement ou un opérateur d'affectation par déplacement"
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr "%q#D hérite depuis plusieurs sous-objets de base"
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q#D est implicitement supprimé car la définition par défaut serait mal formée:"
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F est implicitement supprimé car sa spécification d'exception ne correspond pas à la spécification d'exception implicite %qX"
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "déclaration imposée par défaut %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr "ne correspond pas à la signature %qD attendue"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr "la fonction %q+D est imposée par défaut au moment de sa déclaration avec une spécification d'exception qui diffère de la spécification d'exception implicite %qX"
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr "la fonction %q+D imposée par défaut explicitement ne peut pas être déclarée constexpr car la déclaration implicite n'est pas constexpr:"
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "un patron ne peut pas être imposé par défaut"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD ne peut pas être imposé par défaut"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "fonction %q+D imposée par défaut avec un argument par défaut"
@@ -41930,97 +41983,97 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nomme le constructeur dans %qT"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "impossible d'hériter des constructeurs depuis la base indirecte %qT"
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "aucun membre concordant avec %<%T::%D%> dans %q#T"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "la déclaration de %qD n'est pas dans l'espace de noms entourant %qD"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "qualificatifs explicites dans la déclaration de %qD"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr "%qD n'a pas été déclaré dans %D"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, gcc-internal-format
 msgid "only here as a friend"
 msgstr "uniquement ici comme ami"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD aurait dû être déclaré à l'intérieur de %qD"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "l'attribut %qD requiert un seul argument NTBS"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "l'attribut %qD n'a pas de signification puisque les membres de l'espace de noms anonyme obtiennent des symboles locaux"
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms pas en ligne"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "l'attribut %qD est ignoré sur l'espace de noms anonyme"
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "la directive d'attribut %qD est ignorée"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "l'alias de l'espace de noms %qD n'est pas permis ici, on suppose %qD"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "un « using » fort est déprécié, utilisez plutôt un espace de noms en ligne"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "un « using » fort n'a de sens qu'au niveau de l'espace de noms"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "l'espace de noms actuel %qD n'englobe pas l'espace de noms fortement utilisé %qD"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "limite maximale de %d espaces de noms recherchés pour %qE"
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "alternatives suggérées: %qs"
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -42027,27 +42080,27 @@
 msgstr[0] "alternative suggérée:"
 msgstr[1] "alternatives suggérées:"
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr "la recherche dépendant de l'argument trouve %q+D"
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr "la déclaration de std::initializer_list ne correspond pas à #include <initializer_list> et n'est pas un patron"
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX entre dans pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX quitte pop_everything ()\n"
@@ -42067,7 +42120,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P n'est pas défini à vrai"
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> pas immédiatement suivi par une déclaration ou une définition de fonction"
@@ -42092,7 +42145,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "requête du membre %qE dans le type %qT qui n'est pas une classe"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> n'a pas été déclaré"
@@ -42152,1203 +42205,1208 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(un point virgule est peut-être manquant après la définition de %qT)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "%qE n'est pas un patron de classe"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE n'est pas un patron"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "template-id invalide"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "le C++ ISO interdit l'utilisation d'un littéral en virgule flottante dans une expression constante"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "un transtypage vers un type autre qu'un entier ou une énumération ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "l'opérateur %<typeid%> ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "un littéral composé non constant ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "un appel de fonction ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "une incrémentation ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "une décrémentation ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "une référence vers un tableau ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "l'adresse d'une étiquette ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "des appels à des opérateurs surchargés ne peuvent pas apparaître dans une expression constante"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "une affectation ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "un opérateur virgule ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "un appel à un constructeur ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "une expression de transaction ne peut pas apparaître dans une expression constante"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%qs ne peut pas apparaître dans une expression de constante"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "la déduction des arguments d'un patron de classe est uniquement disponible avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "utilisation invalide du destructeur %qD comme un type"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "combinaison invalide de spécificateurs de types multiples"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE ne nomme pas un type; vouliez-vous utiliser %qs ?"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE ne nomme pas un type"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "le %<constexpr%> du C++11 est uniquement disponible avec -std=c++11 ou -std=gnu++11"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "le %<noexcept%> du C++11 est uniquement disponible avec -std=c++11 ou -std=gnu++11"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "le %<thread_local%> du C++11 est uniquement disponible avec -std=c++11 ou -std=gnu++11"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr "%<concept%> uniquement disponible avec -fconcepts"
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(peut-être que %<typename %T::%E%> était votre intention)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE dans l'espace de noms %qE ne nomme pas un type de patron"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE dans l'espace de noms %qE ne nomme pas un type"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%E%> nomme le constructeur, pas le type"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "et %qT n'a pas de constructeur avec patron"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr "a besoin de %<typename%> avant %<%T::%E%> car %qT est une portée dépendante"
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE dans %q#T ne nomme pas pas un type de patron"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE dans %q#T ne nomme pas un type"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr "chaîne littérale attendue"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr "les suffixes littéraux définis par l'utilisateur %qD et %qD sont inconsistants dans la chaîne littérale"
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr "une chaîne large est invalide dans ce contexte"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr "impossible de trouver l'opérateur littéral de caractère %qD avec l'argument %qT"
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr "le littéral entier dépasse la plage du type %qT"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr "le littéral en virgule flottante dépasse la plage de type %qT"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr "le littéral en virgule flottante est tronqué à zéro"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr "impossible de trouver l'opérateur littéral numérique %qD"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr "utilisez -std=gnu++11 ou -fext-numeric-literals pour activer plus de suffixes internes"
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "impossible de trouver l'opérateur littéral de chaîne %qD avec les arguments %qT, %qT"
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "déclaration attendue"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, gcc-internal-format
 msgid "expected binary operator"
 msgstr "opérateur binaire attendu"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, gcc-internal-format
 msgid "expected ..."
 msgstr "... attendu"
 
 # je n'ai pas trouvé d'autre terme accepté en français pour une fold-expression
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr "expression binaire dans l'opérande d'une expression fold"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "expression conditionnelle dans l'opérande d'une expression fold"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr "opérateur en désaccord dans l'expression fold"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "types en virgule fixe pas supportés en C++"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "le C++ ISO interdit les groupes d'accolades à l'intérieur des expressions"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "les expressions-instructions ne sont pas permises en dehors des fonctions ni dans les listes d'arguments du patron"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "les expressions fold sont uniquement disponibles avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "expression primaire attendue"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "%<this%> ne peut pas être utilisé dans ce contexte"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "une déclaration de patron ne peut pas apparaître au niveau d'un bloc"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "la variable locale %qD ne peut pas apparaître dans ce contexte"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "expression id attendue"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "la portée %qT avant %<~%> n'est pas un nom de classe"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "déclaration de %<~%T%> comme membre de %qT"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "nom du typedef %qD utilisé comme déclaration de destructeur"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "les suffixes d'opérateurs littéraux qui ne sont pas précédés par %<_%> sont réservés pour une standardisation future"
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualified-id attendu"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "%<:%> trouvé dans le spécificateur de nom imbriqué, %<::%> attendu"
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype est évalué en %qT qui n'est ni une classe ni un type énuméré"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "template-id de la fonction %qD dans le spécificateur de nom imbriqué"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "template-id de la variable %qD dans le spécificateur de nom imbriqué"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD n'est pas un patron"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "spécificateur de nom imbriqué attendu"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "les types ne peuvent pas être définis dans les transtypages"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "les types ne peuvent pas être définis dans une expression %<typeid%>"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr "%<_Cilk_spawn%> doit être suivi d'une expression"
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_addressof%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "mauvais nombre d'arguments pour %<__builtin_launder%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "le C++ ISO interdit les littéraux composés"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "deux %<[%> consécutifs n'introduiront qu'un attribut"
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr "l'index de liste entre parenthèses n'est pas permis avec la notation tableau"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "utilisation invalide de %qD"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> n'est pas un membre de classe"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "type non scalaire"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "le C++ ISO ne permet pas %<alignof%> avec un non type"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "les types ne peuvent pas être définis dans des expressions %<noexcept%>"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "les types ne peuvent pas être définis dans une expression « new »"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "les limites de tableau sont interdites après un type-id entre parenthèses"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "essayez d'enlever les parenthèses autour du type-id"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "l'initialisation de l'expression « new » pour le type %<auto%> exige exactement un élément"
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "liste-expression ou type-id attendu"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "les types ne peuvent pas être définis dans un new-type-id"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "l'expression dans la déclaration « new » doit être un type entier ou un type énuméré"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "utilisation d'un vieux style de transtypage"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "l'opérateur %<>>%> est traité comme deux caractères > en C++11"
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "parenthèses suggérées autour de l'expression %<>>%>"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "le C++ ISO ne permet pas d'omettre l'opérande du milieu de ?:"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "expression lambda dans un contexte non évalué"
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "expression lambda dans l'argument du patron"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "fin de liste de capture attendue"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "la capture par copie explicite de %<this%> est redondante avec la capture par copie par défaut"
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "la capture de %<*this%> est uniquement disponible avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "les initialisations par capture des fonctions lambda sont uniquement disponibles avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "initialisation vide pour la capture par initialisation d'une fonction lambda"
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "capture de %qD qui n'est pas une variable"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D déclaré ici"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "capture de la variable %qD avec une durée de stockage non automatique"
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "la capture par copie explicite de %qD est redondante avec la capture par copie par défaut"
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "la capture par référence explicite de %qD est redondante avec la capture par référence par défaut"
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "les patrons lambda sont uniquement disponibles avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, gcc-internal-format
 msgid "ISO C++ does not support lambda templates"
 msgstr "le C++ ISO ne supporte pas les patrons lambda"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "argument par défaut spécifié pour un paramètre lambda"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "%<mutable%> dupliqué"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "les lambda %<constexpr%> sont uniquement disponibles avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "les attributs au début d'une instruction sont ignorés"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "instruction étiquetée attendue"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "le « case » %qE n'est pas à l'intérieur de l'instruction « switch »"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> doit être utilisé avant %qE car %qT est une portée dépendante"
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nomme le constructeur, pas le type"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr "instruction composée dans une fonction constexpr"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "%<if constexpr%> uniquement disponible avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "l'instruction init dans des instructions de sélection est uniquement disponible avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "instruction de sélection attendue"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "des types ne peuvent pas être définis dans des conditions"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "l'expression %<for%> parcourant une plage de type %qT a un type incompatible"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr "l'expression %<for%> parcourant une plage de type %qT a un membre %<end%> mais pas de %<begin%>"
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr "l'expression %<for%> parcourant une plage de type %qT a un membre %<begin%> mais pas de %<end%>"
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "types différents pour « begin » et « end » de l'instruction %<for%> parcourant une plage: %qT et %qT"
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "instruction d'itération attendue"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "les boucles %<for%> parcourant une plage sont uniquement disponibles avec -std=c++11 ou -std=gnu++11"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr "instruction « break » utilisée avec une boucle « for » Cilk Plus"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> dans une fonction %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "le C++ ISO interdit les gotos calculés"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "instruction de saut attendue"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> superflu"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> pas au début du bloc"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "non variable %qD dans la déclaration avec plus d'une déclaration contenant un type à remplacer"
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "déduction incohérente pour %qT: %qT et puis %qT"
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "mélanger des déclarations et des définitions de fonctions est interdit"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "des types ne peuvent pas être définis dans la déclaration d'une instruction « for » parcourant une plage"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initialisation dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "déclarations multiples dans une boucle %<for%> parcourant une plage"
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "les déclarations avec décompositions sont uniquement disponibles avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, gcc-internal-format
 msgid "empty decomposition declaration"
 msgstr "déclaration avec décomposition vide"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
 #, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr "initialisation invalide pour la déclaration de liaison structurée"
+
+#: cp/parser.c:13220
+#, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> utilisé en dehors d'une classe"
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> a changé de signification en C++11; retirez-le"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "spécificateur de déclaration invalide dans une condition"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD est invalide dans une lambda"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "la définition de classe ne peut pas être déclarée comme amie"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "les patrons ne peuvent pas être %<virtual%>"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "spécification de classe de liaison invalide"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "un static_assert sans message est uniquement disponible avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "les types ne peuvent pas être définis dans les expressions %<decltype%>"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "les types ne peuvent pas être définis dans un conversion-type-id"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "utilisation invalide de %<auto%> dans un opérateur de conversion"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "un %<auto%> dans un opérateur de conversion d'un patron membre ne peut jamais être déduit"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "seuls les constructeurs prennent des initialisions membres"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "impossible de développer l'initialisation du membre %<%D%>"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "l'initialisation en mémoire pour %qD suit la délégation du constructeur"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "la délégation du constructeur suit l'initialisation en mémoire pour %qD"
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "ancien style anachronique d'initialisation de classe de base"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (une initialisation de membre qualifiée est implicitement un type)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "mot-clé inattendu; enlevez l'espace entre les guillemets et l'identificateur du suffixe"
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "identificateur de suffixe attendu"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "une chaîne vide était attendue après le mot-clé %<operator%>"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "préfixe d'encodage invalide dans l'opérateur littéral"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "opérateur attendu"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "le mot-clé %<export%> n'est pas implémenté et sera ignoré"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "paramètre de type contraint invalide"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "paramètre de type qualifié avec CV"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "contrainte variadique introduite sans %<...%>"
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "utilisation invalide de %<auto%> dans l'argument par défaut du patron"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "les paquets de paramètres des patrons ne peuvent pas avoir d'arguments par défaut"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "template-id attendu"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> ne peut pas être au début d'une liste d'arguments d'un patron"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> est une écriture alternative pour %<[%>. Insérer un espace entre %<<%> et %<::%>"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(si vous utilisez %<-fpermissive%> ou %<-std=c++11%> ou %<-std=gnu++11%> G++ acceptera votre code)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "erreur d'analyse dans la liste des arguments du patron"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "nom de patron attendu"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD n'est pas un patron mais il est utilisé comme patron"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "utilisez %<%T::template %D%> pour indiquer que c'est un patron"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "paquet de paramètres attendu avant %<...%>"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "argument de patron attendu"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "argument de patron invalide car ce n'est pas un type"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<inline%>"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "une instanciation explicite ne doit pas utiliser le spécificateur %<constexpr%>"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "spécialisation de patron avec édition de liens C"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "spécificateur du type attendu"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "l'utilisation de %<auto%> dans la déclaration d'un paramètre lambda est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "l'utilisation de %<auto%> dans une déclaration de paramètre est uniquement disponible avec -std=c++14 ou -std=gnu++14"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "le C++ ISO interdit l'utilisation de %<auto%> dans une déclaration de paramètre"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "template-id attendu pour le type"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "un nom de type attendu"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "un spécificateur de type élaboré pour un enum fortement typé ne peut pas utiliser le mot-clé %<%D%>"
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "la déclaration %qD ne déclare rien du tout"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributs ignorés sur un type non instancié"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attributs ignorés sur une instanciation de patron"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attributs ignorés sur un spécificateur de type élaboré qui n'est pas une déclaration anticipée"
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD est un patron d'énumération"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD ne nomme pas une énumération dans %qT"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "un enum fortement typé sans nom n'est pas permis"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> ou %<{%> attendu"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "impossible d'ajouter une liste d'énumération à l'instanciation d'un patron"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "le spécificateur de nom imbriqué %qT pour la déclaration d'un enum ne nomme pas une classe ou un espace de noms"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans l'espace de noms %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "déclaration de %qD dans %qD lequel n'englobe pas %qD"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "qualification supplémentaire pas permise"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "définition multiple de %q#T"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "le C++ ISO interdit un enum vide et sans nom"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "spécificateur enum opaque sans nom"
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "un spécificateur enum opaque doit utiliser un simple identificateur"
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD n'est pas un espace de noms"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "espace de noms attendu"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "une définition d'espace de noms imbriqué ne peut pas avoir d'attribut"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "les définitions d'espace de noms imbriqués sont uniquement disponibles avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "une définition d'un espace de noms imbriqué ne peut pas être « inline »"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, gcc-internal-format
 msgid "nested identifier required"
 msgstr "identificateur imbriqué requis"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "entrée dans l'espace de noms %qD"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "la définition %<namespace%> n'est pas permise ici"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "l'expansion de paquets dans une déclaration « using » est uniquement disponible avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "un template-id ne peut pas apparaître dans l'utilisation de la déclaration"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "une liste séparée par des virgules dans une déclaration « using » est uniquement disponible avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "les déclarations d'accès sont dépréciées en faveur des déclarations « using »; suggestion: ajoutez le mot-clé %<using%>"
 
 # alias template est un patron appliqué à un alias == patron d'alias
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "les types ne peuvent pas être définis dans des déclarations de patrons d'alias"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> dans une fonction %<constexpr%>"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "une définition de fonction n'est pas permise ici"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "une spécification asm n'est pas permise dans une définition de fonction"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "des attributs ne sont pas permis dans une définition de fonction"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "constructeur, destructeur ou conversion de type attendu"
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initialisation attendue"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initialisation fournie pour une fonction"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "les attributs après l'initialisation entre parenthèses sont ignorés"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "la non fonction %qD est déclarée comme un patron implicite"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "la limite du tableau n'est pas une constante entière"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "impossible de définir le membre du typedef dépendant %qT"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> n'est pas un type"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "utilisation invalide du constructeur comme patron"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "utilisez %<%T::%D%> au lieu de %<%T::%D%> pour nommer le constructeur dans un nom qualifié"
@@ -43357,7 +43415,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "déclarateur invalide"
@@ -43364,340 +43422,338 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id dans une déclaration"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "déclarateur attendu"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD est un espace de noms"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "impossible de former un pointeur vers un membre de la non classe %q#T"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "opérateur pointeur attendu"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "qualificatif CV dupliqué"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "qualificatifs de référence multiples"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr "%E requiert %<-fgnu-tm%>"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "spécificateurs virtuels (virt-specifier) multiples"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "arguments de patron manquants après %qT"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "utilisation invalide de %qT"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "les types ne peuvent pas être définis dans les arguments du patron"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "utilisation invalide de %<auto%> dans un argument de patron"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "spécificateur de type attendu"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> ou %<...%> attendu"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "des types ne peuvent pas être définis dans des types de paramètres"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "des arguments par défaut sont uniquement permis pour des paramètres de fonction"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "le paquet de paramètres %qD ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres du patron ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "le paquet de paramètres ne peut pas avoir d'argument par défaut"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "le C++ ISO ne permet pas des initialisations par désignation du C99"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "nom de classe attendu"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> attendu après la définition de la classe"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> attendu après la définition de la structure"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> attendu après la définition de l'union"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> ou %<:%> attendu"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ne peut spécifier %<override%> pour une classe"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "la qualification globale du nom de la classe est invalide"
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "le nom qualifié ne nomme pas une classe"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "nom de classe invalide dans la déclaration de %qD"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "une spécialisation explicite doit être précédée par %<template <>%>"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "le patron de fonction %qD est redéclaré comme un patron de classe"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "impossible de résoudre le type de typename"
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "définition précédente de %q#T"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "mot-clé de type classe (class ou struct) attendu"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr "le C++ ISO interdit le mot-clé typename dans un paramètre de patron qui est un patron; utilisez -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> ou %<typename%> attendu"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "en C++03, le mot-clé class (ou struct) doit être utilisé lors de la déclaration d'un ami"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "la déclaration amie ne nomme pas une classe ou une fonction"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "une classe de stockage sur un agrégat anonyme dans une classe n'est pas permis"
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "spécificateur pur sur une définition de fonction"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<,%> égarée à la fin de la déclaration du membre"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> attendu à la fin de la déclaration du membre"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "spécificateur pur invalide (seul %<= 0%> est autorisé)"
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "une initialisation entre accolades n'est par permise ici"
 
-# Je crois que base-specified aurait dû être base-specifier car la fonction où ce message appraît est nommée ainsi. Je n'ai pas signalé ce bug car je ne suis pas sûr qu'il s'agit réellement d'une erreur.
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> spécifié plus d'une fois dans le spécificateur de base"
 
-# Je crois que base-specified aurait dû être base-specifier car la fonction où ce message appraît est nommée ainsi. Je n'ai pas signalé ce bug car je ne suis pas sûr qu'il s'agit réellement d'une erreur.
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr "plus d'un spécificateur d'accès dans le spécificateur de base"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "le mot-clé %<typename%> n'est pas permis en dehors des patrons"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "le mot-clé %<typename%> n'est pas permis dans ce contexte (la classe de base est implicitement un type)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "les types ne peuvent pas être définis dans une spécification d'exception"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "le C++1z ISO n'autorise pas la spécification dynamique des exceptions"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "les spécifications dynamiques d'exceptions sont dépréciées en C++11"
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "utilisation invalide de %<auto%> dans une spécification d'exception"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> dans une fonction %<constexpr%>"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "des types ne peuvent pas être définis dans une déclaration d'exception"
 
 # Je ne suis pas sûr du tout de la signification de « scoped attribute token »…
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "l'attribut de préfixe « using » est utilisé en même temps qu'un élément d'attribut agissant sur une portée"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "un identificateur est attendu pour le nom d'attribut"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "l'attribut %<noreturn%> ne peut apparaître qu'une seule fois au plus dans la liste d'attributs"
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "l'attribut %<deprecated%> ne peut apparaître qu'une seule fois au plus dans la liste d'attributs"
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut attendu avant %<...%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "l'attribut de préfixe « using » est uniquement disponible avec -std=c++1z ou -std=gnu++1z"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> uniquement disponible avec -fconcepts"
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "une expression « requires » ne peut pas apparaître en dehors d'un patron"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "la syntaxe %<template<>%> est requise pour spécialiser %<%T::%E%>"
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "déclaration invalide de %<%T::%E%>"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "trop peu de listes de paramètres pour le patron"
@@ -43706,488 +43762,488 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "trop de listes de paramètres pour le patron"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "les valeurs nommées à retourner ne sont plus supportées"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet d'arguments de type non patron tels que <char...> ou <typename CharT, CharT...>"
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "le patron de l'opérateur littéral %qD a une liste de paramètres invalide. On attendait un paquet d'arguments de type non patron tel que <char...>"
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "liste d'instructions vide"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "pas de concept correspondant pour l'introduction du patron"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "déclaration invalide du patron membre dans la classe locale"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "patron avec liaison C"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "spécialisation explicite invalide"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "déclaration de patron de %<typedef%>"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "une déclaration de patron de classe ne doit rien déclarer d'autre"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "une spécialisation explicite de patron ne peut pas avoir une classe de stockage"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> devrait être %<> >%> à l'intérieur d'une liste d'arguments de patron imbriqués"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "le %<>>%> est faux, utilisez %<>%> pour terminer la liste d'arguments du patron"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "l'argument %<sizeof...%> doit être entouré de parenthèses"
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "utilisation invalide de %qD dans la spécification de la classe de liaison"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> avant %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "le C++ ISO 1998 ne permet pas %<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "%<__thread%> et %<thread_local%> sont tous les deux spécifiés"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "%qD dupliqué"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs dupliqué"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> attendu"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> attendu"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> attendu"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> attendu"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> attendu"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> attendu"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> attendu"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> attendu"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> attendu"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> attendu"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> attendu"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> attendu"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> attendu"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> attendu"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> attendu"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> attendu"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> attendu"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> attendu"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> attendu"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> attendu"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> attendu"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> attendu"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> attendu"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> attendu"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> attendu"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<;%> ou %<::%> attendu"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> ou %<template%> attendu"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "étiquette %qs utilisée en nommant %q#T"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T a été précédemment déclaré ici"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD redéclaré avec un accès différent"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "en C++98, %<template%> (afin de lever une ambigüité) est seulement permis à l'intérieur des patrons"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "fin de fichier dans l'argument par défaut"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "construction Objective-C++ %<@%D%> mal placée"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "récepteur de message objective-c++ attendu"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "un ou des argument(s) de message objective-c++ est/sont attendu(s)"
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> doit spécifier un type comme un argument"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "nom de sélecteur Objective-C++ invalide"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "une déclaration de méthode objective-c++ est attendue"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "les attributs de méthodes doivent être spécifiés à la fin"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "%qs égaré entre des méthodes Objective-C++"
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "type invalide pour la variable d'instance"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identificateur attendu après %<@protocol%>"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "des attributs ne peuvent pas être spécifiés avant le mot-clé %<@%D%> en Objective-C++"
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "les attributs de préfixes sont ignorés avant %<@%D%>"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "type invalide pour une propriété"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "l'expression %<wait%> doit être un nombre entier"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "identificateur de réduction invalide"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "une initialisation entre parenthèses n'est pas permise dans une boucle %<for%> de OpenMP"
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "une initialisation entre parenthèses n'est pas permise dans une boucle « for »"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr "%<_Cild_for%> accepte une expression au lieu d'une déclaration uniquement en C, pas en C++"
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "la variable d'itération %qD ne devrait pas être une réduction"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "pas assez de boucles « for » à combiner"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "l'attribut vecteur n'est pas immédiatement suivi d'une seule déclaration ou définition de fonction"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "clause d'initialisation invalide"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "expression id (arguments) attendue"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "un des arguments de l'appel de l'initialisation devrait être %<omp_priv%> ou %<&omp_priv%>"
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "des types ne peuvent pas être définis dans une liste de types de réductions"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "type arithmétique %qT prédéclaré dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "type tableau ou fonction %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "type référence %qT dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "type %qT qualifié avec const, volatile ou __restrict dans %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> nomme un ensemble de surcharges"
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD ne fait pas référence à une fonction à l'intérieur de l'espace de noms"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> sans avoir activé le support pour la mémoire transactionnelle"
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rebut à la fin de %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "« grainsize » invalide pour _Cilk_for"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "%<#pragma simd%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "%<#pragma cilk grainsize%> doit être à l'intérieur d'une fonction"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr "-fcilkplus doit être activé pour utiliser %<#pragma cilk grainsize%>"
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "les optimisations inter-modules ne sont pas implémentées pour le C++"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, gcc-internal-format
 msgid "expected variable-name"
 msgstr "nom de variable attendu"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "%<,%> ou %<)%> attendu après %qE"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "les patrons implicites ne peuvent pas être %<virtual%>"
@@ -44279,7 +44335,7 @@
 msgid "candidate is: %#D"
 msgstr "le candidat est: %#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %#D"
@@ -44855,122 +44911,137 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE n'est pas un argument de patron valable de type %qT car %qD n'a pas une classe de liaison externe"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
 #, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr "l'adresse de %qD n'est pas un argument de patron valable"
+
+#: cp/pt.c:6634
+#, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "l'adresse du sous-objet %qT de %qD n'est pas un argument de patron valable"
+
+#: cp/pt.c:6641
+#, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "l'adresse de %qD n'est pas un argument de patron valable car elle n'a pas une durée de stockage statique"
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT à cause de conflits dans les qualificatifs CV"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car ce n'est pas une l-valeur"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D n'est pas un argument de patron valable pour le type %qT car une variable de référence n'a pas une adresse constante"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car ce n'est pas un objet avec une classe de liaison"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car l'objet %qD n'a pas de classe de liaison"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est un pointeur"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "essayez d'utiliser %qE à la place"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE n'est pas un argument de patron valable pour le type %qT car il est du type %qT"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "les conversions standard ne sont pas permises dans ce contexte"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "les attributs sur l'argument %qT du patron sont ignorés"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "les attributs dans l'argument %qE du patron sont ignorés"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nom de classe injecté %qD utilisé comme argument de patron qui est lui-même un patron"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "utilisation invalide du destructeur %qE comme un type"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "pour faire référence à un membre type d'un paramètre de patron, utilisez %<typename %E%>"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "non concordance de type/valeur pour l'argument %d dans la liste des paramètres du patron de %qD"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  on attendait une constante de type %qT, on a obtenu %qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  on attendait un patron de classe, on a obtenu %qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  on attendait un type, on a obtenu %qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  on attendait un type, on a obtenu %qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  on attendait un patron de classe, on a obtenu %qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  on attendait un patron de type %qD, on a obtenu %qT"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "désaccord de contrainte à l'argument %d dans la liste des paramètres du patron pour %qD"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  on attendait %qD, on a obtenu %qD"
@@ -44977,102 +45048,102 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "désaccord de type dans le paquet de paramètres non type"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "impossible de convertir l'argument %qE du patron de %qT vers %qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "l'argument %d du patron est invalide"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être %d)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "nombre erroné d'arguments du patron (%d, devrait être au moins %d)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "fournis pour %qD"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du patron d'alias %qD"
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argument d'expansion du paquet pour le paramètre non paquet %qD du concept %qD"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "ainsi, toute instanciation avec un paquet de paramètres non vide serait mal formée"
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "fournis pour %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D n'est pas un patron de fonction"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "type non patron %qT utilisé comme un patron"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "pour la déclaration du patron %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "échec de la contrainte du patron"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "utilisation du patron de variable invalide %qE"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum qui est %d (utilisez -ftemplate-depth= pour augmenter le maximum)"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "repli de l'expansion vide sur %O"
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %<%T%>"
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "les longueurs des paquets d'arguments sont en désaccord durant l'expansion de %<%E%>"
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "  lors de l'instanciation de l'argument par défaut pour l'appel à %D"
@@ -45090,271 +45161,271 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "la variable %qD a un type fonction"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "type de paramètre %qT invalide"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dans la déclaration de %q+D"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fonction retournant un tableau"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fonction retournant une fonction"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "création d'un pointeur vers la fonction membre d'un type non classe %qT"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formation d'une référence vers void"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formation d'un pointeur vers le type de référence %qT"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formation d'une référence vers le type de référence %qT"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formation d'un pointer vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formation d'une référence vers le type de fonction qualifié %qT"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "création d'un pointeur vers le membre d'un type non classe %qT"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "création d'un pointeur vers le type de référence au membre %qT"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "création d'un pointeur vers le membre de type void"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "création d'un tableau de %qT"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT n'est pas un type class, struct ou union"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT est résolu en %qT qui n'est pas un type d'énumération"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT est résolu en %qT qui n'est pas un type de classe"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "initialisation vide dans l'initialisation par capture de la fonction lambda"
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "utilisation de %qs dans le patron"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne correspond pas au nom du destructeur ~%qT"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "le nom dépendant %qE est analysé comme un non type, mais son instanciation produit un type"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "utilisez %<typename %E%> si un type est désiré"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "utilisation du champ %qD invalide"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "utilisation invalide de l'expression d'expansion d'un paquet"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "utilisez %<...%> pour dérouler le paquet d'arguments"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD n'a pas été déclaré dans cette portée et aucune déclaration a été trouvée par le recherche dépendant des arguments au point d'instanciation"
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "les déclarations dans la base dépendante %qT ne sont pas trouvées par une recherche non qualifiée"
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "utilisez plutôt %<this->%D%>"
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "utilisez plutôt %<%T::%D%>"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD déclaré ici, plus loin dans l'unité de traduction"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD n'est pas une classe ou un espace de noms"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT est/utilise un type anonyme"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "l'argument du patron pour %qD utilise le type local %qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT est un type modifié par une variable"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "l'expression intégrale %qE n'est pas une constante"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  tentative d'instancier %qD"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "instanciation de patron ambiguë pour %q#T"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "instanciation de patron ambiguë pour %q#D"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 msgid "%s %#S"
 msgstr "%s %#S"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instanciation explicite du non patron %q#D"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD n'est pas un membre de données statique d'un patron de classe"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "aucun patron correspondant trouvé pour %qD"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "le type %qT pour l'instanciation explicite %qD ne correspond pas au type déclaré %qT"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "instanciation explicite de %q#D"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "instanciation explicite dupliquée pour %q#D"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "le C++ ISO 1998 interdit l'utilisation de %<extern%> sur des instanciations explicites"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "classe de stockage %qD appliquée à l'instanciation du patron"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instanciation explicite du patron non classe %qD"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "instanciation explicite du type non patron %qT"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "instanciation explicite de %q#T avant la définition de patron"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "le C++ ISO interdit l'utilisation de %qE sur des instanciations explicites"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "instanciation explicite dupliquée de %q#T"
@@ -45366,92 +45437,92 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "instanciation explicite de %qD mais pas de définition disponible"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "la profondeur d'instanciation du patron excède le maximum de %d lors de l'instanciation de %q+D, peut-être via la génération de la table virtuelle (utilisez -ftemplate-depth= pour augmenter le maximum)"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "le paramètre non type du patron est invalide"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T n'est pas un type valide pour un paramètre non type du patron"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "la déduction à partir d'une liste d'initialisation entre accolades requiert #include <initializer_list>"
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "le patron non classe %qT est utilisé sans arguments de patron"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "impossible de déduire les arguments du patron pour l'initialisation par copie de %qT car il n'a pas de guides de déduction non explicites ou de constructeur déclaré par l'utilisateur"
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "la déduction des arguments du patron de classe a échoué:"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "les guides de déduction explicites ne sont pas pris en compte pour l'initialisation par copie"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "l'initialisation par liste directe de %<auto%> requiert exactement un élément"
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "pour la déduction de %<std::initializer_list%>, utilisez l'initialisation par liste copiée (c-à-d ajoutez %<=%> avant le %<{%>)"
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT en tant que type plutôt qu'un simple %<decltype(auto)%>"
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "impossible de déduire le type de retour de la lambda à partir de %qE"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "impossible de déduire %qT à partir de %qE"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "les indications de contraintes ne sont pas satisfaites"
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "l'initialisation déduite ne satisfait pas les indications de contraintes"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "le type retourné déduit ne satisfait pas les indications de contraintes"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "le type déduit pour l'expression ne satisfait pas les indications de contraintes"
@@ -45609,466 +45680,466 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  puisque %q+#D est déclaré dans la classe de base"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "des accolades explicites sont suggérées autour du corps vide de l'instruction %<do%>"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "le type de l'opérande asm %qE n'a pas pu être déterminé"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "les déclarations __label__ sont uniquement permises à l'intérieur des fonctions"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "utilisation invalide du membre %qD dans une fonction membre statique"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "le destructeur n'accepte pas d'argument"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> n'est pas disponible pour les fonctions membres statiques"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "utilisation invalide de %<this%> dans une fonction non membre"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "utilisation invalide de %<this%> hors de toute fonction"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "étendue de qualification invalide dans le nom du pseudo-destructeur"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "le type qualifié %qT ne concorde pas avec le nom du destructeur ~%qT"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE n'est pas un type %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "littéral composé du type non objet %qT"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "les paramètres de type du patron doivent utiliser le mot-clé %<class%> ou %<typename%>"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "utilisation invalide du type %qT comme valeur par défaut pour un paramètre de patron qui est lui-même un patron"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argument par défaut invalide pour un paramètre de patron qui est un patron"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "définition de %q#T à l'intérieur d'une liste de paramètres de patron"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "définition invalide du type qualifié %qT"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "spécification de classe de base invalide"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "impossible de capturer le membre %qD d'une union anonyme"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD n'est pas capturé"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "la lambda n'a pas de capture par défaut"
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "la lambda dans la classe locale %q+T ne sait pas capturer des variables du contexte englobant"
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "utilisation d'une variable locale avec un stockage automatique dans la fonction contenante"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "utilisation d'un paramètre dans la fonction contenante"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "utilisation du paramètre en dehors du corps de la fonction"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "arguments de patron manquants"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "le paramètre %qD du patron, du type %qT, n'est pas permis dans une expression constante intégrale parce qu'il n'est pas d'un type intégral ou énuméré"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "utilisation de l'espace de noms %qD comme expression"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "utilisation du patron de classe %qT comme expression"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "l'accès au membre %qD est ambigu dans un réseau d'héritages multiples"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD ne peut pas apparaître dans une expression constante"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "le type de %qE est inconnu"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT n'est pas un type énuméré"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Le paquet de paramètres __bases est uniquement valable dans la déclaration d'un patron"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "impossible d'appliquer %<offsetof%> au destructeur %<~%T%>"
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr "le deuxième opérande de %<offsetof%> n'est ni un simple identificateur ni une séquence d'accès aux membres et de références de tableaux"
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "impossible d'appliquer %<offsetof%> à la fonction membre %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr "l'utilisation de offsetof à l'intérieur du type %qT (qui ne respecte pas l'agencement standard) est indéfini"
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> est autorisé dans OpenMP uniquement dans les clauses %<declare simd%>"
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "la recherche de la réduction définie par l'utilisateur est ambiguë"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE dans la clause %<reduction%> est un tableau de taille nulle"
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE a le type const pour %<reduction%>"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "réduction définie par l'utilisateur avec une initialisation du constructeur pour la classe de base %qT"
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "la clause linéaire avec le modificateur %qs est appliquée à la variable non référence ayant le type %qT"
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr "clause linéaire appliquée à la variable non entière, non décimale, non pointeur ayant le type %qT"
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "clause linéaire appliquée à la variable non entière non pointeur ayant le type %qT"
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "l'expression du pas de « linear » doit être un entier"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD n'est pas une variable dans la clause %qs"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<firstprivate%>"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD n'est pas une variable dans la clause %<lastprivate%>"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "l'expression statique %<gang%> doit être un entier"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "la valeur statique de %<gang%> doit être positive"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "l'expression numérique de %<gang%> doit être un entier"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "l'expression de longueur de %<vector%> doit être un entier"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "l'expression numérique de %<worker%> doit être un entier"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "l'expression %qs doit être un entier"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "la valeur numérique de %<gang%> doit être positive"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "la valeur de longueur de %<vector%> doit être positive"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "la valeur numérique de %<worker%> doit être positive"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "l'expression de taille des tranches d'ordonnancement doit être un entier"
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "l'expression de longueur de %qs doit être un entier"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "l'expression de longueur %qs doit être une expression entière constante positive"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "l'expression de %<async%> doit être un entier"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "l'expression de %<thread_limit%> doit être un entier"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "l'identifiant de %<device%> doit être entier"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "l'expression de la taille des tranches de %<dist_schedule%> doit être un entier"
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<aligned%>"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE dans la clause %<aligned%> n'est ni un pointeur ni un tableau ni une référence vers un pointeur ou un tableau"
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD apparaît plus d'une fois dans les clauses %<aligned%>"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "l'expression d'alignement de la clause %<aligned%> doit être un entier"
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD n'est pas une variable dans la clause %<depend%>"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "nom de fonction surchargée %qE dans la clause %qs"
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "patron %qE dans la clause %qs"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "l'expression de %<grainsize%> doit être un entier"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "l'expression de %<priority%> doit être un entier"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "l'expression de %<num_tasks%> doit être un entier"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "la variable %qs n'est ni un pointeur ni un tableau ni une référence à un pointeur ou un tableau"
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "l'argument de %<tile%> doit être de type entier"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD n'est pas un fichier, un espace de noms ou une variable déclarée dans un bloc"
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "la directive %<threadprivate%> %qE n'est pas dans la définition de %qT"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "la différence entre %qE et %qD n'est pas un type entier"
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> utilisé avec la variable d'itération de classe %qE"
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> utilise deux expressions différentes pour la mémoire"
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "l'assertion statique a échoué"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "l'assertion statique a échoué: %s"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "condition non constante pour l'assertion statique"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "l'argument de decltype doit être une expression"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype ne sait pas résoudre l'adresse d'une fonction surchargée"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "l'opérande de l'expression fold n'a aucun paquet de paramètres non déroulé"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "les deux arguments dans le fold binaire ont des paquets de paramètres non déroulés"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "aucun paquet de paramètres non déroulés dans le fold binaire"
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "l'argument de %<__builtin_launder%> n'est pas un pointeur"
@@ -46083,107 +46154,107 @@
 msgid "lambda-expression in a constant expression"
 msgstr "expression lambda dans une expression constante"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attribut %qE appliqué à %qD avec un type de retour void"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "l'attribut %qE peut uniquement être appliqué aux fonctions ou aux classes ou aux types énumérés"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "le init_priority demandé n'est pas une constante entière"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "l'attribut %qE peut uniquement être utilisé sur les définitions dans la portée du fichier d'objets de type classe"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "le init_priority demandé est hors limite"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "le init_priority demandé est réservé pour un usage interne"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "l'attribut %qE n'est pas supporté sur cette plate-forme"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "la redéclaration de %qD ajoute l'étiquette d'ABI %E"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "l'attribut %qE requiert des arguments"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "les arguments de l'attribut %qE doivent être des chaînes littérales étroites"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "les arguments de l'attribut %qE doivent contenir des identificateurs valables"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> n'est pas un premier caractère valable pour un identificateur"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> n'est pas un caractère valable dans un identificateur"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "attribut %qE appliqué au type %qT qui n'est ni une classe ni un enum"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attribut %qE appliqué à %qT après sa définition"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "l'attribut %qE est ignoré car il est appliqué à l'instanciation du patron %qT"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "l'attribut %qE est ignoré car il est appliqué à la spécialisation du patron %qT"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attribut %qE appliqué à %qD qui n'est ni une fonction ni une variable"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribut %qE appliqué à la déclaration extern \"C\" %qD"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "zéro comme constante de pointeur nul"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "vérification lang_* : échec dans %s, à %s:%d"
@@ -46865,102 +46936,102 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "conversion invalide vers le type %qT à partir du type %qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "ne peut convertir %qT en %qT pour l'argument %qP de %qD"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "ne peut convertir %qT en %qT dans l'argument par défaut"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "ne peut convertir %qT en %qT dans le passage d'argument"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "ne peut convertir %qT en %qT"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "ne peut convertir %qT en %qT dans l'initialisation"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "ne peut convertir %qT en %qT dans le retour"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "ne peut convertir %qT en %qT dans l'affectation"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "le type classe %qT est incomplet"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "le paramètre %qP de %qD pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "le paramètre pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "la cible de la conversion pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "la cible de l'initialisation pourrait être une candidate pour un attribut de format"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "le membre de gauche de l'affectation pourrait être un candidat pour un attribut de format"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "dans le passage de l'argument %P de %qD"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "retourne une référence vers un temporaire"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "référence vers une non l-valeur retournée"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "référence vers la variable locale %qD retournée"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adresse de l'étiquette %qD retournée"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adresse de la variable locale %qD retournée"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "retourne une valeur depuis un destructeur"
@@ -46967,55 +47038,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "ne peut retourner depuis le gestionnaire d'un try..catch sur tout le constructeur"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "retourne une valeur depuis un constructeur"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "instruction « return » sans valeur dans une fonction retournant %qT"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "liste d'initialisation retournée"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "les types incohérents %qT et %qT sont déduits du type retourné par la lambda"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "déduction incohérente pour le type de retour auto: %qT et puis %qT"
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "instruction « return » avec une valeur dans une fonction retournant « void »"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> ne doit pas retourner NULL à moins qu'il soit déclaré %<throw()%> (ou -fcheck-new est actif)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "utilisation d'un temporaire comme l-valeur"
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "utilisation d'une x-valeur (référence à une r-valeur) comme l-valeur"
@@ -50971,87 +51042,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "La cible de l'initialisation du pointeur de procédure à %L ne peut pas être un pointeur de procédure"
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Fonctions pointeurs dans le contexte de la définition de variable (%s) à %L"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Expression non variable dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Constante nommée %qs dans le contexte de la définition de variable (%s) à %L"
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs dans le contexte de définition de variable (%s) à %L n'est pas une variable"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non POINTER dans le contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Type inaccessible dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT dans un contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Argument muet %qs avec INTENT(IN) dans un contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Argument muet %qs avec INTENT(IN) dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "La variable %qs est PROTECTED et ne peut pas apparaître dans le contexte d'association de pointeur (%s) à %L"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "La variable %qs est PROTECTED et ne peut pas apparaître dans le contexte de définition de variable (%s) à %L"
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "La variable %qs ne peut pas apparaître dans le contexte de définition de variable (%s) à %L dans la procédure PURE"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "%qs à %L associé à la cible vecteur indexé ne peut pas être utilisé dans le contexte de définition de variable (%s)"
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "%qs à %L associé a une expression ne peut pas être utilisé dans un contexte de définition de variable (%s)"
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Le nom associé %qs ne peut pas apparaître dans le contexte de définition de variable (%s) à %L car sa cible à %L ne le peut pas non plus"
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Éléments avec la même valeur à %L et %L dans l'indice de vecteur dans le contexte de définition de variable (%s)"
@@ -51238,12 +51309,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'affection définie à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le premier argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Le deuxième argument de l'interface de l'opérateur à %L doit être INTENT(IN)"
@@ -52018,508 +52089,523 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "Fortan 2003: Spécificateur de format DT interdit à %C"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr "Le descripteur X requiert un espace avant le nombre à %L"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr "Descripteur $ à %L"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ devrait être le dernier spécificateur dans le format à %L"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Extension: Largeur zéro après le descripteur L à %L"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Il manque une largeur positive après le descripteur L à %L"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "%<G0%> dans le format à %L"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr "Largeur positive requise dans le spécificateur de format %s à %L"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "Point requis dans le spécificateur de format %s à %L"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "Point requis dans le spécificateur de format à %L"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr "Le spécificateur de format H à %L est une fonctionnalité supprimée du Fortran 95"
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "Virgule manquante à %L"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s dans la chaîne de format à %L"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr "Caractères superflus dans le format à %L"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr "Instruction de format dans le bloc principal du module à %C"
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "L'instruction FORMAT à %C ne peut pas apparaître dans une INTERFACE"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Étiquette de format manquante à %C"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr "IOMSG doit être une variable scalaire caractère par défaut à %L"
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr "%s requiert une expression scalaire caractère par défaut à %L"
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "Valeur invalide pour la spécification %s à %C"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "Spécification %s dupliquée à %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "La variable %s ne peut pas être INTENT(IN) à %C"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "Une valeur ne peut pas être affectée à la variable %s dans une procédure PURE à %C"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "Spécification de l'étiquette %s dupliquée à %C"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr "%s est une extension DEC à %C, recompilez avec -fdec activé"
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "L'expression constante dans l'étiquette du FORMAT à %L doit être de type CHARACTER par défaut"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "L'étiquette du FORMAT à %L doit être du type CHARACTER ou INTEGER du sous-type par défaut"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "Variable ASSIGNED dans l'étiquette du FORMAT à %L"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "La variable %qs à %L n'a pas reçu d'étiquette de format"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr "Le scalaire %qs dans l'étiquette du FORMAT à %L n'est pas une variable ASSIGNED"
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr "Non caractère dans l'étiquette du FORMAT à %L"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "Élément non caractère d'un tableau de forme tacite dans l'étiquette du FORMAT à %L"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "Élément non caractère d'un tableau de taille tacite dans l'étiquette du FORMAT à %L"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "Élément non caractère d'un tableau de pointeurs dans l'étiquette du FORMAT à %L"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "La balise %s à %L doit être du type %s"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "La balise %s à %L doit être une chaîne de caractères du sous-type par défaut"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "La balise %s à %L doit être un scalaire"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr "Balise IOMSG à %L"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Le Fortran 95 exige un INTEGER par défaut dans la balise %s à %L"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr "Sous-type LOGICAL pas par défaut dans la balise %s à %L"
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr "Spécificateur NEWUNIT à %L"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr "Balise CONVERT à %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Fortran 2003: Le spécificateur %s dans l'instruction %s à %C a la valeur %qs"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "Le spécificateur %s dans l'instruction %s à %C à la valeur %qs"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "Extension: Le spécificateur %s dans l'instruction %s à %C a la valeur %qs"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "Le spécificateur %s dans l'instruction %s à %C a la valeur invalide %qs"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "L'instruction OPEN n'est pas permise dans une procédure PURE à %C"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr "Le spécificateur UNIT n'est pas autorisé avec NEWUNIT à %C"
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr "Le spécificateur NEWUNIT doit avoir FILE= ou STATUS='scratch' à %C"
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "L'instruction OPEN à %C doit avoir le spécificateur UNIT ou NEWUNIT"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr "Le type ACTION est en conflit avec le spécificateur READONLY à %C"
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "ASYNCHRONOUS= à %C n'est pas permis en Fortran 95"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "BLANK= à %C n'est pas permis en Fortran 95"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "DECIMAL= à %C n'est pas permis en Fortran 95"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "ENCODING= à %C n'est pas permis en Fortran 95"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "ROUND= à %C n'est pas permis en Fortran 95"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "SIGN= à %C n'est pas permis en Fortran 95"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "L'instruction CLOSE n'est pas permise dans une procédure PURE à %C"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "L'instruction CLOSE à %L requiert le numéro d'un UNIT"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "Le numéro de UNIT dans l'instruction CLOSE à %L doit être non négatif"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "L'instruction %s n'est pas permise dans une procédure PURE à %C"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr "Numéro de UNIT manquant dans l'instruction à %L"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "Le numéro de UNIT dans l'instruction à %L doit être non négatif"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "Instruction FLUSH à %C"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr "Format manquant avec l'unité par défaut à %C"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Spécificateur UNIT dupliqué à %C"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Spécificateur de format dupliqué à %C"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Le symbole %qs dans la liste de noms %qs est INTENT(IN) à %C"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Spécification NML dupliquée à %C"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Le symbole %qs à %C doit être le nom d'un groupe NAMELIST"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "L'étiquette END à %C n'est pas permise dans l'instruction de sortie"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "UNIT pas spécifié à %L"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "La spécification de UNIT à %L doit être une expression INTEGER ou une variable CHARACTER"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "La forme de l'instruction WRITE est invalide à %L, UNIT est requis"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Unité interne avec un indice vecteur à %L"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "La IO UNIT externe ne peut pas être un tableau à %L"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "NAMELIST %qs dans l'instruction READ à %L contient le symbole %qs qui ne peut pas apparaître dans le contexte d'une définition de variable"
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr "L'objet NAMELIST %qs dans la liste de noms %qs à %L est polymorphique et requiert une procédure d'entrée/sortie définie"
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr "Objet NAMELIST %qs dans la liste de noms %qs à %L avec des composants ALLOCATABLE ou POINTER"
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr "L'objet NAMELIST %qs dans la liste de noms %qs à %L a des composants ALLOCATABLE ou POINTER et requiert donc une procédure d'entrée/sortie définie"
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "Virgule avant la liste des éléments e/s à %L"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "L'étiquette de la balise ERR %d à %L n'est pas définie"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "L'étiquette de la balise END %d à %L n'est pas définie"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "L'étiquette de la balise EOR %d à %L n'est pas définie"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "L'étiquette FORMAT %d à %L n'est pas définie"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr "io_kind_name(): mauvais I/O-kind"
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Erreur de syntaxe dans l'itérateur E/S à %C"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Variable attendue dans l'instruction READ à %C"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Expression attendue dans l'instruction %s à %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction %s à %C"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "Fichier interne à %L avec une liste de noms"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "Le spécificateur ASYNCHRONOUS= à %L doit être une expression d'initialisation"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "PAD= à %C pas permis en Fortran 95"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "DELIM= à %C pas permis en Fortran 95"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "La liste de noms dans PRINT à %C est une extension"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Virgule attendue dans la liste des E/S à %C"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "L'instruction PRINT à %C n'est pas permise dans une procédure PURE"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "L'instruction INQUIRE n'est pas permise dans une procédure PURE à %C"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "L'étiquette IOLENGTH est invalide dans l'instruction INQUIRE à %C"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "L'instruction INQUIRE à %L ne peut pas contenir les deux spécificateurs FILE et UNIT en même temps"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "L'instruction INQUIRE à %L requiert l'un des deux spécificateurs FILE ou UNIT"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "Le numéro de UNIT dans l'instruction INQUIRE à %L ne peut pas être %d"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "L'instruction INQUIRE à %L requiert un spécificateur PENDING= avec le spécificateur ID="
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "WAIT à %C interdit en Fortran 95"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "L'instruction WAIT n'est pas permise dans une procédure PURE à %C"
@@ -53416,253 +53502,253 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "Spécification générique manquante dans l'instruction USE à %C"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr "Opérateurs renommés dans les instructions USE à %C"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Le nom %qs à %C a déjà été utilisé comme nom de module externe"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "Déclaration de SUBMODULE à %C"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "La déclaration SUBMODULE à %C ne peut pas apparaître dans une autre unité de portée"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Erreur de syntaxe dans l'instruction SUBMODULE à %C"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "Lecture du module %qs à la ligne %d colonne %d: %s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "Écriture du module %qs à la ligne %d colonne %d: %s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr "Module %qs à la ligne %d colonne %d: %s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr "require_atom(): mauvais type atomique requis"
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Erreur en écrivant le fichier des modules: %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr "write_atom(): Écriture d'un entier négatif"
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr "write_atom(): Tentative d'écrire un atome dab"
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr "unquote_string(): mauvaise chaîne obtenue"
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr "mio_array_ref(): Référence de tableau inconnue"
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "La liste de noms %s ne peut pas être renommée par association USE à %s"
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "!$OMP DECLARE REDUCTION ambigu dans le module %s à %L"
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "!$OMP DECLARE REDUCTION précédent du module %s à %L"
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%qs du module %qs, importé à %C, est aussi le nom de l'unité actuelle du programme"
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Le symbole %qs référencé à %L n'est pas trouvé dans le module %qs"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "L'opérateur utilisateur %qs référencé à %L n'est pas trouvé dans le module %qs"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "L'opérateur intrinsèque %qs référencé à %L n'est pas trouvé dans le module %qs"
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): mauvais symbole de module %qs"
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbole pas écrit"
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "N'a pu ouvrir le fichier module %qs en écriture à %C: %s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Erreur en écrivant dans le fichier module %qs: %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "Impossible d'effacer le fichier module %qs: %s"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Impossible de renommer le fichier module %qs en %qs: %s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Impossible de supprimer le fichier temporaire du module %qs: %s"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Symbole %qs à %C déjà déclaré"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Impossible de créer le symbole pour %s"
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Le symbole %qs, référencé à %L, n'est pas dans le standard sélectionné"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Le symbole %qs référencé à %L n'est pas trouvé dans le module intrinsèque ISO_C_BINDING"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbole %qs déjà déclaré"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "L'utilisation du module intrinsèque %qs à %C est en conflit avec le nom de module non intrinsèque utilisé précédemment"
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "L'utilisation de la constante nommée NUMERIC_STORAGE_SIZE du module intrinsèque ISO_FORTRAN_ENV à %L est incompatible avec l'option %qs"
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "L'utilisation de la constante nommée NUMERIC_STORAGE_SIZE du module intrinsèque ISO_FORTRAN_ENV à %C est incompatible avec l'option %s"
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Le symbole %qs référencé à %L n'a pas été trouvé dans le modèle intrinsèque ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "L'instruction USE à %C n'a pas de qualificatif ONLY"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Module intrinsèque ISO_FORTRAN_ENV à %C"
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Module ISO_C_BINDING à %C"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "N'a pu trouver un module intrinsèque nommé %qs à %C"
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "Module IEEE_FEATURES à %C"
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "Module IEEE_EXCEPTIONS à %C"
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "Module IEEE_ARITHMETIC à %C"
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Ne peut ouvrir le fichier module %qs en lecture à %C: %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Le fichier module %qs n'a pas été généré, soit parce que le module ne contient pas de MODULE PROCEDURE ou il y a une erreur dans le module."
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "L'utilisation du module non intrinsèque %qs à %C est en conflit avec le nom de module intrinsèque utilisé précédemment"
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Le fichier %qs ouvert à %C n'est pas un fichier module GNU Fortran"
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Impossible de lire le fichier module %qs ouvert à %C car il a été créé par une version différente de GNU Fortran"
 
 # %s est « sub » ou rien.
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr "Impossible d'utiliser le même %smodule que celui qui est en cours de construction !"
@@ -56046,7 +56132,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Impossible de résoudre la fonction spécifique %qs à %L"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "La fonction %qs à %L n'a pas de type IMPLICIT"
@@ -57539,187 +57625,177 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Nom générique %qs de la fonction %qs à %L étant le même nom que le type dérivé à %L"
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Le tableau de taille tacite %qs dans la liste de noms %qs à %L n'est pas permis"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme tacite dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Objet tableau NAMELIST %qs avec la forme non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Objet NAMELIST %qs avec une longueur de caractère non constante dans la liste de noms %qs à %L"
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr "L'objet NAMELIST %qs dans la liste de noms %qs à %L est polymorphique et requiert une procédure d'entrée/sortie définie"
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "Objet NAMELIST %qs dans la liste de noms %qs à %L avec des composants ALLOCATABLE ou POINTER"
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a été déclaré PRIVATE et ne peut pas être membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE associés à USE et ne peut pas être membre de la liste de noms %qs à %L"
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "L'objet NAMELIST %qs a des composants PRIVATE et ne peut pas être un membre de la liste de noms PUBLIC %qs à %L"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut NAMELIST dans %qs à %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Le tableau paramètre %qs à %L ne peut pas être automatique ou de forme différée"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Le PARAMETER %qs implicitement typé à %L ne concorde pas avec le type IMPLICIT ultérieur"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Type dérivé incompatible dans PARAMETER à %L"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "La variable CLASS %qs à %L ne peut pas avoir l'attribut PARAMETER"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Désolé, les composants allouables/pointeurs dans des co-tableaux de types polymorphiques (CLASS) à %L ne sont pas supportés"
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "L'attribut PROTECTED est en conflit avec l'attribut EXTERNAL à %L"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "L'attribut PROCEDURE est en conflit avec l'attribut PROTECTED à %L"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs à %L a l'attribut CONTIGUOUS mais il n'est pas un pointeur de tableau ou un tableau de forme tacite ou de rang tacite"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Le tableau de taille tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Le tableau de forme tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Le tableau de rang tacite à %L doit être un argument muet"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Le tableau de rang tacite à %L ne peut pas avoir les attributs VALUE ou CODIMENSION"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Le symbole à %L n'est pas une variable MUETTE"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs à %L ne peut pas avoir l'attribut VALUE car ce n'est pas un argument muet"
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "La variable muette caractère %qs à %L avec l'attribut VALUE doit avoir une longueur constante"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "La variable muette caractère %qs, interopérable avec le C, à %L avec l'attribut VALUE doit avoir la longueur un"
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Le type dérivé %qs à %L est du type %qs qui n'a pas été défini"
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera un argument muet"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera du type TYPE(*) ou d'un type intrinsèque numérique"
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "La variable %s à %L avec l'attribut NO_ARG_CHECK sera soit un scalaire ou un tableau de taille tacite"
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Le type tacite de la variable %s à %L est uniquement permis pour des variables muettes"
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir les attributs ALLOCATABLE, CODIMENSION, POINTER ou VALUE"
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "La variable de type tacite %s à %L ne peut pas avoir l'attribut INTENT(OUT)"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "La variable de type tacite %s à %L ne sera point un tableau de forme explicite"
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "La variable %qs à %L ne peut pas être BIND(C) car elle n'est ni un bloc COMMON ni déclarée au niveau du module"
@@ -57726,262 +57802,262 @@
 
 # %s est soit « parameter » ou « variable » sans traduction
 # voir bug #80195
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs à %L du type dérivé PRIVATE %qs"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s à %L du type LOCK_TYPE ou avec un sous-composant de type LOCK_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "La variable %s à %L du type EVENT_TYPE ou avec un sous-composant du type LOCK_TYPE doit être un co-tableau"
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "L'argument muet INTENT(OUT) %qs à %L est ASSUMED SIZE et, par conséquent, ne peut pas avoir une initialisation par défaut"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est LOCK_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "L'argument muet %qs à %L qui est EVENT_TYPE ne sera point INTENT(OUT)"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Le résultat %qs de la fonction à %L ne sera point un co-tableau et n'aura point un composant co-tableau"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "La variable %qs à %L du TYPE(C_PTR) ou TYPE(C_FUNPTR) ne sera point un co-tableau"
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "La variable %qs à %L avec un composant co-tableau doit être un scalaire non pointeur, non allouable qui n'est pas un co-tableau"
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "La variable %qs à %L est un co-tableau qui n'est pas ALLOCATABLE, SAVE ni un argument muet"
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "La variable co-tableau %qs à %L n'aura pas de co-dimensions avec une forme différée"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "La variable co-tableau allouable %qs à %L doit avoir une forme différée"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "La variable %qs à %L est INTENT(OUT) et ne peut donc pas être un co-tableau allouable ou avoir des composants co-tableaux"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "La variable muette co-tableau %qs à %L n'est pas permise dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Argument muet LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Variable résultat LOGICAL %qs à %L avec le sous-type non C_Bool dans la procédure BIND(C) %qs"
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "La liste de noms %qs ne peut pas être un argument de la sous-routine ou de la fonction à %L"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Le threadprivate à %L n'est pas sauvegardé avec SAVE"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "La variable !$OMP DECLARE TARGET %qs à %L n'est pas sauvegardée avec SAVE"
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Mauvaise expression"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "L'élément BLOCK DATA %qs à %L doit être dans COMMON"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "Le tableau DATA %qs à %L doit être spécifié dans une déclaration précédente"
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "L'élément DATA %qs à %L ne peut pas avoir un co-index"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "L'élément DATA %qs à %L est un pointeur et doit donc être un tableau à part entière"
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Section de tableau non constante à %L dans l'instruction DATA"
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "L'instruction DATA à %L a plus de variables que de valeurs"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le début de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "La fin de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Le pas de la boucle DO implicite à %L n'a pas pu être simplifiée en une valeur constante"
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "L'instruction DATA à %L a plus de valeurs que de variables"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "L'étiquette %d à %L est définie mais non utilisée"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "L'étiquette %d à %L est définie mais ne peut pas être utilisée"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L doit avoir l'attribut SEQUENCE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L ne peut pas avoir des composants ALLOCATABLE pour être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "La variable de type dérivé %qs à %L avec une initialisation par défaut ne peut pas être dans une EQUIVALENCE avec une variable dans COMMON"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "La variable de type dérivé %qs à %L avec un ou des composants pointeurs ne peut pas être dans un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Erreur de syntaxe dans l'instruction EQUIVALENCE à %L"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Soit aucun ou tous les objets dans l'ensemble EQUIVALENCE à %L aura l'attribut PROTECTED"
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Le membre %qs du bloc commun à %L ne peut pas être un objet EQUIVALENCE dans la procédure pure %qs"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "La constante nommée %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Le tableau %qs à %L avec des limites non constantes ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Le composant de structure %qs à %L ne peut pas être un objet EQUIVALENCE"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "La sous-chaîne à %L a une longueur zéro"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fonction PUBLIC %qs à %L du type PRIVATE %qs"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs à %L n'a pas de type IMPLICIT"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "La procédure opérateur utilisateur %qs à %L doit être une FUNCTION"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "La procédure opérateur utilisateur %qs à %L ne peut pas être une longueur de caractère tacite"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "La procédure opérateur utilisateur %qs à %L doit avoir au moins un argument"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Le premier argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Le deuxième argument de l'interface opérateur à %L ne peut pas être optionnel"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "L'interface opérateur à %L doit avoir, au plus, deux arguments"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "La procédure contenue %qs à %L d'une procédure PURE doit aussi être PURE"
@@ -59064,12 +59140,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "La variable d'événement à %L ne sera point co-indexée"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr "build_dt: format avec une liste de noms"
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "Mauvais type de base d'E/S (%d)"
@@ -61525,11 +61601,6 @@
 #~ msgstr "Utiliser l'ordre des octets pour système à octets de poids faible"
 
 #, fuzzy
-#~| msgid "Generate fused multiply/add instructions"
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "Générer des instructions fusionnés de multiplication/addition"
-
-#, fuzzy
 #~| msgid "Enable linker relaxation"
 #~ msgid "Enable Loop Blocking transformation"
 #~ msgstr "Autoriser la relâche par l'éditeur de liens"
Index: gcc/po/hr.po
===================================================================
--- gcc/po/hr.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/hr.po	(.../branches/gcc-7-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.7.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2012-07-05 15:49+0200\n"
 "Last-Translator: Tomislav Krznar <tomislav.krznar@gmail.com>\n"
 "Language-Team: Croatian <lokalizacija@linux.hr>\n"
@@ -202,13 +202,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -521,62 +521,62 @@
 " other options on to these processes the -W<letter> options must be used.\n"
 msgstr ""
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr ""
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr ""
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr ""
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr ""
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc inačica %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr ""
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr ""
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr ""
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "biblioteke: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -585,16 +585,16 @@
 "\n"
 "Za upute o prijavljivanju grešaka, molim pogledajte:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "(C)"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -604,7 +604,7 @@
 "jamstava; čak ni za TRGOVINSKU PRIKLADNOST ili ODGOVARANJE ODREĐENOJ SVRSI.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -613,7 +613,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -620,7 +620,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -628,7 +628,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -640,18 +640,18 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+#| msgid "  -n, --no-output                 Do not create an output file\n"
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -n, --no-output                 Nemoj raditi izlazne datoteke\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 #| msgid "  -v, --version                   Print version number, then exit\n"
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -v, --version                   Ispiši broj inačice, zatim izađi\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -n, --no-output                 Nemoj raditi izlazne datoteke\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -667,14 +667,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -702,31 +702,31 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -f, --function                      Print function level info\n"
 msgstr "  -h, --help                      Ispiši ovu pomoć, zatim izađi\n"
 
-#: gcov-tool.c:422
+#: gcov-tool.c:421
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr "  -h, --help                      Ispiši ovu pomoć, zatim izađi\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:422
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr "  -h, --help                      Ispiši ovu pomoć, zatim izađi\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:423
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -o, --object                        Print object level info\n"
 msgstr "  -h, --help                      Ispiši ovu pomoć, zatim izađi\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -817,20 +817,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Ispiši ovu pomoć, zatim izađi\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Prikaži informacije za svaki temeljni blok\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr ""
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -837,16 +832,21 @@
 "                                    rather than percentages\n"
 msgstr ""
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          Prikaži podatke o napredovanju\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Ispiši sažetke svake funkcije\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Ispiši ovu pomoć, zatim izađi\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1032,82 +1032,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr ""
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Izvršeno redaka:%s od %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr ""
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s '%s'\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr ""
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Izvršeno poziva:%s od %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Nema poziva\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s:nema redaka za „%s”\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr ""
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr ""
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr ""
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "Ne mogu otvoriti datoteku koda %s\n"
@@ -1215,90 +1215,90 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[zadano]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[omogućeno]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[onemogućeno]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Nisu pronađene opcije sa željenim svojstvima\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, fuzzy, c-format
 #| msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end\n"
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Ništa nije pronađeno.  Koristite --help=%s za prikaz *svih* opcija koje podržava sučelje %s\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Sve opcije sa željenim svojstvima su već prikazane\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr ""
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "Sljedeće opcije upravljaju porukama upozorenja kompajlera"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "Sljedeće opcije upravljaju optimizacijama"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "Sljedeće opcije su neovisne o jeziku"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "Opcija --param prepoznaje sljedeće kao parametre"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "Sljedeće opcije su posebne samo za jezik "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "Sljedeće opcije podržava jezik "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "Sljedeće opcije nisu dokumentirane"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "Sljedeće opcije primaju odvojene argumente"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "Sljedeće opcije primaju spojene argumente"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "Sljedeće opcije su vezane uz jezik"
 
@@ -2834,8 +2834,8 @@
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr ""
@@ -2854,7 +2854,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr ""
@@ -2876,8 +2876,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr ""
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2893,18 +2893,18 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr ""
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr ""
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr ""
@@ -2914,7 +2914,7 @@
 msgid "invalid %%h value"
 msgstr ""
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr ""
@@ -2935,7 +2935,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr ""
@@ -2945,7 +2945,7 @@
 msgid "invalid %%C value"
 msgstr ""
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr ""
@@ -2956,7 +2956,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr ""
@@ -3024,7 +3024,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
@@ -3035,29 +3035,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "neispravni izraz kao operand"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr ""
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr ""
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3065,101 +3065,101 @@
 msgid "invalid operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr ""
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr ""
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr ""
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr ""
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr ""
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr ""
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr ""
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr ""
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr ""
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr ""
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr ""
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr ""
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 msgid "unsupported fixed-point conversion"
 msgstr ""
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 msgid "function parameter"
 msgstr ""
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 msgid "structure field"
 msgstr ""
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 msgid "return type of function"
 msgstr ""
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr ""
 
@@ -3181,7 +3181,7 @@
 msgstr ""
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3403,90 +3403,90 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'O'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'z'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "neispravni izraz kao operand"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr ""
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr ""
 
@@ -3523,7 +3523,7 @@
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -3577,7 +3577,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr ""
 
@@ -3610,7 +3610,7 @@
 msgstr ""
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr ""
 
@@ -3702,278 +3702,278 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%-code"
 msgid "invalid %%e value"
 msgstr "neispravni %%-kod"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 msgid "vector argument passed to unprototyped function"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3999,43 +3999,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr ""
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr ""
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4197,30 +4197,30 @@
 msgid "bad test"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr ""
 
@@ -4241,8 +4241,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "očekujem %<;%>"
@@ -4264,14 +4264,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "očekujem %<(%>"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "očekujem %<,%>"
@@ -4302,7 +4302,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "očekujem %<)%>"
@@ -4310,7 +4310,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "očekujem %<]%>"
@@ -4320,7 +4320,7 @@
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "očekujem %<}%>"
@@ -4327,7 +4327,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "očekujem %<{%>"
@@ -4337,7 +4337,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "očekujem %<:%>"
@@ -4350,24 +4350,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr ""
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "očekujem %<while%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4375,18 +4375,18 @@
 msgid "expected %<.%>"
 msgstr "očekujem %<.%>"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "očekujem %<>%>"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "očekujem %<,%> ili %<)%>"
@@ -4394,17 +4394,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "očekujem %<=%>"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "očekujem %<[%>"
@@ -4413,7 +4413,7 @@
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -4424,11 +4424,11 @@
 msgid "expected label"
 msgstr "očekujem %<while%>"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr ""
 
@@ -4647,11 +4647,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4823,80 +4823,80 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr ""
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr ""
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 msgid "Unexpected element %qc in format string at %L"
 msgstr ""
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr ""
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr ""
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr ""
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 msgid "Left parenthesis required after %<*%>"
 msgstr ""
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr ""
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr ""
 
-#: fortran/io.c:726
-#, c-format
-msgid "Right parenthesis expected at %C"
-msgstr ""
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr ""
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr ""
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr ""
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, c-format
+msgid "Right parenthesis expected at %C"
+msgstr ""
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr ""
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4906,75 +4906,75 @@
 msgid "Syntax error in expression at %C"
 msgstr ""
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr ""
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr ""
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr ""
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr ""
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr ""
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr ""
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr ""
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr ""
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr ""
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr ""
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr ""
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr ""
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr ""
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr ""
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr ""
 
@@ -5219,12 +5219,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5587,7 +5587,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr ""
 
@@ -8471,7 +8471,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr ""
@@ -8692,7 +8692,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr ""
 
@@ -8909,12 +8909,12 @@
 msgid "Use 80-bit long double."
 msgstr ""
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 msgid "Use 64-bit long double."
 msgstr ""
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr ""
@@ -9926,87 +9926,87 @@
 msgid "64 bit ABI."
 msgstr ""
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr ""
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr ""
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr ""
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 msgid "Enable decimal floating point hardware support."
 msgstr ""
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 msgid "Enable hardware floating point."
 msgstr ""
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 msgid "Use hardware transactional execution instructions."
 msgstr ""
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr ""
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr ""
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr ""
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 msgid "Disable hardware floating point."
 msgstr ""
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr ""
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr ""
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 msgid "Use the mvcle instruction for block moves."
 msgstr ""
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr ""
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr ""
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr ""
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -10058,11 +10058,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -10288,78 +10288,94 @@
 msgstr ""
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr ""
+
+#: config/sparc/sparc.opt:102
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 msgid "Pointers are 64-bit."
 msgstr ""
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 msgid "Pointers are 32-bit."
 msgstr ""
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 msgid "Use 64-bit ABI."
 msgstr ""
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 msgid "Use 32-bit ABI."
 msgstr ""
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr ""
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr ""
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr ""
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr ""
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr ""
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 msgid "Enable debug output."
 msgstr ""
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr ""
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -14713,7 +14729,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -15119,7 +15135,7 @@
 msgstr ""
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 #| msgid "expected end of line"
 msgid "expected integer"
@@ -15398,125 +15414,125 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 msgid "invalid comparison of non-ordered type"
 msgstr ""
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, c-format
 msgid "invalid operation (%s)"
 msgstr ""
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 msgid "invalid comparison of non-comparable type"
 msgstr ""
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 msgid "invalid comparison of generated struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 msgid "invalid comparison of generated array"
 msgstr ""
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr ""
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr ""
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr ""
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr ""
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr ""
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -15693,7 +15709,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
@@ -15755,27 +15771,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr ""
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr ""
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr ""
@@ -15782,7 +15798,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -15789,12 +15805,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
@@ -15801,62 +15817,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr ""
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr ""
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr ""
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -16765,12 +16781,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr ""
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -16865,12 +16881,12 @@
 msgid "cannot find '%s'"
 msgstr ""
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr ""
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr ""
@@ -16880,7 +16896,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17091,7 +17107,7 @@
 msgid "error writing %qs"
 msgstr ""
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr ""
@@ -17171,17 +17187,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17291,12 +17307,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -17311,12 +17327,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr ""
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr ""
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr ""
@@ -17331,7 +17347,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -17361,7 +17377,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -17371,7 +17387,7 @@
 msgid "total size of local objects too large"
 msgstr ""
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -17471,62 +17487,67 @@
 msgid "input file %qs is the same as output file"
 msgstr ""
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, gcc-internal-format
+msgid "output filename may not be empty"
+msgstr ""
+
+#: gcc.c:4501
+#, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr ""
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr ""
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr ""
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr ""
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr ""
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr ""
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr ""
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr ""
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr ""
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr ""
@@ -17534,228 +17555,228 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr ""
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr ""
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr ""
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr ""
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr ""
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr ""
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr ""
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr ""
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr ""
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr ""
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr ""
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr ""
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr ""
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr ""
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr ""
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr ""
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr ""
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr ""
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr ""
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr ""
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr ""
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr ""
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr ""
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr ""
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr ""
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr ""
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr ""
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr ""
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr ""
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr ""
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr ""
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr ""
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr ""
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr ""
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr ""
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr ""
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr ""
@@ -17903,9 +17924,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr ""
@@ -18320,228 +18341,228 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr ""
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr ""
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr ""
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -18774,7 +18795,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
 #: ipa-devirt.c:1235
@@ -18874,7 +18895,7 @@
 
 #: ipa-devirt.c:1576
 #, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr ""
 
 #: ipa-devirt.c:1599
@@ -19266,199 +19287,199 @@
 msgid "multiple loop axes specified for routine"
 msgstr ""
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr ""
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr ""
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "invalid 'asm': "
 msgid "invalid arguments"
 msgstr "neispravni „asm”: "
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr ""
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr ""
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
@@ -19544,7 +19565,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr ""
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr ""
@@ -19700,127 +19721,137 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.c:1649
+#: opts.c:1656
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr ""
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr ""
 
-#: opts.c:2078
+#: opts.c:2085
 #, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr ""
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr ""
 
-#: opts.c:2217
+#: opts.c:2224
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr ""
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr ""
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr ""
 
-#: opts.c:2371
+#: opts.c:2378
 #, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr ""
 
-#: opts.c:2374
+#: opts.c:2381
 #, gcc-internal-format
 msgid "invalid --param name %qs"
 msgstr ""
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr ""
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr ""
 
-#: opts.c:2513
+#: opts.c:2520
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr ""
 
-#: opts.c:2531
+#: opts.c:2538
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr ""
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr ""
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr ""
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -20158,7 +20189,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr ""
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -20759,12 +20790,12 @@
 msgid "error closing %s: %m"
 msgstr ""
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr ""
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -21675,47 +21706,47 @@
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -21816,33 +21847,33 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr ""
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, fuzzy, gcc-internal-format
 #| msgid "cannot optimize loop, the loop counter may overflow"
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "ne mogu optimizirati petlju, može doći do preljeva brojača petlje"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr ""
@@ -22196,11 +22227,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -23168,7 +23199,7 @@
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -23443,7 +23474,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
@@ -24062,62 +24093,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr ""
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr ""
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -24218,7 +24249,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr ""
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr ""
@@ -24248,7 +24279,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -24263,22 +24294,22 @@
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -24824,8 +24855,8 @@
 msgid "wrong type argument to %s"
 msgstr ""
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -25494,7 +25525,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr ""
@@ -25654,7 +25685,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
@@ -25978,7 +26009,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
@@ -26059,7 +26090,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr ""
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
@@ -26144,9 +26175,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
@@ -26232,7 +26263,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26406,234 +26437,234 @@
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr ""
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr ""
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr ""
@@ -26640,141 +26671,141 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr ""
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr ""
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr ""
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr ""
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr ""
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr ""
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr ""
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr ""
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr ""
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -26782,72 +26813,77 @@
 msgid "%qE attribute only applies to functions"
 msgstr ""
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
 msgstr ""
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr ""
@@ -26855,13 +26891,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
@@ -26955,163 +26991,174 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr ""
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr ""
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr ""
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr ""
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr ""
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr ""
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr ""
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr ""
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr ""
+
+#: config/avr/avr.c:10160
+#, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr ""
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr ""
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr ""
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr ""
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -27394,12 +27441,12 @@
 msgid "invalid IACC argument"
 msgstr ""
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr ""
@@ -27577,7 +27624,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
@@ -27707,287 +27754,287 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr ""
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr ""
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -27994,297 +28041,297 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr ""
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -28408,7 +28455,7 @@
 msgid "argument %qd is not a constant"
 msgstr ""
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr ""
@@ -28418,7 +28465,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr ""
@@ -28519,7 +28566,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -29020,8 +29067,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr ""
@@ -29274,27 +29321,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -29319,7 +29366,7 @@
 msgid "-g option disabled"
 msgstr ""
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
@@ -29454,157 +29501,157 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr ""
@@ -29611,67 +29658,67 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -29680,514 +29727,519 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, gcc-internal-format
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -30374,6 +30426,7 @@
 msgstr ""
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr ""
@@ -30465,7 +30518,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -30492,7 +30545,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -30512,7 +30565,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -30525,160 +30578,160 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr ""
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr ""
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr ""
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr ""
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr ""
@@ -30735,27 +30788,27 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr ""
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr ""
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr ""
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr ""
 
-#: config/sparc/sparc.c:1425
+#: config/sparc/sparc.c:1541
 #, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr ""
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr ""
@@ -31040,22 +31093,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr ""
@@ -31142,7 +31195,7 @@
 msgid "could not read the BRIG file"
 msgstr "ne mogu pisati u privremenu datoteku %s"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -31544,9 +31597,9 @@
 msgstr ""
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -31679,7 +31732,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -32724,7 +32777,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
@@ -32864,17 +32917,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -32924,7 +32977,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "očekujem kraj retka"
@@ -32965,7 +33018,7 @@
 msgstr ""
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -32980,7 +33033,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -32995,8 +33048,8 @@
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -33034,7 +33087,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -33062,7 +33115,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr ""
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -33126,14 +33179,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -33268,7 +33321,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -33293,12 +33346,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -33312,17 +33365,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
@@ -33332,7 +33385,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -33352,7 +33405,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -33529,17 +33582,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr ""
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -33594,61 +33647,61 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
@@ -33663,12 +33716,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -33683,56 +33736,56 @@
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<none%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<data%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -33760,23 +33813,23 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<tofrom%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<scalar%>"
@@ -33787,58 +33840,58 @@
 msgid "%<num_workers%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr ""
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%>"
 msgid "unexpected argument"
 msgstr "očekujem %<@end%>"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -33853,17 +33906,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -33883,19 +33936,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid depend kind"
 msgstr "neispravni izraz kao operand"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid 'asm': "
 msgid "invalid map kind"
 msgstr "neispravni „asm”: "
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -33905,68 +33958,68 @@
 msgid "invalid proc_bind kind"
 msgstr ""
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -33982,7 +34035,7 @@
 msgid "expected function name"
 msgstr "očekujem kraj retka"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -33992,42 +34045,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -34037,27 +34090,27 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr ""
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -34067,74 +34120,74 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<for%> after %qs"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<point%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -34149,7 +34202,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -34159,34 +34212,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>"
 msgid "expected %<target%>"
 msgstr "očekujem %<;%>"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%>"
 msgid "expected %<declare%>"
 msgstr "očekujem %<while%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -34242,23 +34295,23 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "očekujem %<;%>, %<,%> ili %<)%>"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
@@ -34273,52 +34326,52 @@
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr ""
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr ""
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -34328,7 +34381,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr ""
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%>"
 msgid "expected %<:%> or numeral"
@@ -35044,7 +35097,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -35372,7 +35425,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -35382,7 +35435,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -35407,7 +35460,7 @@
 msgid "function returns address of label"
 msgstr ""
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
@@ -35422,7 +35475,7 @@
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -35442,17 +35495,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -35462,7 +35515,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
@@ -35568,12 +35621,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -35583,25 +35636,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -35612,70 +35665,70 @@
 msgstr ""
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
@@ -35695,7 +35748,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -35705,17 +35758,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -35735,18 +35788,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -35758,32 +35811,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -35803,55 +35856,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -35861,32 +35914,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -36434,152 +36487,152 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr ""
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -36680,272 +36733,272 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr ""
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr ""
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -36952,152 +37005,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr ""
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -37107,12 +37160,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr ""
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -37142,332 +37195,332 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr ""
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr ""
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr ""
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr ""
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr ""
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr ""
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -38263,7 +38316,7 @@
 msgid "  skips initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -38278,7 +38331,7 @@
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -39914,7 +39967,7 @@
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
@@ -40365,13 +40418,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr ""
@@ -40381,8 +40434,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
@@ -40432,7 +40485,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
@@ -40496,7 +40549,7 @@
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
@@ -40511,7 +40564,7 @@
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
@@ -40669,27 +40722,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -40698,67 +40751,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -40767,47 +40820,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -40814,12 +40867,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
@@ -41128,18 +41181,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr ""
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
@@ -41239,7 +41292,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
@@ -41259,7 +41312,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
@@ -41454,22 +41507,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr ""
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -41524,186 +41577,186 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr ""
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr ""
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr ""
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr ""
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr ""
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr ""
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -41895,97 +41948,97 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr ""
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, gcc-internal-format
 msgid "only here as a friend"
 msgstr ""
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr ""
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr ""
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -41993,27 +42046,27 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -42033,7 +42086,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -42058,7 +42111,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -42118,1204 +42171,1209 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr ""
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr ""
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr ""
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr ""
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr ""
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr ""
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr ""
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr ""
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr ""
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr ""
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr ""
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr ""
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr ""
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr ""
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr ""
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr ""
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr ""
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr ""
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr ""
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr ""
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, gcc-internal-format
 msgid "expected binary operator"
 msgstr ""
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected type..."
 msgid "expected ..."
 msgstr "Neočekivana vrsta..."
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "binary expression in operand of fold-expression"
 msgstr "neispravni izraz kao operand"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr ""
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr ""
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr ""
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr ""
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr ""
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr ""
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr ""
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr ""
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr ""
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr ""
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr ""
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr ""
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr ""
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr ""
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr ""
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr ""
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr ""
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr ""
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, gcc-internal-format
 msgid "ISO C++ does not support lambda templates"
 msgstr ""
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr ""
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr ""
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr ""
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr ""
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, gcc-internal-format
 msgid "empty decomposition declaration"
 msgstr ""
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
 #, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr ""
+
+#: cp/parser.c:13220
+#, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr ""
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr ""
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "invalid expression as operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "neispravni izraz kao operand"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr ""
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr ""
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, gcc-internal-format
 msgid "nested identifier required"
 msgstr ""
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -43324,7 +43382,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
@@ -43331,339 +43389,339 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr ""
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected attribute before %<...%>"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -43672,490 +43730,490 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr ""
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr ""
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr ""
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr ""
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr ""
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<while%>"
 msgid "expected variable-name"
 msgstr "očekujem %<while%>"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "očekujem %<,%> ili %<)%>"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
@@ -44247,7 +44305,7 @@
 msgid "candidate is: %#D"
 msgstr ""
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr ""
@@ -44827,122 +44885,137 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
 #, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6634
+#, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6641
+#, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr ""
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
@@ -44949,102 +45022,102 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr ""
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr ""
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr ""
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr ""
@@ -45062,271 +45135,271 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 msgid "%s %#S"
 msgstr ""
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
@@ -45338,94 +45411,94 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn ne zadovoljava svoja ograničenja:"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -45583,466 +45656,466 @@
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr ""
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr ""
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr ""
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -46057,107 +46130,107 @@
 msgid "lambda-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr ""
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -46840,102 +46913,102 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr ""
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr ""
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr ""
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr ""
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr ""
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -46942,55 +47015,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr ""
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -50952,87 +51025,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -51219,12 +51292,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -51999,508 +52072,523 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr ""
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr ""
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr ""
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr ""
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr ""
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr ""
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr ""
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr ""
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr ""
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr ""
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr ""
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr ""
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr ""
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr ""
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr ""
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr ""
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr ""
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr ""
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr ""
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr ""
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr ""
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr ""
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr ""
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr ""
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr ""
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr ""
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr ""
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr ""
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr ""
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -53398,256 +53486,256 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr ""
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr ""
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr ""
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr ""
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr ""
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr ""
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr ""
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 #| msgid "Cannot open source file %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "Ne mogu otvoriti datoteku koda %s\n"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "Failed to open file %s for writing state: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Nisam uspio otvoriti datoteku %s za pisanje stanja: %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr ""
@@ -56023,7 +56111,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -57511,447 +57599,437 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -59035,12 +59113,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr ""
Index: gcc/po/nl.po
===================================================================
--- gcc/po/nl.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/nl.po	(.../branches/gcc-7-branch)
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.9-b20140202\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2014-02-05 12:25+0100\n"
 "Last-Translator: Benno Schulenberg <benno@vertaalt.nl>\n"
 "Language-Team: Dutch <vertaling@vrijschrift.org>\n"
@@ -195,13 +195,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "floating-point constante verkeerd gebruikt"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -469,62 +469,62 @@
 " other options on to these processes the -W<letter> options must be used.\n"
 msgstr ""
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr ""
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr ""
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr ""
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr ""
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc versie %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "gcc stuurprogramma versie %s %svoert gcc versie %s uit\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr ""
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr ""
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr ""
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -532,7 +532,7 @@
 msgstr ""
 
 # XXX FIXME:  useless gettextization
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
@@ -539,11 +539,11 @@
 
 # Het copyright symbool zit in latin-1 dus lijkt me toepasselijk voor Nederlands (aangezien we ook accenten hebben).
 # Maar misschien toch als (C) laten?
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "©"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -554,7 +554,7 @@
 "doel.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -563,7 +563,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -570,7 +570,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -578,7 +578,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -590,14 +590,14 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, c-format
-msgid "    -v, --verbose                       Verbose mode\n"
+msgid "    -o, --output <dir>                  Output directory\n"
 msgstr ""
 
-#: gcov-tool.c:177 gcov-tool.c:271
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
 #, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
+msgid "    -v, --verbose                       Verbose mode\n"
 msgstr ""
 
 #: gcov-tool.c:178
@@ -615,14 +615,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -650,28 +650,28 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
+#: gcov-tool.c:420
+#, c-format
+msgid "    -f, --function                      Print function level info\n"
+msgstr ""
+
 #: gcov-tool.c:421
 #, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr ""
 
 #: gcov-tool.c:422
 #, c-format
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr ""
 
 #: gcov-tool.c:423
 #, c-format
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -o, --object                        Print object level info\n"
 msgstr ""
 
 #: gcov-tool.c:424
 #, c-format
-msgid "    -o, --object                        Print object level info\n"
-msgstr ""
-
-#: gcov-tool.c:425
-#, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
 
@@ -750,36 +750,36 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
+msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr ""
 
 #: gcov.c:659
 #, c-format
-msgid "  -a, --all-blocks                Show information for every basic block\n"
+msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr ""
 
 #: gcov.c:660
 #, c-format
-msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
-msgstr ""
-
-#: gcov.c:661
-#, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
 "                                    rather than percentages\n"
 msgstr ""
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr ""
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr ""
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr ""
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -967,84 +967,84 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr ""
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Uitgevoerde lijnen:%s van %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Geen uitvoerbare lijnen\n"
 
 # XXX FIXME:  useless gettextization
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s '%s'\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Uitgevoerde aftakkingen:%s van %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "Minstens één keer uitgevoerd:%s van %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Geen aftakkingen\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Uitgevoerde calls:%s van %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Geen calls\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s:geen lijnen voor '%s'\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "call   %2d kwam %s terug\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "call   %2d nooit uitgevoerd\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr ""
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr ""
 
 # is me niet helemaal duidelijk wat een 'unconditional' is
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "onvoorwaardelijke tak %2d werd %s genomen\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "onvoorwaardelijke tak %2d werd nooit uitgevoerd\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "Kan bronbestand %s niet openen\n"
@@ -1154,70 +1154,70 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[ingeschakeld]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[uitgeschakeld]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "De volgende opties zijn afhankelijk van het doelsysteem"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "De volgende opties beheren waarschuwingsboodschappen van de compiler"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "De volgende opties beheren optimalisaties"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "De volgende opties zijn taalafhankelijk"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "De --param optie herkent de volgende parameters"
 
 # Zou een format spec moeten hebben voor de taalnaam...
-#: opts.c:1390
+#: opts.c:1397
 #, fuzzy
 msgid "The following options are specific to just the language "
 msgstr "De volgende opties enkel van toepassing voor de taal "
@@ -1224,26 +1224,26 @@
 
 # Zou een format spec moeten hebben voor de taalnaam...
 # Of beter "voor de taal "?
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "De volgende opties worden ondersteund door de taal "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "De volgende opties zijn niet gedocumenteerd"
 
-#: opts.c:1405
+#: opts.c:1412
 #, fuzzy
 msgid "The following options take separate arguments"
 msgstr "De volgende opties zijn niet gedocumenteerd"
 
-#: opts.c:1407
+#: opts.c:1414
 #, fuzzy
 msgid "The following options take joined arguments"
 msgstr "De volgende opties zijn niet gedocumenteerd"
 
 # Betere vertaling?
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "De volgende opties hebben iets met een taal te maken"
 
@@ -2789,8 +2789,8 @@
 msgid "<command-line>"
 msgstr "<opdrachtregel>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
@@ -2809,7 +2809,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "operand ontbreekt"
@@ -2829,8 +2829,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "ongeldige operandprefix '%%%c'"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2846,18 +2846,18 @@
 msgstr "ongeldige waarde voor %%r"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "ongeldige waarde voor %%R"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "ongeldige waarde voor %%N"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "ongeldige waarde voor %%P"
@@ -2867,7 +2867,7 @@
 msgid "invalid %%h value"
 msgstr "ongeldige waarde voor %%h"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "ongeldige waarde voor %%L"
@@ -2888,7 +2888,7 @@
 msgstr "ongeldige waarde voor %%U"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "ongeldige waarde voor %%s"
@@ -2898,7 +2898,7 @@
 msgid "invalid %%C value"
 msgstr "ongeldige waarde voor %%C"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "ongeldige waarde voor %%E"
@@ -2910,7 +2910,7 @@
 msgstr "onbekende 'unspec' relocatie"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ongeldige code voor %%xn"
@@ -2973,7 +2973,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "ongeldige code voor operanduitvoer"
@@ -2983,30 +2983,30 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ongeldige UNSPEC als operand: %d"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "ongeldige shift-operand"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "Thumb-instructie met predicaat"
 
 # mja. snappen wie snappen kan ^^
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instructie met predicaat in voorwaardelijke sequentie"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3014,107 +3014,107 @@
 msgid "invalid operand for code '%c'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "instructie wordt nooit uitgevoerd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 #, fuzzy
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "operand %<%d%> is geen register"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr ""
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "adres-offset is geen constante"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr ""
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr ""
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "interne compilerfout.  Slecht adres:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "interne compilerfout.  Onbekende modus:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "ongeldige insn:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr ""
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "onbekende move-insn:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr ""
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "interne compilerfout.  Verkeerde shift:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 msgid "unsupported fixed-point conversion"
 msgstr ""
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 #, fuzzy
 msgid "variable"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 msgid "function parameter"
 msgstr "%Jherdefinitie van parameter %qD"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 msgid "structure field"
 msgstr "%qs tevoren hier gedefinieerd"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 msgid "return type of function"
 msgstr "doorgeven van argument %d van %qs"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 #, fuzzy
 msgid "pointer"
 msgstr "ongeldige lvalue in toewijzing"
@@ -3137,7 +3137,7 @@
 msgstr "ongeldige const_double operand"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3361,88 +3361,88 @@
 msgid "bad output_condmove_single operand"
 msgstr "ongeldige output_condmove_single operand"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ongeldige UNSPEC als operand"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ongeldige operand voor code '%c'"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand is noch een constante, noch een conditiecode ⇒ ongeldige operandcode 'c'"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ongeldige operand voor '%c'"
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ongeldige constraints voor operand"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "onbekende insn-modus"
 
@@ -3479,7 +3479,7 @@
 msgid "invalid %%P operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "ongeldige waarde voor %%p"
@@ -3537,7 +3537,7 @@
 msgstr "post-increment adres is geen register"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "slecht adres"
 
@@ -3571,7 +3571,7 @@
 msgstr "ongeldig adres"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "ongeldig adres"
 
@@ -3663,269 +3663,269 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 #, fuzzy
 msgid "-mvsx requires hardware floating point"
 msgstr "lege declaratie"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx en -mpaired zijn incompatibel"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 #, fuzzy
 msgid "-mvsx needs indexed addressing"
 msgstr "Schakel geïndexeerde adressering uit"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx en -mno-altivec zijn incompatibel"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 #, fuzzy
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "case-label niet in een switch-statement"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 #, fuzzy
 msgid "bad move"
 msgstr "slechte test"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "ongeldige waarde voor %%H"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "ongeldige waarde voor %%K"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "ongeldige waarde voor %%O"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "ongeldige waarde voor %%q"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "ongeldige waarde voor %%x"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "twee %<u%>s in integerconstante"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "interne fout - slechte ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
 # Betere vertaling voor 'decompose'?
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "kan adres niet ontleden"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ongeldige operand voor 'O' modifier"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ongeldige operand voor 'b' modifier"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ongeldige code voor operanduitvoer"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ongeldige expressie als operand"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ongeldige operand voor 'o' modifier"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
@@ -3932,20 +3932,20 @@
 msgstr "AltiVec argument doorgegeven aan functie zonder prototype"
 
 # 'signedness' = 'signed-heid'?
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 msgid "types differ in signedness"
 msgstr "doelen van pointer in %s verschillen in signedness"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3972,43 +3972,43 @@
 msgid "created and used with different endianness"
 msgstr "aangemaakt en gebruikt met verschillende \"endianness\""
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ongeldige operand voor %%Y"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ongeldige operand voor %%A"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ongeldige operand voor %%B"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "ongeldige operand voor %%P"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ongeldige operand voor %%f"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ongeldige operand voor %%s"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4177,30 +4177,30 @@
 msgid "bad test"
 msgstr "slechte test"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "ongeldige waarde voor %%D"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "ongeldig masker"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "ongeldige waarde voor %%d"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "ongeldige waarde voor %%t/%%b"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "geen register in adres"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "adres-offset is geen constante"
 
@@ -4221,8 +4221,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ongeldige operand van %s"
@@ -4244,14 +4244,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ongeldige operand van %s"
@@ -4282,7 +4282,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ongeldige operand van %s"
@@ -4290,7 +4290,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ongeldige operand van %s"
@@ -4301,7 +4301,7 @@
 msgstr "ongeldige operand van %s"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ongeldige operand van %s"
@@ -4308,7 +4308,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ongeldige operand van %s"
@@ -4318,7 +4318,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ongeldige operand van %s"
@@ -4333,27 +4333,27 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 #, fuzzy
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr "cast geeft functie-type op"
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 #, fuzzy
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr "cast geeft functie-type op"
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 #, fuzzy
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr "cast geeft functie-type op"
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 #, fuzzy
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr "parameternamen (zonder types) in functiedeclaratie"
@@ -4363,18 +4363,18 @@
 msgid "expected %<.%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ongeldige operand van %s"
@@ -4382,17 +4382,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ongeldige operand van %s"
@@ -4401,7 +4401,7 @@
 msgid "(anonymous)"
 msgstr "(anoniem)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ongeldige operand van %s"
@@ -4411,11 +4411,11 @@
 msgid "expected label"
 msgstr "ongeldige operand van %s"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "kandidaat 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "kandidaat 2:"
 
@@ -4649,11 +4649,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "kandidaten zijn:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -4840,88 +4840,88 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr ""
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 #, fuzzy
 msgid "Nonnegative width required"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Array subscript verwacht op %C"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr ""
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 #, fuzzy
 msgid "Zero width in format descriptor"
 msgstr "breedte van nul in %s formaat"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 #, fuzzy
 msgid "Missing leading left parenthesis"
 msgstr "beginwaarde ontbreekt"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 msgid "Left parenthesis required after %<*%>"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr ""
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr ""
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-msgid "Right parenthesis expected at %C"
-msgstr "Bestandsnaam ontbreekt na %qs optie"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 #, fuzzy
 msgid "Positive width required with T descriptor"
 msgstr "overflow in constante expressie"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr ""
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 #, fuzzy
 msgid "Positive exponent width required"
 msgstr "overflow in constante expressie"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+msgid "Right parenthesis expected at %C"
+msgstr "Bestandsnaam ontbreekt na %qs optie"
+
+#: fortran/io.c:1040
 #, fuzzy
 msgid "Period required in format specifier"
 msgstr "onbekende formaatspecificatie"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4931,82 +4931,82 @@
 msgid "Syntax error in expression at %C"
 msgstr "integer overflow in expressie"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 #, fuzzy
 msgid "Unexpected EOF"
 msgstr "ongeldige operand van %s"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 #, fuzzy
 msgid "Integer overflow"
 msgstr "integer overflow in expressie"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr ""
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr ""
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 #, fuzzy
 msgid "Expected name"
 msgstr "ongeldige operand van %s"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr ""
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr ""
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 #, fuzzy
 msgid "Expected integer"
 msgstr "ongeldige operand van %s"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Verwachtte een string"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 #, fuzzy
 msgid "find_enum(): Enum not found"
 msgstr "veld %qs niet gevonden"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr ""
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Verwachtte een integer-string"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Verwachtte een real-string"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 #, fuzzy
 msgid "Bad operator"
 msgstr "ongeldige operand voor %P"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 #, fuzzy
 msgid "Bad type in constant expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "ongeldige operand van %s"
@@ -5271,12 +5271,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5649,7 +5649,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 en -m64 gaan niet samen"
 
@@ -8812,7 +8812,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr ""
@@ -9044,7 +9044,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr ""
 
@@ -9276,12 +9276,12 @@
 msgid "Use 80-bit long double."
 msgstr ""
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 msgid "Use 64-bit long double."
 msgstr ""
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr ""
@@ -10415,93 +10415,93 @@
 msgid "64 bit ABI."
 msgstr ""
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr ""
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr ""
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr ""
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 msgid "Enable decimal floating point hardware support."
 msgstr "Geef de naam op van hardware/formaat voor floating-point getallen op het doelplatform"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 msgid "Enable hardware floating point."
 msgstr "lege declaratie"
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 msgid "Use hardware transactional execution instructions."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 #, fuzzy
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr ""
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr ""
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 msgid "Disable hardware floating point."
 msgstr "lege declaratie"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr ""
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr ""
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 msgid "Use the mvcle instruction for block moves."
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr ""
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr ""
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr ""
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -10553,11 +10553,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -10808,84 +10808,101 @@
 msgstr ""
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 #, fuzzy
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
 #, fuzzy
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "ongeldig gebruik van %<restrict%>"
+
+#: config/sparc/sparc.opt:102
+#, fuzzy
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 #, fuzzy
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 msgid "Pointers are 64-bit."
 msgstr "ongeldige lvalue in toewijzing"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 msgid "Pointers are 32-bit."
 msgstr "ongeldige lvalue in toewijzing"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 msgid "Use 64-bit ABI."
 msgstr ""
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 msgid "Use 32-bit ABI."
 msgstr ""
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr ""
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr ""
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr ""
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr ""
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr ""
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 msgid "Enable debug output."
 msgstr "Schakel uitgebreide boodschappen in"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr ""
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -15688,7 +15705,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -16129,7 +16146,7 @@
 msgstr "ongeldige operand van %s"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "ongeldige operand van %s"
@@ -16442,135 +16459,135 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 msgid "invalid comparison of non-ordered type"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 #, fuzzy
 msgid "slice can only be compared to nil"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 msgid "invalid operation (%s)"
 msgstr "ongeldige operand voor %%R"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 msgid "invalid comparison of non-comparable type"
 msgstr "ongeldige toepassing van %qs op onvolledig type %qT "
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 msgid "invalid comparison of generated struct"
 msgstr "ongeldige toepasing van %qs op een void-type"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 msgid "invalid comparison of generated array"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 #, fuzzy
 msgid "invalid comparison of non-comparable array"
 msgstr "ongeldig gebruik van array die geen lvalue is"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr "expliciete conversie is nodig"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, fuzzy, c-format
 msgid "cannot use type %s as type %s"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 #, fuzzy
 msgid "different receiver types"
 msgstr "ongeldige operand voor %p-code"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 #, fuzzy
 msgid "different number of parameters"
 msgstr "%Jherdefinitie van parameter %qD"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 #, fuzzy
 msgid "different parameter types"
 msgstr "ongeldige operand voor %p-code"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "expliciete conversie is nodig; ontbrekende methode %s%s%s"
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr ""
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 #, fuzzy
 msgid "type has no methods"
 msgstr "struct heeft geen leden"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -16747,7 +16764,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
@@ -16809,27 +16826,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
@@ -16836,7 +16853,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
@@ -16843,12 +16860,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "ongeldig argument voor %<__builtin_frame_address%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "tweede argument van %<__builtin_longjmp%> moet 1 zijn"
@@ -16855,63 +16872,63 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "doelformaat ondersteunt geen oneindige waarde"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "doelformaat ondersteunt geen oneindige waarde"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> gebruikt in functie met vaste argumenten"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> opgeroepen zonder argument"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -17823,12 +17840,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -17923,12 +17940,12 @@
 msgid "cannot find '%s'"
 msgstr "kan '%s' niet vinden"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init mislukt"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr ""
@@ -17938,7 +17955,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
@@ -18155,7 +18172,7 @@
 msgid "error writing %qs"
 msgstr "#error %s"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "open %s"
@@ -18235,17 +18252,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -18355,12 +18372,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -18375,12 +18392,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "grootte van %qs is %u bytes"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "kan bestand '%s' niet openen"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "kan bestand '%s' niet openen"
@@ -18395,7 +18412,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vergelijking is altijd %d vanwege breedte van bit-veld"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -18425,7 +18442,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18435,7 +18452,7 @@
 msgid "total size of local objects too large"
 msgstr "variabele %qs is te groot"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -18535,62 +18552,67 @@
 msgid "input file %qs is the same as output file"
 msgstr ""
 
-#: gcc.c:4498
+#: gcc.c:4476
+#, fuzzy, gcc-internal-format
+msgid "output filename may not be empty"
+msgstr "Bestandsnaam voor uitvoer twee keer opgegeven"
+
+#: gcc.c:4501
 #, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr ""
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr ""
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr ""
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "kon tijdelijk antwoordbestand %s niet openen"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "kon niet schrijven naar tijdelijk antwoordbestand %s"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "kon tijdelijk antwoordbestand %s niet sluiten"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, fuzzy, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "spec '%s' heeft een ongeldige '%%0%c'"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "spec '%s' heeft een ongeldige '%%W%c'"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "spec '%s' heeft een ongeldige '%%x%c'"
@@ -18598,230 +18620,230 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr ""
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr ""
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "onbekende spec-functie '%s'"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "misvormde naam van spec-functie"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "geen argumenten voor spec-functie"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr ""
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, fuzzy, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "spec '%s' is ongeldig"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, fuzzy, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "kan niet schrijven naar antwoordbestand %s"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s:kon uitvoerbestand '%s' niet openen\n"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr ""
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "niet-herkende opdrachtregeloptie %<-fdump-%s%>"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "niet-herkende opdrachtregeloptie %<-%s%>"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr ""
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "geen invoerbestanden"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr ""
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: %s compiler niet geïnstalleerd op dit systeem"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr ""
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr ""
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "veld %qs niet gevonden"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "taal %s wordt niet herkend"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "multilib spec '%s' is ongeldig"
 
 # hoe moet 'multilib exclusions' vertaald worden?
-#: gcc.c:8798
+#: gcc.c:8801
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "multilib exclusions '%s' is ongeldig"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib select '%s' in ongeldig"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "multilib select '%s' in ongeldig"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "multilib exclusion '%s' is ongeldig"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, fuzzy, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, fuzzy, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "ongeldig versienummer `%s'"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "te weinig argumenten voor %%:version-compare"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "te veel argumenten voor %%:version-compare"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, fuzzy, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "onbekende operator '%s' in %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "te veel argumenten voor %%:version-compare"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "te veel argumenten voor %%:version-compare"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "te weinig argumenten voor %%:version-compare"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "te veel argumenten voor %%:version-compare"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "te weinig argumenten voor functie"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "te weinig argumenten voor functie %<va_start%>"
@@ -18967,9 +18989,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -19388,228 +19410,228 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, fuzzy, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "ongeldige lvalue in toewijzing"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D not declared in class"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%q#D is niet gedeclareerd in class"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "#error %s"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE is hier niet gedeclareerd (eerste gebruik in deze functie)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "%Jvariabele %qD als %<inline%> gedeclareerd"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "ongeldige operand van %s"
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "herhaalde label-declaratie %qs"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, fuzzy, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "aantal argumenten kom niet overeen met prototype"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "ongeldige operand van %s"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT wordt tot %qT gepromoveerd indien het via %<...%> wordt doorgegeven"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(dus U zou %qT, en niet %qT, moeten doorgeven aan %<va_arg%>)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "indien deze code bereikt wordt, zal het programma afgebroken worden"
@@ -19844,7 +19866,7 @@
 
 #: ipa-devirt.c:1229
 #, fuzzy, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "eerdere definitie van %qs"
 
 #: ipa-devirt.c:1235
@@ -19944,7 +19966,7 @@
 
 #: ipa-devirt.c:1576
 #, fuzzy, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
 #: ipa-devirt.c:1599
@@ -20335,198 +20357,198 @@
 msgid "multiple loop axes specified for routine"
 msgstr "opslagklasse opgegeven voor typenaam"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr ""
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr ""
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments"
 msgstr "ongeldige waarde voor %%C"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "continue-statement niet in een lus"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "continue-statement niet in een lus"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "continue-statement niet in een lus"
@@ -20611,7 +20633,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "opdrachtregeloptie %qs wordt niet ondersteund door deze configuratie"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "ontbrekend argument bij %qs"
@@ -20769,130 +20791,140 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
+#, fuzzy, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
+
+#: opts.c:1015
+#, fuzzy, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
+
+#: opts.c:1417
 #, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize= option: %q.*s"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "niet-herkend argument bij optie '--fsanitize=': %q.*s"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize= option: %q.*s"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "niet-herkend argument bij optie '--fsanitize=': %q.*s"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "niet-herkend argument bij optie '--help=': %q.*s"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "Alignment moet een kleine macht van twee zijn, en niet %d, in #pragma pack"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr ""
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "ongeldige registernaam voor %qs"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 msgid "invalid --param name %qs"
 msgstr "ongeldige registernaam voor %qs"
 
-#: opts.c:2382
+#: opts.c:2389
 #, fuzzy, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "ongeldige registernaam voor %qs"
 
-#: opts.c:2504
+#: opts.c:2511
 #, fuzzy, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "doelformaat ondersteunt geen oneindige waarde"
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "sectie van %qs geeft een conflict met een eerdere declaratie"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized register name %qs"
 msgid "unrecognized debug output level %qs"
 msgstr "niet-herkende registernaam %qs"
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr ""
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr ""
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -21232,7 +21264,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "registernaam opgegeven voor niet-registervariabele %qs"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "conflicterende types voor %qs"
@@ -21832,12 +21864,12 @@
 msgid "error closing %s: %m"
 msgstr "#error %s"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr "case-selector niet compatibel met label"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -22749,48 +22781,48 @@
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "beginwaarde ontbreekt"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -22892,32 +22924,32 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "%Jgeneste functie %qD gedeclareerd maar niet gedefinieerd"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr "bewerking op %qs is mogelijk niet gedefinieerd"
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr ""
@@ -23273,11 +23305,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -24253,7 +24285,7 @@
 msgid "type was previously declared %qE"
 msgstr "eerdere declaratie van %qs"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
@@ -24533,7 +24565,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "het adres van %qD, zal altijd %<true%> zijn"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gebruik liefst haakjes rond toewijzingen die als waarheid gebruikt worden"
@@ -25159,63 +25191,63 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s zou van type %<%s%s%> moeten zijn, maar argument %d heeft %qT als type"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s zou van type %<%s%s%> moeten zijn, maar argument %d heeft %qT als type"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, fuzzy, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%qs is geen iterator"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%qs is geen iterator"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%qs is geen iterator"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, fuzzy, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "de te formatteren argumenten zijn niet ..."
 
 # Klinkt wat vreemd...
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime formaten kunnen geen argumenten formatteren"
@@ -25316,7 +25348,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr ""
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr ""
@@ -25346,7 +25378,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ongeldig type voor iteratie-variabele %qE"
@@ -25362,22 +25394,22 @@
 msgid "%qE is not initialized"
 msgstr "parameter %qD krijgt beginwaarde"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Ongeldig token in expressie"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "toewijzingsonderdrukking"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Ongeldig token in expressie"
@@ -25926,8 +25958,8 @@
 msgid "wrong type argument to %s"
 msgstr "argument van verkeerd type voor abs"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow in constante expressie"
@@ -26600,7 +26632,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
@@ -26761,7 +26793,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
@@ -27086,7 +27118,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "argument moet een constante zijn"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%<defined%> zonder een naam"
@@ -27167,7 +27199,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "slechte waarde (%s) voor de -march= optie"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "optie -mcpu=%s geeft conflicten met optie -mtune="
@@ -27252,9 +27284,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "spec '%s' is ongeldig"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "het argument van %<alias%> is geen string"
@@ -27341,7 +27373,7 @@
 msgstr "slechte waarde %qs voor -mmeroy-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27516,234 +27548,234 @@
 msgid "insn addresses not freed"
 msgstr "pre-increment adres is geen register"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt en NEON zijn incompatibel"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, fuzzy, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g met -fomit-frame-pointer geeft mogelijk geen fatsoenlijke debug-mogelijkheden"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "case-selector niet compatibel met label"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "doel-CPU ondersteunt geen interworking"
@@ -27750,142 +27782,142 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "De -shared optie wordt op het ogenblik niet ondersteund voor VAX ELF."
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check is niet compatibel met -mno-apcs-frame"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic en -mapcs-reent zijn incompatibel"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS reentrant code wordt niet ondersteund.  Genegeerd"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable en -msdata=%s zijn incompatibel"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr ""
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "Grens voor structure-grootte kan enkel op 8 of 32 insgesteld worden"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "Grens voor structure-grootte kan enkel op 8 of 32 insgesteld worden"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "case-selector niet compatibel met label"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr ""
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, fuzzy, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -27893,77 +27925,82 @@
 msgid "%qE attribute only applies to functions"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "attribuut %qE wordt genegeerd voor non-class-types"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applies only to initialized variables with external linkage"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "attribuut %qE is enkel van toepassing op geïnitialiseerde variabelen die extern gelinkt zijn"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "ongeldige operand van %s"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid fpu for attribute(target(\"%s\"))"
@@ -27972,13 +28009,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
@@ -28072,168 +28109,179 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "functie %qs kan geen waarde teruggeven"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, fuzzy, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "de zwakke declaratie van %qs moet publiek zijn"
 
 # goede vertaling van variadic?
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "attribuut %qE is enkel van toepassing op variabelen en functies"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%Jsectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "attribuut %qE is enkel van toepassing op variabelen"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute has no effect"
 msgid "%qE attribute address out of range"
 msgstr "attribuut %qE heeft geen effect"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "attribuut %qE is enkel van toepassing op variabelen"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, fuzzy, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, fuzzy, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr "%Jeerdere definitie van %qD was hier"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, fuzzy, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst worden."
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, fuzzy, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst worden."
+
+#: config/avr/avr.c:10160
+#, fuzzy, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst worden."
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 #| msgid "%qE incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "ongeldige registernaam voor %qs"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "ongeldige registernaam voor %qs"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -28517,12 +28565,12 @@
 msgid "invalid IACC argument"
 msgstr "ongeldige waarde voor %%C"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, fuzzy, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "te veel argumenten voor procedure `%s'"
@@ -28700,7 +28748,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
@@ -28838,290 +28886,290 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred_stack_boundary=%d ligt niet tussen 2 en 31"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "case-selector niet compatibel met label"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, fuzzy, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, fuzzy, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "pointer naar functie gebruikt in rekensom"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument van attribuut %qE is groter dan %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, fuzzy, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, fuzzy, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, fuzzy, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, fuzzy, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
 # XXX FIXME, ERROR:  s/none /non-/
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "attribuut %qE is gebruikt voor non-class-methode"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "ondersteunt geen multilib"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "conflicterende types voor ingebouwde functie %qs"
@@ -29128,297 +29176,297 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "herdefinitie van %<union %s%>"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "eerdere declaratie van %qs"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "instructie-scheduling wordt niet ondersteund op deze doelmachine"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "ongeldige const_double operand"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "%<defined%> zonder een naam"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attribuut %qE is alleen beschikbaar voor 32-bits"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, fuzzy, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "-pg en -fomit-frame-pointer zijn niet compatibel"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "incompatibel attribuut %qE wordt genegeerd"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, fuzzy, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "onbekende machine-modus %qs"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "niet-ondersteunde versie"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "ongebruikte argumenten in $-stijl formaat"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -29539,7 +29587,7 @@
 msgid "argument %qd is not a constant"
 msgstr "argument %qd is geen constante"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr ""
@@ -29549,7 +29597,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr ""
@@ -29650,7 +29698,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "-pipe wordt niet ondersteund"
@@ -30154,8 +30202,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, fuzzy, gcc-internal-format
 msgid "bad builtin code"
 msgstr "slechte conditiecode"
@@ -30410,29 +30458,29 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "attribuut %qE wordt genegeerd voor types"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -30457,7 +30505,7 @@
 msgid "-g option disabled"
 msgstr "ingeschakelde opties: "
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
@@ -30594,158 +30642,158 @@
 msgid "junk at end of #pragma longcall"
 msgstr "rommel aan einde van #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, fuzzy, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, fuzzy, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, fuzzy, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, fuzzy, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
 # Betere term voor "mismatched"?
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "slechte combinatie van argumenten"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr "conflicterende types voor ingebouwde functie %qs"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, fuzzy, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr ""
@@ -30752,67 +30800,67 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, fuzzy, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "lege declaratie"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -30821,516 +30869,521 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "argument voor %<__builtin_args_info%> moet een constante zijn"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "alias-definities worden niet ondersteund in deze configuratie; genegeerd"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr "%J%qD neemt ofwel geen, ofwel twee argumenten"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "%<defined%> zonder een naam"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "het tweede argument moet 0 of 1 zijn"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "het derde argument moet in het bereik 0..15 liggen"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "derde argument voor %<__builtin_prefetch%> moet een constante zijn"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "argument voor %<__builtin_args_info%> moet een constante zijn"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "argument voor %<__builtin_args_info%> moet een constante zijn"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "argument voor %<__builtin_args_info%> buiten bereik"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "%Jingebouwde functie %qD gedeclareerd als niet-functie"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "-pipe wordt niet ondersteund"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "bestand %qs is te groot"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 ondersteunt geen flexibele array-leden"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "ongeldig gebruik van '%%%c'"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "spec '%s' is ongeldig"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -31517,6 +31570,7 @@
 msgstr "-mapcs-stack-check is niet compatibel met -mno-apcs-frame"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr ""
@@ -31608,7 +31662,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -31635,7 +31689,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -31655,7 +31709,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -31668,161 +31722,161 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "te veel argumenten voor procedure `%s'"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "slechte conditiecode"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "ongeldig argument voor %<__builtin_return_address%>"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, fuzzy, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "gevraagde positie is geen integerconstante"
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "trapmodus niet ondersteund voor VAX-floats"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "afrondingsmodus niet ondersteund voor VAX-floats"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "ISO C staat het testen van asserties niet toe"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argument van %qs moet een niet-negatieve integer zijn"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argument van %qs is te groot (max. %d)"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
@@ -31880,27 +31934,27 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr ""
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr ""
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "slechte waarde (%s) voor optie -mcmodel="
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
-msgstr ""
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+msgid "-mcmodel= is not supported on 32-bit systems"
+msgstr "ISO C ondersteunt de %<%c%> lengte-optie niet"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
@@ -32185,22 +32239,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "misvormde #pragma pack"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "doel-CPU ondersteunt geen interworking"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, fuzzy, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "Enkel variabelen met beginwaarde kunnen in het 8-bit gebied geplaatst worden."
@@ -32290,7 +32344,7 @@
 msgid "could not read the BRIG file"
 msgstr "kan niet schrijven naar antwoordbestand %s"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -32697,9 +32751,9 @@
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qs tevoren hier gedeclareerd"
@@ -32834,7 +32888,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -33882,7 +33936,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "twee of meer data types opgegeven bij declaratie"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> is te lang voor GCC"
@@ -34024,17 +34078,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ondersteunt gewone %<complex%> niet in de betekenis van %<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, fuzzy, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -34087,7 +34141,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "ongeldige operand van %s"
@@ -34128,7 +34182,7 @@
 msgstr "onbekende machine-modus %qs"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "meerdere opslagklassen in declaratie van %qs"
@@ -34143,7 +34197,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -34158,8 +34212,8 @@
 msgid "unexpected attribute"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -34199,7 +34253,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -34227,7 +34281,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ondersteunt %<long long%> niet"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -34291,14 +34345,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma aan het einde van enumerator-lijst"
@@ -34433,7 +34487,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -34458,12 +34512,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -34477,17 +34531,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "ongeldige beginwaarde"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "leeg body in een else-statement"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "leeg body in een else-statement"
@@ -34497,7 +34551,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -34517,7 +34571,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ongeldig register in de instructie"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -34697,17 +34751,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "tweede argument van %<__builtin_longjmp%> moet 1 zijn"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -34762,61 +34816,61 @@
 msgid "no type or storage class may be specified here,"
 msgstr "opslagklasse opgegeven voor parameter %qs"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "misvormde #pragma pack"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attribuut %<getter%> mag slechts één keer opgegeven worden"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "misvormde #pragma pack(pop[,id])"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "misvormde #pragma pack(pop[,id])"
@@ -34831,12 +34885,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "ongeldige waarheidsexpressie"
@@ -34851,53 +34905,53 @@
 msgid "%qD is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "te veel invoerbestanden"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -34925,22 +34979,22 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "ongeldige operand van %s"
@@ -34950,58 +35004,58 @@
 msgid "%<num_workers%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "te veel argumenten voor formaat"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "zowel %<long%> als %<void%> opgegeven bij declaratie"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ongeldige const_double operand"
@@ -35016,17 +35070,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -35046,17 +35100,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ongeldige const_double operand"
@@ -35066,67 +35120,67 @@
 msgid "invalid proc_bind kind"
 msgstr "ongeldige const_double operand"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "-fPIC is niet geldig met -mcoff"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%<__thread%> samen met %s gebruikt"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "lege declaratie"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "de declaratie van %qs verbergt een globale declaratie"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ongeldige linker operand van %s"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -35141,7 +35195,7 @@
 msgid "expected function name"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qs is meestal een functie"
@@ -35151,42 +35205,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ongeldige bewerking met %<__fpreg%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -35196,27 +35250,27 @@
 msgid "expected %<(%> or end of line"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "overflow in constante expressie"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "herdeclaratie van %qs"
@@ -35226,73 +35280,73 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> als enige parameter mag niet gekwalificeerd worden"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -35307,7 +35361,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -35317,32 +35371,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "ongeldige operand van %s"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -35397,22 +35451,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%Jparameter %u heeft een onvolledig type"
@@ -35427,52 +35481,52 @@
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -35482,7 +35536,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "ongeldige operand van %s"
@@ -36214,7 +36268,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -36547,7 +36601,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C verbiedt %<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, fuzzy, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> gedeclareerde functie bevat een %<return%> statement"
@@ -36557,7 +36611,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -36583,7 +36637,7 @@
 msgid "function returns address of label"
 msgstr "functie geeft adres van lokale variabele terug"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-waarde is geen integer"
@@ -36598,7 +36652,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-label niet in een switch-statement"
@@ -36618,17 +36672,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-statement niet in een lus"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-statement niet in een lus of switch"
@@ -36638,7 +36692,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-statement niet in een lus of switch"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-statement niet in een lus"
@@ -36746,12 +36800,12 @@
 msgid "used vector type where scalar is required"
 msgstr "waarde van struct-type gebruikt waar een scalair nodig is"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -36761,25 +36815,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "te veel invoerbestanden"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qs is meestal een functie"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -36790,70 +36844,70 @@
 msgstr "te veel invoerbestanden"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "grootte van array %qs is van een niet-integer type"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qs is smaller dan waarden van zijn type"
@@ -36873,7 +36927,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "grootte van %qs is %u bytes"
@@ -36883,17 +36937,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "ISO C90 verbiedt array %qs van variabele grootte"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -36913,18 +36967,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -36936,32 +36990,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -36981,55 +37035,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qs is geen static veld"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
@@ -37039,32 +37093,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "waarde met subscript is noch een array, noch een pointer"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -37611,152 +37665,152 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "cast laat qualifiers van doeltype van pointer vallen"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "kan oproep van %qs niet inline maken"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "herdeclaratie van %qs"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "te veel argumenten voor %s %q+#D"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "Teveel argumenten in oproep van %qs"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "union heeft geen lid dat %qs heet"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, fuzzy, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, fuzzy, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "kandidaat is: %+#D"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -37857,272 +37911,272 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "%s voor %qs"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bitveld %qs heeft een negatieve breedte"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bitveld %qs heeft breedte 0"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "breedte van %qs overschrijdt zijn type"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "bitveld %qs heeft een ongeldig type"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "overtollige elementen in beginwaarde van union"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "%qs is geen iterator"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, fuzzy, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%s heeft geen benoemde leden"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "geen beginwaarde voor variant-veld %qs"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%qs is geen iterator"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "%qs is geen static veld"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "%qs is geen static veld"
@@ -38129,153 +38183,153 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "omvang van array %qs is te groot"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ongeldig gebruik van strcture met flexibel array-lid"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jflexibel array-lid in overigens lege struct"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jflexibel array-lid niet aan het eind van de struct"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jflexibel array-lid in overigens lege struct"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "veld %qs heeft een onvolledig type"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "taal-string %<\"%E\"%> wordt niet herkend"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "herhaald lid %qs"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -38285,12 +38339,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -38320,333 +38374,333 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%qs is geen iterator"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%J%qD is gewoonlijk een niet-static funtie"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%J%qD werd voor haar definitie gebruikt zonder protoype"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "array subscript is geen integer"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "array subscript is geen integer"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> pointer wordt gederefereerd"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "grootte van array %qs is van een niet-integraal type"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "array-index in beginwaarde van niet-array"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%qs is geen iterator"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "ongeldige opslagklasse voor functie %qs"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "niet-constante array-index in beginwaarde"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "onverwachte operand"
@@ -39443,7 +39497,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "(dicht bij initialisatie van %qs)"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -39458,7 +39512,7 @@
 msgid "%qD is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "macro %qs gebruikt zonder argumenten"
@@ -41102,7 +41156,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "%Jparameter %qD als %<inline%> gedeclareerd"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ongeldig gebruik van een void-expressie"
@@ -41555,13 +41609,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "eerdere declaratie van %qs"
@@ -41571,8 +41625,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "grootte van %qs is %u bytes"
@@ -41622,7 +41676,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "eerdere definitie van %qs"
@@ -41686,7 +41740,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
@@ -41701,7 +41755,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "de terugkeerwaarde van een functie kan geen funtie zijn"
@@ -41859,27 +41913,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "breedte van bitveld %qs is geen integerconstante"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qs is geen static veld"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, fuzzy, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, fuzzy, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonieme %s gedeclareerd binnen parameterlijst"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -41888,67 +41942,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, fuzzy, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "de tweede parameter van %<va_start%> is niet het laatste benoemde argument"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, fuzzy, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "parameter %qs als void gedeclareerd"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
@@ -41957,47 +42011,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "eerdere declaratie van %qs"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "parameternaam ontbreekt uit parameterlijst"
@@ -42004,12 +42058,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "kan functie %<main%> niet inline maken"
@@ -42318,18 +42372,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "parameter %qs krijgt beginwaarde"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "ongeldige beginwaarde voor member %qs"
@@ -42429,7 +42483,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qs is geen iterator"
@@ -42449,7 +42503,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
@@ -42644,22 +42698,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "kan niet derefereren, is geen pointer."
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "ongeldige operanden voor binaire %s-operator"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
@@ -42714,186 +42768,186 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "%qs is geen static veld"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr ""
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr ""
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "variable met beginwaarde %qs is als dllimport aangeduid"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "%qs is geen static veld"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "lege declaratie"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr ""
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "ongeldig type-argument %qs"
@@ -43085,97 +43139,97 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, fuzzy, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "geneste functie %qs is als %<extern%> gedeclareerd"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eerdere impliciete declaratie van `%s'"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 msgid "only here as a friend"
 msgstr "veld %qs als een functie gedeclareerd"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attribuut-commando %qD wordt genegeerd"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr ""
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr ""
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, fuzzy, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -43182,27 +43236,27 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%s voor %qs"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -43222,7 +43276,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -43247,7 +43301,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
@@ -43307,1207 +43361,1212 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, fuzzy, gcc-internal-format
 msgid "invalid template-id"
 msgstr "ongeldig karakter in naam van macro-parameter"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, fuzzy, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, fuzzy, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, fuzzy, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, fuzzy, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "ongeldige beginwaarde voor member %qs"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, fuzzy, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, fuzzy, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr ""
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr ""
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "%qs is meestal een functie"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr ""
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr ""
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr "floating-point getal overschrijdt het bereik van een %<float%>"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr "floating-point getal overschrijdt het bereik van een %<float%>"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, fuzzy, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr "floating-point constante verkeerd gebruikt"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr ""
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "lege declaratie"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 msgid "expected binary operator"
 msgstr "onverwachte operand"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 msgid "expected ..."
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in vector shift expression"
 msgid "mismatched operator in fold-expression"
 msgstr "types in vector-shift-expressie komen niet overeen"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "sectie-attributen worden niet ondersteund voor dit doelsysteem"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ verbiedt accolade-groepen in expressies"
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, fuzzy, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, fuzzy, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, fuzzy, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "overbodige herdeclaratie van %qs in zelfde bereik"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, fuzzy, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "de declaratie van %qs verbergt een parameter"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, fuzzy, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "te weinig argumenten voor functie %<va_start%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ verbiedt het gebruik van samengestelde expressies als lvalues"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr ""
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr ""
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "gebruik liefst haakjes rond && binnen ||"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "%s van alleen-lezen variabele %qs"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C ondersteunt %<long long%> niet"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "herhaalde %<volatile%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-label niet in een switch-statement"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%d constructor(s) gevonden\n"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
 # vertaling voor 'statement'?
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr "break-statement niet in een lus of switch"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ verbiedt geneste functies"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "lege declaratie"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
 #, fuzzy, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr "ongeldige beginwaarde voor member %qs"
+
+#: cp/parser.c:13220
+#, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "herdefinitie van %<union %s%>"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "%qs mag niet als alleen-lezen gedeclareerd worden"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%Jdeclaratie van %qD als static volgt declaratie als niet-static"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ongeldige const_double operand"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "onverwachte operand"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ongeldig gebruik van onvolledige typedef %qs"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "ongeldige macronaam %<%.*s%>"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "%qs is geen iterator"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "ongeldige beginwaarde"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
 # Of is 'verbiedt parameterdeclaraties op voorhand' beter?
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C verbiedt voorwaartse declaraties van parameters"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qs wordt gedeclareerd als een array van functies"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "herdefinitie van %qs"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ verbiedt het %sen van een enum"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 msgid "nested identifier required"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "geen eerdere declaratie voor %qs"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "ingebouwde functie %qs kan niet uitgeschakeld worden"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "functie %qs geherdeclareerd als inline"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -44516,7 +44575,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "herdeclaratie van %qs"
@@ -44523,337 +44582,337 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "herhaald lid %qs"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "onverwachte operand"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "herhaalde case-waarde"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%qs neemt ofwel geen, ofwel twee argumenten"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ staat het gebruik van %<varargs.h%> niet toe"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "conflicterende declaraties van %qs"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "[kan %s niet vinden]"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "eerdere definitie van %qs"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ingebouwde functie %qs als niet-functie gedeclareerd"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "attributen genegeerd in declarator van parameter-array"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "kan functie %<main%> niet inline maken"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "%qs staat niet aan het begin van een declaratie"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "top-level declaratie van %qs specifieert %<auto%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "overflow in constante expressie"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "twee of meer data types in de declaratie van %qs"
@@ -44862,450 +44921,450 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe wordt niet ondersteund"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "herdeclaratie van %<enum %s%>"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "herdeclaratie van %qs"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "declaratie declareert niets"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%qs is geen iterator"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vóór %<extern%> gebruikt"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ ondersteunt %<long long%> niet"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "zowel %<short%> als %<char%> opgegeven bij declaratie"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "herhaalde %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Ongeldige optie %qs"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "dit is een eerdere declaratie"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qs als ander soort symbool geherdeclareerd"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "ongeldig type-argument %qs"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "meerdere opslagklassen in declaratie van %qs"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefix-attributen worden genegeerd vóór %<@%D%>"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ongeldige operand voor 'p' modifier"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabele %qs gebruikt in geneste functie"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "globale registervariabele volgt op een functiedefinitie"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ongeldige beginwaarde"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "ongeldige waarheidsexpressie"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qs is meestal een functie"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "rommel aan einde van %<#pragma GCC pch_preprocess%>"
 
 # "constraints" hier te vertalen ("beperkingen"/"restricties") of niet?
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
@@ -45312,42 +45371,42 @@
 msgstr "ongeldige constraints voor operand"
 
 # 'braced-group'? Wie schrijft verdorie die foutmeldingen?
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "accolade-groep in expressie enkel toegestaan binnen een functie"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "argument-formaat opgegeven voor niet-functie %qs"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 msgid "expected variable-name"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "ongeldige operand van %s"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
@@ -45439,7 +45498,7 @@
 msgid "candidate is: %#D"
 msgstr "kandidaat is: %+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr ""
@@ -46015,122 +46074,137 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr "variabele %qs als inline gedeclareerd"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "variabele %qs als inline gedeclareerd"
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%qs is geen iterator"
+
+#: cp/pt.c:6672
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ongeldige beginwaarde voor member %qs"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "meerdere parameters hebben de naam %qs"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
@@ -46137,104 +46211,104 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "types in voorwaardelijke expressie komen niet overeen"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d or more)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "verkeerd aantal sjabloonargumenten (%d, moet %d of meer zijn)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "gegeven voor %q+D"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumenten aan macro %qs gegeven"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "gegeven voor %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D is geen functiesjabloon"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "lege declaratie"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure"
 msgstr "niet-beëindigde parameterlijst in %<#define%>"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "herdefinitie van %<struct %s%>"
@@ -46252,274 +46326,274 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabele %qs als inline gedeclareerd"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ongeldige operand voor %p-code"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "herdeclaratie van %qs"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "%qs gedeclareerd als een functie die een array teruggeeft"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "%qs gedeclareerd als een functie die een functie teruggeeft"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "pointer naar lid-functie gebruikt in rekensom"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "herhaald lid %qs"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "argument %qs komt niet overeen met prototype"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ontbrekende witruimte na getal %qs"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ongeldig gebruik van een void-expressie"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD als inline gedeclareerd na zijn definitie"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qs is smaller dan waarden van zijn type"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "eerste argument van %qs zou een %<int%> moeten zijn"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "herhaalde definitie %qs"
 
 # XXX FIXME:  useless gettextization
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 #| msgid "%s %qs"
 msgid "%s %#S"
 msgstr "%s %qs"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qs is geen static veld"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "herhaalde definitie %qs"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "impliciete declaratie van functie %qs"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "pointer naar functie gebruikt in aftrekking"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "herhaalde definitie %qs"
@@ -46531,94 +46605,94 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eerdere impliciete declaratie van %qs"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%qs is geen iterator"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "parameter %qs heeft enkel een voorwaartse declaratie"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "functie wordt niet als kandidaat voor inlining beschouwd"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan %qs niet nabootsen"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "beginwaarde-element is niet constant"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
@@ -46775,469 +46849,469 @@
 msgid "  since %q+#D declared in base class"
 msgstr "%qs tevoren hier gedeclareerd"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, fuzzy, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "type van parameter %qs is niet gedeclareerd"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ongeldig gebruik van %<this%> op hoogste niveau"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "%s laat qualifiers van doeltype van pointer vallen"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%<%c%> optie gebruikt bij type %<%c%>"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "de declaratie van %qs verbergt een symbool uit de parameterlijst"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ongeldig gebruik van het niet gedefinieerde type %<%s %s%>"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ongeldige linker operand van %s"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "kan functie %<main%> niet inline maken"
 
 # Betere term voor "mismatched"?
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "slechte combinatie van argumenten"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, fuzzy, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "modi in %s expressie komen niet overeen"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "overflow in constante expressie"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "opslaggrootte van %qs is onbekend"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qs is geen iterator"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "nutteloze type-kwalificatie in lege declaratie"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<this%> is niet beschikbaar in static member-funties"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "grootte van %qs is %u bytes"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "ongeldig gebruik van %<restrict%>"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "statische variable %qs is als dllimport aangeduid"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 #| msgid "vectorlength must be an integer constant"
 msgid "%<vector%> length expression must be integral"
 msgstr "vectorlengte moet een integerconstante zijn"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "te veel invoerbestanden"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<defined%> zonder een naam"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%qs is geen iterator"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparameter %u heeft een onvolledig type"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "pex_init mislukt"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "%Jdeclaratie van %qD als niet-static volgt declaratie als static"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "modi in %s expressie komen niet overeen"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "einde van niet-void functie werd bereikt zonder teruggeefwaarde"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "linker operand van comma-expressie heeft geen effect"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, fuzzy, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "argument %d is alleen-lezen"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -47253,114 +47327,114 @@
 msgid "lambda-expression in a constant expression"
 msgstr "overflow in constante expressie"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attribuut %qE is enkel van toepassing op functie-types"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "attribuut %qE is enkel van toepassing op class-definities"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "sectie-attributen worden niet ondersteund op dit doelsysteem"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "herdeclaratie van %qs"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "herhalings-aantal is geen integerconstante"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argument van attribuut %qE is geen string-constante"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "'%%%c' is not a valid operand prefix"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%%%c' is geen geldige operand-prefix"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "herhaalde definitie %qs"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies, niet %s"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attribuut %qE is enkel van toepassing op functies"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "array subscript is geen integer"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -48046,102 +48120,102 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ongeldige registernaam voor %qs"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "kon 0x%l.8x niet naar een regio omzetten"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "type van teruggeefwaarde is onvolledig"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "doorgeven van argument %d van %qs"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adres van globale registervariabele %qs gevraagd"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -48148,55 +48222,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%<return%> zonder waarde in een functie die een niet-void waarde teruggeeft"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "beginwaarde ontbreekt"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "%<return%> met waarde in een functie die void teruggeeft"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -52237,89 +52311,89 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
 # dit klinkt niet al te best
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "ongeldige waarheidsexpressie"
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
 # dit klinkt niet al te best
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "functie-oproep heeft geaggregeerde waarde"
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "overflow in constante expressie"
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -52506,12 +52580,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -53286,512 +53360,527 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr ""
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr "%<void%> moet de enige parameter zijn"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "breedte van nul in %s formaat"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr "overflow in constante expressie"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "ingesloten %<\\0%> in formaat"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr "onbekende formaatspecificatie"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "onbekende formaatspecificatie"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "onbekende formaatspecificatie"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr ""
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr ""
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "overflow in constante expressie"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr ""
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr ""
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr "opvulkarakter in strfmon-formaat"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "%qs is geen bestand, pipe of tty"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr ""
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr ""
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr ""
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr "Ontbrekende argumenten voor intrinsic %s op %L"
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "break-statement niet in een lus of switch"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr ""
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr "expressie-statement heeft onvolledig type"
 
 # vertaling voor 'statement'?
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr "parameternaam ontbreekt uit parameterlijst"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "herhaalde label-declaratie %qs"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "-I- twee keer opgegeven"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "ongeldige registernaam voor %qs"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "label %qs gebruikt maar niet gedefinieerd"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "ongeldige expressie als operand"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "case-selector niet compatibel met label"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "overflow in constante expressie"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
 # vertaling voor 'statement'?
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "expressie-statement heeft onvolledig type"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -54689,252 +54778,252 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr ""
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr "%s voor %qs"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "veld %qs heeft al een beginwaarde gekregen"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "twee of meer data types in de declaratie van %qs"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr ""
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "%s voor %qs"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "%s:fout bij schrijven van uitvoerbestand '%s'\n"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "naar label %s gerefereerd buiten enige functie"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, fuzzy, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "grootte van %qs is %u bytes"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: kan bestand '%s' niet openen om te lezen: %s\n"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: fout bij schrijven van bestand '%s': %s\n"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: kan aux-infobestand '%s' niet verwijderen: %s\n"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: waarschuwing: kan naam van bestand '%s' niet wijzigen in '%s': %s\n"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: kan aux-infobestand '%s' niet verwijderen: %s\n"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "gevraagd alignment is geen macht van 2"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "%<%.*s%> is niet gedefinieerd"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "ongeldige beginwaarde"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: kan bestand '%s' niet openen om te lezen: %s\n"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr ""
@@ -57314,7 +57403,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "fout in argumenten voor spec-functie '%s'"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
@@ -58812,448 +58901,438 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Lege array-constructor op %C is niet toegestaan"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "attribuut %qE botst met attribuut %s"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "overflow in constante expressie"
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Bestandsnaam ontbreekt na %qs optie"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "label %qs gedefinieerd maar niet gebruikt"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring bij %L heeft lengte nul"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "object van variabele lengte mag geen beginwaarde krijgen"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Intrinsic '%s' op %L moet minstens twee argumenten hebben"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -60341,12 +60420,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "ongeldig type-argument %qs"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, fuzzy, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr "case-selector niet compatibel met label"
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr ""
Index: gcc/po/ChangeLog
===================================================================
--- gcc/po/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ gcc/po/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,17 @@
+2017-08-21  Joseph Myers  <joseph@codesourcery.com>
+
+	* de.po: Update.
+
+2017-08-16  Joseph Myers  <joseph@codesourcery.com>
+
+	* fr.po: Update.
+
+2017-08-15  Joseph Myers  <joseph@codesourcery.com>
+
+	* be.po, da.po, de.po, el.po, es.po, fi.po, fr.po, hr.po, id.po,
+	ja.po, nl.po, ru.po, sr.po, sv.po, tr.po, uk.po, vi.po, zh_CN.po,
+	zh_TW.po: Update.
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: gcc/po/vi.po
===================================================================
--- gcc/po/vi.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/vi.po	(.../branches/gcc-7-branch)
@@ -9,7 +9,7 @@
 msgstr ""
 "Project-Id-Version: gcc 7.1-b20170101\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2017-01-08 08:33+0700\n"
 "Last-Translator: Trần Ngọc Quân <vnwildman@gmail.com>\n"
 "Language-Team: Vietnamese <translation-team-vi@lists.sourceforge.net>\n"
@@ -195,13 +195,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "sai sử dụng hằng số dấu chấm động"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -506,62 +506,62 @@
 "thì được tự động gửi cho những tiến trình con khác nhau được %s gọi.\n"
 "Phải sử dụng tùy chọn -W<chữ> để gửi thêm tùy chọn cho những tiến trình này.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Đang xử lý đặc tả (%s), cái mà “%s”\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Đích: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Cấu hình bằng: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Mô hình tuyến trình: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc phiên bản %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "Trình điều khiển gcc phiên bản %s %sexecuting gcc phiên bản %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr "Nếu lỗi không được tái lặp lại, thế thì gần như chắc chắn là phần cứng hay HDH có trục trặc.\n"
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr "Nguồn tiền xử lý lưu vào trong tập tin %s, vui lòng đính kèm cái này vào báo cáo lỗi của bạn.\n"
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "cài đặt: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "chương trình: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "thư viện: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -571,16 +571,16 @@
 "Để tìm hướng dẫn về thông báo lỗi, thăm địa chỉ:\n"
 
 # Variable: don't translate / Biến: đừng dịch
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "©"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -591,7 +591,7 @@
 "KHẢ NĂNG BÁN HAY KHẢ NĂNG LÀM ĐƯỢC VIỆC DỨT KHOÁT.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -604,7 +604,7 @@
 "=================\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -613,7 +613,7 @@
 "Hãy sử dụng \"-Wl,TÙY_CHỌN\" để gửi tùy chọn đó cho bộ liên kết.\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -624,7 +624,7 @@
 "=================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -638,16 +638,16 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr "  merge [options] <dir1> <dir2>         Hòa trộng nội dung tập tin phủ quét\n"
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "    -o, --output <dir>                  Thư mục xuất\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr " -v, --verbose                         Chế độ chi tiết\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "    -o, --output <dir>                  Thư mục xuất\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -663,16 +663,16 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr "  rewrite [options] <dir>               Ghi lại nội dung tập tin phủ quét\n"
 
+#: gcov-tool.c:270
+#, c-format
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgstr "    -n, --normalize <int64_t>           Tiêu chuẩn hóa hồ sơ\n"
+
 #: gcov-tool.c:272
 #, c-format
 msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr "    -s, --scale <float or simple-frac>  Tỷ lệ con đếm hồ sơ\n"
 
-#: gcov-tool.c:273
-#, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
-msgstr "    -n, --normalize <int64_t>           Tiêu chuẩn hóa hồ sơ\n"
-
 #: gcov-tool.c:290
 #, c-format
 msgid "Rewrite subcommand usage:"
@@ -698,29 +698,29 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr "  overlap [options] <dir1> <dir2>       Tính toán chồng đè hai hồ sơ\n"
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "    -h, --hotonly                       Chỉ in thông tin cho hàm/đối tượng nóng\n"
-
-#: gcov-tool.c:422
-#, c-format
 msgid "    -f, --function                      Print function level info\n"
 msgstr ""
 "    -f, --function                      In thông tin mức hàm\n"
 "\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:421
 #, c-format
 msgid "    -F, --fullname                      Print full filename\n"
 msgstr "    -F, --fullname                      In tên tập tin đầy đủ\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:422
 #, c-format
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr "    -h, --hotonly                       Chỉ in thông tin cho hàm/đối tượng nóng\n"
+
+#: gcov-tool.c:423
+#, c-format
 msgid "    -o, --object                        Print object level info\n"
 msgstr "    -o, --object                        In thông tin mức đối tượng\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr "    -t <float>, --hot_threshold <float> Đặt ngưỡng cho không nóng\n"
@@ -809,20 +809,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Hiển thị trợ giúp này rồi thoát.\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Hiển thị thông tin cho mọi khối cơ bản\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Bao gồm trong kết xuất các xác xuất nhánh\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -831,16 +826,21 @@
 "  -c, --branch-counts             Đưa ra số lượng nhánh được theo,\n"
 "                                     thay cho phần trăm\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          Hiển thị tiến trình công việc\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Xuất bản tóm tắt cho mỗi hàm\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Hiển thị trợ giúp này rồi thoát.\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1026,82 +1026,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s: đồ thị không thể giải được cho “%s”\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Dòng được thực hiện: %s trên %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Không có dòng thực thi\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s “%s”\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Nhánh được thực hiện: %s trên %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "Đã lấy ít nhất một lần: %s trên %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Không có nhánh\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Cuộc gọi được thực hiện: %s trên %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Không có cuộc gọi\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s: không có dòng cho “%s”\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "cuộc gọi   %2d trả về %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "cuộc gọi   %2d chưa bao giờ thực hiện\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "nhánh %2d được lấy %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "nhánh %2d chưa bao giờ thực hiện\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "%2d không điều kiện được lấy %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "%2d không điều kiện chưa bao giờ thực hiện\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "Không thể mở tập tin nguồn %s\n"
@@ -1208,89 +1208,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr "Dùng tùy-chọn này để chuẩn đoán."
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr "mặc định %d tối thiểu %d tối đa %d"
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr "Giống như %s. Dùng tùy-chọn sau đó để thay thế."
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s Giống như %s."
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[mặc định]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[đã bật]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[bị tắt]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Không tìm thấy tùy chọn có những đặc điểm đã muốn\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Không tìm thấy. Hãy sử dụng --help=%s để hiển thị *tất cả* các tùy chọn được giao diện %s hỗ trợ.\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Đã hiển thị tất cả các tùy chọn có những đặc điểm đã muốn\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "Theo đây có những tùy chọn đặc trưng cho đích"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "Theo đây có những tùy chọn điều khiển các thông điệp cảnh báo của bộ biên dịch"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "Theo đây có những tùy chọn điều khiển việc tối ưu hóa"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "Theo đây có những tùy chọn không phụ thuộc vào ngôn ngữ"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "Tùy chọn --param nhận ra những điều theo đây như là tham số"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "Theo đây có những tùy chọn đặc trưng cho chỉ ngôn ngữ "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "Theo đây có những tùy chọn được hỗ trợ bởi ngôn ngữ "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "Theo đây có những tùy chọn không có tài liệu diễn tả"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "Theo đây có những tùy chọn chấp nhận các đối số riêng"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "Theo đây có những tùy chọn chấp nhận các đối số nối lại"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "Theo đây có những tùy chọn liên quan đến ngôn ngữ"
 
@@ -2823,8 +2823,8 @@
 msgid "<command-line>"
 msgstr "<dòng lệnh>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Không hỗ trợ toán hạng cho mã “%c”"
@@ -2843,7 +2843,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "toán hạn dấu chấm động / thanh ghi véctơ không tương thích cho “%%%c”"
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "toán hạng còn thiếu"
@@ -2863,8 +2863,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "tiền tố toán hạng không hợp lệ “%%%c”"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "“%%&” bị sử dụng mà không có tham chiếu TLS năng động cục bộ"
@@ -2880,18 +2880,18 @@
 msgstr "giá trị %%r sai"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "giá trị %%R sai"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "giá trị %%N sai"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "giá trị %%P sai"
@@ -2901,7 +2901,7 @@
 msgid "invalid %%h value"
 msgstr "giá trị %%h sai"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "giá trị %%L sai"
@@ -2922,7 +2922,7 @@
 msgstr "giá trị %%U sai"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "giá trị %%s sai"
@@ -2932,7 +2932,7 @@
 msgid "invalid %%C value"
 msgstr "giá trị %%C sai"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "giá trị %%E sai"
@@ -2943,7 +2943,7 @@
 msgstr "không rõ bỏ ghi rõ bố trí lại"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "mã %%xn sai"
@@ -3006,7 +3006,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "sai đặt mã kết xuất toán hạng"
@@ -3016,29 +3016,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC không hợp lệ như là toán hạng: %d"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "sai đặt toán hạng dời"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "lệnh Thumb căn cứ vào"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "gặp lệnh căn cứ vào trong dãy có điều kiện"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3046,109 +3046,109 @@
 msgid "invalid operand for code '%c'"
 msgstr "sai đặt toán hạng cho mã “%c”"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "lệnh chưa bao giờ thực hiện"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "định dạng mã Maverick đã cũ “%c”"
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "toán hạng địa chỉ yêu cầu ràng buộc cho thanh ghi X, Y, hay Z"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "các toán hạng cho %T/%t phải là reg + const_int:"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr "Địa chỉ sai, không phải địa chỉ V/R:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr "địa chỉ sai, không phải là một hằng số:"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "địa chỉ sai, không phải (reg+disp):"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "địa chỉ sai, không phải post_inc hoặc pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "lỗi biên dịch nội bộ. Địa chỉ sai:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Không hỗ trợ mã “%c” cho dấu chấm cố định:"
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "lỗi biên dịch nội bộ. Không hiểu chế độ:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "lệnh sai:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "lệnh không đúng:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "không rõ lệnh di chuyển:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "lệnh dời sai:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "lỗi biên dịch nội bộ. Dịch không đúng:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 msgid "unsupported fixed-point conversion"
 msgstr "không hỗ trợ chuyển đổi dấu chấm cố định"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 #, fuzzy
 #| msgid "Loop variable"
 msgid "variable"
 msgstr "Biến vòng lặp"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "định nghĩa lại của đối số %q+D"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 #| msgid "struct defined here"
 msgid "structure field"
 msgstr "struct được định nghĩa ở đây"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 #| msgid "creating array of functions"
 msgid "return type of function"
 msgstr "tạo mảng hàm"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 #, fuzzy
 #| msgid "null pointer"
 msgid "pointer"
@@ -3172,7 +3172,7 @@
 msgstr "toán hạng const_double sai"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3394,91 +3394,91 @@
 msgid "bad output_condmove_single operand"
 msgstr "đặt sai toán hạng output_condmove_single"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "đặt sai UNSPEC như là toán hạng"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "sử dụng kết xuất cờ asm sai"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “O”"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “z”"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "sử dụng loại toán hạng không hợp lệ với mã toán hạng “Z”"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "sai kích cỡ toán hạng cho mã toán hạng “Z”"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “D”"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng không hợp lệ “%c”"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "toán hạng không phải là một mã điều kiện, mã toán hạng sai “Y”"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "mã toán hạng sai “%c”"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "sai đặt ràng buộc cho toán hạng"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "không rõ chế độ lệnh"
 
@@ -3515,7 +3515,7 @@
 msgid "invalid %%P operand"
 msgstr "gặp toán hạng %%P sai"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "gặp giá trị %%p sai"
@@ -3569,7 +3569,7 @@
 msgstr "địa chỉ hậu gia không phải là một thanh ghi"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "địa chỉ sai"
 
@@ -3602,7 +3602,7 @@
 msgstr "insn chứa một địa chỉ sai !"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "địa chỉ sai"
 
@@ -3693,279 +3693,279 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Hãy thử chạy “%s” trong trình bao để tăng giới hạn.\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le không cho phép trên đích big-endian"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx yêu cầu dấu chấm động loại phần cứng"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx và -mpaired không tương thích với nhau"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx yêu cầu đặt địa chỉ một cách phụ lục"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx và -mno-altivec không tương thích với nhau"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec thì tắt vsx"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory yêu cầu chế độ 64-bit"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic cần chế độ 64-bit"
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory không sẵn sàng trên chế độ little endian"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mtoc-fusion yêu cầu chế độ 64-bit"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion yêu cầu mô hình mã medium/large"
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr "sai di chuyển"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr "Di chuyển 128-bit sai"
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, c-format
 msgid "invalid %%e value"
 msgstr "giá trị %%e sai"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "giá trị %%f sai"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "giá trị %%F sai"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "giá trị %%G sai"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "mã %%j sai"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "mã %%J sai"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "giá trị %%k sai"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "giá trị %%K sai"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "giá trị %%O sai"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "giá trị %%q sai"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "giá trị %%T sai"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "giá trị %%u sai"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "giá trị %%v sai"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "giá trị %%x sai"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "giá trị %%y sai, hãy thử sử dụng ràng buộc “Z”"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 và __ibm128 không thể được dùng trong cùng một biểu thức"
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 và long double không thể được dùng trong cùng một biểu thức"
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 và long double không thể được dùng trong cùng một biểu thức"
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "đối số AltiVec bị gửi cho hàm không nguyên mẫu"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 msgid "Could not generate addis value for fusion"
 msgstr "Không thể tạo addis cho sát nhập"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Không thể tạo ra việc tải/lưu offset cho hợp nhất"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr "Hợp nhất GPR sai"
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, reg #1 sai"
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, reg #2 sai"
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load không MEM"
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, reg #1 sai"
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, reg #2 sai"
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store không MEM"
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "không thể giải mã địa chỉ"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "hằng không hợp lệ cho bổ nghĩa kết xuất “%c”"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "hằng không hợp lệ - hãy thử dùng bổ nghĩa kết xuất"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "véc-tơ hằng không hợp lệ cho bổ nghĩa kết xuất “%c”"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "biểu thức không hợp lệ - hãy thử dùng bổ nghĩa kết xuất"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "biểu thức không hợp lệ cho bộ sửa đầu ra “%c”"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "Vector argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "Đối số véc-tơ bị gửi cho hàm không nguyên mẫu"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3991,43 +3991,43 @@
 msgid "created and used with different endianness"
 msgstr "tạo và sử dụng với các trình trạng cuối khác nhau"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "toán hạng %%Y sai"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "toán hạng %%A sai"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "toán hạng %%B sai"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "sai toán hạng %%C"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "sai toán hạng %%D"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "toán hạng %%f sai"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "toán hạng %%s sai"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "hằng số dấu chấm động không phải là một giá trị trực tiếp hợp lệ"
@@ -4189,30 +4189,30 @@
 msgid "bad test"
 msgstr "sai kiểm tra"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "giá trị %%D sai"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "bộ lọc sai"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "giá trị %%d sai"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "giá trị %%t/%%b sai"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "địa chỉ không chứa thanh ghi"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "hiệu số địa chỉ không phải là một hằng số"
 
@@ -4233,8 +4233,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "cần %<;%>"
@@ -4256,14 +4256,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "cần %<(%>"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "cần %<,%>"
@@ -4294,7 +4294,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "cần %<)%>"
@@ -4302,7 +4302,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "cần %<]%>"
@@ -4312,7 +4312,7 @@
 msgstr "cần %<;%>, %<,%> hoặc %<)%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "cần %<}%>"
@@ -4319,7 +4319,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "cần %<{%>"
@@ -4329,7 +4329,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "cần %<:%>"
@@ -4342,24 +4342,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr ""
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "cần %<while%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4367,18 +4367,18 @@
 msgid "expected %<.%>"
 msgstr "cần %<.%>"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "cần %<@end%>"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "cần %<>%>"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "cần %<,%> hoặc %<)%>"
@@ -4386,17 +4386,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "cần %<=%>"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "cần %<#pragma omp section%> hoặc %<}%>"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "cần %<[%>"
@@ -4405,7 +4405,7 @@
 msgid "(anonymous)"
 msgstr "(nặc danh)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "cần %<<%>"
@@ -4415,11 +4415,11 @@
 msgid "expected label"
 msgstr "cần kênh"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "ứng cử 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "ứng cử 2:"
 
@@ -4640,11 +4640,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%r%s:%d:%R   trong khai triển constexpr của %qs"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "các ứng cử là:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ứng cử là:"
@@ -4814,80 +4814,80 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "tham số thực tế cho INTENT = OUT/INOUT"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "Yêu cầu chiều rộng dương"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "Yêu cầu chiều rộng không phải âm"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Gặp phần tử không cần “%qc” trong chuỗi định dạng tại %L"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "Gặp kết thức chuỗi định dạng bất thường"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr "Bộ mô tả định dạng chứa chiều rộng số không"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "Thiếu dấu ngoặc đơn mở đi trước"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 msgid "Left parenthesis required after %<*%>"
 msgstr "Đẳng sau “%<*%>” thì yêu cầu một dấu ngoặc đơn mở"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "cần bộ mô tả chỉnh sửa P"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "Bộ mô tả P yêu cầu hệ số tỷ lệ đi trước"
 
-#: fortran/io.c:726
-#, c-format
-msgid "Right parenthesis expected at %C"
-msgstr "Cần dấu ngoặc đơn phải tại %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr "Đẳng sau bộ mô tả P thì yêu cầu một dấu phẩy"
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr "Dùng bộ mô tả T thì yêu cầu chiều rộng dương"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "Dùng bộ mô tả g0 thì không cho phép bộ ghi rõ E"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "Yêu cầu chiều rộng lũy thừa dương"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, c-format
+msgid "Right parenthesis expected at %C"
+msgstr "Cần dấu ngoặc đơn phải tại %C"
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr "Bộ ghi rõ định dạng thì yêu cầu một dấu chấm"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr "thẻ %s"
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr "đơn vị bên trong trong GHI"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "thẻ %s với INQUIRE"
@@ -4897,75 +4897,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "Gặp lỗi cú pháp trong biểu thức tại %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Gặp kết thúc tập tin bất thường"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Tràn số nguyên"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "Tên quá dài"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Tên sai"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Mong đợi một tên"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "Mong đợi một dấu ngoặc đơn mở"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "Mong đợi một dấu ngoặc đơn đóng"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Mong đợi một số nguyên"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Mong đợi một chuỗi"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum(): không tìm thấy bộ đếm"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "Mong đợi một tên bit thuộc tính"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Mong đợi một chuỗi số nguyên"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "Gặp lỗi khi chuyển đổi số nguyên"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Mong đợi một chuỗi thật"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "Mong đợi một loại biểu thức"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "Toán tử sai"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "Gặp loại saio trong biểu thức bất biến"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "Gặp kết thức mô-đun bất thường"
 
@@ -5210,12 +5210,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Chiều dài chuỗi thật vẫn nhỏ hơn điều khai báo cho đối số giả “%s” (%ld/%ld)"
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr "Gán vô hướng cho mảng chưa cấp phát"
 
@@ -5562,7 +5562,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "không cho phép sử dụng đồng thời hai tùy chọn -m32 và -m64"
 
@@ -8481,7 +8481,7 @@
 msgstr "Ghi rõ kích cỡ bit của hiệu số TLS trực tiếp."
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr "Định thời mã cho CPU đưa ra."
@@ -8702,7 +8702,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr "Sử dụng LRA thay cho reload ."
 
@@ -8919,12 +8919,12 @@
 msgid "Use 80-bit long double."
 msgstr "Sử dụng đôi dài 80-bit."
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 msgid "Use 64-bit long double."
 msgstr "Sử dụng đôi dài 64-bit."
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr "Sử dụng đôi dài 128-bit."
@@ -9955,87 +9955,87 @@
 msgid "64 bit ABI."
 msgstr "ABI 64-bit."
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr "Bảo tồn hàm trỏ dây chuyền ngược"
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr "Lần bổ sung in ra thông tin gỡ rối."
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr "Kiến trúc ESA/390."
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 msgid "Enable decimal floating point hardware support."
 msgstr "Bật việc hỗ trợ phần cứng dấu chấm động thập phân."
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 msgid "Enable hardware floating point."
 msgstr "Bật dấu chấm động loại phần cứng."
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 msgid "Use hardware transactional execution instructions."
 msgstr "Sử dụng các chỉ lệnh thực thi giao dịch bằng phần cứng."
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr ""
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr "Sử dụng bố trí ngăn xếp đóng gói."
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr "Sử dụng BRAS cho tập tin thực thị < 64k."
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 msgid "Disable hardware floating point."
 msgstr "Tắt dấu chấm động bằng phần cứng."
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "Đặt số tối đa các byte cần để cho kích cỡ ngăn xếp trước khi gây ra một câu lệnh đặt bẫy."
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr "Tắt tùy chọn -mstack-guard=."
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "Xuất mã bổ sung trong đoạn mở đầu hàm để đặt bẫy nếu kích cỡ ngăn xếp vượt quá giới hạn đưa ra."
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 msgid "Use the mvcle instruction for block moves."
 msgstr "Tạo ra câu lệnh chuỗi mvcle để di chuyển khối."
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "Cảnh báo nếu một hàm sử dụng alloca hoặc tạo một mảng có kích cỡ năng động."
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "Cảnh báo nếu có một hàm riêng lẻ với kích cỡ khung vượt quá kích cỡ khung đưa ra."
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr "z/Kiến trúc."
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -10088,11 +10088,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr "Hiểu ARM CPUs (để dùng với tùy chọn -mcpu= và -mtune=):"
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr "Hiểu kiến trúc ARM (để dùng với tùy chọn -march=):"
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr "Hiểu ARM FPUs (để dùng với tùy chọn -mfpu=):"
 
@@ -10319,78 +10319,97 @@
 msgstr ""
 
 #: config/sparc/sparc.opt:86
+#, fuzzy
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr "Đừng sử dụng chỉ lệnh callt (mặc định)."
+
+#: config/sparc/sparc.opt:90
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+#, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Tạo ra câu lệnh nhân-cộng kiểu dấu chấm động"
+
+#: config/sparc/sparc.opt:102
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 msgid "Pointers are 64-bit."
 msgstr "Con trỏ là 64-bit"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 msgid "Pointers are 32-bit."
 msgstr "Con trỏ là 32-bit."
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 msgid "Use 64-bit ABI."
 msgstr "Sử dụng ABI 64-bit."
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 msgid "Use 32-bit ABI."
 msgstr "Sử dụng ABI 32-bit."
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr "Sử dụng khuynh hướng về ngăn xếp."
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Sử dụng cấu trúc khi xếp hàng mạnh hơn các bản sao từ đôi."
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Tối ưu hóa các câu lệnh gọi đuôi trong bộ dịch mã số và bộ liên kết."
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr "Đừng tạo mã mà nó chỉ chạy được trong chế độ siêu giám sát (mặc định)."
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr "Sử dụng các tính năng của CPU đưa ra, và định thời mã cho CPU đó."
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr "Sử dụng mẫu mã SPARC-V9 đưa ra."
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 msgid "Enable debug output."
 msgstr "Bật kết xuất gỡ rối."
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "Bật chức năng kiểm tra trả lại cấu trúc psABI 32-bit ngặt"
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -14760,7 +14779,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -15162,7 +15181,7 @@
 msgstr "cần kiểu boolean"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Mong đợi một số nguyên"
@@ -15440,127 +15459,127 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 msgid "invalid comparison of non-ordered type"
 msgstr ""
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, c-format
 msgid "invalid operation (%s)"
 msgstr "toán tử không hợp lệ (%s)"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 msgid "invalid comparison of non-comparable type"
 msgstr ""
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 msgid "invalid comparison of generated struct"
 msgstr "dùng %<restrict%> không hợp lệ"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 msgid "invalid comparison of generated array"
 msgstr "sai sử dụng mảng không phải lvalue"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr ""
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr "cần chuyển đổi rõ ràng"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr "không thể dùng kiểu %s như là %s"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr "khác kiểu nhận được"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr "khác số lượng đối số"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr "khác kiểu tham số"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr "varargs khác biệt"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr "khác số của kết quả"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr "kiểu kết quả khác biệt"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "kiểu không tương thích cho phương thức %s%s%s"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "kiểu không tương thích cho phương thức %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr "kiểu không có phương thức"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "phương thức còn chưa rõ ràng %s%s%s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "thiếu phương thức%s%s%s"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "phương thức %s%s%s yêu cầu bộ nhận con trỏ"
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "phương thức %s%s%s được đánh dấu là go:nointerface"
@@ -15740,7 +15759,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
@@ -15802,27 +15821,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "mô hình bộ nhớ không hợp lệ cho %<__atomic_load%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "mô hình bộ nhớ không hợp lệ cho %<__atomic_store%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_thread_pointer không được hỗ trợ trên đích này"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_set_thread_pointer không được hỗ trợ trên đích này"
@@ -15829,7 +15848,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -15836,12 +15855,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> đối số thứ hai phải là 1"
@@ -15848,62 +15867,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Nền tảng đích của bạn không hỗ trợ -fcheck-pointer-bounds"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "định dạng đích không hỗ trợ vô cực"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr ""
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "sai số lượng đối số cho hàm %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> được gọi mà không có đối số"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "sai số lượng đối số cho hàm %<__builtin_next_arg%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "đối số thứ hai của %<va_start%> không là đối số có tên cuối"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -16811,12 +16830,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F được dùng mà chưa từng được định nghĩa"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -16911,12 +16930,12 @@
 msgid "cannot find '%s'"
 msgstr "không tìm thấy “%s”"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init bị lỗi: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -16926,7 +16945,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER phải được đặt"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17140,7 +17159,7 @@
 msgid "error writing %qs"
 msgstr "lỗi ghi %qs"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "không thể mở %s"
@@ -17220,17 +17239,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17340,12 +17359,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -17360,12 +17379,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr ""
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr ""
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr ""
@@ -17380,7 +17399,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -17410,7 +17429,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -17420,7 +17439,7 @@
 msgid "total size of local objects too large"
 msgstr ""
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -17520,62 +17539,68 @@
 msgid "input file %qs is the same as output file"
 msgstr "tập tin đầu vào %qs là cùng với tập tin đầu ra"
 
-#: gcc.c:4498
+#: gcc.c:4476
+#, fuzzy, gcc-internal-format
+#| msgid "output file not specified"
+msgid "output filename may not be empty"
+msgstr "chưa chỉ định tập tin đầu vào"
+
+#: gcc.c:4501
 #, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "-pipe bị bỏ qua bởi vì -save-temps được chỉ ra"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "%<-x %s%> sau tập tin đầu vào cuối không chịu tác động"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "switch %qs không bắt đầu với %<-%>"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "không thể mở tập tin đáp ứng tạm thời %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "không thể ghi vào tập tin đáp ứng tạm thời %s"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "không thể đóng tập tin đáp ứng tạm thời %s"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "đặc tả %qs không hợp lệ"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "đặc tả %qs có %<%%0%c%> không hợp lệ"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "đặc tả %qs có %<%%W%c%> không hợp lệ"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "đặc tả %qs có %<%%x%c%> không hợp lệ"
@@ -17583,228 +17608,228 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr ""
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr ""
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "không hiểu hàm đặc tả %qs"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "gặp lỗi trong các đối số tới hàm đặc tả %qs"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "tên hàm đặc tả dạng sai"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "không có đối số tới hàm đặc tả"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "đối số hàm đặc tả dạng sai"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "đặc tả giữa ngoặc móc %qs không hợp lệ tại %qc"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "thân của đặc tả giữa ngoặc móc %qs không hợp lệ"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr ""
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr "%s: -fcompare-debug thất bại (độ dài)"
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s: không thể mở tập tin compare-debug %s"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "%s: -fcompare-debug thất bại"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "spec thất bại: có nhiều hơn một đối số chuyển cho SYSROOT_SUFFIX_SPEC"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "spec thất bại: có nhiều hơn một đối số chuyển cho SYSROOT_HEADERS_SUFFIX_SPEC"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "không thừa nhận tùy chọn dòng lệnh %<-%s%>"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "không được cấu hình với hậu số phần đầu sysroot"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "không có tập tin nhập vào"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "không thể ghi rõ nhiều tập tin với tùy chọn -S hoặc -E, và hai tùy chọn -o và c loại từ lẫn nhau"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: trình biên dịch %s chưa được cài đặt trên hệ thống này"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "hãy dịch lại với tùy chọn -fcompare-debug"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr ""
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "-fuse-linker-plugin, mà không tìm thấy %s"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "không chấp nhận ngôn ngữ %s"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "đặc tả đa thư viện %qs không hợp lệ"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "sự loại từ đa thư viện %qs không hợp lệ"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "sự lựa chọn đa thư viện %qs %qs không hợp lệ"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "sự lựa chọn đa thư viện %qs không hợp lệ"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "sự loại từ đa thư viện %qs không hợp lệ"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "chưa định nghĩa biến môi trường%qs"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "số thứ tự phiên bản không hợp lệ %qs"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "quá ít đối số tới %%:version-compare"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "quá nhiều đối số tới %%:version-compare"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "không hiểu toán tử %qs trong %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "quá nhiều đối số tới %%:compare-debug-dump-opt"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "quá nhiều đối số tới %%:compare-debug-self-opt"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "quá ít đối số tới %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "quá nhiều đối số tới %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr "đối số tới %%:compare-debug-auxbase-opt không kết thúc bằng .gk"
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "quá ít đối số cho %%:replace-extension"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %%:debug-level-gt"
@@ -17950,9 +17975,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "được khai báo ở đây"
@@ -18367,229 +18392,229 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D not declared in class"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%q#D chưa được khai báo trong lớp"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing %s"
 msgid "enclosing %qs"
 msgstr "bao quanh %s"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr ""
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "cần %<_Cilk_spawn%> trước %<_Cilk_sync%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gặp lỗi"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -18822,9 +18847,9 @@
 msgstr ""
 
 #: ipa-devirt.c:1229
-#, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
-msgstr ""
+#, fuzzy, gcc-internal-format
+msgid "type %qT itself violates the C++ One Definition Rule"
+msgstr "định nghĩa trước ở đây"
 
 #: ipa-devirt.c:1235
 #, gcc-internal-format
@@ -18922,9 +18947,10 @@
 msgstr ""
 
 #: ipa-devirt.c:1576
-#, gcc-internal-format
-msgid "fields has different layout in another translation unit"
-msgstr ""
+#, fuzzy, gcc-internal-format
+#| msgid "%qD declared here, later in the translation unit"
+msgid "fields have different layout in another translation unit"
+msgstr "%+D đã khai báo weakref sau khi được dùng"
 
 #: ipa-devirt.c:1599
 #, gcc-internal-format
@@ -19302,198 +19328,198 @@
 msgid "multiple loop axes specified for routine"
 msgstr ""
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr "cấu tử %qs mồ côi"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr "%<#pragma omp cancel for%> trong %<nowait%> cho cấu trúc"
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr "%<#pragma omp cancel for%> trong %<ordered%> cho cấu trúc"
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<#pragma omp cancel sections%> trong %<nowait%> phần cấu trúc"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, gcc-internal-format
 msgid "invalid arguments"
 msgstr "các đối số không hợp lệ"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr ""
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr ""
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
@@ -19578,7 +19604,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr ""
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "thiếu đối số đối cho %qs"
@@ -19734,130 +19760,142 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
+#, fuzzy, gcc-internal-format
+#| msgid "-fcheck-pointer-bounds is not supported with -fsanitize=bounds"
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "-fcheck-pointer-bounds không hỗ trợ với -fsanitize=bounds"
+
+#: opts.c:1015
+#, fuzzy, gcc-internal-format
+#| msgid "-fsanitize=address is incompatible with -fsanitize=kernel-address"
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "-fsanitize=address xung khắc với -fsanitize=kernel-address"
+
+#: opts.c:1417
 #, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr "tùy chọn -fsanitize=all không hợp lệ"
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize%s= option: %q.*s"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "không nhận ra đối số cho tùy chọn -fsanitize%s=: %q.*s"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to -fsanitize%s= option: %q.*s"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "không nhận ra đối số cho tùy chọn -fsanitize%s=: %q.*s"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "đối số --help %q.*s chưa rõ ràng, hãy chính xác hơn"
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "không nhận ra đối số cho tùy chọn --help=: %q.*s"
 
-#: opts.c:2078
+#: opts.c:2085
 #, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr ""
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr ""
 
-#: opts.c:2217
+#: opts.c:2224
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr ""
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "dwarf phiên bản %d không được hỗ trợ"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr ""
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "sai tên cho tùy chọn --param %qs"
 
-#: opts.c:2374
+#: opts.c:2381
 #, gcc-internal-format
 msgid "invalid --param name %qs"
 msgstr "sai tên cho tùy chọn --param %qs"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "sai giá trị cho tùy chọn --param %qs"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "hệ thống đích không hỗ trợ xuất gỡ lỗi"
 
-#: opts.c:2513
+#: opts.c:2520
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr ""
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized register name %qs"
 msgid "unrecognized debug output level %qs"
 msgstr "không nhận ra tên thanh ghi %qs"
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "mức gỡ lỗi %qs là quá cao"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: không có tùy chọn -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr "-Werror=%s: -%s không phải là tùy chọn mà điều khiển cảnh báo"
@@ -20206,7 +20244,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr ""
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "xung đột với %qD"
@@ -20812,12 +20850,12 @@
 msgid "error closing %s: %m"
 msgstr "lỗi đóng %s: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr "self-tests không tương thích với -E"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "self-tests không được bật trong lần biên dịch này"
@@ -21729,47 +21767,47 @@
 msgid "in expansion of macro %qs"
 msgstr "trong phần mở rộng macro %qs"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "BB %i thiếu cạnh"
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "BB %i có cạnh sai"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -21870,32 +21908,32 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "không thể tắt hàm dựng sẵn %qs"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "hàm chung dòng %q+D được khai báo yếu"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "không thể tối ưu hóa vòng lặp vì bộ đếm vòng lặp có thể bị tràn"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr "trong vòng lặp này"
@@ -22249,11 +22287,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -23221,7 +23259,7 @@
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -23496,7 +23534,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "gợi ý là dùng dấu ngoặc đơn bao quanh phép gán được dùng như là giá trị chân lý"
@@ -24116,62 +24154,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> cần khớp một đối số %<%s%s%>"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> cần khớp một đối số %<%T%s%> argument"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> không được định nghĩa là một kiểu"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> không được định nghĩa như là kiểu %<long%> hay %<long long%>"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> không được định nghĩa như là một kiểu"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> không được định nghĩa như là một kiểu"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> không được định nghĩa như là một kiểu"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> không được định nghĩa là kiểu con trỏ"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "args được định dạng không %<…%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -24272,7 +24310,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr ""
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr ""
@@ -24302,7 +24340,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -24317,22 +24355,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE chưa được khởi tạo"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "thiếu biểu thức gia số"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "biểu thức gia không hợp lệ"
@@ -24877,8 +24915,8 @@
 msgid "wrong type argument to %s"
 msgstr "sai kiểu đối số cho %s"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "tràn trong biểu thức hằng"
@@ -25545,7 +25583,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "%<_Cilk_spawn%> chỉ có thể được dùng trong một hàm"
@@ -25706,7 +25744,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "không hiểu tùy chọn -mdebug-%s"
@@ -26029,7 +26067,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
@@ -26113,7 +26151,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "không hiểu giá trị %qs dành cho -mtune"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
@@ -26198,9 +26236,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "thuộc tính %<target%> không là một chuỗi"
@@ -26286,7 +26324,7 @@
 msgstr "giá trị sai %qs cho -mmemory-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26460,235 +26498,235 @@
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections không được hỗ trợ cho đích này"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "bộ chọn phải là một giá trị trực tiếp"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 7"
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 3"
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "vùng bộ chọn phải nằm từ 0 đến 1"
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mặt nạ phải là một giá trị trực tiếp"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "vùng mặt nạ phải nằm từ 0 đến 255"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_rori_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_rori_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_ror_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 32.  hãy kiểm tra bên trong _mm_ror_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 64.  hãy kiểm tra bên trong _mm_rori_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "vùng của số lượng phải nằm trong vùn 0 đến 64.  hãy kiểm tra bên trong _mm_ror_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srli_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_slli_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srai_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_srl_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sll_si64 trong mã."
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_pi16 trong mã."
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_pi32 trong mã."
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "số lượng không được nhỏ hơn 0.  hãy kiểm tra bên trong _mm_sra_si64 trong mã."
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt và NEON là xung khác lẫn nhau"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "CPU đích không hỗ trợ chế độ ARM"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr "iWMMXt không được hỗ trợ dưới chế độ Thumb"
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "không thể sử dụng -mtp=cp15 với 16-bit Thumb"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC không tương thích với Thumb"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr "-mslow-flash-data chỉ hỗ trợ mã không-pic trên đích armv7-m"
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, fuzzy, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr "-mslow-flash-data chỉ hỗ trợ mã không-pic trên đích armv7-m"
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "CPU đích không hỗ trợ chỉ lệnh THUMB"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "CPU đích không hỗ trợ truy cập chưa cân chỉnh"
@@ -26695,141 +26733,141 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mpcrel -fPIC hiện tại chưa được hỗ trợ trên cpu đã chọn"
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "CPU đích không hỗ trợ làm việc tương tác"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check không tương thích với -mno-apcs-frame"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic và -mapcs-reent là xung khắc nhau"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable và -msdata=%s là không tương thích"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS không hỗ trợ -mcaller-super-interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS không hỗ trợ -mcallee-super-interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 và không ldrh"
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, fuzzy, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard và VFP"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard và VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "RTP PIC không tương thích với -msingle-pic-base"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= là vô ích nếu không có -fpic"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "không thể dùng “%s” cho thanh ghi PIC"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition không được hỗ trợ trên kiến trúc này"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "CPU đích không hỗ trợ chỉ lệnh THUMB"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "non-AAPCS dẫn suất biến thể PCS"
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "biến thể PCS"
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 dấu-chấm-động-bằng-phần-cứng VFP ABI"
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -26837,72 +26875,77 @@
 msgid "%qE attribute only applies to functions"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "Thuộc tính %qE bị lờ đi với các kiểu"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd nằm ngoài vùng %wd - %wd"
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd nằm ngoài vùng %wd - %wd"
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr "-fstack-check=specific cho Thumb-1"
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
@@ -26910,13 +26953,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "thuộc tính(đích(\"%s\")) là không hiểu"
@@ -27010,163 +27053,174 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs hàm không có đối số"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs hàm không trả về giá trị nào"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr "Thuộc tính %qE nằm ngoài vùng địa chỉ"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "Thuộc tính %qE trên biến không hay thay đổi"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr ""
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr ""
+
+#: config/avr/avr.c:10160
+#, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qs không tương thích với %s %s"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr ""
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr ""
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr ""
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -27449,12 +27503,12 @@
 msgid "invalid IACC argument"
 msgstr "đối số IACC không hợp lệ"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs cần một đối số hằng"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "đối số hằng nằm ngoài phạm vi cho %qs"
@@ -27632,7 +27686,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "mô hình mã %qs không được hỗ trợ trong chế độ x32"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "mô hình mã %s không hỗ trợ chế độ PIC"
@@ -27764,288 +27818,288 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<-mrtd%> bị bỏ qua trong chế độ 64bit"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary không được hỗ trợ trên đích này"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d không nằm giữa %d và %d"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d không ở giữa %d và 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount không tương thích với đích này"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount không được thực hiện cho -fPIC"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, fuzzy, gcc-internal-format
 #| msgid "%<-msseregparm%> used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<-msseregparm%> được dùng mà không bật SSE"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "Chỉ lệnh SSE đặt là tắt, sử dụng số học 387"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry không hỗ trợ cho 32-bit trong tổ hợp cùng với -fpic"
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry không tương thích với SEH"
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "không hiểu tùy chọn cho -mrecip=%s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "tùy chọn (\"%s\") đã sẵn được đưa ra rồi"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "thuộc tính regparam và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính fastcall và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "các thuộc tính stdcall và thiscal không tương thích với nhau"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "các thuộc tính cdecl và thiscall không tương thích với nhau"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -28052,297 +28106,297 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "khai báo trước đây của %D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 2-bít"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "đối số thứ ba phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 3-bít"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 1-bít"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "đối số thứ năm phải là giá trị trực tiếp 8-bit"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "chế độ so sánh không đúng"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 4-bít"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 5-bít"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "đối số trực tiếp phải là giá trị trực tiếp 8-bít"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp 32-bít"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE cần là tùy chọn %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "đối số cuối phải là giá trị trực tiếp"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "đối số cuối phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "đối số thứ tư phải là tỷ lệ 1, 2, 4, 8"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "lệnh không đúng:"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Thuộc tính %qE chỉ dùng được trên hệ thống 32-bit"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "simdlen không được hỗ trợ %d"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -28462,7 +28516,7 @@
 msgid "argument %qd is not a constant"
 msgstr "đối số %qd không phải hằng số"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, con trỏ null"
@@ -28472,7 +28526,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: không hiểu dấu chấm “%c”"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND con trỏ null"
@@ -28573,7 +28627,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -29076,8 +29130,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr "mã dựng sẵn sai"
@@ -29330,27 +29384,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "Thuộc tính %qE cần kiểu trả về là void"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "Thuộc tính %qE chỉ được áp dụng cho các biến"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -29375,7 +29429,7 @@
 msgid "-g option disabled"
 msgstr "tùy chọn -g bị tắt"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
@@ -29511,157 +29565,157 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_mul chỉ chấp nhận hai tham số"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_cmpne chỉ chấp nhận hai tham số"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_adde chỉ chấp nhận ba tham số"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_addec chỉ chấp nhận ba tham số"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s chỉ chấp nhận %d tham số"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s chỉ chấp nhận một tham số"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s chỉ chấp nhận hai tham số"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract chỉ chấp nhận hai tham số"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert chỉ chấp nhận ba tham số"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "-pie không được hỗ trợ trong cấu hình này"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr "-mrecip cần -ffinite-math hoặc -ffast-math"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr "-mrecip cần -fno-trapping-math hoặc -ffast-math"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr "-mrecip yêu cầu -freciprocal-math hoặc -ffast-math"
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 yêu cầu kiến trúc PowerPC64, đang bật"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr "chưa cấu hình cho SPE ABI"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec không được hỗ trợ ở đích này"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "SPE không được hỗ trợ ở đích này"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple không được hỗ trợ trên hệ thống bé trước"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring không được hỗ trợ trên hệ thống lớn trước"
@@ -29668,68 +29722,68 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "-mcmodel không tương thích với các tùy chọn toc khác"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr "-mcrypto cần -maltivec"
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr "-mdirect-move cần -mvsx"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr "-mpower8-vector cần -maltivec"
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr "-mpower8-vector cần -mvsx"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr "-mvsx-timode cần -mvsx"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "-mhard-dfp cần -mhard-float"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "-mupper-regs-df cần -mvsx"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "-mupper-regs-df cần -mvsx"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr "-mupper-regs-sf cần -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr "-mpower8-fusion-sign cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
@@ -29738,515 +29792,520 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "-mpower9-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr "-mpower9-vector cần -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr "-mpower9-dform cần -mpower9-vector"
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr "-mpower9-dform cần -mupper-regs-df"
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr "-mpower9-dform cần -mupper-regs-sf"
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, fuzzy, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr "-mvsx-timode cần -mvsx"
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr "-mallow-movmisalign cần -mvsx"
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr "-mefficient-unaligned-vsx cần -mvsx"
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr "-mefficient-unaligned-vsx cần -mallow-movmisalign"
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr "-mfloat128 cần hỗ trợ VSX"
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, fuzzy, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr "-mfloat128 cần hỗ trợ VSX"
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, fuzzy, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr "-mfloat128 cần hỗ trợ VSX"
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, fuzzy, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr "-mfloat128-hardware cần được ISA 3.0 hỗ trợ"
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr "-mfloat128-hardware cần được ISA 3.0 hỗ trợ"
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, fuzzy, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr "-mfloat128-hardware cần được ISA 3.0 hỗ trợ"
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "“%qs” không phải là một tùy chọn hợp lệ cho bộ tiền xử lý"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "đối số 1 phải là trường 8-bit"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "đối số 1 phải là kiểu văn có dấu 5-bit"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "đối số 1 phải là kiểu văn không dấu 1-bit"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 5-bit"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr "%s chỉ chấp nhận một tham số"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 4-bit"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 2-bit"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "đối số 3 phải là kiểu văn không dấu 1-bit"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "đối số 1 phải là 0 hay 2"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "đối số 1 phải là kiểu văn không dấu 1-bit"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "đối số 2 phải là kiểu văn không dấu 6-bit"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "đối số 2 phải là 0 hay 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "đối số 3 phải nằm trong vùng 0…15"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, gcc-internal-format
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "đối số 1 của __builtin_paired_predicate phải là một hằng"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "đối số 1 của __builtin_paired_predicate nằm ngoài phạm vi"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "-mtoc-fusion cần -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "khung stack quá lớn"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "sai cpu \"%s\" cho %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s là không được phép"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s không hợp lệ"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, fuzzy, gcc-internal-format
 #| msgid "-mpower9-vector requires -mpower8-vector"
 msgid "-mno-power9-vector turns off -mpower9-dform"
@@ -30434,6 +30493,7 @@
 msgstr "-mcall-aixdesc xung khắc với -mabi=elfv2"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 yêu cầu cpu PowerPC64"
@@ -30525,7 +30585,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -30554,7 +30614,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -30574,7 +30634,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -30588,162 +30648,162 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr ""
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr ""
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<chưa giải quyết loại hàm quá tải>"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "icode dựng sẵn sai"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %qD"
 msgid "invalid argument %d for builtin %qF"
 msgstr "đối số không hợp lệ cho %qD"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr ""
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float không được hỗ trợ trong tổ hợp"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "đối số cho %qs quá lớn (tối đa là %d)"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int%d%> is not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -30801,27 +30861,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax chỉ hỗ trợ cho RTP PIC"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s không được hỗ trợ bởi cấu hình này"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 là không được phép với -m64"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "giá trị sai (%s) cho -mcmodel="
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= không được hỗ trợ trên hệ thống 32"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr ""
@@ -31106,22 +31167,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "hằng không hợp lệ trong %<#pragma %s%>"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "-f%s không hỗ trợ với chỉ lệnh CONST16"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr ""
@@ -31208,7 +31269,7 @@
 msgid "could not read the BRIG file"
 msgstr "không thể ghi vào tập tin đáp ứng %s"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -31610,9 +31671,9 @@
 msgstr "nhãn %qD được định nghĩa ở đây"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD được khai báo ở đây"
@@ -31745,7 +31806,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -32790,7 +32851,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> là quá dài đối với GCC"
@@ -32930,17 +32991,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -32990,7 +33051,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "cần kết thúc dòng"
@@ -33031,7 +33092,7 @@
 msgstr "không hiểu tên kiểu %qE"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "cần các định danh khai báo"
@@ -33046,7 +33107,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "cần %<;%>, định danh hoặc %<(%>"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -33061,8 +33122,8 @@
 msgid "unexpected attribute"
 msgstr "cần thuộc tính"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -33100,7 +33161,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> có lẽ chỉ được dùng với khai báo đơn"
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "cần %<,%> hoặc %<;%>"
@@ -33128,7 +33189,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 không hỗ trợ %<_Static_assert%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "cần chuỗi văn chương"
@@ -33192,14 +33253,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "cần định danh"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "dấu phẩy ở cuối của danh dánh liệt kê"
@@ -33334,7 +33395,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "cần %<}%> trước %<else%>"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> mà không có %<if%> ở trước"
@@ -33359,12 +33420,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr "-fcilkplus phải được bật để dùng %<_Cilk_for%>"
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr "-fcilkplus phải được bật để dùng %<_Cilk_sync%>"
@@ -33378,17 +33439,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "cần biểu thức"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
@@ -33398,7 +33459,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -33418,7 +33479,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -33596,17 +33657,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_complex%> toán hạng không đúng kiểu"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "sai số tham số cho %<__builtin_shuffle%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -33661,62 +33722,62 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "không hiểu thuộc tính tính chất"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<getter%>)"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "thiếu %<=%> (sau thuộc tính %<setter%>)"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> chỉ có thể sử dụng trong cấu trúc %<#pragma omp sections%>"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "cần câu lệnh for, while hoặc do"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> phải là đầu tiên"
@@ -33731,12 +33792,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "%<#pragma grainsize%> phải ở bên trong một hàm"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "quá nhiều mệnh đề %qs"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "cần biểu thức nguyên trước “)”"
@@ -33751,53 +33812,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD không phải là một biến"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD không phải là một biến trỏ"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, gcc-internal-format
 msgid "expected %<none%>"
 msgstr "cần %<none%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "cần %<none%> hoặc %<shared%>"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "cần %<data%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "quá nhiều mệnh đề %<if%>"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -33825,22 +33886,22 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%> giá trị phải dương"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%> giá trị phải dương"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%> giá trị phải dương"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "cần %<tofrom%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "cần %<scalar%>"
@@ -33850,58 +33911,58 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "%<num_threads%> giá trị phải dương"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "quá nhiều đối số %<static%>"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "gặp tham số thừa"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "ordered argument needs positive constant integer expression"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "cần biểu thức nguyên"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "cần %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> hoặc định danh"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%qs giá trị phải dương"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "kiểu lịch biểu không hợp lệ"
@@ -33916,17 +33977,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%> giá trị phải dương"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%> giá trị phải dương"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -33946,17 +34007,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "kiểu phụ thuộc không hợp lệ"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "kiểu ánh xạ không hợp lệ"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "kiểu dist_schedule không hợp lệ"
@@ -33966,67 +34027,67 @@
 msgid "invalid proc_bind kind"
 msgstr "kiểu proc_bind không hợp lệ"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "cần mệnh đề %<#pragma acc%>"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs không hợp lệ cho %qs"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs phải là mệnh đề đầu tiên của %qs"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "cần mệnh đề %<#pragma omp%>"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp cancel%> chỉ có thể sử dụng trong các biểu thức phức hợp"
@@ -34041,7 +34102,7 @@
 msgid "expected function name"
 msgstr "cần tên hàm"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD không phải là hàm thành viên mẫu"
@@ -34051,44 +34112,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> đã được áp dụng với %D"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma acc routine%> must be applied before %s"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> phải được áp dụng trước %s"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "sai dạng thức của %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "thao tác không hợp lệ cho %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> sử dụng hai biểu thức khác nhau cho bộ nhớ"
@@ -34098,27 +34159,27 @@
 msgid "expected %<(%> or end of line"
 msgstr "cần %<(%> hoặc xuống dòng"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "cần câu lệnh for"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "cần câu lệnh _Cilk_for"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "cần khai báo nhắc lại hay sự khởi tạo"
@@ -34128,72 +34189,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> với mệnh đề %<depend%> chỉ có thể sử dụng trong các biểu thức phức hợp"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "cần %<for%> sau %qs"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "cần %<point%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -34208,7 +34269,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -34218,32 +34279,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "cần %<target%>"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "cần %<declare%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -34298,22 +34359,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
@@ -34328,52 +34389,52 @@
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "chiều dài véc-tơ phải là một hằng nguyên"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "vectorlength phải là lũy thừa 2"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "cần mệnh đề %<#pragma simd%>"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> nằm trong một %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "vòng ngoài hơn %<__transaction_cancel%> không nằm trong vòng ngoài hơn %<__transaction_atomic%>"
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  hoặc một hàm %<transaction_may_cancel_outer%>"
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> không nằm trong %<__transaction_atomic%>"
@@ -34383,7 +34444,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr ""
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "cần %<:%> hoặc số"
@@ -35100,7 +35161,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -35428,7 +35489,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C cấm %<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "hàm đã khai báo %<noreturn%> có một câu lệnh %<return%>"
@@ -35438,7 +35499,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "biểu thức không thể được dùng như một hàm"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -35463,7 +35524,7 @@
 msgid "function returns address of label"
 msgstr "hàm trả về địa chỉ của biến cục bộ"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
@@ -35478,7 +35539,7 @@
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -35498,17 +35559,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "câu lệnh “continue” nằm ở ngoài một vòng lặp"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -35518,7 +35579,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
@@ -35624,12 +35685,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma acc update%> phải chứa ít nhất là một mệnh đề %<device%> hay %<host%> hay %<self%>"
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -35639,25 +35700,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE trong mệnh đề %qs"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE không phải là thành viên của union"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE không phải một biến trong mệnh đề %qs"
@@ -35668,70 +35729,70 @@
 msgstr "%<_Atomic%> %qD trong mệnh đề %qs"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE không có con trỏ hay kiểu mảng"
@@ -35751,7 +35812,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE có kiểu không hợp lệ cho %<reduction(%s)%>"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -35761,17 +35822,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE phải là %<threadprivate%> với %<copyin%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -35791,18 +35852,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -35814,32 +35875,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<aligned%>"
@@ -35859,55 +35920,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE không phải một biến trong mệnh đề %<depend%>"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE không phải một kiểu ánh xạ được trong mệnh đề %qs"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE không phải một biến cũng không phải tên hàm trong mệnh đề %qs"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD không phải một đối số trong mệnh đề %<uniform%>"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE không phải một đối số trong mệnh đề %<uniform%>"
@@ -35917,32 +35978,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -36487,154 +36548,154 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  trong gọi đến %qD"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "suy diễn %qT như là %qT"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "không thể gọi cấu tử %<%T::%D%> một cách trực tiếp"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "gọi hàm quá tải %<%s(%A)%> chưa rõ ràng"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "trả về một giá trị từ hủy tử"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "đóng %qD thông qua %qD"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  cho chuyển đổi từ %qT thành %qT"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " ứng cử 1: %q#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " ứng cử 2: %q#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr ""
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -36735,273 +36796,273 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%q#D không thể được tạo đè"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%q+D bị ẩn"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  bởi %q+D"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "thành viên riêng %q+#D trong hỗn hợp nặc danh"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr "thành viên riêng %q+#D trong cấu trúc nặc danh"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "thành viên bảo vệ %q+#D trong hỗn hợp nặc danh"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr "thành viên bảo vệ %q+#D trong cấu trúc nặc danh"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr ""
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "độ rộng bị âm trong trường bít %q+D"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "trường bít %q+D có độ rộng là không"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %qD has non-literal type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "trường %q#D với cùng tên với lớp"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T có thành viên dữ liệu con trỏ"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  nhưng không đè %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  hoặc %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  nhưng không được ghi đè %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T không là kiểu văn chương vì:"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T có một cấu tử non-trivial"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  lớp cơ sở %qT của %q+T là non-literal"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu không-văn-chương"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  thành viên dữ liệu không-tĩnh %qD có kiểu hay thay đổi"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "lớp cơ sở %q+T có một hủy tử non-trivial truy cập được"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -37008,152 +37069,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "thành viên mảng %q#D đã khai báo ở đây"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "trong định nghĩa của %q#T"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "thành viên kế %q#D đã khai báo ở đây"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "định nghĩa lại của %q#T"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "không đủ thông tin kiểu"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -37163,12 +37224,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "khai báo của %q#D"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr "thay đổi nghĩa của %qD từ %q#D"
@@ -37198,332 +37259,332 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr ""
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T có lớp cơ sở ảo"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr ""
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E không phải biểu thức hằng"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "gọi hàm nội bộ"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr ""
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr ""
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD được gọi trong một biểu thức hằng"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD được dùng trước khi nó được định nghĩa"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "toán hạng phải của biểu thức dịch %q+E là số âm"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "con trỏ rỗng"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD được dùng trong bộ khởi tạo của chính nó"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D không là const"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D là volatile"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD không được khởi tạo với một biểu thức hằng"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD chưa được khai báo %<constexpr%>"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "biểu thức %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "lệnh không phải biểu thức hằng"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "bổ từ %qE không phải là biểu thức hằng"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<delete[]%> không phải biểu thức hằng"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "cần AST thuộc kiểu %s"
@@ -38320,7 +38381,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  bỏ qua sự khởi tạo của %q#D"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -38335,7 +38396,7 @@
 msgid "%qD is not a type"
 msgstr "%qD không phải là một kiểu"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -39973,7 +40034,7 @@
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
@@ -40426,13 +40487,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT không phải một mẫu"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "khai báo trước ở đây"
@@ -40442,8 +40503,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
@@ -40493,7 +40554,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "định nghĩa trước ở đây"
@@ -40558,7 +40619,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "kiểu trả về %q#T là một kiểu không hoàn toàn"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> cần trả về một tham chiếu đến %<*this%>"
@@ -40573,7 +40634,7 @@
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
@@ -40731,27 +40792,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "thành viên dữ liệu tĩnh %q+D bên trong của chỉ thị khai báo đích"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> phải trả về kiểu %qT"
@@ -40760,67 +40821,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> nhận kiểu %<size_t%> (%qT) như là đối số thứ nhất"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> phải trả về kiểu %qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nhận kiểu %qT như là đối số thứ nhất"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
@@ -40829,47 +40890,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "hàm chung dòng %qD được dùng nhưng chưa bao giờ được định nghĩa"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -40876,12 +40937,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "dùng hàm bị xóa %qD"
@@ -41190,18 +41251,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D nên được khởi tạo"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
@@ -41301,7 +41362,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT không phải là kiểu lớp"
@@ -41321,7 +41382,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
@@ -41516,22 +41577,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr ""
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -41586,186 +41647,186 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr ""
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr ""
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "bộ khởi tạo cho %q#D không hợp lệ"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr ""
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "khai báo được mặc định %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr ""
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "một mẫu không thể là mặc định"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD không thể là mặc định"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -41957,124 +42018,124 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> các tên cấu tử trong %qT"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr ""
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, gcc-internal-format
 msgid "only here as a friend"
 msgstr ""
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -fsanitize-recover= instead."
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "Cái chuyển này đã lạc hậu: hãy thay thế bằng -fsanitize-recover=."
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr ""
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "các khả năng được gợi ý:"
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "các khả năng được gợi ý:"
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX vào pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX rời bỏ pop_everything ()\n"
@@ -42094,7 +42155,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -42119,7 +42180,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> chưa được khai báo"
@@ -42179,726 +42240,732 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr ""
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "%qE không phải một lớp mẫu"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE không phải là một mẫu"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "template-id không hợp lệ"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "cú gọi hàm không được xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "%<typeid%> toán tử không thể xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "cú gọi hàm không được xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "phép gia số không được phép xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "phép gia số không thể được xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "phép gán không thể được xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "toán tử dấu phẩy không được xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%qs không thể xuất hiện trong biểu thức hằng"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr ""
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr ""
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE không phải tên một kiểu"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE không phải tên một kiểu"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<noexcept%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<thread_local%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr "%<concept%> chỉ sẵn sàng với -fconcepts"
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr ""
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr ""
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr ""
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%E%> tên cấu tử, không phải kiểu"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "và %qT không có các cấu tử mẫu"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr "cần %<typename%> trước %<%T::%E%> bởi vì %qT có phạm vi phụ thuộc"
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE trong %q#T không phải là tên của kiểu mẫu"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE trong %q#T không là tên một kiểu"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr "cần một chuỗi chữ"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr "một chuỗi lớn là không hợp lệ trong ngữ cảnh này"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr ""
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr ""
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr "văn bản dấu chấm động cắt ngắn thành số không"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr ""
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "cần khai báo"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, gcc-internal-format
 msgid "expected binary operator"
 msgstr "cần toán tử hai ngôi"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, gcc-internal-format
 msgid "expected ..."
 msgstr "cần …"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr ""
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr ""
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr ""
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "kiểu dấu chấm cố định không hỗ trợ trong C++"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr ""
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr ""
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "cần biểu thức cơ bản"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "%<this%> có lẽ không nên được dùng trong ngữ cảnh này"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr ""
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "cần id-expression"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> chỉ sẵn sàng trên -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "phần khai báo của %<~%T%> là thành viên của %qT"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "cần unqualified-id"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD không phải một mẫu"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "cần nested-name-specifier"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr "%<_Cilk_spawn%> phải được theo sau bởi một biểu thức"
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "sai số tham số cho %<__builtin_addressof%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "đối số sai số lượng cho %<__builtin_launder%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ cấm compound-literals"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr ""
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "dùng %qD không hợp lệ"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> không phải là thành viên lớp"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "kiểu không-scalar"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ không cho phép %<alignof%> với một non-type"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "dùng áp kiểu theo cách cũ"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "gợi ý bao quanh biểu thức %<>>%> bằng dấu ngoặc đơn"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ không cho phép ?: với toán hạng ở giữa bị bỏ qua"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr ""
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "cần kết thúc của capture-list"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "chụp %<*this%> chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "khởi tạo chụp lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D được khai báo ở đây"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "mẫu lambda chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support boolean types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C90 không hỗ trợ kiểu lô-gíc"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr ""
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "lặp lại %<volatile%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "cần labeled-statement"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> tên cấu tử, không phải kiểu"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++11 %<constexpr%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "cần selection-statement"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "cần iteration-statement"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "vòng lặp range-based %<for%> chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr ""
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ cấm tính toán gotos"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "cần jump-statement"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "%<;%> mở rộng"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> không ở đầu của một khối"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "các kiểu có lẽ không nên được định nghĩa trong áp kiểu"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, fuzzy, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 msgid "empty decomposition declaration"
 msgstr "khai báo trống rỗng"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+#| msgid "invalid member function declaration"
+msgid "invalid initializer for structured binding declaration"
+msgstr "khai báo hàm thành viên không hợp lệ"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> được dùng bên ngoài lớp"
@@ -42905,476 +42972,476 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> thay đổi ý nghĩa trong C++11; hãy bỏ nó đi"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD không hợp lệ trong lambda"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "các mẫu không thể là %<virtual%>"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "đặc tả linkage không hợp lệ"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "static_assert không có lời nhắn chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr ""
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "cần định danh hậu tố"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "cần toán tử"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr ""
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu mặc định"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "cần template-id"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "cần template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "cần template-argument"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "cần bộ chỉ định kiểu"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "việc dùng %<auto%> trong khai báo tham số chỉ sẵn sàng với -std=c++11 hay -std=gnu++11"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr ""
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "cần template-id cho kiểu"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "cần type-name (tên kiểu)"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD là một mẫu liệt kê"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD không phải tên một kiểu enumeration trong %qT"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "cần %<;%> hoặc %<{%>"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "không cho phép từ hạn định mở rộng"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "nhiều định nghĩa cho %q#T"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ cấm kiểu liệt kê nặc danh không tên trống rỗng"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD không là một namespace-name"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "cần namespace-name"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "định nghĩa namespaces lồng nhau chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, gcc-internal-format
 msgid "nested identifier required"
 msgstr ""
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> không cho phép định nghĩa ở đây"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "fold-expressions chỉ sẵn sàng với -std=c++1z hay -std=gnu++1z"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "không cho phép định nghĩa hàm tại đây"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "cần bộ khởi tạo"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "bộ khởi tạo được cung cấp cho hàm"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> không phải một kiểu"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "dùng cấu tử như là một mẫu là không hợp lệ"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "dùng %<%T::%D%> thay cho %<%T::%D%> cho tên của cấu tử trong tên hạn định"
@@ -43383,7 +43450,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "bộ khai báo không hợp lệ"
@@ -43390,337 +43457,337 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "mã hạn định trong khai báo"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "cần câu khai báo"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD là một namespace"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "cần ptr-operator"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "trùng cv-qualifier"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "đa ref-qualifiers"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr "%E cần %<-fgnu-tm%>"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "trùng virt-specifier"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "cách dùng không hợp lệ %qT"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "các kiểu không nên được định nghĩa trong đối số mẫu"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "cần type-specifier"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "cần %<,%> hoặc %<…%>"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "cần class-name"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "cần %<;%> sau định nghĩa lớp"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "cần %<;%> sau định nghĩa cấu trúc"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "cần %<;%> sau định nghĩa kiểu hỗn hợp"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "cần %<{%> hoặc %<:%>"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "không thể chỉ định %<override%> cho lớp"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "khai báo trước đây của %q+#T"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "cần class-key"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "cần %<class%>, hoặc %<typename%>"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "cần %<;%> tại cuối khai báo thành viên"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr ""
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "dùng %<auto%> không hợp lệ trong đặc tả ngoại lệ"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "cần %<:%> hoặc %<…%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "mẫu biến chỉ sẵn sàng với -std=c++14 hay -std=gnu++14"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> chỉ sẵn sàng với -fconcepts"
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "khai báo không hợp lệ của %<%T::%E%>"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -43729,488 +43796,488 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr ""
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "đặc tả rõ ràng không hợp lệ"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "đối số cho %<sizeof…%> phải được bao quanh bởi dấu ngoặc đơn"
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> trước %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr ""
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "đã chỉ ra cả hai %<__thread%> và %<thread_local%>"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "trùng %qD"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "trùng %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "cần %<new%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "cần %<delete%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "cần %<return%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "cần %<extern%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "cần %<static_assert%>"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "cần %<decltype%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "cần %<operator%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "cần %<class%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "cần %<template%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "cần %<namespace%>"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "cần %<using%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "cần %<asm%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "cần %<try%>"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "cần %<catch%>"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "cần %<throw%>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "cần %<__label__%>"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "cần %<@try%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "cần %<@synchronized%>"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "cần %<@throw%>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "cần %<__transaction_atomic%>"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "cần %<__transaction_relaxed%>"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "cần %<::%>"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "cần %<…%>"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "cần %<*%>"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "cần %<~%>"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "cần %<:%> hoặc %<::%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "cần %<class%>, %<typename%>, hoặc %<template%>"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T trước đã khai báo ở đây"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "kiểu không hợp lệ cho biến instance (minh dụ)"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "kiểu không hợp lệ cho thuộc tính"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "biểu thức %<wait%> phải là số nguyên"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "bộ khởi tạo sai"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "mệnh đề khởi tạo không hợp lệ"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "cần id-expression (các đối số)"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD không phải là hàm thành viên mẫu"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr ""
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, gcc-internal-format
 msgid "expected variable-name"
 msgstr "cần tên biến"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "cần %<,%> hoặc %<)%> sau %qE"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "các mẫu ngầm không nên là %<virtual%>"
@@ -44302,7 +44369,7 @@
 msgid "candidate is: %#D"
 msgstr "ứng cử là: %#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %#D"
@@ -44874,122 +44941,139 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+#| msgid "  member function type %qT is not a valid template argument"
+msgid "the address of %qD is not a valid template argument"
+msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+#| msgid "  member function type %qT is not a valid template argument"
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "  kiểu hàm thành viên %qT không phải là một đối số mẫu hợp lệ"
+
+#: cp/pt.c:6641
 #, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr ""
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "dùng %qE để thay thế"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "dùng %<auto%> không hợp lệ trong đối số mẫu"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  cần hằng của kiểu %qT, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  cần kiểu, nhưng lại nhận %qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  cần một kiểu, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  cần mẫu lớp, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  cần mẫu kiểu %qD, nhưng lại nhận được %qT"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  cần %qD nhưng lại nhận %qD"
@@ -44996,102 +45080,102 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr ""
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "không thể chuyển đổi %qE từ %qT thành %qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "sai số lượng đối số hàm mẫu (%d, phải là %d)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "sai số lượng đối số mẫu (%d, cần ít nhất phải là %d)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "được cung cấp cho %qD"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "được cung cấp cho %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D không phải là hàm mẫu"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "cho khai báo hàm mẫu %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "ràng buộc mẫu gặp lỗi nghiêm trọng"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD không phải là một biến"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr ""
@@ -45109,271 +45193,271 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "biến %qD có kiểu hàm"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "kiểu đối số không hợp lệ %qT"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "trong khai báo %q+D"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "hàm trả về một mảng"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "hàm trả về hàm"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "đang tạo con trỏ đến thành viên của kiểu void"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "đang tạo mảng của %qT"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT không phải có kiểu lớp, cấu trúc hay union"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "dùng %qs trong mẫu"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "đang dùng trường không hợp lệ %qD"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "dùng %<this->%D%> thay thế"
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "dùng %<%T::%D%> thay thế"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%+D đã khai báo weakref sau khi được dùng"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT không phải là một lớp hay namespace"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD không phải là một lớp hay namespace"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT là/dùng kiểu nặc danh"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "biểu thức nguyên %qE không là hằng"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 msgid "%s %#S"
 msgstr "%s %#D"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD không phải là một thành viên dữ liệu tĩnh của một mẫu lớp"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
@@ -45385,93 +45469,93 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "mẫu không phải lớp %qT được dùng mà không có đỗi số mẫu"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "gặp yếu tố thừa trong bộ khởi tạo hợp"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "hàm không phải được tính để chèn vào trực tiếp"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
@@ -45628,472 +45712,472 @@
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE không là kiểu %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "định nghĩa không hợp lệ của kiểu hạn định %qT"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "đặc tả lớp-cơ-sở không hợp lệ"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "không thể chụp thành viên %qD trong hỗn hợp nặc danh"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD không bị bắt"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "use of deleted function %qD"
 msgid "use of parameter outside function body"
 msgstr "dùng hàm bị xóa %qD"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "missing template arguments after %qT"
 msgid "missing template arguments"
 msgstr "thiếu đối số mẫu sau %qT"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "không hiểu kiểu của %qE"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT không phải một kiểu enumeration"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "biểu thức bước thẳng phải là số nguyên"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD không phải một biến trong mệnh đề %qs"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD không phải một biến trong mệnh đề %<lastprivate%>"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "biểu thức tĩnh %<gang%> phải nguyên"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "%<gang%> static value must bepositive"
 msgid "%<gang%> static value must be positive"
 msgstr "giá trị tĩnh %<gang%> phải dương"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "biểu thức số %<gang%> phải nguyên"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "chiều dài %<vector%> phải là số nguyên"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "biểu thức số %<worker%> phải là số nguyên"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "biểu thức %qs phải là số nguyên"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%> giá trị phải dương"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<vector%> length value must bepositive"
 msgid "%<vector%> length value must be positive"
 msgstr "chiều dài %<vector%> giá trị phải dương"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<worker%> num value must bepositive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%> giá trị phải dương"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%> biểu thức phải nguyên"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%> biểu thức phải nguyên"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD không phải một biến trong mệnh đề  %<aligned%>"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD không phải một biến trong mệnh đề %<depend%>"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "chỉ số %<device%> phải là số nguyên"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_teams%> biểu thức phải nguyên"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%<tile%> value must be integral"
 msgid "%<tile%> argument needs integral type"
 msgstr "giá trị %<tile%> phải là số nguyên"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "thẩm tra tĩnh gặp lỗi"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "thẩm tra tĩnh gặp lỗi: %s"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "đối số không được hỗ trợ cho %<__builtin_return_address%>"
@@ -46108,107 +46192,107 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Gặp biểu thức lambda trong biểu thức bất biến"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "Thuộc tính %qE cần kiểu trả về là void"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "thuộc tính %qE chỉ áp dụng cho các hàm"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr ""
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "thuộc tính %qE cần tham số"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: gặp lỗi trong %s, tại %s:%d"
@@ -46891,102 +46975,102 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr ""
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "không thể chuyển đổi %qT thành %qT"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr ""
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr ""
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr ""
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "kiểu lớp %qT chưa hoàn thiện"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "trong đối số chuyển qua %P của %qD"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "trả về tham chiếu đến tạm thời (temporary)"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "tham chiếu đến biến cục bộ %qD được trả về"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "địa chỉ của nhãn %qD được trả về"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "địa chỉ của biến cục bộ %q+D được trả về"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "trả về một giá trị từ hủy tử"
@@ -46993,55 +47077,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "trả về một giá trị từ cấu tử"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "trả về danh sách bộ khởi tạo"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "biểu thức trả về với một giá trị, trong hàm trả lại “void”"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "đang dùng mẫu như là lvalue"
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -51002,87 +51086,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -51271,12 +51355,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -52052,508 +52136,523 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr ""
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr ""
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr "$ mô tả tại %L"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr ""
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Bộ mô tả định dạng chứa chiều rộng số không"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Dùng bộ mô tả T thì yêu cầu chiều rộng dương"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "%<G0%> trong chuỗi định dạng tại %L"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "Thiếu dấu phẩy tại %L"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s trong chuỗi định dạng tại %L"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr ""
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr ""
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Thiếu nhãn định dạng tại %C"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr ""
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "Trùng đặc tả %s tại %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr ""
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr ""
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr ""
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr ""
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "thẻ %s tại %L phải là kiểu %s"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "thẻ %s tại %L phải là chuỗi ký tự của kiểu mặc định"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "thẻ %s tại %L phải là scalar"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr "IOMSG tag tại %L"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr "CONVERT tag tại %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr ""
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr ""
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "BLANK= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "DECIMAL= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "ENCODING= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "ROUND= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "SIGN= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr ""
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr ""
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "câu lệnh FLUSH tại %C"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr "Thiếu nhãn định dạng tại %C"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr ""
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr ""
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "UNIT không được chỉ ra tại %L"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "PAD= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "DELIM= tại %C không được phép trong Fortran 95"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "Câu lệnh V/R chứa con số đơn vị quá lớn"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -53455,253 +53554,253 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr ""
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr ""
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 #| msgid "Name %qs at %C is already defined as a generic interface at %L"
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Tên “%qs” tại %C đã được định nghĩa trước tại %L"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr ""
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr ""
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr ""
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Gặp lỗi khi ghi tập tin môt-đun: %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr "write_atom(): Ghi số nguyên âm"
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr "unquote_string(): nhận chuỗi sai"
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr ""
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr ""
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Ký hiệu %qs đã sẵn được khai báo"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Ký hiệu %qs đã sẵn được khai báo"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "mô đun ISO_C_BINDING tại %C"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr ""
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr ""
@@ -56083,7 +56182,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Không thể phân giải hàm đặc tả %qs tại %L"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -57571,448 +57670,438 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist '%s' can not be an argument at %L"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Danh sách tên “%s” không thể là đối số tại %L"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nhãn %d tại %L đã định nghĩa nhưng chưa được dùng"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Chuỗi con tại %L có độ dài là không"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -59094,12 +59183,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Biến sự kiện tại %L sẽ không thể là coindexed "
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr ""
@@ -61125,9 +61214,6 @@
 #~ msgid "Use little-endian byte order"
 #~ msgstr "Sử dụng thứ tự byte về cuối nhỏ"
 
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "Tạo ra câu lệnh nhân-cộng kiểu dấu chấm động"
-
 #~ msgid "expected integer or boolean type"
 #~ msgstr "cần số nguyên hoặc lôgíc"
 
@@ -61140,10 +61226,6 @@
 #~ msgid "unsupported argument to %<__builtin_frame_address%>"
 #~ msgstr "đối số không được hỗ trợ cho %<__builtin_frame_address%>"
 
-#, fuzzy
-#~ msgid "type %qT should match type %qT that itself violate one definition rule"
-#~ msgstr "định nghĩa trước ở đây"
-
 #~ msgid "clause not supported yet"
 #~ msgstr "mệnh đề vẫn chưa được hỗ trợ"
 
Index: gcc/po/uk.po
===================================================================
--- gcc/po/uk.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/uk.po	(.../branches/gcc-7-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 7.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2017-07-18 13:34+0200\n"
 "Last-Translator: Yuri Chornoivan <yurchor@ukr.net>\n"
 "Language-Team: Ukrainian <translation-team-uk@lists.sourceforge.net>\n"
@@ -196,13 +196,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -465,62 +465,62 @@
 " other options on to these processes the -W<letter> options must be used.\n"
 msgstr ""
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr ""
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr ""
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr ""
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr ""
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr ""
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr ""
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr ""
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr ""
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr ""
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -527,16 +527,16 @@
 "For bug reporting instructions, please see:\n"
 msgstr ""
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "©"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -543,7 +543,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -552,7 +552,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -559,7 +559,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -567,7 +567,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -579,16 +579,16 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr ""
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "    -v, --verbose                       докладний режим\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr ""
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -604,14 +604,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -639,28 +639,28 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
+#: gcov-tool.c:420
+#, c-format
+msgid "    -f, --function                      Print function level info\n"
+msgstr ""
+
 #: gcov-tool.c:421
 #, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr ""
 
 #: gcov-tool.c:422
 #, c-format
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr ""
 
 #: gcov-tool.c:423
 #, c-format
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -o, --object                        Print object level info\n"
 msgstr ""
 
 #: gcov-tool.c:424
 #, c-format
-msgid "    -o, --object                        Print object level info\n"
-msgstr ""
-
-#: gcov-tool.c:425
-#, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
 
@@ -734,36 +734,36 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
+msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr ""
 
 #: gcov.c:659
 #, c-format
-msgid "  -a, --all-blocks                Show information for every basic block\n"
+msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr ""
 
 #: gcov.c:660
 #, c-format
-msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
-msgstr ""
-
-#: gcov.c:661
-#, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
 "                                    rather than percentages\n"
 msgstr ""
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr ""
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr ""
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr ""
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -946,82 +946,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr ""
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Виконаних рядків:%s з %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Немає виконуваних рядків\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s «%s»\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr ""
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr ""
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr ""
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr ""
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr ""
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr ""
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr ""
@@ -1128,89 +1128,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr "типово: %d мінімум: %d максимум: %d"
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[типовий]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[увімкнено]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[вимкнено]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr ""
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr ""
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr ""
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr ""
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr ""
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr ""
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr ""
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr ""
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr ""
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr ""
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr ""
 
@@ -2735,8 +2735,8 @@
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr ""
@@ -2755,7 +2755,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "пропущено операнд"
@@ -2775,8 +2775,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr ""
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' використано без будь-яких локальних динамічних посилань TLS"
@@ -2792,18 +2792,18 @@
 msgstr "некоректне значення %%r"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "некоректне значення %%R"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "некоректне значення %%N"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "некоректне значення %%P"
@@ -2813,7 +2813,7 @@
 msgid "invalid %%h value"
 msgstr "некоректне значення %%h"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "некоректне значення %%L"
@@ -2834,7 +2834,7 @@
 msgstr "некоректне значення %%U"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "некоректне значення %%s"
@@ -2844,7 +2844,7 @@
 msgid "invalid %%C value"
 msgstr "некоректне значення %%C"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "некоректне значення %%E"
@@ -2855,7 +2855,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr ""
@@ -2918,7 +2918,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
@@ -2928,29 +2928,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr ""
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr ""
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr ""
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -2958,101 +2958,101 @@
 msgid "invalid operand for code '%c'"
 msgstr ""
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr ""
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr ""
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr ""
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr ""
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr ""
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr ""
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr ""
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr ""
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr ""
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr ""
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr ""
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr ""
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 msgid "unsupported fixed-point conversion"
 msgstr ""
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 msgid "function parameter"
 msgstr "параметр функції"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 msgid "structure field"
 msgstr "поле структури"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 msgid "return type of function"
 msgstr "тип значення, яке повертає функція"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr "вказівник"
 
@@ -3074,7 +3074,7 @@
 msgstr ""
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3296,87 +3296,87 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr ""
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr ""
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr ""
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr ""
 
@@ -3413,7 +3413,7 @@
 msgid "invalid %%P operand"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -3467,7 +3467,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "помилкова адреса"
 
@@ -3500,7 +3500,7 @@
 msgstr ""
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "некоректна адреса"
 
@@ -3591,277 +3591,277 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr "Помилкове 128-бітове пересування"
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, c-format
 msgid "invalid %%e value"
 msgstr "некоректне значення %%e"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "некоректне значення %%f"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "некоректне значення %%F"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "некоректне значення %%G"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr ""
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "некоректний вираз для модифікатора виведення «%c»"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 msgid "vector argument passed to unprototyped function"
 msgstr ""
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -3887,43 +3887,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "некоректний операнд %%Y"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "некоректний операнд %%A"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "некоректний операнд %%B"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "некоректний операнд %%C"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "некоректний операнд %%D"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "некоректний операнд %%f"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "некоректний операнд %%s"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4085,30 +4085,30 @@
 msgid "bad test"
 msgstr "помилкова перевірка"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "некоректне значення %%D"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "некоректна маска"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "некоректне значення %%d"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "некоректне значення %%t/%%b"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "немає регістру у адресі"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "зсув адреси не є сталою величиною"
 
@@ -4129,8 +4129,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "мало бути %<;%>"
@@ -4152,14 +4152,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "мало бути %<(%>"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "мало бути %<,%>"
@@ -4190,7 +4190,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "мало бути %<)%>"
@@ -4198,7 +4198,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "мало бути %<]%>"
@@ -4208,7 +4208,7 @@
 msgstr "мало бути %<;%>, %<,%> або %<)%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "мало бути %<}%>"
@@ -4215,7 +4215,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "мало бути %<{%>"
@@ -4225,7 +4225,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "мало бути %<:%>"
@@ -4238,24 +4238,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr ""
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "мало бути %<while%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4263,18 +4263,18 @@
 msgid "expected %<.%>"
 msgstr "мало бути %<.%>"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "мало бути %<@end%>"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "мало бути %<>%>"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "мало бути %<,%> або %<)%>"
@@ -4282,17 +4282,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "мало бути %<=%>"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "мало бути %<#pragma omp section%> або %<}%>"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "мало бути %<[%>"
@@ -4301,7 +4301,7 @@
 msgid "(anonymous)"
 msgstr "(анонімний)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "мало бути %<<%>"
@@ -4310,11 +4310,11 @@
 msgid "expected label"
 msgstr "мало бути вказано мітку"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
@@ -4533,11 +4533,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4709,80 +4709,80 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr ""
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr ""
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 msgid "Unexpected element %qc in format string at %L"
 msgstr ""
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr ""
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr ""
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr ""
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 msgid "Left parenthesis required after %<*%>"
 msgstr ""
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr ""
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr ""
 
-#: fortran/io.c:726
-#, c-format
-msgid "Right parenthesis expected at %C"
-msgstr ""
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr ""
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr ""
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr ""
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, c-format
+msgid "Right parenthesis expected at %C"
+msgstr ""
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr ""
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4792,75 +4792,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "Синтаксична помилка у виразі у %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Неочікуваний символ кінця файла"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Переповнення типу цілого значення"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "Назва є надто довгою"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Помилкова назва"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr ""
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr ""
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr ""
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Мало бути ціле число"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr ""
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr ""
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr ""
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr ""
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr ""
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr ""
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr ""
 
@@ -5105,12 +5105,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5455,7 +5455,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr ""
 
@@ -8334,7 +8334,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr ""
@@ -8555,7 +8555,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr ""
 
@@ -8772,12 +8772,12 @@
 msgid "Use 80-bit long double."
 msgstr ""
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 msgid "Use 64-bit long double."
 msgstr ""
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr ""
@@ -9789,87 +9789,87 @@
 msgid "64 bit ABI."
 msgstr ""
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr ""
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr ""
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr ""
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 msgid "Enable decimal floating point hardware support."
 msgstr ""
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 msgid "Enable hardware floating point."
 msgstr ""
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 msgid "Use hardware transactional execution instructions."
 msgstr ""
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr ""
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr ""
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr ""
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 msgid "Disable hardware floating point."
 msgstr ""
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr ""
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr ""
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 msgid "Use the mvcle instruction for block moves."
 msgstr ""
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr ""
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr ""
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr ""
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -9921,11 +9921,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -10151,78 +10151,94 @@
 msgstr ""
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr ""
+
+#: config/sparc/sparc.opt:102
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 msgid "Pointers are 64-bit."
 msgstr ""
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 msgid "Pointers are 32-bit."
 msgstr ""
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 msgid "Use 64-bit ABI."
 msgstr ""
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 msgid "Use 32-bit ABI."
 msgstr ""
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr ""
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr ""
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr ""
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr ""
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr ""
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 msgid "Enable debug output."
 msgstr "Увімкнути виведення діагностичних даних."
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr ""
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -14566,7 +14582,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -14968,7 +14984,7 @@
 msgstr ""
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "мало бути ціле число"
@@ -15246,125 +15262,125 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 msgid "invalid comparison of non-ordered type"
 msgstr ""
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, c-format
 msgid "invalid operation (%s)"
 msgstr "некоректна операція (%s)"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 msgid "invalid comparison of non-comparable type"
 msgstr ""
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 msgid "invalid comparison of generated struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 msgid "invalid comparison of generated array"
 msgstr ""
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr ""
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr ""
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr ""
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr ""
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr ""
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -15539,7 +15555,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr ""
@@ -15601,27 +15617,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr ""
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr ""
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr ""
@@ -15628,7 +15644,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -15635,12 +15651,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
@@ -15647,62 +15663,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr ""
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr ""
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr ""
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr ""
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr ""
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -16610,12 +16626,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr ""
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -16710,12 +16726,12 @@
 msgid "cannot find '%s'"
 msgstr "не вдалося знайти «%s»"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr ""
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr ""
@@ -16725,7 +16741,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -16936,7 +16952,7 @@
 msgid "error writing %qs"
 msgstr ""
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "не вдалося відкрити %s"
@@ -17016,17 +17032,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -17136,12 +17152,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -17156,12 +17172,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr ""
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr ""
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr ""
@@ -17176,7 +17192,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -17206,7 +17222,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -17216,7 +17232,7 @@
 msgid "total size of local objects too large"
 msgstr ""
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -17316,62 +17332,67 @@
 msgid "input file %qs is the same as output file"
 msgstr ""
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, gcc-internal-format
+msgid "output filename may not be empty"
+msgstr ""
+
+#: gcc.c:4501
+#, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr ""
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr ""
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr ""
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr ""
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr ""
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr ""
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr ""
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr ""
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr ""
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr ""
@@ -17379,228 +17400,228 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr ""
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr ""
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr ""
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr ""
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr ""
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr ""
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr ""
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr ""
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr ""
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr ""
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr ""
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr ""
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr ""
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr ""
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "немає вхідних даних"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr ""
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr ""
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr ""
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr ""
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr ""
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr ""
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr ""
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr ""
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr ""
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr ""
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr ""
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr ""
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr ""
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr ""
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr ""
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr ""
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr ""
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr ""
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr ""
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr ""
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr ""
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr ""
@@ -17745,9 +17766,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "оголошено тут"
@@ -18162,227 +18183,227 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE не задано у замиканні %qs"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr ""
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "некоректне приватне спрощення %qE"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr ""
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -18615,7 +18636,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
 #: ipa-devirt.c:1235
@@ -18715,7 +18736,7 @@
 
 #: ipa-devirt.c:1576
 #, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr ""
 
 #: ipa-devirt.c:1599
@@ -19102,198 +19123,198 @@
 msgid "multiple loop axes specified for routine"
 msgstr ""
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr ""
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr ""
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, gcc-internal-format
 msgid "invalid arguments"
 msgstr "некоректні аргументи"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr ""
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr ""
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
@@ -19378,7 +19399,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr ""
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr ""
@@ -19534,127 +19555,137 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.c:1649
+#: opts.c:1656
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr ""
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr ""
 
-#: opts.c:2078
+#: opts.c:2085
 #, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr ""
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr ""
 
-#: opts.c:2217
+#: opts.c:2224
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr ""
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr ""
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr ""
 
-#: opts.c:2371
+#: opts.c:2378
 #, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "некоректна назва --param %qs; ви мали на увазі %qs?"
 
-#: opts.c:2374
+#: opts.c:2381
 #, gcc-internal-format
 msgid "invalid --param name %qs"
 msgstr "некоректна назва --param %qs"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr ""
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr ""
 
-#: opts.c:2513
+#: opts.c:2520
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr ""
 
-#: opts.c:2531
+#: opts.c:2538
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr ""
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr ""
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr ""
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -19991,7 +20022,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr ""
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -20591,12 +20622,12 @@
 msgid "error closing %s: %m"
 msgstr ""
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr ""
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -21507,47 +21538,47 @@
 msgid "in expansion of macro %qs"
 msgstr "у розгортанні макросу %qs"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i має декілька країв EH"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -21648,32 +21679,32 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "у виклику вбудованої функції %qD"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "у виклику функції %qD, оголошено тут"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr ""
@@ -22027,11 +22058,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -22998,7 +23029,7 @@
 msgid "type was previously declared %qE"
 msgstr ""
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -23273,7 +23304,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
@@ -23892,62 +23923,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr ""
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr ""
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -24048,7 +24079,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr ""
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr ""
@@ -24078,7 +24109,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -24093,22 +24124,22 @@
 msgid "%qE is not initialized"
 msgstr ""
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr ""
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr ""
@@ -24653,8 +24684,8 @@
 msgid "wrong type argument to %s"
 msgstr ""
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -25323,7 +25354,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr ""
@@ -25483,7 +25514,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
@@ -25806,7 +25837,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr ""
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
@@ -25886,7 +25917,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr ""
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
@@ -25971,9 +26002,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr ""
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
@@ -26059,7 +26090,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26233,234 +26264,234 @@
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr ""
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr ""
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr ""
@@ -26467,141 +26498,141 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr ""
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr ""
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr ""
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr ""
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr ""
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr ""
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr ""
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr ""
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr ""
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -26609,72 +26640,77 @@
 msgid "%qE attribute only applies to functions"
 msgstr ""
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
 msgstr ""
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr ""
@@ -26682,13 +26718,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
@@ -26782,163 +26818,174 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr ""
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr ""
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr ""
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr ""
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr ""
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr ""
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr ""
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr ""
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr ""
+
+#: config/avr/avr.c:10160
+#, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr ""
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr ""
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr ""
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr ""
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -27221,12 +27268,12 @@
 msgid "invalid IACC argument"
 msgstr ""
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr ""
@@ -27404,7 +27451,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr ""
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr ""
@@ -27534,287 +27581,287 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr ""
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr ""
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr ""
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr ""
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr ""
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -27821,297 +27868,297 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr ""
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr ""
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr ""
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr ""
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr ""
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr ""
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr ""
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr ""
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -28231,7 +28278,7 @@
 msgid "argument %qd is not a constant"
 msgstr ""
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr ""
@@ -28241,7 +28288,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr ""
@@ -28342,7 +28389,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -28843,8 +28890,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr ""
@@ -29095,27 +29142,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -29140,7 +29187,7 @@
 msgid "-g option disabled"
 msgstr ""
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
@@ -29275,157 +29322,157 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr ""
@@ -29432,67 +29479,67 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -29501,514 +29548,519 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, gcc-internal-format
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -30195,6 +30247,7 @@
 msgstr ""
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr ""
@@ -30286,7 +30339,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -30312,9 +30365,10 @@
 msgstr "%qF потребує -mvx"
 
 #: config/s390/s390-c.c:889
-#, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
-msgstr ""
+#, fuzzy, gcc-internal-format
+#| msgid "%qF requires -mvx"
+msgid "%qF requires z14 or higher"
+msgstr "%qF потребує -mvx"
 
 #: config/s390/s390-c.c:903
 #, gcc-internal-format
@@ -30333,7 +30387,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -30346,160 +30400,160 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr ""
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr ""
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "некоректний аргумент %d для вбудованої %qF"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr ""
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr ""
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr ""
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr ""
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr ""
@@ -30556,27 +30610,27 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr ""
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr ""
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr ""
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr ""
 
-#: config/sparc/sparc.c:1425
+#: config/sparc/sparc.c:1541
 #, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr ""
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr ""
@@ -30861,22 +30915,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr ""
@@ -30962,7 +31016,7 @@
 msgid "could not read the BRIG file"
 msgstr ""
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -31364,9 +31418,9 @@
 msgstr ""
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr ""
@@ -31499,7 +31553,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -32544,7 +32598,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
@@ -32684,17 +32738,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -32744,7 +32798,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -32785,7 +32839,7 @@
 msgstr ""
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr ""
@@ -32800,7 +32854,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -32815,8 +32869,8 @@
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -32854,7 +32908,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "мало бути %<,%> або %<;%>"
@@ -32882,7 +32936,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr ""
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -32946,14 +33000,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -33088,7 +33142,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -33113,12 +33167,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -33132,17 +33186,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
@@ -33152,7 +33206,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -33172,7 +33226,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -33348,17 +33402,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "помилкова кількість аргументів %<__builtin_shuffle%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -33413,61 +33467,61 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> має перебувати у області видимості файла"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
@@ -33482,12 +33536,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr ""
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -33502,53 +33556,53 @@
 msgid "%qD is not a variable"
 msgstr ""
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr ""
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, gcc-internal-format
 msgid "expected %<none%>"
 msgstr "мало бути %<none%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "мало бути %<none%> або %<shared%>"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "мало бути %<data%>, %<update%>, %<enter%> або %<exit%>"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "мало бути %<data%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr ""
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -33576,22 +33630,22 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "значення %<num_tasks%> має бути додатним"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "значення %<grainsize%> має бути додатним"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "значення %<priority%> має бути невід’ємним"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "мало бути %<tofrom%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "мало бути %<scalar%>"
@@ -33601,57 +33655,57 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "Значення %<num_workers%> має бути додатним"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "забагато аргументів %<static%>"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "несподіваний аргумент"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "значення %qs має бути додатним"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "значення розміру фрагмента має бути додатним"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr ""
@@ -33666,17 +33720,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "значення %<num_teams%> має бути додатним"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "значення %<thread_limit%> має бути додатним"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -33696,17 +33750,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr ""
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr ""
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -33716,67 +33770,67 @@
 msgid "invalid proc_bind kind"
 msgstr ""
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr ""
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "мало бути %<data%> після %<#pragma acc %s%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -33791,7 +33845,7 @@
 msgid "expected function name"
 msgstr "мало бути вказано назву функції"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr ""
@@ -33801,42 +33855,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> вже застосовано до %qD"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> має бути застосовано до використання"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> має бути застосовано до визначення"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -33846,27 +33900,27 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr ""
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr ""
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -33876,72 +33930,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "мало бути %<for%> після %qs"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "мало бути %<point%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -33956,7 +34010,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -33966,32 +34020,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "мало бути %<target%>"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "мало бути %<declare%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -34046,22 +34100,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr ""
@@ -34076,52 +34130,52 @@
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr ""
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr ""
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -34131,7 +34185,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr ""
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr ""
@@ -34846,7 +34900,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -35174,7 +35228,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -35184,7 +35238,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -35209,7 +35263,7 @@
 msgid "function returns address of label"
 msgstr ""
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
@@ -35224,7 +35278,7 @@
 msgid "case label is not an integer constant expression"
 msgstr ""
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -35244,17 +35298,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -35264,7 +35318,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
@@ -35370,12 +35424,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -35385,25 +35439,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -35414,70 +35468,70 @@
 msgstr ""
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
@@ -35497,7 +35551,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -35507,17 +35561,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -35537,18 +35591,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -35560,32 +35614,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -35605,55 +35659,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -35663,32 +35717,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -36232,152 +36286,152 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " кандидат 1: %q#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " кандидат 2: %q#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr ""
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -36478,272 +36532,272 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr ""
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr ""
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr ""
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr ""
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr ""
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  або %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -36750,152 +36804,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr ""
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "член масиву %q#D оголошено тут"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "у оголошенні %q#T"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr ""
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr ""
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -36905,12 +36959,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr ""
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -36940,332 +36994,332 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr ""
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr ""
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "виклик внутрішньої функції %qE"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr ""
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr ""
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr ""
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr ""
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "розіменування нульового вказівника"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr ""
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr ""
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "зміна %qE не є сталим виразом"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "значення %qE типу %qT не є сталим виразом"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "reinterpret_cast не є сталим виразом"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "перетворення нульового вказівника %qT на %qT не є сталим виразом"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> не є сталим виразом"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "вираз %qE не є сталим виразом"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "інструкція не є сталим виразом"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "ділення на нуль не є сталим виразом"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> не є сталим виразом"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr ""
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> не є сталим виразом"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -38061,7 +38115,7 @@
 msgid "  skips initialization of %q#D"
 msgstr ""
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -38076,7 +38130,7 @@
 msgid "%qD is not a type"
 msgstr ""
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -39712,7 +39766,7 @@
 msgid "parameter declared %<auto%>"
 msgstr ""
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr ""
@@ -40163,13 +40217,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr ""
@@ -40179,8 +40233,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr ""
@@ -40230,7 +40284,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr ""
@@ -40294,7 +40348,7 @@
 msgid "return type %q#T is incomplete"
 msgstr ""
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
@@ -40309,7 +40363,7 @@
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
@@ -40467,27 +40521,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr ""
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -40496,67 +40550,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -40565,47 +40619,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr ""
@@ -40612,12 +40666,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
@@ -40926,18 +40980,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr ""
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
@@ -41037,7 +41091,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr ""
@@ -41057,7 +41111,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr ""
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr ""
@@ -41252,22 +41306,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr ""
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -41322,186 +41376,186 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr ""
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr ""
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr ""
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr ""
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr ""
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr ""
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -41693,97 +41747,97 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr ""
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, gcc-internal-format
 msgid "only here as a friend"
 msgstr ""
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr ""
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr ""
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr ""
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -41791,27 +41845,27 @@
 msgstr[1] ""
 msgstr[2] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -41831,7 +41885,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -41856,7 +41910,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -41916,1201 +41970,1206 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr ""
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr ""
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr ""
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr ""
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr ""
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr ""
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr ""
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr ""
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr ""
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr ""
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr ""
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr ""
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr ""
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr ""
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr ""
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr ""
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr ""
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr ""
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr ""
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr ""
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, gcc-internal-format
 msgid "expected binary operator"
 msgstr "мав бути бінарний оператор"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, gcc-internal-format
 msgid "expected ..."
 msgstr "мало бути ..."
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr ""
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr ""
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr ""
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr ""
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr ""
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr ""
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr ""
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr ""
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr ""
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr ""
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "помилкова кількість аргументів %<__builtin_addressof%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "помилкова кількість аргументів %<__builtin_launder%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr ""
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr ""
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr ""
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr ""
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr ""
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr ""
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr ""
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr ""
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, gcc-internal-format
 msgid "ISO C++ does not support lambda templates"
 msgstr "у ISO C++ не передбачено підтримки шаблонів лямбд"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "визначено типовий аргумент для лямбда-параметра"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "дублювання %<mutable%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr ""
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr ""
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> у функції %<constexpr%>"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "зайве %<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, gcc-internal-format
 msgid "empty decomposition declaration"
 msgstr "порожнє оголошення розкладання"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
 #, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr ""
+
+#: cp/parser.c:13220
+#, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD є некоректним у лямбді"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr ""
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr ""
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr ""
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "некоректний параметр обмеженого типу"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr ""
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr ""
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr ""
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr ""
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "мало бути вказано тип-назву"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "мало бути %<;%> або %<{%>"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr ""
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "У ISO C++ заборонено порожні enum без назви"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr ""
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, gcc-internal-format
 msgid "nested identifier required"
 msgstr ""
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> у функції %<constexpr%>"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr ""
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr ""
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не є типом"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr ""
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -43119,7 +43178,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr ""
@@ -43126,337 +43185,337 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr ""
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr ""
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr "%E потребує %<-fgnu-tm%>"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr ""
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr ""
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr ""
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr ""
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "мало бути %<,%> або %<...%>"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "мало бути %<{%> або %<:%>"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr ""
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr ""
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "не вдалося визначити тип typename"
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "попереднє визначення %q#T"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "мало бути %<class%> або %<typename%>"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr ""
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "У ISO C++1z не можна визначати динамічні специфікації виключень"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr ""
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> у функції %<constexpr%>"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "мав бути атрибут перед %<...%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr ""
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -43465,488 +43524,488 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr ""
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr ""
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr ""
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "У ISO C++ 1998 не передбачено підтримки %<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "вказано одразу %<__thread%> і %<thread_local%>"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "дублювання %qD"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублювання %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "мало бути %<new%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "мало бути %<delete%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "мало бути %<return%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "мало бути %<extern%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "мало бути %<static_assert%>"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "мало бути %<decltype%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "мало бути %<operator%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "мало бути %<class%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "мало бути %<template%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "мало бути %<namespace%>"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "мало бути %<using%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "мало бути %<asm%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "мало бути %<try%>"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "мало бути %<catch%>"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "мало бути %<throw%>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "мало бути %<__label__%>"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "мало бути %<@try%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "мало бути %<@synchronized%>"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "мало бути %<@throw%>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "мало бути %<__transaction_atomic%>"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "мало бути %<__transaction_relaxed%>"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "мало бути %<::%>"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "мало бути %<...%>"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "мало бути %<*%>"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "мало бути %<~%>"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "мало бути %<:%> або %<::%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "мало бути %<class%>, %<typename%> або %<template%>"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "теґ %qs використано у назві %q#T"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr ""
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr ""
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr ""
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr ""
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr ""
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, gcc-internal-format
 msgid "expected variable-name"
 msgstr ""
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
@@ -44038,7 +44097,7 @@
 msgid "candidate is: %#D"
 msgstr "кандидат: %#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %#D"
@@ -44618,122 +44677,137 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
 #, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6634
+#, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6641
+#, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr ""
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr ""
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  мало бути %qD, втім, маємо %qD"
@@ -44740,102 +44814,102 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr ""
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr ""
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr ""
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr ""
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr ""
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr ""
@@ -44853,271 +44927,271 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr ""
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr ""
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr ""
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr ""
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr ""
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr ""
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 msgid "%s %#S"
 msgstr "%s %#S"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr ""
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr ""
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
@@ -45129,92 +45203,92 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr ""
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr ""
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
@@ -45371,466 +45445,466 @@
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr ""
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr ""
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr ""
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr ""
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr ""
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr ""
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "пропущено аргументи шаблона"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr ""
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "статичне значення %<gang%> має бути додатним"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "значення num %<gang%> має бути додатним"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "значення довжини %<vector%> має бути додатним"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "значення num %<worker%> має бути додатним"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "аргумент, який не є вказівником, у %<__builtin_launder%>"
@@ -45845,107 +45919,107 @@
 msgid "lambda-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr ""
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr ""
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr ""
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr ""
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr ""
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr ""
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr ""
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -46627,102 +46701,102 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr ""
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr ""
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr ""
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr ""
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr ""
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr ""
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr ""
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -46729,55 +46803,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr ""
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr ""
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -50732,87 +50806,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -50999,12 +51073,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -51779,508 +51853,523 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr ""
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr ""
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr ""
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr ""
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr ""
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr ""
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr ""
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr ""
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr ""
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr ""
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr ""
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr ""
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr ""
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr ""
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr ""
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr ""
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr ""
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr ""
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr ""
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr ""
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr ""
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr ""
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr ""
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr ""
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr ""
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr ""
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr ""
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr ""
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr ""
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr ""
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -53177,252 +53266,252 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr ""
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr ""
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr ""
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr ""
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr ""
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Синтаксична помилка у інструкції SUBMODULE у %C"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr ""
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr ""
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr ""
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr ""
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr ""
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr ""
@@ -55795,7 +55884,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -57283,447 +57372,437 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr ""
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -58804,12 +58883,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr ""
Index: gcc/po/sr.po
===================================================================
--- gcc/po/sr.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/sr.po	(.../branches/gcc-7-branch)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.2.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2007-08-19 12:00+0200\n"
 "Last-Translator: Caslav Ilic <caslav.ilic@gmx.net>\n"
 "Language-Team: Serbian <gnu@prevod.org>\n"
@@ -214,13 +214,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "лоша употреба реалне константе"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -601,65 +601,65 @@
 "прослеђују разним потпроцесима које сазива %s. Да би се тим процесима\n"
 "проследиле друге опције, мора се употребити -W<слово>.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, fuzzy, c-format
 #| msgid "Processing spec %c%s%c, which is '%s'\n"
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Обрађујем навод %c%s%c, који је ‘%s’\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Циљ: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Конфигурисано помоћу: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Нитни модел: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, fuzzy, c-format
 #| msgid "gcc version %s\n"
 msgid "gcc version %s %s\n"
 msgstr "gcc верзија %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, fuzzy, c-format
 #| msgid "gcc driver version %s executing gcc version %s\n"
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "gcc драјвер верзије %s извршава gcc верзију %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "инсталирање: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "програми: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "библиотеке: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -668,17 +668,17 @@
 "\n"
 "За упутства за пријављивање грешака, погледајте:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, fuzzy, c-format
 #| msgid "(%s %s %s %s"
 msgid "%s %s%s\n"
 msgstr "(%s %s %s %s"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "©"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -688,7 +688,7 @@
 "ГАРАНЦИЈЕ; чак ни за КОМЕРЦИЈАЛНУ ВРЕДНОСТ или ИСПУЊАВАЊЕ ОДРЕЂЕНЕ ПОТРЕБЕ.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -697,7 +697,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -704,7 +704,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -712,7 +712,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -724,18 +724,18 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+#| msgid "  -n, --no-output                 Do not create an output file\n"
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -n, --no-output                 Не прави излазну датотеку\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 #| msgid "  -v, --version                   Print version number, then exit\n"
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -v, --version                   Испиши број верзије, затим изађи\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -n, --no-output                 Не прави излазну датотеку\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -751,14 +751,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -786,31 +786,31 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -f, --function                      Print function level info\n"
 msgstr "  -h, --help                      Испиши ову помоћ, затим изађи\n"
 
-#: gcov-tool.c:422
+#: gcov-tool.c:421
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr "  -h, --help                      Испиши ову помоћ, затим изађи\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:422
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr "  -h, --help                      Испиши ову помоћ, затим изађи\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:423
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -o, --object                        Print object level info\n"
 msgstr "  -h, --help                      Испиши ову помоћ, затим изађи\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -898,20 +898,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Испиши ову помоћ, затим изађи\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Прикажи податке за сваки основни блок\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Укључи вероватноће гранања у излаз\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, fuzzy, c-format
 #| msgid ""
 #| "  -c, --branch-counts             Given counts of branches taken\n"
@@ -923,17 +918,22 @@
 "  -c, --branch-counts             Дати збирови извршених гранања\n"
 "                                    пре него проценти\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, fuzzy, c-format
 #| msgid "  --help                   Display this information\n"
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  --help                   Прикажи ове информације\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Испиши сажетке за сваку функцију\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Испиши ову помоћ, затим изађи\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1131,82 +1131,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s:граф је нерешив за ‘%s’\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Извршено линија:%s од %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Нема извршивих линија\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s ‘%s’\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Извршених гранања:%s од %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "Извршених бар једном:%s од %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Нема гранања\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Извршених позива:%s од %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Нема позива\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s:нема линија за ‘%s’\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "позив   %2d се вратио %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "позив   %2d никада није извршен\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "грана %2d извршена %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "грана %2d никада није извршена\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "безусловни %2d извршен %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "безусловни %2d никад није извршен\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, fuzzy, c-format
 #| msgid "%s:cannot open source file\n"
 msgid "Cannot open source file %s\n"
@@ -1326,111 +1326,111 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 #, fuzzy
 #| msgid "GCSE disabled"
 msgid "[disabled]"
 msgstr "ГЦСЕ искључен"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.c:1372
+#: opts.c:1379
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are target specific"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.c:1375
+#: opts.c:1382
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options control compiler warning messages"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.c:1378
+#: opts.c:1385
 #, fuzzy
 #| msgid "Do the full register move optimization pass"
 msgid "The following options control optimizations"
 msgstr "Изврши потпуни пролаз оптимизације померањем регистара"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are language-independent"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.c:1384
+#: opts.c:1391
 #, fuzzy
 #| msgid "The --param option recognizes the following as parameters:\n"
 msgid "The --param option recognizes the following as parameters"
 msgstr "Опција --param препознаје следеће параметре:\n"
 
-#: opts.c:1390
+#: opts.c:1397
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are specific to just the language "
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.c:1392
+#: opts.c:1399
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are supported by the language "
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.c:1403
+#: opts.c:1410
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are not documented"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.c:1405
+#: opts.c:1412
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options take separate arguments"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.c:1407
+#: opts.c:1414
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options take joined arguments"
 msgstr "Следеће опције не зависе од језика:\n"
 
-#: opts.c:1418
+#: opts.c:1425
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are language-related"
@@ -3099,8 +3099,8 @@
 msgid "<command-line>"
 msgstr "<командна-линија>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
@@ -3121,7 +3121,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "недостаје операнд"
@@ -3144,8 +3144,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -3161,18 +3161,18 @@
 msgstr "неисправна %%r вредност"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "неисправна %%R вредност"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "неисправна %%N вредност"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "неисправна %%P вредност"
@@ -3182,7 +3182,7 @@
 msgid "invalid %%h value"
 msgstr "неисправна %%h вредност"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "неисправна %%L вредност"
@@ -3203,7 +3203,7 @@
 msgstr "неисправна %%U вредност"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "неисправна %%s вредност"
@@ -3213,7 +3213,7 @@
 msgid "invalid %%C value"
 msgstr "неисправна %%C вредност"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "неисправна %%E вредност"
@@ -3224,7 +3224,7 @@
 msgstr "непознато unspec релокације"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "неисправан %%xn кôд"
@@ -3292,7 +3292,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "неисправан кôд излаза операнада"
@@ -3303,29 +3303,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "неисправан УНСПЕЦ као операнд"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "неисправан операнд помака"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикатна инструкција Тамба"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикатна инструкција у условном редоследу"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3333,7 +3333,7 @@
 msgid "invalid operand for code '%c'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
@@ -3340,107 +3340,107 @@
 msgstr "инструкција се никад не извршава"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "адресни операнд захтева ограничење за X, Y или Z регистар"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 #, fuzzy
 #| msgid "output operand %d must use %<&%> constraint"
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "излазни операнд %d мора користити ограничење %<&%>"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 #, fuzzy
 #| msgid "bad address, not (reg+disp):"
 msgid "bad address, not an I/O address:"
 msgstr "лоша адреса, није (reg+disp):"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 #, fuzzy
 #| msgid "address offset not a constant"
 msgid "bad address, not a constant:"
 msgstr "помак адресе није константа"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "лоша адреса, није (reg+disp):"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "лоша адреса, није post_inc или pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "унутрашња грешка компилатора. Лоша адреса:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "унутрашња грешка компилатора. Непознат режим:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "неисправна ија:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "нетачна ија:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "непозната ија премештања:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "лоша ија помака:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "унутрашња грешка компилатора. Нетачан помак:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 #| msgid "unsupported combination: %s"
 msgid "unsupported fixed-point conversion"
 msgstr "неподржана комбинација: %s"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "поновљена дефиниција параметра %q+D"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 msgid "structure field"
 msgstr ""
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "return type of function"
 msgstr "повратни тип функције не може бити функција"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr ""
 
@@ -3463,7 +3463,7 @@
 msgstr "неисправан const_double операнд"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3687,100 +3687,100 @@
 msgid "bad output_condmove_single operand"
 msgstr "лош операнд output_condmove_single"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "неисправан УНСПЕЦ као операнд"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "неисправан операнд за кôд ‘%c’"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд није ни константа ни условни кôд, неисправан кôд аргумента ‘c’"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "неисправан кôд операнда ‘%c;’"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "неисправна ограничења за операнд"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "непознат режим ије"
 
@@ -3819,7 +3819,7 @@
 msgid "invalid %%P operand"
 msgstr "неисправан %%P операнд"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "неисправна %%p вредност"
@@ -3877,7 +3877,7 @@
 msgstr "адреса постувећања није регистар"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "лоша адреса"
 
@@ -3914,7 +3914,7 @@
 msgstr "неисправна адреса"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "неисправна адреса"
 
@@ -4009,313 +4009,313 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Покушајте да покренете ‘%s’ у шкољци да повећате ограничење.\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "-mvsx requires hardware floating point"
 msgstr "Користи хардверски покретан зарез"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-f%s и -msdata=%s нису сагласни"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "-mvsx needs indexed addressing"
 msgstr "Искључи индексно адресирање"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-f%s и -msdata=%s нису сагласни"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--resource захтева -o"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Створи кôд у режиму мале крајности"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--resource захтева -o"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "лоша проба"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "неисправна %%H вредност"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "неисправна %%f вредност"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "неисправна %%F вредност"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "неисправна %%G вредност"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "неисправан %%j кôд"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "неисправан %%J кôд"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "неисправна %%k вредност"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "неисправна %%K вредност"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "неисправна %%O вредност"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "неисправна %%q вредност"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "неисправна %%T вредност"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "неисправна %%u вредност"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "неисправна %%v вредност"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "неисправна %%x вредност"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "неисправна интерпункција %qc у ограничењу"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не стварај јединствену излазну тачку за сваку функцију"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "не могу да створим поновљена учитавања за:"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "не могу да разложим адресу"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "неисправан операнд за модификатор ‘O’"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "неисправан операнд за модификатор ‘b’"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "неисправан кôд излаза операнада"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression - try using an output modifier"
 msgstr "неисправан израз као операнд"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "неисправан операнд за модификатор ‘o’"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "алтивек аргумент прослеђен непрототипизираној функцији"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "циљеви показивача у повратку разликују се у означености"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4341,43 +4341,43 @@
 msgid "created and used with different endianness"
 msgstr "направљено и употребељно са различитом крајношћу"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "неисправан %%Y операнд"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "неисправан %%A операнд"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "неисправан %%B операнд"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "неисправан %%C операнд"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "неисправан %%D операнд"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "неисправан %%f операнд"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "неисправан %%s операнд"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4560,30 +4560,30 @@
 msgid "bad test"
 msgstr "лоша проба"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "неисправна %%D вредност"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "неисправна маска"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "неисправна %%d вредност"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "неисправна %%t/%%b вредност"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "нема регистара у адреси"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "помак адресе није константа"
 
@@ -4606,8 +4606,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "очекивано је %<;%>"
@@ -4629,14 +4629,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "очекивано је %<(%>"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4668,7 +4668,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4677,7 +4677,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4690,7 +4690,7 @@
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
@@ -4698,7 +4698,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "очекивано је %<{%>"
@@ -4708,7 +4708,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
@@ -4724,25 +4724,25 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "израз %qE апстрактног класног типа %qT не може се употребити у изразу за бацање"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4752,20 +4752,20 @@
 msgid "expected %<.%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4774,17 +4774,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "очекивано је %<=%>"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -4796,7 +4796,7 @@
 msgid "(anonymous)"
 msgstr "<анонимно>"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -4808,11 +4808,11 @@
 msgid "expected label"
 msgstr "Очекивано је име"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
@@ -5072,11 +5072,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "кандидати су:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -5276,93 +5276,93 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "Стварни аргумент код %L мора бити могуће дефинисати да одговара лажном INTENT = OUT/INOUT"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "Потребна је позитивна ширина"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "Потребна је ненегативна ширина"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 #| msgid "Unexpected end of format string"
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Неочекивани крај форматирајуће ниске"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "Неочекивани крај форматирајуће ниске"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 #, fuzzy
 #| msgid "zero width in %s format"
 msgid "Zero width in format descriptor"
 msgstr "нулта дужина у формату %s"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "Недостаје водећа лева заграда"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 #| msgid "template argument required for %<%s %T%>"
 msgid "Left parenthesis required after %<*%>"
 msgstr "потребан шаблонски аргумент за %<%s %T%>"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "Очекиван је описник уређивања P"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "Описник P захтева водећи фактор размере"
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-#| msgid "Expected a right parenthesis in expression at %C"
-msgid "Right parenthesis expected at %C"
-msgstr "Очекивана је десна заграда у изразу код %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 #, fuzzy
 #| msgid "Positive width required"
 msgid "Positive width required with T descriptor"
 msgstr "Потребна је позитивна ширина"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 #, fuzzy
 #| msgid "Expected P edit descriptor"
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "Очекиван је описник уређивања P"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "Потребна је позитивна ширина изложиоца"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+#| msgid "Expected a right parenthesis in expression at %C"
+msgid "Right parenthesis expected at %C"
+msgstr "Очекивана је десна заграда у изразу код %C"
+
+#: fortran/io.c:1040
 #, fuzzy
 #| msgid "Period required in format specifier at %C"
 msgid "Period required in format specifier"
 msgstr "Потребна тачка у наводиоцу формата код %C"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -5372,75 +5372,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "Синтаксна грешка у изразу код %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Неочекивано EOF"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Целобројно преливање"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "Предугачко име"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Лоше име"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Очекивано је име"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "Очекивана је лева заграда"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "Очекивана је десна заграда"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Очекиван је цео број"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Очекивана је ниска"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum(): Енумерација није нађена"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "Очекивано је име атрибутског бита"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Очекивана је целобројна ниска"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "Грешка при претварању целог броја"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Очекивана је реална ниска"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "Очекиван је тип израза"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "Лош оператор"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "Неочекиван крај модула"
 
@@ -5736,12 +5736,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 #, fuzzy
 #| msgid "assignment of read-only location"
 msgid "Assignment of scalar to unallocated array"
@@ -6145,7 +6145,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "не могу се навести и -m32 и -m64"
 
@@ -9939,7 +9939,7 @@
 msgstr "Наведите битску величину непосредних ТЛС помака"
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 #, fuzzy
 #| msgid "Schedule code for given CPU"
@@ -10206,7 +10206,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
 msgid "Use LRA instead of reload."
@@ -10511,7 +10511,7 @@
 msgid "Use 80-bit long double."
 msgstr "Користи 128-битни long double"
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 #| msgid "Use 64-bit long double"
@@ -10518,7 +10518,7 @@
 msgid "Use 64-bit long double."
 msgstr "Користи 64-битни long double"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy
 #| msgid "Use 128-bit long double"
@@ -11898,117 +11898,117 @@
 msgid "64 bit ABI."
 msgstr "64-битни АБИ"
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 #, fuzzy
 #| msgid "Maintain backchain pointer"
 msgid "Maintain backchain pointer."
 msgstr "Одржавај показивач контраланца"
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 #, fuzzy
 #| msgid "Additional debug prints"
 msgid "Additional debug prints."
 msgstr "Додатно исправљачко исписивање"
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 #, fuzzy
 #| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
 msgstr "Архитектура ЕСА/390"
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 #| msgid "decimal floating point not supported for this target"
 msgid "Enable decimal floating point hardware support."
 msgstr "децимални покретни зарез није подржан за овај циљ"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "Enable hardware floating point."
 msgstr "Користи хардверски покретан зарез"
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 #| msgid "Use hardware quad FP instructions"
 msgid "Use hardware transactional execution instructions."
 msgstr "Користи хардверске четворне ФП инструкције"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr ""
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 #, fuzzy
 #| msgid "Use packed stack layout"
 msgid "Use packed stack layout."
 msgstr "Користи распоред пакованог стека"
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 #, fuzzy
 #| msgid "Use bras for executable < 64k"
 msgid "Use bras for executable < 64k."
 msgstr "Користи bras за извршне датотеке < 64k"
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "Користи хардверски покретан зарез"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 #, fuzzy
 #| msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered"
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "Постави највећи број бајтова који се мора одложити на стек пре него што се окине инструкција клопке"
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 #, fuzzy
 #| msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit"
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "Емитуј додатни кôд у прологу функције ради клопке кад величина стека премашује дато ограничење"
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 #| msgid "Generate string instructions for block moves"
 msgid "Use the mvcle instruction for block moves."
 msgstr "Стварај инструкције ниски за премештања блокова"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 #, fuzzy
 #| msgid "Warn if a function uses alloca or creates an array with dynamic size"
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "Упозори ако функција користи alloca или прави низ динамичке величине"
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 #, fuzzy
 #| msgid "Warn if a single function's framesize exceeds the given framesize"
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "Упозори ако величина оквира једне функције премашује дату величину"
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 #, fuzzy
 #| msgid "z/Architecture"
 msgid "z/Architecture."
 msgstr "Архитектура z/"
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -12064,11 +12064,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -12370,104 +12370,122 @@
 msgstr "Користи скуп визуелних инструкција (ВИС) УлтраСПАРКа"
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 #, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "Користи скуп визуелних инструкција (ВИС) УлтраСПАРКа"
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 #, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "Користи скуп визуелних инструкција (ВИС) УлтраСПАРКа"
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
 #, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Стварај инструкције множење-додавање у покретном зарезу"
+
+#: config/sparc/sparc.opt:102
+#, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "Користи скуп визуелних инструкција (ВИС) УлтраСПАРКа"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 #| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "Показивачи су 64-битни"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 #| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "Показивачи су 32-битни"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "Користи 64-битни АБИ"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "Користи 32-битни АБИ"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 #, fuzzy
 #| msgid "Use stack bias"
 msgid "Use stack bias."
 msgstr "Користи нагињање стека"
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 #, fuzzy
 #| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Користи структуре на јачем равнању за дворечне копије"
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 #, fuzzy
 #| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Оптимизуј инструкције репних позива у асемблеру и повезивачу"
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "Користи могућности и распоређуј кôд за дати ЦПУ"
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 #, fuzzy
 #| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
 msgstr "Користи дати модел кôда СПАРКа В9"
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "Enable debug output."
 msgstr "Укључи исправљачки излаз"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "Укључи строгу проверу враћања структуре за 32-битни псАБИ."
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -18211,7 +18229,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -18744,7 +18762,7 @@
 msgstr "Очекиван је тип израза"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -19113,157 +19131,157 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 #| msgid "invalid application of %qs to a void type"
 msgid "invalid comparison of non-ordered type"
 msgstr "неисправна примена %qs на празан тип"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 #, fuzzy
 #| msgid "%Hduplicate class will only be compiled once"
 msgid "slice can only be compared to nil"
 msgstr "%Hудвостручена класа ће бити компилована само једном"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 #, fuzzy
 #| msgid "%qs can only be specified for functions"
 msgid "map can only be compared to nil"
 msgstr "%qs може бити наведено само за функције"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 #, fuzzy
 #| msgid "%Hduplicate class will only be compiled once"
 msgid "func can only be compared to nil"
 msgstr "%Hудвостручена класа ће бити компилована само једном"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operation (%s)"
 msgstr "неисправан операнд за %%R"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "invalid comparison of non-comparable type"
 msgstr "неисправна примена %qs на непотпун тип %qT"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 #| msgid "invalid operand in the instruction"
 msgid "invalid comparison of generated struct"
 msgstr "неисправан операнд у инструкцији"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of generated array"
 msgstr "неисправна употреба не-л-вредносног низа"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of non-comparable array"
 msgstr "неисправна употреба не-л-вредносног низа"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 #, fuzzy
 #| msgid "Warn about implicit conversion"
 msgid "need explicit conversion"
 msgstr "Упозори на имплицитно претварање"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, fuzzy, c-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot use type %s as type %s"
 msgstr "не може се претворити из типа %qT у %qT"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 #, fuzzy
 #| msgid "invalid receiver type %qs"
 msgid "different receiver types"
 msgstr "неисправан тип примаоца %qs"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "different number of parameters"
 msgstr "поновљена дефиниција параметра %q+D"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 #, fuzzy
 #| msgid "invalid parameter type %qT"
 msgid "different parameter types"
 msgstr "неисправан тип параметра %qT"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible type for method %s%s%s"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "несагласни тип за аргумент %d у %qE"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 #, fuzzy
 #| msgid "error while parsing methods"
 msgid "type has no methods"
 msgstr "грешка при рашчлањивању метода"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, fuzzy, c-format
 #| msgid "ambiguous abbreviation %s"
 msgid "ambiguous method %s%s%s"
 msgstr "двосмислена скраћеница %s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, fuzzy, c-format
 #| msgid "missing argument to \"%s\""
 msgid "missing method %s%s%s"
 msgstr "недостаје аргумент за „%s“"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -19450,7 +19468,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "премало аргумената за функцију %<va_start%>"
@@ -19518,29 +19536,29 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -19548,7 +19566,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
@@ -19556,13 +19574,13 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "неисправан аргумент за %<__builtin_frame_address%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> други аргумент мора бити 1"
@@ -19569,67 +19587,67 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "циљни формат не подржава бесконачност"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "циљни формат не подржава бесконачност"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> употребљено у функцији са фиксним аргументима"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> позвано без аргумената"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "премало аргумената за функцију %<va_start%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "други параметар за %<va_start%> није последњи именовани аргумент"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%Hпрви аргумент за %D мора бити показивач, а други целобројна константа"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%Hпоследњи аргумент за %D није целобројна константа између 0 и 3"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -20588,12 +20606,12 @@
 msgstr "атрибут %qE се игнорише јер је %qT већ дефинисан"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F употребљено али недефинисано"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
@@ -20699,13 +20717,13 @@
 msgid "cannot find '%s'"
 msgstr "не могу да нађем ‘%s’"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "pex_init failed: %m"
 msgstr "pex_init није прошло"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -20716,7 +20734,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
@@ -20941,7 +20959,7 @@
 msgid "error writing %qs"
 msgstr "грешка при писању %qs"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "не могу да отворим %s"
@@ -21024,17 +21042,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -21148,13 +21166,13 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "функција %q+D поново декларисана са атрибутом неуткане"
 
-#: expr.c:10811
+#: expr.c:10809
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute warning: %s"
@@ -21172,13 +21190,13 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "величина %q+D је већа од %wd бајтова"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open final insn dump file %qs: %m"
 msgstr "нисам могао да отворим датотеку пописа %qs: %s"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not close final insn dump file %qs: %m"
@@ -21195,7 +21213,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "поређење је увек %d услед ширине битског поља"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "претпостављам да се означено преливање не дешава при упрошћавању пробе опсега"
@@ -21227,7 +21245,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "претпостављам да се означено преливање не дешава при негирању дељења"
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "провера сажимања: првобитно дрво измењено сажимањем"
@@ -21238,7 +21256,7 @@
 msgid "total size of local objects too large"
 msgstr "%Jукупна величина локалних објеката је превелика"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "немогуће ограничење у %<asm%>"
@@ -21345,71 +21363,77 @@
 msgid "input file %qs is the same as output file"
 msgstr "%qs није исправна излазна датотека"
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, fuzzy, gcc-internal-format
+#| msgid "output filename specified twice"
+msgid "output filename may not be empty"
+msgstr "излазна датотека наведена двапут"
+
+#: gcc.c:4501
+#, fuzzy, gcc-internal-format
 #| msgid "warning: -pipe ignored because -save-temps specified"
 msgid "-pipe ignored because -save-temps specified"
 msgstr "упозорење: -pipe се игнорише јер је задато -save-temps"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, fuzzy, gcc-internal-format
 #| msgid "warning: '-x %s' after last input file has no effect"
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "упозорење: „-x %s“ после последње улазне датотеке нема ефекта"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "switch '%s' does not start with '-'"
 msgid "switch %qs does not start with %<-%>"
 msgstr "прекидач ‘%s’ не почиње са ‘-’"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open temporary response file %s"
 msgstr "нисам могао да отворим датотеку пописа %qs: %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot create temporary file"
 msgid "could not write to temporary response file %s"
 msgstr "не могу да направим привремену датотеку"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot create temporary file"
 msgid "could not close temporary response file %s"
 msgstr "не могу да направим привремену датотеку"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' invalid"
 msgid "spec %qs invalid"
 msgstr "неисправан навод ‘%s’"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' has invalid '%%0%c'"
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "навод ‘%s’ има неисправно ‘%%0%c’"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' has invalid '%%W%c"
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "навод ‘%s’ има неисправно ‘%%W%c’"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' has invalid '%%x%c'"
 msgid "spec %qs has invalid %<%%x%c%>"
@@ -21418,254 +21442,254 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, fuzzy, gcc-internal-format
 #| msgid "spec failure: '%%*' has not been initialized by pattern match"
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "крах навода: „%%*“ није успостављено шематским поклапањем"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, fuzzy, gcc-internal-format
 #| msgid "spec failure: unrecognized spec option '%c'"
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "крах навода: непрепозната опција навода „%c“"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown spec function %qs"
 msgstr "непозната функција навода ‘%s’"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function '%s'"
 msgid "error in args to spec function %qs"
 msgstr "грешка у аргументима за функцију навода ‘%s’"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "лоше формирано име функције навода"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "нема аргумената за функцију навода"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "лоше формирани аргументи функције навода"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, fuzzy, gcc-internal-format
 #| msgid "braced spec '%s' is invalid at '%c'"
 msgid "braced spec %qs is invalid at %qc"
 msgstr "навод ‘%s’ у витичастим заградама није исправан код ‘%c’"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "braced spec body '%s' is invalid"
 msgid "braced spec body %qs is invalid"
 msgstr "тело навода ‘%s’ у витичастим заградама није исправно"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s:нисам могао да отворим излазну датотеку ‘%s’\n"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s:нисам могао да отворим излазну датотеку ‘%s’\n"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr ""
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "крах навода: више од једног аргумента за SYSROOT_SUFFIX_SPEC"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "крах навода: више од једног аргумента за SYSROOT_HEADERS_SUFFIX_SPEC"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized command line option %<-%s%>"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr ""
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "нема улазних датотека"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify -o with -c or -S with multiple files"
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "не може се задати -o са -c или -S кад има више датотека"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: компилатор за %s није инсталиран на овом систему"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr ""
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always %d"
 msgid "comparing final insns dumps"
 msgstr "поређење је увек %d"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "field %qs not found"
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "поље %qs није нађено"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: улазна датотека повезивача се не користи је се повезивање не извршава"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "језик %s није препознат"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 #| msgid "multilib spec '%s' is invalid"
 msgid "multilib spec %qs is invalid"
 msgstr "вишебиб. навод ‘%s’ није исправан"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, fuzzy, gcc-internal-format
 #| msgid "multilib exclusions '%s' is invalid"
 msgid "multilib exclusions %qs is invalid"
 msgstr "вишебиб. искључење ‘%s’ није исправно"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select '%s' is invalid"
 msgid "multilib select %qs %qs is invalid"
 msgstr "вишебиб. избор ‘%s’ није исправан"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select '%s' is invalid"
 msgid "multilib select %qs is invalid"
 msgstr "вишебиб. избор ‘%s’ није исправан"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, fuzzy, gcc-internal-format
 #| msgid "multilib exclusion '%s' is invalid"
 msgid "multilib exclusion %qs is invalid"
 msgstr "вишебиб. искључење ‘%s’ није исправно"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable %qs not defined"
 msgstr "променљива окружења DJGPP није дефинисана"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number `%s'"
 msgid "invalid version number %qs"
 msgstr "неисправан број верзије ‘%s’"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "премало аргумената за %%:version-compare"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "премало аргумената за %%:version-compare"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, fuzzy, gcc-internal-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "непознате оператор ‘%s’ у %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %%:version-compare"
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "премало аргумената за %%:version-compare"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %%:version-compare"
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "премало аргумената за %%:version-compare"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to %%:version-compare"
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "премало аргумената за %%:version-compare"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %%:version-compare"
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "премало аргумената за %%:version-compare"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to %%:replace-extension"
 msgstr "превише аргумената за функцију"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %%:debug-level-gt"
@@ -21825,9 +21849,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -22251,250 +22275,250 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "using result of function returning %<void%>"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "немеморијски улаз %d мора остати у меморији"
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "меморијски улаз %d не може се непосредно адресирати"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variables not supported in this target"
 msgid "threadprivate variable %qE used in target region"
 msgstr "нитно-локалне променљиве нису подржане за овај циљ"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing target region"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variables not supported in this target"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "нитно-локалне променљиве нису подржане за овај циљ"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing task"
 msgstr "%Hобухватајуће паралелно"
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "грешка при затварању %s: %m"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qs није наведено у обухватајућем паралелном"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%H%qE недекларисано (прва употреба у овој функцији)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "променљива %q+D декларисана као %<inline%>"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%Hнеозначена променљива итерације %qE"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should be private"
 msgstr "требало би да променљива итерације %qs буде приватна"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be linear"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should not be private"
 msgstr "требало би да променљива итерације %qs буде приватна"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s променљива %qs је приватна у спољашњем контексту"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "неисправна декларација шаблона %qD"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "уређена област мора бити блиско угњеждена унутар петље са одредбом уређености"
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "гимплификација није успела"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT се унапређује у %qT при прослеђивању кроз %<...%>"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(стога би требало да проследите %qT уместо %qT за %<va_arg%>)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "ако се овај кôд досегне, програм ће се прекинути"
@@ -22742,7 +22766,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
 #: ipa-devirt.c:1235
@@ -22844,7 +22868,7 @@
 
 #: ipa-devirt.c:1576
 #, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr ""
 
 #: ipa-devirt.c:1599
@@ -23266,205 +23290,205 @@
 msgid "multiple loop axes specified for routine"
 msgstr "складишна класа наведена за име типа"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region may not be closely nested inside of critical region"
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr "уређена област не може бити блиско угњеждена унутар критичне"
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr ""
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, fuzzy, gcc-internal-format
 #| msgid "master region may not be closely nested inside of work-sharing region"
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr "главна област не може бити блиско угњеждена унутар дељене"
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "invalid IACC argument"
 msgid "invalid arguments"
 msgstr "неодговарајући аргумент за IACC"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, fuzzy, gcc-internal-format
 #| msgid "work-sharing region may not be closely nested inside of work-sharing, critical, ordered or master region"
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "подељена област не може бити блиско угњеждена унутар подељене, критичне, уређене или главне области"
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "work-sharing region may not be closely nested inside of work-sharing, critical, ordered or master region"
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "подељена област не може бити блиско угњеждена унутар подељене, критичне, уређене или главне области"
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, fuzzy, gcc-internal-format
 #| msgid "master region may not be closely nested inside of work-sharing region"
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr "главна област не може бити блиско угњеждена унутар дељене"
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr "уређена област мора бити блиско угњеждена унутар петље са одредбом уређености"
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region may not be closely nested inside of critical region"
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr "уређена област не може бити блиско угњеждена унутар критичне"
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region may not be closely nested inside of critical region"
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr "уређена област не може бити блиско угњеждена унутар критичне"
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr "уређена област мора бити блиско угњеждена унутар петље са одредбом уређености"
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, fuzzy, gcc-internal-format
 #| msgid "critical region may not be nested inside a critical region with the same name"
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr "критична област не може бити угњеждена унутар истоимене критичне области"
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "неисправан излаз из структуираног блока ОпенМПа"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -23471,7 +23495,7 @@
 msgstr "неисправан улаз у структуирани блок ОпенМПа"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
@@ -23560,7 +23584,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "опција командне линије %qs није подржана овом конфигурацијом"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "missing argument to %qs"
@@ -23735,138 +23759,148 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.c:1837
+#: opts.c:1844
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "непрепозната опција командне линије „%s“"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "HSA has not been enabled during configuration"
 msgstr "%s није подржано овом конфигурацијом"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "равнање структуре мора бити мали степен двојке, не %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown stack check parameter %qs"
 msgstr "непознат машински режим %qs"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "dwarf version %d is not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: аргументи за --param треба да су облика ИМЕ=ВРЕДНОСТ"
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "неисправна вредност %qs за --param"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs"
 msgstr "неисправна вредност %qs за --param"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "неисправна вредност %qs за --param"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "циљни систем не подржава исправљачки излаз"
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "исправљачки формат „%s“ коси се са претходним избором"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "непрепознат ниво исправљачког излаза „%s“"
 
-#: opts.c:2533
+#: opts.c:2540
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "ниво исправљачког излаза %s је превисок"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "добављам ограничење највеће величине датотеке језгра: %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "постављам ограничење највеће величине датотеке језгра: %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "непрепозната исправљачка опција: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-Werror=%s: No option -%s"
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: нема опције -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -24232,7 +24266,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "регистар се користи за две глобалне регистарске променљиве"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -24863,13 +24897,13 @@
 msgid "error closing %s: %m"
 msgstr "грешка при затварању %s: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "self-tests incompatible with -E"
 msgstr "тврдња: %s је доделом сагласно са %s"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -25873,53 +25907,53 @@
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i has multiple EH edges"
 msgstr "Об. %i не може да баци али има ЕХ ивице"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i can not throw but has an EH edge"
 msgstr "Об. %i не може да баци али има ЕХ ивице"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "Последња наредба у об. %i има неисправно постављену област"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unnecessary EH edge %i->%i"
 msgid "Incorrect EH edge %i->%i"
 msgstr "непотребна ЕХ ивица %i->%i"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i too many fallthru edges"
 msgstr "погрешна ија у пропадном потегу"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i has incorrect edge"
 msgstr "Последња наредба у об. %i има неисправно постављену област"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i has incorrect fallthru edge"
@@ -26025,35 +26059,35 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in function %qD"
 msgstr "позив не-функције %qD"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 #| msgid "nested function %qs declared %<extern%>"
 msgid "in a call to function %qD declared here"
 msgstr "угњеждена функција %qs декларисана као %<extern%>"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, fuzzy, gcc-internal-format
 #| msgid "cannot optimize loop, the loop counter may overflow"
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "не могу да оптимизујем петљу, бројач петље се може прелити"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "within this loop"
@@ -26425,11 +26459,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -27461,7 +27495,7 @@
 msgid "type was previously declared %qE"
 msgstr "%q+#D претходно декларисано овде"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -27749,7 +27783,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "предлажем заграде око израза употребљеног као истинитосна вредност"
@@ -28408,66 +28442,66 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "сувишна одредба типа у форматирајућем аргументу (аргумент %d)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%s%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "формат %q.*s очекује тип %<%s%s%>, али аргумент %d је типа %qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%qs очекује константан аргумент"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "формат %q.*s очекује тип %<%T%s%>, али аргумент %d је типа %qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%qs очекује константан аргумент"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> није дефинисано као тип"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> није дефинисано као %<long%> или %<long long%>"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> није дефинисано као тип"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> није дефинисано као тип"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> није дефинисано као тип"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> није дефинисано као показивачки тип"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "аргументи за форматирање нису %<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "формати strftime не могу форматирати аргументе"
@@ -28574,7 +28608,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "конструкција %<@%D%> објективног Ц++а на погрешном месту"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr ""
@@ -28605,7 +28639,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for iteration variable %qE"
@@ -28623,25 +28657,25 @@
 msgid "%qE is not initialized"
 msgstr "%H%qE није успостављено"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing controlling predicate"
 msgid "missing controlling predicate"
 msgstr "%Hнедостаје контролишући предикат"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid controlling predicate"
 msgid "invalid controlling predicate"
 msgstr "%Hнеисправан контролишући предикат"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmissing increment expression"
 msgid "missing increment expression"
 msgstr "%Hнедостаје израз увећања"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid increment expression"
 msgid "invalid increment expression"
@@ -29223,8 +29257,8 @@
 msgid "wrong type argument to %s"
 msgstr "погрешан тип аргумента за abs"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "преливање у константном изразу"
@@ -29961,7 +29995,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<_Cilk_spawn%> may only be used inside a function"
@@ -30133,7 +30167,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "непознат прекидач -mdebug-%s"
@@ -30473,7 +30507,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "аргумент %qd није константа"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -30562,7 +30596,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "Непозната вредност %qs за -mmacosx-version-min"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
@@ -30656,9 +30690,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "Аргумент у %s код %L није исправног типа"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -30749,7 +30783,7 @@
 msgstr "лоша вредност %qs за -mmemory-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -30936,239 +30970,239 @@
 msgid "insn addresses not freed"
 msgstr "адреса предувећања није регистар"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections није подржано за овај циљ"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "селектор мора бити непосредни"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -G are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-fPIC и -G нису сагласни"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support ARM mode"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "укључивање подршке за контраход има смисла само када се компилује за Тамб"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "укључивање подршке за интерворкинг позваних има смисла само када се компилује за Тамб"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g уз -mno-apcs-frame може дати бесмислено исправљање"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with -mthumb"
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "не може се користити -mtp=cp15 уз -mthumb"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support unaligned accesses"
@@ -31176,150 +31210,150 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr ""
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check није сагласно са -mno-apcs-frame"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic и -mapcs-reent нису сагласни"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "Вишеулазни кôд АПЦСа није подржан, игноришем"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable и -msdata=%s нису сагласни"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iWMMXt захтева ААПЦС-сагласан АБИ за правилан рад"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iWMMXt АБИ захтева iWMMXt-способан ЦПУ"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "циљни ЦПУ не подржава интерворкинг"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard и ВФП"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard и ВФП"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "граница величине структура може бити постављена само на %s"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "граница величине структура може бити постављена само на %s"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= је бескорисно без -fpic"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "не могу да користим „%s“ за ПИЦ регистар"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition не ради на овој архитектури"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "циљни ЦПУ не подржава инструкције Тамба"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -31328,77 +31362,82 @@
 msgid "%qE attribute only applies to functions"
 msgstr "атрибут %qs примењује се само на функције"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD не може имати променљив број аргумената"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "атрибут %qE има утицаја само у јавним објектима"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "атрибут %qs је примењив само на функцијске типове"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "не могу да срачунам стварну локацију параметра на стеку"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Неочекиван крај модула"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нема доступних ниских регистара за подизање високих регистара"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for attribute(target(\"%s\"))"
@@ -31407,13 +31446,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
@@ -31521,182 +31560,194 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
 msgstr "Функција не враћа вредност"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%qs appears to be a misspelled signal handler"
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs изгледа као погрешно написан руковалац сигналима"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "Број регистара који се користи за прослеђивање целобројних аргумената"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D not supported"
 msgid "writing to address space %qs not supported"
 msgstr "слаба декларација %q+D није подржана"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "атрибут %qE је примењив само на варијадичке функције"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute address out of range"
 msgstr "атрибут %qs није примењив на типове"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "static IO declaration for %q+D needs an address"
 msgstr "декларација %q+D заклања параметар"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "IO definition for %q+D needs an address"
 msgstr "претходна дефиниција %q+D беше овде"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "само неуспостављене променљиве могу се сместити у одељак .noint"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "само успостављене променљиве могу се сместити у меморијску област програма"
+
+#: config/avr/avr.c:10160
+#, fuzzy, gcc-internal-format
+#| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "само успостављене променљиве могу се сместити у меморијску област програма"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "МЦУ %qs подржан само за асемблер"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "conversion from address space %qs to address space %qs"
 msgstr "Претварање из %s у %s код %L"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of module in string constant"
 msgid "%s expects a compile time integer constant"
 msgstr "Неочекиван крај модула у константној ниски"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -31999,12 +32050,12 @@
 msgid "invalid IACC argument"
 msgstr "неодговарајући аргумент за IACC"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs очекује константан аргумент"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "константан аргумент ван опсега за %qs"
@@ -32202,7 +32253,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "модела кôда %s није подржан у ПИЦ режиму"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
@@ -32348,316 +32399,316 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays није подржано за овај циљ"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d није између %d и 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm употребљено без укључених ССЕ инструкција"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "скуп ССЕ инструкција искључен, користим 387 аритметику"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "скуп 387 инструкција искључен, користим ССЕ аритметику"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "табеле одмотавања тренутно захтевају или показивач оквира или -maccumulate-outgoing-args за исправност"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "непозната опција типа -m%s=: „%s“"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ACCESS specification at %L was already specified"
 msgid "option(\"%s\") was already specified"
 msgstr "Одредница ACCESS код %L је већ наведена "
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "стандардна претварања нису дозвољена у овом контексту"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибути fastcall и regparm нису сагласни"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "атрибут %qs захтева целобројну константу као аргумент"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент за атрибут %qs већи од %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибути fastcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибути stdcall и cdecl нису сагласни"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибути stdcall и fastcall нису сагласни"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Позивање %qT са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "не подржава вишебиб"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s није сагласно са изабраним АБИјем"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "ССЕ векторски аргумент без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "ССЕ векторско враћање без укључених ССЕ мења АБИ"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "ММИкс векторски аргумент без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "ММИкс векторско враћање без укључених ММИкс мења АБИ"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "ССЕ враћање регистра уз искључене ССЕ"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "ССЕ регистарски аргумент уз искључене ССЕ"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "враћање из регистра x87 када је x87 искључено"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Позивање %qD са атрибутом sseregparm без укључених ССЕ/ССЕ2"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "%s није подржано за угњеждене функције"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -32665,336 +32716,336 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, fuzzy, gcc-internal-format
 #| msgid "%s functions limited to %d register parameters"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "%s функције ограничене на %d регистарских параметара"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "неподржана величина операнда за проширени регистар"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "проширени регистри немају високе половине"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "неподржана величина операнда за проширени регистар"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "No dispatcher found for %s"
 msgstr "Није нађена дефиниција етикете за %qs"
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "израз ограничења стека није подржан"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %D"
 msgstr "претходна декларација %q+D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return није подржан на овом циљу"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Аргумент за -ffpe-trap није исправан: %s"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "помак мора бити непосредни"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "нетачна ија:"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "нетачно дељење чворова стабла"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "маска мора бити непосредна"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "нетачна ија:"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qs примењује се само на променљиве"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "атрибути fastcall и stdcall нису сагласни"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs несагласан атрибут игнорисан"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "сервисне рутине прекида не могу бити кодиране у режиму Тамба"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Аргумент-по-вредности код %L није дозвољен у овом контексту"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown asm flag output %qs"
 msgstr "непознат машински режим %qs"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for asm flag output"
 msgstr "неисправна л-вредност у излазу асемблера %d"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "неподржана комбинација: %s"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid argument type %qs to %qs"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "Неисправан тип аргумента %qs за %qs"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33126,7 +33177,7 @@
 msgid "argument %qd is not a constant"
 msgstr "аргумент %qd није константа"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, нулти показивач"
@@ -33136,7 +33187,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: Непозната интерпункција „%c“"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND нулти показивач"
@@ -33249,7 +33300,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "израз ограничења стека није подржан"
@@ -33788,8 +33839,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
 msgid "bad builtin code"
@@ -34062,29 +34113,29 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "атрибут %qE се игнорише на типовима"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "атрибут __BELOW100__ није дозвољен са аутом. складишном класом"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -34109,7 +34160,7 @@
 msgid "-g option disabled"
 msgstr "опција -g искључена"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "равнање (%u) за %s премашује највеће равнање за глобалне заједничке податке. Користим %u"
@@ -34252,167 +34303,167 @@
 msgid "junk at end of #pragma longcall"
 msgstr "смеће на крају #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "%s only accepts %d arguments"
 msgstr "%q+D прима или ниједан или два аргумента"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "%s only accepts 1 argument"
 msgstr "%q+D прима или ниједан или два аргумента"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "%s only accepts 2 arguments"
 msgstr "%q+D прима или ниједан или два аргумента"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "прослеђивање арга %d за %qE одбацује одредбе типа показивачког циља"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "%Jдефиниције алијаса нису подржане у овој конфигурацији"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "неисправна комбинација параметара за алтивек сопствену"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 захтева архитектуру ПауерПЦ-64, укључујем"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power није подржано на 64-битном Дарвину; није сагласно са инсталираним Ц и Ц++ библиотекама"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, fuzzy, gcc-internal-format
 #| msgid "not configured for ABI: '%s'"
 msgid "not configured for SPE ABI"
 msgstr "није подешено за АБИ: „%s“"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use PowerPC instruction set"
 msgid "not configured for SPE instruction set"
 msgstr "Не користи скуп инструкција ПауерПЦа"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "SPE not supported in this target"
 msgstr "ограничења стека нису подржана на овом циљу"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple није подржано на системима мале крајности"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring није подржано на системима мале крајности"
@@ -34419,74 +34470,74 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d requires -mpaired-single"
 msgid "-mcrypto requires -maltivec"
 msgstr "-mips3d захтева -mpaired-single"
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mdirect-move requires -mvsx"
 msgstr "--resource захтева -o"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-vector requires -mvsx"
 msgstr "--resource захтева -o"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode requires -mvsx"
 msgstr "--resource захтева -o"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d requires -mpaired-single"
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "-mips3d захтева -mpaired-single"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "--resource захтева -o"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "--resource захтева -o"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d requires -mpaired-single"
 msgid "-mtoc-fusion requires -mpower8-fusion"
@@ -34496,239 +34547,239 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d requires -mpaired-single"
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "-mips3d захтева -mpaired-single"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор враћен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "вредност се не може вратити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "вредност се не може проследити у векторском регистру јер су алтивек инструкције искључене; употребите -maltivec да их укључите"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "ГЦЦ вектор прослеђен упућивачем: нестандарно проширење АБИја, без јемства сагласности"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %s already processed"
 msgstr "Сматрај улазну датотеку већ предобрађеном"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "аргумент 1 мора бити петобитна означена константа"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "аргумент 1 за __builtin_altivec_predicate мора бити константа"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "аргумент 1 за __builtin_altivec_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "builtin %s only accepts a string argument"
@@ -34735,7 +34786,7 @@
 msgstr "%qs очекује константан аргумент"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "cpu %s is an invalid argument to builtin %s"
@@ -34742,303 +34793,308 @@
 msgstr "неисправан аргумент за уграђену функцију"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 мора бити четворобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "број мора бити 0 или 1"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 мора бити петобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "број мора бити 0 или 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "Аргумент у ATANH код %L мора бити у опсегу -1 до 1"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент за %qs мора бити двобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "неразрешено препуњавање за алтивек уграђено %qF"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "аргумент за dss мора бити двобитна неозначена константа"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, fuzzy, gcc-internal-format
 #| msgid "second argument to %<__builtin_expect%> must be a constant"
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr "други аргумент за %<__builtin_expect%> мора бити константа"
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "трећи аргумент за %<__builtin_prefetch%> мора бити константа"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "аргумент 1 за __builtin_spe_predicate мора бити константа"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "аргумент 1 за __builtin_spe_predicate мора бити константа"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "аргумент 1 за __builtin_spe_predicate ван опсега"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "ова уграђена функција доступна је само на фр450"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "уграђена функција %q+D декларисана као нефункција"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "опција командне линије %qs није подржана овом конфигурацијом"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "оквир стека превелик"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "нема профилисања 64-битног кôда за овај АБИ"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "употреба %<long double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "употреба логичких типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "употреба %<complex%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "употреба децималних реалних типова у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "употреба %<long%> у алтивек типовима није исправна у 64-битном кôду"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "превазиђена употреба %<long%> у алтивек; користите %<int%>"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "употреба %<long long%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "употреба %<double%> у алтивек типовима није исправна"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "неисправна употреба %<::%>"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s\"%s\"%s is invalid"
 msgstr "навод ‘%s’ није исправан"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -35231,6 +35287,7 @@
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 захтева ЦПУ типа ПауерПЦ-64"
@@ -35323,7 +35380,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -35351,7 +35408,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -35373,7 +35430,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -35388,40 +35445,40 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "константан аргумент ван опсега за %qs"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 #| msgid "unresolved overload for Altivec builtin %qF"
 msgid "unresolved overloaded builtin"
 msgstr "неразрешено препуњавање за алтивек уграђено %qF"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
@@ -35428,122 +35485,122 @@
 msgid "bad builtin icode"
 msgstr "лош уграђени fcode"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "неисправан аргумент за уграђену функцију"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "укупна величина локалних променљивих премашује ограничење архитектуре"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "величина оквира за %qs је "
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs користи динамичко резервисање стека"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "режим з/Архитектуре није подржан на %s"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битни АБИ није подржан у режиму ЕСЕ/390"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Ограничи употребу хардверских инструкција покретног зареза на 32-битне операције"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float нису подржани у комбинацији"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "величина стека мора бити већа од вредности браника стека"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "величина стека не сме бити већа од 64k"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard имплицира коришћење -mstack-size"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргумент за „%s“ треба да је ненегативан цео број"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
@@ -35550,7 +35607,7 @@
 msgstr "аргумент за атрибут %qs већи од %d"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -35614,27 +35671,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "static није подржано на ТПФ-ОСу"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s није подржано овом конфигурацијом"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 није дозвољено уз -m64"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "лоша вредност (%s) за прекидач -mcmodel="
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= није подржано на 32-битним системима"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "-fcall-saved-REG is not supported for out registers"
@@ -35943,22 +36001,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "неисправна константа у %<#pragma pack%> — игноришем"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "потребни су логички регистри за опцију покретног зареза"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "-f%s није подржано КОНСТ16 инструкцијама"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "ПИЦ је потребан али није подржан КОНСТ16 инструкцијама"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "само неуспостављене променљиве могу бити смештене у одељак .bss"
@@ -36053,7 +36111,7 @@
 msgid "could not read the BRIG file"
 msgstr "нисам могао да нађем датотеку навода %s\n"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -36480,9 +36538,9 @@
 msgstr "етикета %q+D дефинисана али неупотребљена"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -36624,7 +36682,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> није дозвољено другде осим у досегу прототипа функције"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -37779,7 +37837,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "два или више типова података у наводиоцима декларације"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> је предуго за ГЦЦ"
@@ -37934,17 +37992,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ИСО Ц не подржава да обичан %<complex%> значи %<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ИСО Ц не подржава комплексне целобројне типове"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -37997,7 +38055,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -38042,7 +38100,7 @@
 msgstr "непознато име регистра: %s"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "очекивани су наводиоци декларације"
@@ -38059,7 +38117,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -38077,8 +38135,8 @@
 msgid "unexpected attribute"
 msgstr "Очекивано је име атрибутског бита"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -38120,7 +38178,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "очекивано је %<,%> или %<;%>"
@@ -38150,7 +38208,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ИСО Ц 90 не подржава %<long long%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "очекивана је дословна ниска"
@@ -38222,14 +38280,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "очекиван је идентификатор"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "зарез на крају листе набрајања"
@@ -38369,7 +38427,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "очекивано је %<,%> или %<}%>"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -38394,12 +38452,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -38413,18 +38471,18 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "очекивана је наредба"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hпразно тело у наредби if"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
@@ -38435,7 +38493,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -38457,7 +38515,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "неисправан регистар у инструкцији"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -38652,18 +38710,18 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> други аргумент мора бити 1"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "погрешан број аргумената наведне за атрибут %qs"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -38721,35 +38779,35 @@
 msgid "no type or storage class may be specified here,"
 msgstr "складишна класа наведена за %qs"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "недостаје %<(%> после %<#pragma pack%> — игноришем"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
@@ -38756,33 +38814,33 @@
 msgstr "%Jадресна област атрибута не може бити наведена за функције"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> може бити употребљено само у конструкцији %<#pragma omp sections%>"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> мора бити прво"
@@ -38798,12 +38856,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -38821,60 +38879,60 @@
 msgid "%qD is not a variable"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD није шаблон"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "поређење означених и неозначених целобројних израза"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<none%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -38904,25 +38962,25 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<tofrom%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<scalar%>"
@@ -38934,66 +38992,66 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "превише %qs одредби"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Неочекивани елемент"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент атрибута %qs није целобројна константа"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "поређење уређености показивача са целобројном нулом"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "очекивано је %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%> или %<||%>"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "и %<long%> и %<void%> у наводиоцима декларације"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 #| msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "распоред %<runtime%> не узима параметар %<chunk_size%>"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "неисправна врста распореда"
@@ -39010,18 +39068,18 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -39043,19 +39101,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "неисправна маска"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -39067,73 +39125,73 @@
 msgid "invalid proc_bind kind"
 msgstr "неисправна врста распореда"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs није исправно за %qs"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT није угњеждена класа у %qT"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "декларација спољашње променљиве %q+D у почетној декларацији %<for%> петље"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "неисправна употреба %<--%> на логичкој променљивој %qD"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %qs is used more than once in the argument list of method %qs"
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Променљива %qs употребљена више од једном у листи аргумената метода %qs"
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -39150,7 +39208,7 @@
 msgid "expected function name"
 msgstr "очекивано је име класе"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -39161,44 +39219,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "неисправан оператор за %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -39208,28 +39266,28 @@
 msgid "expected %<(%> or end of line"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "очекивана је наредба for"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "очекивано је успостављање или декларација итерације"
@@ -39239,77 +39297,77 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be firstprivate"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "не би требало да променљива итерације %qs буде firstprivate"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> као једини параметар не може бити одређен"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> може бити употребљено само у сложеним наредбама"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -39325,7 +39383,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> мора да се јави пре декларације %D, игноришем"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -39335,34 +39393,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "очекивано је %<{%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -39420,23 +39478,23 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "очекивано је %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE декларисано као нитно-локално после прве употребе"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "аутоматска променљива %qE не може бити нитно-локална"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "нитно-локално %qE има непотпун тип"
@@ -39452,57 +39510,57 @@
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "величина стека мора бити тачан степен двојке"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "селектор мора бити целобројна константа у опсегу 0..%wi"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "очекивана је одредба %<#pragma omp%>"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -39513,7 +39571,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or numeral"
@@ -40289,7 +40347,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "лева страна успостављања може бити кандидат за форматски атрибут"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
@@ -40625,7 +40683,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ИСО Ц забрањује %<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функција декларисана са %<noreturn%> има наредбу %<return%>"
@@ -40635,7 +40693,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -40663,7 +40721,7 @@
 msgid "function returns address of label"
 msgstr "функција враћа адресу на локалну променљиву"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "величина у прекидачу није целобројна"
@@ -40679,7 +40737,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "величина низа није интегралан констатан израз"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "етикета случаја није у оквиру наредбе прекидача"
@@ -40699,17 +40757,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "наредба искакања није у оквиру петље или прекидача"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "наредба настављања није у оквиру петље"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "наредба искакања употребљена са ОпенМПом за петљу"
@@ -40720,7 +40778,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "наредба искакања није у оквиру петље или прекидача"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
@@ -40831,12 +40889,12 @@
 msgid "used vector type where scalar is required"
 msgstr "употребљена вредност структурног типа где се захтева скалар"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -40847,27 +40905,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "превише %qs одредби"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD није чланска шаблонска функција"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -40880,19 +40938,19 @@
 msgstr "превише %qs одредби"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "величина у низовном new мора бити интегралног типа"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -40899,55 +40957,55 @@
 msgstr "величина у низовном new мора бити интегралног типа"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Копирај одељке низа у непрекидан блок при улазу у процедуру"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
@@ -40968,7 +41026,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE има неисправан тип за %<reduction(%s)%>"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "No label definition found for %qs"
 msgid "user defined reduction not found for %qE"
@@ -40979,17 +41037,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE мора бити нитно-локално за %<copyin%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -41009,18 +41067,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -41033,33 +41091,33 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -41082,63 +41140,63 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE није променљива у одредби %qs"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE се појављује више од једном у одредбама података"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -41150,33 +41208,33 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "тип уз векторско delete није ни показивачки ни низовни"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, fuzzy, gcc-internal-format
 #| msgid "%<-G%> is incompatible with %<-mabicalls%>"
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<-G%> није сагласно са %<-mabicalls%>"
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE је предодређено као %qs за %qs"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -41781,167 +41839,167 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "прослеђивање %qT као аргумента %<this%> у %q#D одбацује одредбе"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  у позиву %qD"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT није приступна основа од %qT"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "deducing %qT as %qT"
 msgstr "декларација %qD као %s"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Недостају аргументи за сопствено %s код %L"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "конструктор не може бити виртуелан"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "нема одговарајуће функције за позив %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нема одговарајуће функције за позив %<%D(%A)%>"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "двосмислен позив препуњене %<%s(%A)%>"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT нема нестатички члански податак по имену %qD"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "враћање вредности из конструктора"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "враћање вредности из деструктора"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "чланска функција %qD не може се позвати без објекта"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "прослеђивање %qT бира %qT пре него %qT"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "бирам %qD пре него %qD"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  за претварање из %qT у %qT"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  зато што је редослед претварања за аргумент бољи"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "наведен подразумевани аргумент у експлицитној специјализацији"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 1:"
 msgid " candidate 1: %q#F"
 msgstr "кандидат 1:"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 #| msgid "candidate 2:"
 msgid " candidate 2: %q#F"
 msgstr "кандидат 2:"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ИСО Ц++ каже да је ово двосмислено, чак иако је најгоре претварање првог боље од најгорег претварања другог:"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "не могу да претворим %qE у %qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "неисправно успостављање неконстантног упућивача типа %qT привременим типа %qT"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "неисправно успостављање упућивача типа %qT изразом типа %qT"
@@ -42049,297 +42107,297 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "не може се претворити из основе %qT у изведени тип %qT преко виртуелне основе %qT"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "све чланске функције у класи %qT су приватне"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T дефинише само приватни деструктор и нема пријатељâ"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T дефинише само приватне конструкторе и нема пријатељâ"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "нема јединственог коначног потискивача за %qD у %qT"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D не може бити препуњено"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D је сакривено"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  овим %q+D"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D није исправно; анонимна унија може имати само нестатичке чланске податке"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "приватни члан %q+#D у анонимној унији"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous struct"
 msgstr "приватни члан %q+#D у анонимној унији"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous struct"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "битско поље %q+#D неинтегралног типа"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ширина битског поља %q+D није целобројна константа"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "негативна ширина у бистком пољу %q+D"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "нулта ширина за битско поље %q+D"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "ширина %q+D премашује свој тип"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D је премало да садржи све вредности за %q#T"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "члан %q+#D са конструктором није дозвољен у унији"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "члан %q+#D са деструктором није дозвољен у унији"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "члан %q+#D са оператором копирања-доделе није дозвољен у унији"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D не може бити статичко зато што је члан уније"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "нестатчики константни члан %q+#D у класи без конструктора"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "поље %q+D неисправно декларисан функцијски тип"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "поље %q+D неисправно декларисан методски тип"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "игноришем атрибут паковања због непакованог не-ПОД поља %q+#D"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "не-члан %qs не може бити декларисан %<mutable%>"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "успостављена вишеструка поља у унији %qT"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "поље %q+#D истог имена као и класа"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T има показивачке чланске податке"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  али не потискује %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  али не потискује %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "успостављач наведен за невиртуелни метод %q+D"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T није класа"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD has non-integral type %qT"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "величина низа %qD има неинтегрални тип %qT"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %qD"
 msgid "  non-static data member %qD has volatile type"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "основна класа %q#T има не-виртуелни деструктор"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "нестатички упућивач %q+#D у класи без конструктора"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -42347,166 +42405,166 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуелна основа %qT није доступна у %qT услед двосмислености"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "помак за %q+D можда не поштује АБИ и може се изменити у будућим верзијама ГЦЦа"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "величина низа %qs је превелика"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "неисправна употреба структуре са флексибилним чланским низом"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jфлексибилан члански низ у иначе празној структури"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jфлексибилан члански низ није на крају структуре"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jфлексибилан члански низ у иначе празној структури"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D декларисано овде"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "поновна дефиниција %q#T"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T има виртуелне функције, али невиртуелни деструктор"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "класа %qT нема поље по имену %qD"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "тип %qs има виртуелне чланске функције"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "у покушају да довршим структуру, али избачен услед претходних грешака у рашчлањивању"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "језичка ниска %<\"%E\"%> није препозната"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "не могу да разрешим препуњену функцију %qD на основу претварања у тип %qT"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нема поклапања за претварање функције %qD у тип %q#T"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "двосмислено претварање препуњене функције %qD у тип %q#T"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "претпостављам показивач на члан %qD"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(показивач на члан може бити формиран само помоћу %<&%E%>)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "нема довољно података о типу"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "не може се претворити %qE из типа %qT у тип %qT"
@@ -42516,12 +42574,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "декларација %q#D"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -42555,380 +42613,380 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "неисправан апстрактни повратни тип за функцију %q+#D"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#T has virtual base classes"
 msgstr "%q#T није класа"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%Jосновна класа %q#T треба да се експлицитно успостави у копи-конструктору"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%qD није шаблон функције"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%q+E is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "позив не-функције %qD"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "expression %qE does not designate a constexpr function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
 msgstr "позив не-функције %qD"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no declaration before its definition"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%q+D је употребљено без декларације пре дефиниције"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D је употребљено без прототипа пре дефиниције"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "протокол %qs има кружну зависност"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "негативан десни помак"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "разрешавање %<void *%> показивача"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "разрешавање %<void *%> показивача"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "array used as initializer"
 msgid "%qD used in its own initializer"
 msgstr "низ употребљен као успостављач"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T није класа"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D је приватно"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD није декларисано у овом досегу"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "набројиви и ненабројиви тип у условном изразу"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "величина низа %qD није интегралан констатан израз"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "очекиван је израз"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "регистарска променљива %qD употребљена у угњежденој функцији"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Недостаје или неисправан константан израз"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "неконстантан индекс низа у успостављачу"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "преливање у константном изразу"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -43817,7 +43875,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  прескаче успостављање %q+#D"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "неисправан излаз из структуираног блока ОпенМПа"
@@ -43832,7 +43890,7 @@
 msgid "%qD is not a type"
 msgstr "%qD није тип"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD употребљено без параметара шаблона"
@@ -45617,7 +45675,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "параметар %q+D декларисан као %<inline%>"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "неисправна употреба шаблонског имена %qE без листе аргумената"
@@ -46107,13 +46165,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD има исто име као и класа у којој је декларисано"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT није шаблон"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -46124,8 +46182,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "двосмислено упућивање на %qD"
@@ -46176,7 +46234,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
@@ -46245,7 +46303,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> треба да враћа упућивач на %<*this%>"
@@ -46262,7 +46320,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "нема повратне наредбе у функцији која враћа непразан тип"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
@@ -46428,27 +46486,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "битско поље %qD неинтегралног типа"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "анонимна структура није унутар именованог типа"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "анонимне скупине у досегу именског простора морају бити статичке"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "анонимна унија без чланова"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> мора враћати тип %qT"
@@ -46457,72 +46515,72 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of %<va_start%> not last named argument"
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "други параметар за %<va_start%> није последњи именовани аргумент"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> узима тип %<size_t%> (%qT) као први параметар"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> мора враћати тип %qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> узима тип %<size_t%> (%qT) као први параметар"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT има поље %qD чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT декларисано са већом видљивошћу од типа његовог поља %qD"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT има основу %qT чији тип користи анонимни именски простор"
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT декларисано са већом видљивошћу од своје основе %qT"
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -46532,51 +46590,51 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D не упућује на неодређени тип, тако да се не користи за повезивост"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F декларисано као %<static%> али нигде дефинисано"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "претходна декларација %q+#D са повезивошћу %qL"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "уткана функција %q+D употребљена али недефинисана"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "недостаје подразумевани аргумент за параметар %P од %q+#D"
@@ -46583,12 +46641,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
@@ -46916,7 +46974,7 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "неисправна почетна вредност за члан %qs"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
@@ -46923,13 +46981,13 @@
 msgstr "неуспостављени константни члан %qD"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "%q+D ће бити успостављено после"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
@@ -47037,7 +47095,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "успостављач низа мора бити нешто у витичастим заградама"
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%qT is not a class type"
@@ -47058,7 +47116,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "неисправна употреба нестатичке чланске функције %qD"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "неисправна употреба нестатичког чланског податка %qD"
@@ -47265,24 +47323,24 @@
 msgid "because the array element type %qT has variable size"
 msgstr "сложена дословна ниска има променљиву величину"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot capture %qE by reference"
 msgstr "не може се декларисати упућивач на %q#T"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "capture by copy of incomplete type %qT"
 msgstr "не може се %s показивач на непотпуни тип %qT"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> was not captured for this lambda function"
@@ -47338,120 +47396,120 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(ако употребите %<-fpermissive%>, Г++ ће прихватити овакав кôд, али дозвољавање недекларисаног имена је превазиђено)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "изостављени средњи операнд у %<?:%> не може бити запетљан"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "запетљано име за %qD биће измењено у будућим верзијама ГЦЦа"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "запетљано име за %qD биће измењено у будућим верзијама ГЦЦа"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "запетљано име за %qD биће измењено у будућим верзијама ГЦЦа"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q#D, can't use default assignment operator"
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "нестатички константни члан %q#D, не може се користити подразумевани оператор доделе"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member %q#D, can't use default assignment operator"
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "нестатички упућивачки члан %q#D, не може се користити подразумевани оператор доделе"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsynthesized method %qD first required here "
 msgid "synthesized method %qD first required here "
 msgstr "%Hсамосачињени метод %qD прво захтеван овде "
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "union member %q+D with non-trivial %qD"
 msgstr "%Jнеуспостављени члан %qD са %<const%> типом %qT"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr ""
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "initializer for %q#D is invalid"
 msgstr "успостављач за %qT мора бити у витичастим заградама"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "copying non-static data member %q#D of rvalue reference type"
@@ -47458,79 +47516,79 @@
 msgstr "неисправан приступ нестатичком чланском податку %qD нултог објекта"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 #| msgid "repeated using declaration %q+D"
 msgid "defaulted declaration %q+D"
 msgstr "поновљена декларација коришћења %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, fuzzy, gcc-internal-format
 #| msgid "array does not match the region tree"
 msgid "does not match expected signature %qD"
 msgstr "низ не одговара стаблу области"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a template cannot be defaulted"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "%qD cannot be defaulted"
 msgstr "%q+#D се не може декларисати"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, fuzzy, gcc-internal-format
 #| msgid "file ends in default argument"
 msgid "defaulted function %q+D with default argument"
@@ -47738,101 +47796,101 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "нема члана који одговара %<%T::%D%> у %q#T"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларација %qD није у именском простору који окружује %qD"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "експлицитна одредба у декларацији %qD"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared within %D"
 msgstr "%qD није декларисано"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a friend"
 msgstr "%q+D декларисано као пријатељ"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD треба да је декларисано унутар %qD"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибутска директива %qD игнорисана"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "алијас именског простора %qD није дозвољен овде, претпостављам %qD"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "Овај прекидач је превазиђен; користите -Wextra"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "јако using има смисла само у досегу именског простора"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "текући именски простор %qD не обухвата јако употребљени именски простор %qD"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -47841,28 +47899,28 @@
 msgstr[2] ""
 msgstr[3] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr "потрага у зависности од аргумента даје %q+D"
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX entering pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX leaving pop_everything ()\n"
@@ -47883,7 +47941,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -47911,7 +47969,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "захтев за члан %qD у некласном типу %qT"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -47981,799 +48039,805 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(можда недостаје тачка-зарез после дефиниције %qT)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a template"
 msgid "%qE is not a class template"
 msgstr "%qE није шаблон"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE није шаблон"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "неисправан ид. шаблона"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ИСО Ц++ забрањује употребу показивача на функцију у одузимању"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "претапање у тип који није ни интегрални ни набројиви не може се јавити у изразу константе"
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a function call cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an increment cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%s не може да се јави у константном изразу"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "неисправна употреба деструктора %qD као типа"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "неисправна комбинација вишеструких наводилаца типа"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE не именује тип"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE не именује тип"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(можда је намера била %<typename %T::%E%>)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in namespace %qE does not name a type"
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE у именском простору %qE не именује тип"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE у именском простору %qE не именује тип"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has no default constructor to call"
 msgid "and %qT has no template constructors"
 msgstr "тип %qs нема подразумевани конструктор за позивање"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in class %qT does not name a type"
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE у класи %qT не именује тип"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in class %qT does not name a type"
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE у класи %qT не именује тип"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected string-literal"
 msgstr "очекивана је дословна ниска"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "a wide string is invalid in this context"
 msgstr "Аргумент-по-вредности код %L није дозвољен у овом контексту"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "integer literal exceeds range of %qT type"
 msgstr "реална константа премашује опсег за %qT"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "floating literal exceeds range of %qT type"
 msgstr "реална константа премашује опсег за %qT"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr ""
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, fuzzy, gcc-internal-format
 #| msgid "unable to find a register to spill in class %qs"
 msgid "unable to find numeric literal operator %qD"
 msgstr "не могу да нађем регистар за просипање у класи %qs"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
 msgstr "празна декларација"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "Elemental binary operation"
 msgid "expected binary operator"
 msgstr "Елементална бинарна операција"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected EOF"
 msgid "expected ..."
 msgstr "Неочекивано EOF"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "binary expression in operand of fold-expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "conditional expression in operand of fold-expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "integer overflow in expression"
 msgid "mismatched operator in fold-expression"
 msgstr "целобројно преливање у изразу"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "fixed-point types not supported in C++"
 msgstr "-pipe није подржано"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ИСО Ц++ забрањује витичасто заграђене групе унутар израза"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "statement-expressions are allowed only inside functions"
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "наредбени изрази дозвољени су само унутар функција"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
 msgstr "очекиван је израз"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "%<this%> се не може употребити у овом контексту"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "Objective-C declarations may only appear in global scope"
 msgid "a template declaration cannot appear at block scope"
 msgstr "декларације објективног Ц-а могу се јављати само у глобалном досегу"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "локална променљива %qD не може се појавити у овом контексту"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression"
 msgstr "очекиван је израз"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "досег %qT пре %<~%> није име класе"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "декларација %<~%T%> као члана у %qT"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-име %qD употребљено као декларатор деструктора"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "очекивана је листа наводилаца-одредби"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is not an enumeration type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "непотпун тип %qT употребљен у угњежденом наводиоцу имена"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "непотпун тип %qT употребљен у угњежденом наводиоцу имена"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD није шаблон"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected nested-name-specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_frame_address%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неподржан аргумент за %<__builtin_frame_address%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неподржан аргумент за %<__builtin_return_address%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ИСО Ц++ забрањује сложене константе"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "braced list index is not allowed with array notation"
 msgstr "-client_name није дозвољено са -dynamiclib"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "неисправна употреба %qD"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "%<%D::%D%> is not a member of %qT"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> није члан у %qT"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "граница низа забрањена је после заграђеног ид. типа"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "покушајте да уклоните заграде око ид. типа"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "израз у декларатору new мора имати интегрални или набројиви тип"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "употреба старовремског претапања"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "предложи заграде око && унутар ||"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "lambda-expression in template-argument"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Неочекиван крај модула"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qD "
 msgstr "увећање само-за-читање променљиве %qD"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "%q+D декларисано овде"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ИСО Ц 90 не подржава комплексне типове"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "default argument specified for lambda parameter"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "удвостручено %<volatile%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "етикета случаја %qE ван наредбе пребацивања"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> именује конструктор у %qT"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, fuzzy, gcc-internal-format
 #| msgid "Discover pure and const functions"
 msgid "compound-statement in constexpr function"
 msgstr "Откривај чисте и константне функције"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "очекивана је декларација или наредба"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "наредба израза има непотпун тип"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "очекивана је декларација или наредба"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 #| msgid "break statement used with OpenMP for loop"
 msgid "break statement used with Cilk Plus for loop"
 msgstr "наредба искакања употребљена са ОпенМПом за петљу"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ИСО Ц++ забрањује рачунско goto"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "сувишно %<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "забрањено је мешање декларација и дефиниција функција"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "празна декларација"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+#| msgid "invalid member function declaration"
+msgid "invalid initializer for structured binding declaration"
+msgstr "неисправна декларација чланске функције"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> употребљено изван класе"
@@ -48780,123 +48844,123 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "decl-specifier invalid in condition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D неисправно у %q#T"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "дефиниција класе не може бити декларисана пријатељем"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблони не могу бити виртуелни"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "само конструктори узимају успостављаче основе"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "недостаје успостављач за члан %qD"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "статичка декларација %q+D прати нестатичку декларацију"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "анахронистични старовремски успостављач основне класе"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (успостављач одређеног члана имплицитно је тип)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "неисправан операнд услова"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -48903,75 +48967,75 @@
 msgstr "неочекиван операнд"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "кључна реч %<export%> није имплементирана, игнорише се"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "неисправна ограничења за операнд"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> не може започети листу шаблонских аргумената"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> је другачије написано %<[%>. Убаците размак између %<<%> и %<::%>"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(Г++ ће прихватити ово ако задате -fpermissive)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
@@ -48978,328 +49042,328 @@
 msgstr "очекивана је наредба"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "употребите %<%T::template %D%> да назначите да је шаблон"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "очекивани су наводиоци декларације или %<...%>"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специјализација шаблона са Ц повезивошћу"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ИСО Ц забрањује унапредне декларације параметара"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Очекиван је тип израза"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Очекивано је име"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибут се игнорише за класе без примерака"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибут се игнорише при предоченом-наводиоцу-типа који није унапредна декларација"
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD није шаблон функције"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD није члан у %qT"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Инструкције min/max нису дозвољене"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Укључи аутоматско извођење шаблона"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларација %qD у %qD која не обухвата %qD"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "сувишне одредбе се игноришу"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "вишеструке дефиниције %q#T"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ИСО Ц++ забрањује %s-вање набрајања"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD није име именског простора"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Упозори када се уткана функција не може уткати"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "nested identifier required"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "употреба именског простора %qD као израза"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> није дозвољена овде"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ид. шаблона не може да се јави у декларацији употребе"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: дефиниција функције није претворена\n"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "навод asm није дозвољен на дефиницији функције"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "успостављач дат за функцију"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "игноришу се атрибути после заграђеног успостављача"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "функција %q+D поново декларисана као уткана"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "неисправна употреба конструктора као шаблона"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "употреба %<%T::%D%> уместо %<%T::%D%> за именовање конструктора у одређеном имену"
@@ -49308,7 +49372,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "invalid declarator"
@@ -49316,376 +49380,376 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Неисправна декларација"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "очекивани су наводиоци декларације"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD је именски простор"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "неочекиван операнд"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "удвостручена кн-одредба"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "недостаје справљачки циљ после %qs"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "неисправна употреба %qD"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "очекиван је идентификатор"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "подразумевани аргументи су дозвољени само за параметре функција"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "шаблонски параметри не могу бити пријатељи"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD не може имати подразумеване аргументе"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D декларисано уткано после своје дефиниције"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Неочекивано смеће после декларације функције код %C"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "не могу да нађем датотеку за класу %s"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "неисправно име класе у декларацији %qD"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "експлицитној специјализацији мора претходити %<template <>%>"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "претходна дефиниција %q+#T"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "очекивано је име класе"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "при декларацији пријатеља мора бити употребљена кључна реч class"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "декларација пријатеља не именује ни класу ни функцију"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "наводилац pure на дефиницији функције"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "не може се користити %<::%> у декларацији параметра"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "очекивано је %<(%> или крај линије"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "кључна реч %<typename%> није дозвољена изван шаблона"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "кључна реч %<typename%> није дозвољена у овом контексту (основна класа је имплицитно тип)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "ИСО Ц++ не дозвољава утврђене успостављаче"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD in linkage specification"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Атрибут %s коси се са атрибутом %s код %L"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "очекиван је идентификатор или %<(%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "неисправна поновљена декларација %q+D"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "премало листа параметара шаблона"
@@ -49694,473 +49758,473 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "превише листа шаблонских параметера"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именоване повратне вредности нису више подржане"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "Use media instructions"
 msgid "empty introduction-list"
 msgstr "Користи медија-инструкције"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "неисправна декларација чланског шаблона у локалној класи"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон са Ц повезивошћу"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "неисправан навод основне класе"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "декларација шаблона %qs"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "декларација ништа не декларише"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "експлицитна специјализација у не-именскопросторном досегу %qD"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> треба да је %<> >%> унутар угњеждене листе шаблонских аргумената"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "сувишно %<>>%>, користите %<>%> за затварање листе шаблонских аргумената"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "неисправна употреба %qD у одредници повезивости"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> пре %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ИСО Ц++ не подржава %<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "и %<short%> и %<char%> у наводиоцима декларације"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "удвостручено %qE"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "удвостручено %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "очекивана је наредба"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "очекивано је %<none%> или %<shared%>"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "очекивано је %<{%>"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "очекивано је %<:%> или %<...%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "очекивано је %<,%>, %<;%> или %<}%>"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "ознака %qs употребљена при именовању %q#T"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D претходно декларисано овде"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD поново декларисано са другачијим приступом"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (као разјашњење двосмислености) дозвољено је само унутар шаблона"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "датотека се завршава подразумеваним аргументом"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "конструкција %<@%D%> објективног Ц++а на погрешном месту"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> мора навести тип као аргумент"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "неисправно име селектора објективног Ц++а"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Очекивана је декларација класе или сучеља"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jатрибут одељка се не може навести за локалне променљиве"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "очекиван је идентификатор после %<@protocol%>"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "атрибут %qE се игнорише за %qE"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "неисправан типски аргумент"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 #| msgid "Initialization at %C is not allowed in a PURE procedure"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "Успостављање код %C није дозвољено у чистој процедури"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qD should not be reduction"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "атрибути нису дозвољени на дефиницији функције"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неисправан успостављач"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "очекиван је израз"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -50167,73 +50231,73 @@
 msgstr "%qD није чланска шаблонска функција"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "смеће на крају %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "неисправна ограничења за операнд"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC diagnostic not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC diagnostic није дозвољено унутар функција"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "унутармодулске оптимизације нису имплеметиране за Ц++"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "Очекивано је име променљиве код %C"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "очекивано је %<,%> или %<;%>"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
@@ -50331,7 +50395,7 @@
 msgid "candidate is: %#D"
 msgstr "кандидат је: %+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
@@ -50972,132 +51036,149 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+#| msgid "the address of %qD will always evaluate as %<true%>"
+msgid "the address of %qD is not a valid template argument"
+msgstr "адреса за %qD ће увек бити израчуната као %<true%>"
+
+#: cp/pt.c:6634
 #, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+#| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qD нема спољашњу повезивост"
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер се коси са кн-одредбом"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није константан израз"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер није л-вредност"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер објекат %qD нема спољашњу повезивост"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је показивач"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "покушајте са %qE уместо тога"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE није исправан шаблонски аргумент за тип %qT јер је типа %qT"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "стандардна претварања нису дозвољена у овом контексту"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "примењивање атрибута на шаблонске параметре није имплементирано"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "Ignoring statement label in empty statement at %C"
 msgid "ignoring attributes in template argument %qE"
 msgstr "Игноришем етикету наредбе у празној наредби код %C"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "име класе заклања шаблонски шаблонски параметар %qD"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "неисправна употреба деструктора %qD као типа"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "да упутите на тип шаблонског параметра, употребите %<typename %E%>"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  очекивах константу типа %qT, добих %qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  очекивах шаблон класе, добих %qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  очекивах тип, добих %qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr " очекивах тип, добих %qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  очекивах шаблон класе, добих %qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  очекивах шаблон типа %qD, добих %qD"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "неслагање типа/вредности код аргумента %d у листи шаблонских параметара за %qD"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
@@ -51105,111 +51186,111 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in nontype parameter pack"
 msgstr "неслагање типова у условном изразу"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "нисам могао да претворим шаблонски аргумент %qE у %qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "погрешан број шаблонских аргумената ((%d, а треба %d)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "дат за %q+D"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "подразумевани аргумент дат за параметар %d у %q#D"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "дат за %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD није шаблон функције"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "нешаблонски тип %qT употребљен као шаблон"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "за декларацију шаблона %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "неуспех услед унутрашње неусаглашености"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d (употребите -ftemplate-depth-NN да повећате дубину) извођења %qD"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -51228,289 +51309,289 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "променљива %qD има функцијски тип"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "неисправан тип параметра %qT"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "у декларацији %q+D"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функција враћа низ"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функција враћа функцију"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "стварање показивача на чланску функцију некласног типа %qT"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "обликовање упућивача на празно"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "обликовање %s на тип упућивача %qT"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring %qV qualifiers added to function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "игнорисање %qV одредбе додате функцијском типу %qT"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "стварање показивача на члан некласног типа %qT"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "стварање показивача на члан упућивачког типа %qT"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "стварање показивача на члан празног типа"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "стварање низа типа %qT"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT није тип класе, структуре, нити уније"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT се разрешава до %qT, што није набројиви тип"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT се разрешава до %qT, што није класни тип"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "употреба %qs у шаблону"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависно име %qE рашчлањује се као не-тип, али извођење производи тип"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "ставите %<typename %E%> ако мислите на тип"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "употреба неисправног поља %qD"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "неисправна употреба израза празног типа"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> за аргументе.)"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> није тип"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE недекларисано овде (не у функцији)"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT није ни класа ни именски простор"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD није ни класа ни именски простор"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT јесте/користи анонимни тип"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "шаблонски аргумент за %qD користи локални тип %qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT је променљиво измењив тип"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "интегрални израз %qE није константа"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  покушај извођења %qD"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "двосмислено извођење шаблона класе за %q#T"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D је нестатички члански податак у %qT"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "поклапајући шаблон за %qD није нађен"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "експлицитно извођење %q#D"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "удвостручено експлицитно извођење %q#D"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %<extern%> на експлицитним извођењима"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "складишна класа %qD примењена на извођење шаблона"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "експлицитно извођење не-шаблона %q#D"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "експлицитно извођење нешаблонског типа %qT"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "експлицитно извођење %q#T пре дефиниције шаблона"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ИСО Ц++ забрањује употребу %qE на експлицитним извођењима"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "удвостручено експлицитно извођење %q#T"
@@ -51522,102 +51603,102 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "експлицитно извођење %qD али дефиниција није доступна"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "дубина извођења шаблона премашује максимум од %d извођења %q+D, могуће услед стварања виртуелних табела (употребите -ftemplate-depth-NN да повећате максимум)"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "употреба параметра шаблонског типа %qT после %qs"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T није исправан тип за шаблонски константан параметар"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "%qD употребљено као шаблон, а није"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "неисправан шаблонски аргумент %d"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "функција се не разматра за уткивање"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Неисправна декларација метода, неопходан је повратни тип"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "не могу да емулирам %qs"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "ија не задовољава своја ограничења:"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -51788,176 +51869,176 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  пошто је %q+#D декларисано у основној класи"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "%Hпредложи експлицитне витичасте заграде ради избегавања двосмисленог %<else%>"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "тип asm-операнда %qE не може бити одређен"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, fuzzy, gcc-internal-format
 #| msgid "Objective-C declarations may only appear in global scope"
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "декларације објективног Ц-а могу се јављати само у глобалном досегу"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "неисправна употреба члана %q+D у статичкој чланској функцији"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "аргументи нису дозвољени у деструктору"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> није доступно за статичке чланске функције"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "неисправна употреба %<this%> у нечланској функцији"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "неисправна употреба %<this%> на највишем нивоу"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "неисправан одредбени досег у имену псеудодеструктора"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "одређени тип %qT не поклапа се са именом деструктора ~%qT"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE није типа %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "сложени дословни необјектног типа %qT"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "типски параметри шаблона морају користити кључну реч %<class%> или %<typename%>"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "неисправна употреба типа %qT као подразумеване вредности за шаблонски шаблонски параметар"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "неисправан подразумевани аргумент за шаблонски шаблонски параметар"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "дефиниција %q#T унутар листе шаблонских параметара"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "неисправна дефиниција одређеног типа %qT"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "неисправан навод основне класе"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "заштићени члан %q+#D у анонимној унији"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD није тип"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "употреба %<auto%> променљиве из обухватајуће функције"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "употреба параметра из обухватајуће вункције"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter from containing function"
 msgid "use of parameter outside function body"
 msgstr "употреба параметра из обухватајуће вункције"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "missing template arguments"
 msgstr "грешка у рашчлањивању листе шаблонских аргумената"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "шаблонски параметар %qD типа %qT није дозвољен у интегралном константном изразу јер није интегралног или набројивог типа"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "употреба именског простора %qD као израза"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "употреба шаблона класе %qT као израза"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "захтев за члан %qD двосмислен је у вишеструком снопу наслеђивања"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD се не може јавити у константном изразу"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип за %qE није познат"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -51964,339 +52045,339 @@
 msgstr "%qT није шаблонски тип"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "наводиоци складишне класе нису исправни у декларацијама параметара"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "не може се применити %<offsetof%> на деструктор %<~%T%>"
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "не може се применити %<offsetof%> на чланску функцију %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "двосмислено упућивање на %qD"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE има неисправан тип за %<reduction%>"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<firstprivate%>"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qE није променљива у одредби %<firstprivate%>"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %<lastprivate%>"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qE није променљива у одредби %<lastprivate%>"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "вредност %<num_threads%> мора бити позитивна"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "листа израза %s узима се као сложени израз"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, fuzzy, gcc-internal-format
 #| msgid "%<continue%> must be in loop"
 msgid "%<device%> id must be integral"
 msgstr "%<continue%> мора бити у оквиру петље"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD се појављује више од једном у одредбама података"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "израз за величину одломка при распоређивању мора бити интегрални"
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD није променљива у одредби %qs"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "поновљена имплементација класе %qs"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "израз за num_threads мора бити интегрални"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> није дефинисано као показивачки тип"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE is not file, namespace or block scope variable"
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qE није датотека, именски простор нити променљива блоковског досега"
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, fuzzy, gcc-internal-format
 #| msgid "%<threadprivate%> %qE has incomplete type"
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "нитно-локално %qE има непотпун тип"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Hнеисправан тип променљиве итерације %qE"
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "Тврдња КРИС-порта није прошла: "
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "нестатичка декларација %q+D прати статичку декларацију"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to decltype must be an expression"
 msgstr "Аргумент наредбе SELECT код %L мора бити скаларни израз"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s не може да разреши адресу препуњене функције"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "леви операнд зарез-израза нема ефекта"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "шаблонски аргумент %qE уплиће шаблонске параметре"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -52313,122 +52394,122 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Лош тип у константном изразу"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "атрибут %qs је примењив само на функцијске типове"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "захтевано init_priority није целобројна константа"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "атрибут %qE може се користити само уз дефиниције објеката класног типа у датотечном досегу"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "захтевано init_priority је ван опсега"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "захтевано init_priority резервисано је за унутрашњу употребу"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "атрибут %qE није подржан на овој платформи"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "декларација %qD као %s"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "атрибут %qs захтева тачно један НТБС аргумент"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент атрибута %qs није константна ниска"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> није исправан декларатор"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE се игнорише на не-класним типовима"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "атрибут %qE може се применити само на дефиниције класа"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 #| msgid "attributes ignored on template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "атрибут се игнорише при извођењу шаблона"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%Jатрибут %qE примењује се само на функције"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "граница низа није целобројна константа"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "провера lang_*: крах у %s, код %s:%d"
@@ -53172,118 +53253,118 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "неисправно претварање у тип %qT из типа %qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "не може се претворити %qT у %qT као аргумент %qP за %qD"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in return"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "не може се претворити %qT у %qT у %s"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "повратни тип %q#T није потпун"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "аргумент %d од %qE може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "повратни тип може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "аргумент позива функције може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "лева страна доделе може бити кандидат за форматски атрибут"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "у прослеђивању аргумента %P за %q+D"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "враћање упућивача на привремени"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "враћање упућивача на не-л-вредност"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "враћање упућивача на локалну променљиву %q+D"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "враћање адресе локалне променљиве %q+D"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "враћање вредности из деструктора"
@@ -53290,58 +53371,58 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "не може се враћати из руковаоца у блоку покушаја у конструктору"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "враћање вредности из конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "наредба враћања без вредности, у функцији која враћа %qT"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "недостаје успостављач"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "не могу се дефинисати нови типови у повратном типу"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "Неусаглашени рангови за оператор код %L и %L"
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "наредба враћања са вредношћу, у функцији која враћа ‘void’"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> не сме вратити NULL, осим ако је декларисан уз %<throw()%> (или је задато -fcheck-new)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -57689,89 +57770,89 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qE није исправан шаблонски аргумент типа %qT јер %qE није променљива"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Променљива ‘%s’ се не може јавити у изразу код %L"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -57975,12 +58056,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Други аргумент дефинисане доделе код %L мора бити намере-у"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Први аргумент сучеља оператора код %L мора бити намере-у"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Други аргумент сучеља оператора код %L мора бити намере-у"
@@ -58828,567 +58909,583 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "Фортран 2003: Наредба FLUSH код %C"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: X descriptor requires leading space count at %C"
 msgid "X descriptor requires leading space count at %L"
 msgstr "Проширење: Описник X захтева водећи број размака код %C"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: $ descriptor at %C"
 msgid "$ descriptor at %L"
 msgstr "Проширење: описник $ код %C"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "$ should be the last specifier in format at %C"
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ треба да је задњи наводилац у формату код %C"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %C"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Проширење: Недостаје позитивна ширина после описника L код %C"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %C"
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Проширење: Недостаје позитивна ширина после описника L код %C"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %C"
 msgid "%<G0%> in format at %L"
 msgstr "%s у форматирајућој ниски код %C"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Positive width required in format specifier %s at %L"
 msgstr "Потребна тачка у наводиоцу формата код %C"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Period required in format specifier %s at %L"
 msgstr "Потребна тачка у наводиоцу формата код %C"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Period required in format specifier at %L"
 msgstr "Потребна тачка у наводиоцу формата код %C"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing comma at %C"
 msgid "Missing comma at %L"
 msgstr "Проширење: Недостаје зарез код %C"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s in format string at %C"
 msgid "%s in format string at %L"
 msgstr "%s у форматирајућој ниски код %C"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Non-character in FORMAT tag at %L"
 msgid "Extraneous characters in format at %L"
 msgstr "Проширење: Не-знак у ознаци FORMAT код %L"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Format statement in module main block at %C."
 msgid "Format statement in module main block at %C"
 msgstr "Наредба форматирања у главном блоку модула код %C."
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "Наредба ENTRY код %C не може бити унутар INTERFACE"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Недостаје етикета формата код %C"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Invalid value for %s specification at %C"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "Удвостручена одредница %s код %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable tag cannot be INTENT(IN) at %C"
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "Ознака променљиве не може бити намере-у код %C"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable tag cannot be assigned in PURE procedure at %C"
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "Ознака променљиве не може бити додељена у чистој процедури код %C"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "Удвостручена одредница етикете %s код %C"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "Константан израз у ознаци FORMAT код %L мора бити типа подразумеваног CHARACTER"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "Константан израз у ознаци FORMAT код %L мора бити типа подразумеваног CHARACTER"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: ASSIGNED variable in FORMAT tag at %L"
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "Застарело: Додељена променљива у ознаци FORMAT код %L"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L has not been assigned a format label"
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "Променљивој ‘%s’ код %L није додељена етикета формата"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "scalar '%s' FORMAT tag at %L is not an ASSIGNED variable"
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr "скаларна ознака формата ‘%s’ код %L није додељена променљива"
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Non-character in FORMAT tag at %L"
 msgid "Non-character in FORMAT tag at %L"
 msgstr "Проширење: Не-знак у ознаци FORMAT код %L"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Character array in FORMAT tag at %L"
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "Проширење: Знаковни низ у ознаци FORMAT код %L"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Character array in FORMAT tag at %L"
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "Проширење: Знаковни низ у ознаци FORMAT код %L"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Character array in FORMAT tag at %L"
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "Проширење: Знаковни низ у ознаци FORMAT код %L"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "Ознака %s код %L мора бити типа %s"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s or %s"
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "Ознака %s код %L мора бити типа %s или %s"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "Ознака %s код %L мора бити скалар"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: IOMSG tag at %L"
 msgid "IOMSG tag at %L"
 msgstr "Фортран 2003: Ознака IOMSG код %L"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 95 requires default INTEGER in SIZE tag at %L"
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Фортран 95 захтева подразумевни цео број у ознаци SIZE код %L"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad INTENT specification at %C"
 msgid "NEWUNIT specifier at %L"
 msgstr "Лоша одредница намере код %C"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: CONVERT tag at %L"
 msgid "CONVERT tag at %L"
 msgstr "Проширење: ознака CONVERT код %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: %s specifier in %s statement at %C has value '%s'"
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Фортран 2003: наводилац %s у наредби %s код %C има вредност ‘%s’"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 #| msgid "%s specifier in %s statement at %C has invalid value '%s'"
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "Наводилац %s у наредби %s код %C има неисправну вредност ‘%s’"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: %s specifier in %s statement at %C has value '%s'"
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "Проширење: наводилац %s у наредби %s код %C има вредност ‘%s’"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "%s specifier in %s statement at %C has invalid value '%s'"
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "Наводилац %s у наредби %s код %C има неисправну вредност ‘%s’"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "Наредба OPEN није дозвољена у чистој процедури код %C"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "Наредба INQUIRE код %L захтева или наводилац FILE или UNIT"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "Наредба CLOSE није дозвољена у чистој процедури код %C"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "Наредба ASSIGNED GOTO код %L захтева целобројну променљиву"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "Наредба %s није дозвољена у чистој процедури код %C"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expected expression in %s statement at %C"
 msgid "UNIT number missing in statement at %L"
 msgstr "Очекиван је израз у наредби %s код %C"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "Израз у наредби CASE код %L мора бити типа %s"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "FLUSH statement at %C"
 msgstr "Фортран 2003: Наредба FLUSH код %C"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing format with default unit at %C"
 msgstr "Недостаје етикета формата код %C"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Удвостручена одредница UNIT код %C"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Удвостручена одредница формата код %C"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Симбол ‘%s’ у листи имена ‘%s’ је намере-у код %C"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Удвостручена одредница NML код %C"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Симбол ‘%s’ код %C мора бити име групе листе имена"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-I- specified twice"
 msgid "UNIT not specified at %L"
 msgstr "-I- наведено двапут"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "Одредница UNIT код %L мора бити целобројни израз или знаковна променљива"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Неисправан облик наредбе PROGRAM код %C"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Унутрашња јединица са векторским индексом код %L"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Спољашња У/И јединица не може бити низ код %L"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, fuzzy, gcc-internal-format
+#| msgid "NAMELIST object '%s' at %L cannot have ALLOCATABLE components"
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr "Објекат листе имена ‘%s’ код %L не може имати резервљиве компоненте"
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Comma before output item list at %C is an extension"
 msgid "Comma before i/o item list at %L"
 msgstr "Проширење: Зарез пре ставке излазне листе код %C је проширење"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "Етикета %d за ERR код %L није дефинисана"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "Етикета %d за END код %L није дефинисана"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "Етикета %d за EOR код %L није дефинисана"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "Етикета %d за FORMAT код %L није дефинисана"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Синтаксна грешка у У/И итератору код %C"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Очекивана је променљива у наредби READ код %C"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Очекиван је израз у наредби %s код %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Синтаксна грешка у наредби %s код %C"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic at %L does not exist"
 msgid "Internal file at %L with namelist"
 msgstr "Сопствено код %L не постоји"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "Параметар врсте за %s код %L мора бити инцијализовани израз"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "Листа имена PRINT код %C је проширење"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Очекиван је зарез у У/И листи код %C"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "Наредба PRINT код %C није дозвољена у чистој процедури"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "Наредба INQUIRE код %C није дозвољена у чистој процедури"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "Неисправна ознака IOLENGTH у наредби INQUIRE код %C"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "Наредба INQUIRE код %L не може садржати и наводилац FILE и UNIT"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "Наредба INQUIRE код %L захтева или наводилац FILE или UNIT"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "Аргумент наредбе SELECT код %L не може бити %s"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "Наредба INQUIRE код %L захтева или наводилац FILE или UNIT"
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Ознака END код %C није дозвољена у излазној наредби"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "WAIT statement not allowed in PURE procedure at %C"
@@ -60370,277 +60467,277 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "Недостаје генеричка одредница у наредби USE код %C"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Renaming operators in USE statements at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Глобално име ‘%s’ код %L се већ користи као %s код %L"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in declaration %q+D"
 msgid "SUBMODULE declaration at %C"
 msgstr "у декларацији %q+D"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "Наредба ENTRY код %C не може бити унутар садржаног потпрограма"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Синтаксна грешка у наредби SAVE код %C"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "Reading module %s at line %d column %d: %s"
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "Читање модула %s, линија %d колона %d: %s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "Writing module %s at line %d column %d: %s"
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "Писање модула %s, линија %d колона %d: %s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, fuzzy, gcc-internal-format
 #| msgid "Module %s at line %d column %d: %s"
 msgid "Module %qs at line %d column %d: %s"
 msgstr "Модул %s, линија %d колона %d: %s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Грешка при писању датотеке модула: %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Кориснички оператор ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Сопствени оператор ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за писање код %C: %s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Грешка при отварању датотеке модула ‘%s’ за писање: %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file '%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: не могу да обришем датотеку ‘%s’: %s\n"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за писање код %C: %s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file '%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: не могу да обришем помоћну инфотеку ‘%s’: %s\n"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs at %C already declared"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Сопствено ‘%s’ код %L није укључено у изабрани стандард"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs already declared"
 msgstr "Компонента ‘%s’ код %C већ је декларисана код %L"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Симбол ‘%s’ поменут код %L није нађен у модулу ‘%s’"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "Наредба %s код %C није унутар петље"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Не могу да отворим датотеку модула ‘%s’ за читање код %C: %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Датотека ‘%s’ отворена код %C није модул Гфортрана"
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building!"
@@ -63250,7 +63347,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Не могу да разрешим одређену функцију ‘%s’ код %L"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -64888,485 +64985,474 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Низ претпостављене величине ‘%s’ у листи имена ‘%s’ код %C није дозвољен."
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
+#: fortran/resolve.c:13903
 #, fuzzy, gcc-internal-format
-#| msgid "NAMELIST object '%s' at %L cannot have ALLOCATABLE components"
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "Објекат листе имена ‘%s’ код %L не може имати резервљиве компоненте"
-
-#: fortran/resolve.c:13942
-#, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "Приватни симбол ‘%s’ не може бити члан јавне листе имена код %L"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Параметарски низ ‘%s’ код %L не може бити аутоматског или претпостављеног облика"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Имплицитно типски параметар ‘%s’ код %L не одговара каснијем имплицитном типу"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несагласан изведени тип у параметру код %L"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, fuzzy, gcc-internal-format
 #| msgid "Object '%s' at %L must have the SAVE attribute %s"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Објекат ‘%s’ код %L мора имати атрибут %s за SAVE"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Атрибут процедуре коси се са атрибутом листе имена у ‘%s’ код %L"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Низ претпостављене величине код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Низ претпостављеног облика код %L мора бити лажни аргумент"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Симбол код %L није лажна променљива"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Наредбена функција знаковне вредности ‘%s’ код %L мора имати константну дужину"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined."
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Изведени тип ‘%s’ код %L је типа ‘%s’, који није дефинисан."
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Derived type variable in COMMON at %C does not have the SEQUENCE attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Променљива изведеног типа у заједничком код %C нема атрибут SEQUENCE"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Лажни аргумент намере-из ‘%s’ код %L је претпостављене величине и зато не може имати подразумевани успостављач"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Лажни аргумент ‘%s’ код %L не може бити намере-из"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Аргумент-по-вредности код %L не може бити низ или одељак низа"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Низ ‘%s’ код %L не може имати одложен облик"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Резервљиви низ ‘%s’ код %L мора имати одложени облик"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Лажна процедура код %L није дозвољена у елементалној процедури"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Листа имена %s не може се преименовати у %s придружењем USE."
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Нитно-приватно код %L не снима се"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA елемент ‘%s’ код %L мора бити у заједничком"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Лажно ‘%s’ код %L не може имати успостављач"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантан одељак низа код %L у наредби DATA"
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "Наредба DATA код %L има више променљивих него вредности"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "Наредба DATA код %L има више вредности него променљивих"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Ознака %d код %L дефинисана али неупотребљена"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Ознака %d код %L дефинисана али не може бити употребљена"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L мора имати атрибут SEQUENCE да би била објекат еквиваленције"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L не може имати резервљиве компоненте како би била објекат еквиваленције"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Променљива изведеног типа ‘%s’ код %L са подразумеваним успостављачем не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Променљива изведеног типа ‘%s’ код %L са показивачким компонентама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксна грешка у наредби EQUIVALENCE код %L"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Члан заједничког блока ‘%s’ код %L не може бити објекат еквиваленције у чистој процедури ‘%s’"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именована константа ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Низ ‘%s’ код %L са неконстантним границама не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонената структуре ‘%s’ код %L не може бити објекат еквиваленције"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подниска код %L има нулту дужину"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Јавна функција ‘%s’ код %L не може бити приватног типа ‘%s’"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "Унос ‘%s’ код %L нема имплицитан тип"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора бити функција"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура корисничког оператора ‘%s’ код %L не може бити претпостављене знаковне дужине"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура корисничког оператора ‘%s’ код %L мора имати бар један аргумент"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Први аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Други аргумент сучеља оператора код %L не може бити опциони"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Сучеље оператора код %L мора имати, највише, два аргумента"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -66540,12 +66626,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "не би требало да променљива итерације %qs буде свођена"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "Лош У/И основни тип (%d)"
@@ -69927,9 +70013,6 @@
 #~ msgid "If set, control speculative instructions will be chosen for schedule only if there are no other choices at the moment "
 #~ msgstr "Ако је постављено, инструкције спекулације контроле биће узете за распоређивање само ако у датом тренутку нема другог избора"
 
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "Стварај инструкције множење-додавање у покретном зарезу"
-
 #~ msgid "Generate mips16 code"
 #~ msgstr "Створи кôд за мипс16"
 
Index: gcc/po/da.po
===================================================================
--- gcc/po/da.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/da.po	(.../branches/gcc-7-branch)
@@ -137,7 +137,7 @@
 msgstr ""
 "Project-Id-Version: gcc 7.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2017-05-21 11:00+0200\n"
 "Last-Translator: Joe Hansen <joedalton2@yahoo.dk>\n"
 "Language-Team: Danish <dansk@dansk-gruppen.dk>\n"
@@ -324,13 +324,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "kommatalskonstant misbrugt"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -618,62 +618,62 @@
 " videregive andre indstillinger til disse processer kan tilvalg på formen\n"
 " »-W<bogstav>« bruges.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Behandler specifikation (%s), som er »%s«\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Mål: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Konfigureret med: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Trådmodel: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc-version %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "gcc-styringsprogram version %s %skører gcc-version %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr "Fejlen kan ikke genskabes, så det er sandsynligvis et udstyrsproblem eller et problem med operativsystemet.\n"
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr "Forbrændt kilde lagret i %s-filen, vedhæft venligst den til din fejlrapport.\n"
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "installering: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "programmer: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "biblioteker: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -682,16 +682,16 @@
 "\n"
 "For fejlrapporteringsinstruktioner, se:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "(C)"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -700,7 +700,7 @@
 "Dette er et frit program; se kildekoden for kopieringsbetingelser. Der er\n"
 "INGEN garanti; ikke engang for SALGBARHED eller BRUGBARHED TIL NOGET FORMÅL.\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -713,7 +713,7 @@
 "==============\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -722,7 +722,7 @@
 "Brug »-Wl,TILVALG« for at sende »TILVALG« til sammenkæderen.\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -733,7 +733,7 @@
 "=================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -747,16 +747,16 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr "  merge [tilvalg] <map1> <map2>         Sammenføj dækningsfilindhold\n"
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "    -o, --output <map>                  Vis mappe\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "    -v, --verbose                       Uddybende tilstand\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "    -o, --output <map>                  Vis mappe\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -772,14 +772,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr "  rewrite [tilvalg] <map>               Genskriv dækningsfilindhold\n"
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -807,27 +807,27 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr "  overlap [tilvalg] <map1> <map2>       Beregn overlap for to profiler\n"
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "    -h, --hotonly                       Udskriv kun info for varme objekter/funktioner\n"
-
-#: gcov-tool.c:422
-#, c-format
 msgid "    -f, --function                      Print function level info\n"
 msgstr "    -f, --function                      Udskriv info om funktionsniveau\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:421
 #, c-format
 msgid "    -F, --fullname                      Print full filename\n"
 msgstr "    -F, --fullname                      Udskriv fuldt filnavn\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:422
 #, c-format
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr "    -h, --hotonly                       Udskriv kun info for varme objekter/funktioner\n"
+
+#: gcov-tool.c:423
+#, c-format
 msgid "    -o, --object                        Print object level info\n"
 msgstr "    -o, --object                        Udskriv info på objektniveau\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr "    -t <float>, --hot_threshold <float> Angiv tærskel for varme\n"
@@ -914,20 +914,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Udskriv denne hjælp og afslut\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Vis oplysninger for alle basisblokke\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Medtag forgreningssandsynligheder i uddata\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -936,16 +931,21 @@
 "  -c, --branch-counts             Antal forgreninger taget i stedet\n"
 "                                    for procenter\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          Vis statusinformation\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Udskriv sammendrag for hver funktion\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Udskriv denne hjælp og afslut\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1130,82 +1130,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s:graf kan ikke løses for »%s«\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Linjer kørt:%s af %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Ingen kørbare linjer\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s »%s«\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Forgreninger kørt:%s af %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "Taget mindst en gang:%s af %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Ingen forgreninger\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Kald kørt:%s af %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Ingen kald\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s:ingen linjer for »%s«\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "kald   %2d returnerede %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "kald   %2d aldrig udført\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "forgrening %2d valgt %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "forgrening %2d aldrig udført\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "ubetinget %2d valgt %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "ubetinget %2d aldrig udført\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "Kan ikke åbne kildefilen %s\n"
@@ -1312,89 +1312,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr "Brug af dette tilvalg diagnosticeres."
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr "standard %d minimum %d maksimum %d"
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr "Samme som %s. Brug det sidste tilvalg i stedet."
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s Samme som %s."
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[standard]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[aktiveret]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[deaktiveret]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Ingen tilvalg med de ønskede karakteristika blev fundet\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Ingen fundet. Brug --help=%s for at vise *alle* tilvalgene understøttet af brugerfladen %s.\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Alle tilvalg med de ønskede karakteristika er allerede blevet vist\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "De følgende tilvalg er målspecifikke"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "De følgende tilvalg kontrollerer advarselsbeskeder for oversætteren"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "De følgende tilvalg kontrollerer optimeringer"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "De følgende tilvalg er sproguafhængige"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "Tilvalget --param genkender følgende som parametre"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "De følgende tilvalg er specifikke kun for sproget "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "De følgende tilvalg er understøttet af sproget "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "De følgende tilvalg er ikke dokumenterede"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "De følgende tilvalg anvender forskellige parametre"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "De følgende tilvalg anvender fælles parametre"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "De følgende tilvalg er sprogrelaterede"
 
@@ -2939,8 +2939,8 @@
 msgid "<command-line>"
 msgstr "<kommandolinje>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ikke understøttet operand for koden »%c«"
@@ -2959,7 +2959,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "manglende operand"
@@ -2979,8 +2979,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "ugyldig operandpræfiks »%%%c«"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« brugt uden nogle lokale dynamiske TLS-referencer"
@@ -2996,18 +2996,18 @@
 msgstr "ugyldig %%r-værdi"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "ugyldig %%R-værdi"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "ugyldig %%N-værdi"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "ugyldig %%P-værdi"
@@ -3017,7 +3017,7 @@
 msgid "invalid %%h value"
 msgstr "ugyldig %%h-værdi"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "ugyldig %%L-værdi"
@@ -3038,7 +3038,7 @@
 msgstr "ugyldig %%U-værdi"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "ugyldig %%s-værdi"
@@ -3048,7 +3048,7 @@
 msgid "invalid %%C value"
 msgstr "ugyldig %%C-værdi"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "ugyldig %%E-værdi"
@@ -3059,7 +3059,7 @@
 msgstr "ukendt relokaliserings-unspec"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ugyldig %%xn-kode"
@@ -3122,7 +3122,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "ugyldig operand-uddatakode"
@@ -3132,31 +3132,31 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ugyldig UNSPEC som operand: %d"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "ugyldig skift-operand"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, fuzzy, c-format
 #| msgid "Generate char instructions"
 msgid "predicated Thumb instruction"
 msgstr "Generér char-instruktioner"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, fuzzy, c-format
 #| msgid "ret instruction not implemented"
 msgid "predicated instruction in conditional sequence"
 msgstr "ret-instruktion ikke implementeret"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3164,107 +3164,107 @@
 msgid "invalid operand for code '%c'"
 msgstr "ugyldig operand for koden »%c«"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktion aldrig udført"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "forældet Maverick-formatkode »%c«"
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "adresseoperand kræver begrænsning for X-, Y- eller Z-register"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "operander til %T/%t skal være reg + const_int:"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr "ugyldig adresse, ikke en I/O-adresse:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr "ugyldig adresse, ikke en konstant:"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "ugyldig adresse, ikke (reg+disp):"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "ugyldig adresse, ikke post_inc eller pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "intern oversætterfejl - ugyldig adresse:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Ikke understøttet kode »%c« for fast-punkt:"
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "intern oversætterfejl - ugyldig tilstand:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "ugyldig instruktion:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "ukorrekt instruktion:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "ukendt flytteinstruktion:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "ugyldig skifteinstruktion:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "intern oversætterfejl - ukorrekt skift:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 msgid "unsupported fixed-point conversion"
 msgstr "fast-punkt-konvertering er ikke understøttet"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "a parameter"
 msgid "function parameter"
 msgstr "en parameter"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 #| msgid "structure"
 msgid "structure field"
 msgstr "struktur"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 #| msgid "declaration of `%s' as array of functions"
 msgid "return type of function"
 msgstr "'%s' erklæret som en tabel af funktioner"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 #, fuzzy
 #| msgid "pointer"
 msgid "pointer"
@@ -3290,7 +3290,7 @@
 msgstr "ugyldig const_double-operand"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3512,88 +3512,88 @@
 msgid "bad output_condmove_single operand"
 msgstr "ugyldig output_condmove_single-operand"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ugyldig UNSPEC som operand"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "ugyldig brug af asm-flaguddata"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ugyldig operandstørrelse for operandkoden »O«"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ugyldig operandstørrelse for operandkoden »z«"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ugyldig operandtype brugt med operandkoden »Z«"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ugyldig operandstørrelse for operandkoden »Z«"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »Y«"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »D«"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand er ikke en betingelseskode, ugyldig operandkode »%c«"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand er ikke en offsettable-hukommelsesreference, ugyldig operandkode »H«"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operand er ikke et heltal, ugyldig operandkode »K«"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operand er ikke et specifikt heltal, ugyldig operandkode »r«"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operand er ikke et heltal, ugyldig operandkode »R«"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "operand is not a specific integer, invalid operand code 'r'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operand er ikke et specifikt heltal, ugyldig operandkode »r«"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ugyldig operandkode »%c«"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ugyldige begrænsninger for operand"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "ukendt instruktionstilstand"
 
@@ -3630,7 +3630,7 @@
 msgid "invalid %%P operand"
 msgstr "ugyldig %%P-operand"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "ugyldig %%p-værdi"
@@ -3684,7 +3684,7 @@
 msgstr "postfiks forøgelsesadresse er ikke et register"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "ugyldig adresse"
 
@@ -3718,7 +3718,7 @@
 msgstr "instruktion indeholder en ugyldig adresse!"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "ugyldig adresse"
 
@@ -3809,291 +3809,291 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le er ikke tilladt for storendede mål"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx kræver udstyrskommatal"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx og -mpaired er indbyrdes uforenelige"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx kræver indekseret adressering"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx og -mno-altivec er indbyrdes uforenelige"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec deaktiverer vsx"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory kræver 64-bit tilstand"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic kræver 64-bit tilstand"
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory er ikke tilgængelig i lilleendet tilstand"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mquad-memory kræver 64-bit tilstand"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 #, fuzzy
 #| msgid "bad operand"
 msgid "bad move"
 msgstr "ugyldig operand"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, c-format
 msgid "invalid %%e value"
 msgstr "ugyldig %%e-værdi"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "ugyldig %%f-værdi"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "ugyldig %%F-værdi"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "ugyldig %%G-værdi"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "ugyldig %%j-kode"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "ugyldig %%J-kode"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "ugyldig %%k-værdi"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "ugyldig %%K-værdi"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "ugyldig %%O-værdi"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "ugyldig %%q-værdi"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "ugyldig %%T-værdi"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "ugyldig %%u-værdi"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "ugyldig %%v-værdi"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "ugyldig %%x-værdi"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ugyldig %%y-værdi, prøv at brug »Z«-begrænsningen"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 og __ibm128 kan ikke bruges i det samme udtryk"
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "for få parametre til funktionen"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 #| msgid "Do not generate code for a Sun FPA"
 msgid "Could not generate addis value for fusion"
 msgstr "Generér ikke kode til en Sun FPA"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "kunne ikke generere genindlæsninger for:"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, ugyldig reg #1"
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, ugyldig reg #2"
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load ikke MEM"
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, ugyldig reg #1"
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, ugyldig reg #2"
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store ikke MEM"
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "symbolske hukommelsesreferencer er kun understøttet på z10 eller senere"
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "Kan ikke nedbryde adresse"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ugyldig sammenligningsoperator til »E«-ændring"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ugyldig reference til »J«-uddataændring"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ugyldig adresse til »O«-uddataændring"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ugyldig adresse til »R«-uddataændring"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "hukommelsesreference forventet til »S«-uddataændring"
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ugyldig adresse for »S«-uddatamodifikation"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "register eller hukommelsesudtryk forventet til »N«-uddataændring"
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "register eller hukommelsesudtryk forventet til »M«-uddataændring"
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ugyldig konstant til uddataændringen »%c«"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ugyldig konstant - prøv at bruge en uddataændring"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ugyldig konstantvektor for uddataændringen »%c«"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ugyldigt udtryk - prøv at brug en uddataændring"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ugyldig udtryk til uddataændringen »%c«"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "vector argument passed to unprototyped function"
 msgstr "for få parametre til funktionen"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 #| msgid "pointer targets in %s differ in signedness"
 msgid "types differ in signedness"
 msgstr "fortegnene i henvisningsmål i %s er forskellige"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr "binær operator understøtter ikke vektor bool-operand"
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4121,43 +4121,43 @@
 msgid "created and used with different endianness"
 msgstr "oprettet og brugt med en anden indstilling af '-m%s'"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ugyldig %%Y-operand"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ugyldig %%A-operand"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ugyldig %%B-operand"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "ugyldig %%C-operand"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "ugyldig %%D-operand"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ugyldig %%f-operand"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ugyldig %%s-operand"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "kommatalskonstant er ikke en gyldig umiddelbar operand"
@@ -4340,30 +4340,30 @@
 msgid "bad test"
 msgstr "ugyldig test"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "ugyldig %%D-værdi"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "ugyldig maske"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, fuzzy, c-format
 msgid "invalid %%d value"
 msgstr "ugyldig %%V-værdi"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, fuzzy, c-format
 msgid "invalid %%t/%%b value"
 msgstr "ugyldig %%b-værdi"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "ingen registre i adresse"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "adresseafsæt er ikke en konstant"
 
@@ -4386,8 +4386,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<;%>"
@@ -4410,8 +4410,8 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<(%>"
@@ -4418,7 +4418,7 @@
 msgstr "';' forventet"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<,%>"
@@ -4450,7 +4450,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<)%>"
@@ -4459,7 +4459,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<]%>"
@@ -4470,7 +4470,7 @@
 msgstr ""
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<}%>"
@@ -4478,7 +4478,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<{%>"
@@ -4489,7 +4489,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<:%>"
@@ -4503,24 +4503,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr ""
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr ""
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4530,20 +4530,20 @@
 msgid "expected %<.%>"
 msgstr "';' forventet"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<@end%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<>%>"
 msgstr "';' forventet"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -4551,18 +4551,18 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<=%>"
 msgstr "';' forventet"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<[%>"
@@ -4574,7 +4574,7 @@
 msgid "(anonymous)"
 msgstr "((anonym))"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, fuzzy, gcc-internal-format
 #| msgid "';' expected"
 msgid "expected %<<%>"
@@ -4586,12 +4586,12 @@
 msgid "expected label"
 msgstr "uventet operand"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 #, fuzzy
 msgid "candidate 1:"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 #, fuzzy
 msgid "candidate 2:"
 msgstr "candidate%s: %+#D"
@@ -4848,12 +4848,12 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 #, fuzzy
 msgid "candidates are:"
 msgstr "candidate%s: %+#D"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -5050,98 +5050,98 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 #, fuzzy
 #| msgid "  but %d required"
 msgid "Positive width required"
 msgstr "  men %d påkrævet"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 #, fuzzy
 #| msgid "negative width in bit-field `%s'"
 msgid "Nonnegative width required"
 msgstr "negativ bredde i bitfeltet '%s'"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 #| msgid "unterminated format string"
 msgid "Unexpected element %qc in format string at %L"
 msgstr "uafsluttet formateringsstreng"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 #, fuzzy
 #| msgid "unterminated format string"
 msgid "Unexpected end of format string"
 msgstr "uafsluttet formateringsstreng"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 #, fuzzy
 #| msgid "zero width in %s format"
 msgid "Zero width in format descriptor"
 msgstr "bredde på nul i %s-formatering"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 #, fuzzy
 #| msgid "missing open paren"
 msgid "Missing leading left parenthesis"
 msgstr "manglende startparantes"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 msgid "Left parenthesis required after %<*%>"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr ""
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr ""
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-#| msgid "Missing formal parameter term"
-msgid "Right parenthesis expected at %C"
-msgstr "Manglende formel parameterterm"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr ""
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 #, fuzzy
 #| msgid "type specifier `%s' not allowed after struct or class"
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "typeangivelsen '%s' er ikke tilladt efter struct eller class"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr ""
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+#| msgid "Missing formal parameter term"
+msgid "Right parenthesis expected at %C"
+msgstr "Manglende formel parameterterm"
+
+#: fortran/io.c:1040
 #, fuzzy
 #| msgid "unrecognized format specifier"
 msgid "Period required in format specifier"
 msgstr "ukendt formateringsanvisning"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -5152,96 +5152,96 @@
 msgid "Syntax error in expression at %C"
 msgstr "heltalsoverløb i udtryk"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 #, fuzzy
 #| msgid "unexpected operand"
 msgid "Unexpected EOF"
 msgstr "uventet operand"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 #, fuzzy
 #| msgid "integer overflow in expression"
 msgid "Integer overflow"
 msgstr "heltalsoverløb i udtryk"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr ""
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr ""
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 #, fuzzy
 msgid "Expected name"
 msgstr "uventet operand"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 #, fuzzy
 msgid "Expected left parenthesis"
 msgstr "uventet operand"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr ""
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 #, fuzzy
 msgid "Expected integer"
 msgstr "uventet operand"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 #, fuzzy
 #| msgid "unexpected operand"
 msgid "Expected string"
 msgstr "uventet operand"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr ""
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 #, fuzzy
 #| msgid "packed attribute is unnecessary"
 msgid "Expected attribute bit name"
 msgstr "packed-egenskab er unødvendig"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 #, fuzzy
 #| msgid "section pointer missing"
 msgid "Expected integer string"
 msgstr "sektionshenvisning mangler"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 #, fuzzy
 #| msgid "unterminated format string"
 msgid "Expected real string"
 msgstr "uafsluttet formateringsstreng"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 #, fuzzy
 #| msgid "unexpected address expression"
 msgid "Expected expression type"
 msgstr "uventet adresseudtryk"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 #, fuzzy
 #| msgid "bad operand"
 msgid "Bad operator"
 msgstr "ugyldig operand"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 #, fuzzy
 #| msgid "overflow in constant expression"
 msgid "Bad type in constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 #, fuzzy
 #| msgid "unexpected PIC symbol"
 msgid "Unexpected end of module"
@@ -5529,12 +5529,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5921,7 +5921,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 og -m64 er indbyrdes uforenelige"
 
@@ -9405,7 +9405,7 @@
 msgstr "Angiv bitstørrelse for umiddelbar TLS-afsæt"
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 #, fuzzy
 #| msgid "Schedule code for given CPU"
@@ -9681,7 +9681,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
 msgid "Use LRA instead of reload."
@@ -9978,7 +9978,7 @@
 msgid "Use 80-bit long double."
 msgstr "Benyt 128 bit long double"
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 #| msgid "Use 64 bit long doubles"
@@ -9985,7 +9985,7 @@
 msgid "Use 64-bit long double."
 msgstr "Benyt 64 bit long double"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy
 #| msgid "Use 128 bit long doubles"
@@ -11348,103 +11348,103 @@
 msgid "64 bit ABI."
 msgstr "Benyt 64 bit-API"
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr ""
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 #, fuzzy
 #| msgid "Additional debug prints"
 msgid "Additional debug prints."
 msgstr "Udskriv ekstra fejlanalyseringsinfo"
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr ""
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 #| msgid "hexadecimal floating constants require an exponent"
 msgid "Enable decimal floating point hardware support."
 msgstr "hexadecimal kommatalskonstant skal have en eksponent"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "Enable hardware floating point."
 msgstr "Benyt hardware-kommatal"
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Use hardware transactional execution instructions."
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr ""
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 #, fuzzy
 #| msgid "Use bras for executable < 64k"
 msgid "Use bras for executable < 64k."
 msgstr "Benyt bras til kørbar fil < 64k"
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "Benyt hardware-kommatal"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr ""
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr ""
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 #| msgid "Generate string instructions for block moves"
 msgid "Use the mvcle instruction for block moves."
 msgstr "Generér strengoperationer til blokflytninger"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr ""
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr ""
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr ""
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -11498,11 +11498,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -11798,105 +11798,125 @@
 
 #: config/sparc/sparc.opt:86
 #, fuzzy
+#| msgid "Use vector/scalar (VSX) instructions"
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr "Benyt vektor/skalar-instruktioner (VSX)"
+
+#: config/sparc/sparc.opt:90
+#, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
 #, fuzzy
+#| msgid "Generate fused multiply/add instructions"
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Generér sammensatte gang/addér-instruktioner"
+
+#: config/sparc/sparc.opt:102
+#, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 #| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "Henvisninger er 64 bit"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 #| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "Henvisninger er 32 bit"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "Benyt 64 bit-API"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "Benyt 32 bit-API"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 #, fuzzy
 #| msgid "Use stack bias"
 msgid "Use stack bias."
 msgstr "Benyt stakafsæt"
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 #, fuzzy
 #| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Benyt strukturer på stærkere justering til dobbelt-ord kopier"
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 #, fuzzy
 #| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Optimér halekaldsinstruktioner i maskinkodeoversætteren og sammenkæderen"
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 #, fuzzy
 #| msgid "Do not generate code which uses the FPU"
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr "Generér ikke kode som bruger FPU'en"
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "Benyt faciliteter fra og planlæg koden til en given processor"
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 #, fuzzy
 #| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
 msgstr "Benyt given SPARC-V9-kodemodel"
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "Enable debug output."
 msgstr "Aktivér fejlanalyseringsuddata"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr ""
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -17557,7 +17577,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -18060,7 +18080,7 @@
 msgstr "forventet boolesk type"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "uventet operand"
@@ -18368,152 +18388,152 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 #| msgid "invalid operation on uninstantiated type"
 msgid "invalid comparison of non-ordered type"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 #| msgid "invalid option %s"
 msgid "invalid operation (%s)"
 msgstr "ugyldigt tilvalg %s"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 #| msgid "invalid application of `%s' to an incomplete type"
 msgid "invalid comparison of non-comparable type"
 msgstr "ugyldig anvendelse af '%s' på en ufuldstændig type"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 #| msgid "invalid operation on uninstantiated type"
 msgid "invalid comparison of generated struct"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of generated array"
 msgstr "ugyldig brug af en tabel der ikke kan optræde som en venstreværdi"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of non-comparable array"
 msgstr "ugyldig brug af en tabel der ikke kan optræde som en venstreværdi"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr ""
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, fuzzy, c-format
 #| msgid "cannot convert type `%T' to type `%T'"
 msgid "cannot use type %s as type %s"
 msgstr "kan ikke konvertere typen '%T' til typen '%T'"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 #, fuzzy
 #| msgid "different type"
 msgid "different receiver types"
 msgstr "anden type"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 #, fuzzy
 #| msgid "destructors take no parameters"
 msgid "different number of parameters"
 msgstr "destruktionsfunktioner kan ikke have parametre"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 #, fuzzy
 #| msgid "different type"
 msgid "different parameter types"
 msgstr "anden type"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 #, fuzzy
 #| msgid "different type"
 msgid "different varargs"
 msgstr "anden type"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 #, fuzzy
 #| msgid "different type"
 msgid "different result types"
 msgstr "anden type"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "incompatible type for method %s%s%s"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of `%s'"
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "typen af den %d. parameter i '%s' passer ikke"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 #, fuzzy
 #| msgid "error while parsing methods"
 msgid "type has no methods"
 msgstr "fejl ved tolkning af metoder"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, fuzzy, c-format
 #| msgid "ambiguous abbreviation %s"
 msgid "ambiguous method %s%s%s"
 msgstr "tvetydig forkortelse %s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "der mangler en parameter til tilvalget '-%s'"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -18704,7 +18724,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `va_start'"
 msgid "too few arguments to function %<va_start%>"
@@ -18773,29 +18793,29 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ugyldig tilstand for gen_tst_reg"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return understøttes ikke på målarkitekturen"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -18803,7 +18823,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -18810,12 +18830,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_longjmp second argument must be 1"
 msgid "%<__builtin_longjmp%> second argument must be 1"
@@ -18823,70 +18843,70 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "målprocessoren understøtter ikke uendelig"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "målprocessoren understøtter ikke uendelig"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, fuzzy, gcc-internal-format
 #| msgid "`va_start' used in function with fixed args"
 msgid "%<va_start%> used in function with fixed args"
 msgstr "`va_start' benyttet i en funktion med fast antal parametre"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `va_start'"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "for mange parametre til funktionen 'va_start'"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "`__builtin_next_arg' kaldt uden en parameter"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "forkert antal parametre angivet til egenskaben '%s'"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of `va_start' not last named argument"
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "den anden parameter til 'va_start' er ikke den sidste navngivne parameter"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `asm' is not a constant string"
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -19868,12 +19888,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F brugt, men aldrig defineret"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F erklæret %<static%>, men aldrig defineret"
@@ -19979,12 +19999,12 @@
 msgid "cannot find '%s'"
 msgstr "kan ikke finde '%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "åbner uddatafilen %s"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -19995,7 +20015,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -20219,7 +20239,7 @@
 msgid "error writing %qs"
 msgstr "fejl ved skrivning til %s"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "kan ikke åbne %s"
@@ -20304,17 +20324,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -20430,12 +20450,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
 
-#: expr.c:10811
+#: expr.c:10809
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "funktionen '%s' omerklæret med egenskaben noinline"
@@ -20452,13 +20472,13 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "%Jstørrelsen af '%D' er større end %d byte"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file `%s'"
 msgid "could not open final insn dump file %qs: %m"
 msgstr "kunne ikke åbne dumpningsfilen '%s'"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file `%s'"
 msgid "could not close final insn dump file %qs: %m"
@@ -20475,7 +20495,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "sammenligning er altid %d på grund af den begrænsede rækkevidde af bitfeltet"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -20508,7 +20528,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -20519,7 +20539,7 @@
 msgid "total size of local objects too large"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "impossible constraint in `asm'"
 msgid "impossible constraint in %<asm%>"
@@ -20624,67 +20644,73 @@
 msgid "input file %qs is the same as output file"
 msgstr "ingen inputfiler; vil ikke skrive outputfiler"
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, fuzzy, gcc-internal-format
+#| msgid "no input file specified"
+msgid "output filename may not be empty"
+msgstr "ingen inddatafiler angivet"
+
+#: gcc.c:4501
+#, fuzzy, gcc-internal-format
 #| msgid "warning: -pipe ignored because -save-temps specified"
 msgid "-pipe ignored because -save-temps specified"
 msgstr "advarsel: -pipe ignoreret fordi -save-temps er angivet"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, fuzzy, gcc-internal-format
 #| msgid "warning: `-x %s' after last input file has no effect"
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "advarsel: '-x %s' efter den sidste inddatafil har ingen effekt"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr ""
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "could not open dump file `%s'"
 msgid "could not open temporary response file %s"
 msgstr "kunne ikke åbne dumpningsfilen '%s'"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot create temporary file"
 msgid "could not write to temporary response file %s"
 msgstr "kan ikke oprette midlertidig fil"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "could not open dump file `%s'"
 msgid "could not close temporary response file %s"
 msgstr "kunne ikke åbne dumpningsfilen '%s'"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr ""
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr ""
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr ""
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr ""
@@ -20692,247 +20718,247 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, fuzzy, gcc-internal-format
 #| msgid "spec failure: '%%*' has not been initialized by pattern match"
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "specifikationsfejl: '%%*' er ikke blevet klargjort af mønstersøgning"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, fuzzy, gcc-internal-format
 #| msgid "spec failure: unrecognized spec option '%c'"
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "specifikationsfejl: ukendt specifikationstilvalg '%c'"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown spec function `%s'"
 msgid "unknown spec function %qs"
 msgstr "ukendt specifikationsfunktion '%s'"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function `%s'"
 msgid "error in args to spec function %qs"
 msgstr "fejl i parametre til specifikationsfunktion '%s'"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "forkert udformet specifikationsfunktionsnavn"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "ingen parametre til specifikationsfunktion"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "forkert udformede specifikationsfunktionsparametre"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, fuzzy, gcc-internal-format
 #| msgid "Zero-size specification invalid at %0"
 msgid "braced spec %qs is invalid at %qc"
 msgstr "Nulstørrelses angivelse ugyldig ved %0"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr ""
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "could not determine date and time"
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "kunne ikke bestemme dato og tid"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "Kunne ikke åbne uddatafilen %s.\n"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr ""
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr ""
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "ingen inddatafiler"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, fuzzy, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "kan ikke angive -o med -c eller -S og flere oversættelser"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: %s-oversætter ikke installeret på dette system"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr ""
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always %d"
 msgid "comparing final insns dumps"
 msgstr "sammenligning er altid %d"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "library lib%s not found"
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "biblioteket lib%s ikke fundet"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: sammenkæderinddatafil ikke benyttet eftersom sammenkædning ikke blev foretaget"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "sproget %s ikke genkendt"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "multilib spec %qs is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr ""
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr ""
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "multilib select %qs is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr ""
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable %qs not defined"
 msgstr "miljøvariablen DJGPP er ikke defineret"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number format"
 msgid "invalid version number %qs"
 msgstr "ugyldigt versionsnummerformat"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to %%:version-compare"
 msgstr "for få parametre til funktionen"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to %%:version-compare"
 msgstr "for mange parametre til funktionen"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr ""
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "for mange parametre til formatering"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "for mange parametre til formatering"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments for format"
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "for få parametre til formatering"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "for mange parametre til formatering"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to %%:replace-extension"
 msgstr "for få parametre til funktionen"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %%:debug-level-gt"
@@ -21081,9 +21107,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "declared here"
@@ -21514,246 +21540,246 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "using result of function returning %<void%>"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid lvalue in asm statement"
 msgid "invalid lvalue in asm output %d"
 msgstr "ugyldig venstreværdi i asm-sætning"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "output number %d not directly addressable"
 msgid "memory input %d is not directly addressable"
 msgstr "uddata nr. %d kan ikke adresseres direkte"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qE not specified in enclosing %qs"
 msgstr "'%D' ikke erklæret"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "fejl ved lukning af %s: %m"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, fuzzy, gcc-internal-format
 #| msgid "In construct"
 msgid "enclosing OpenACC %qs construct"
 msgstr "I konstruktionen"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "'%s' er ikke erklæret (først benyttet i denne funktion)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variablen '%s' er erklæret 'inline'"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should be private"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qE should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be linear"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "iteration variable %qE should not be private"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid member template declaration `%D'"
 msgid "invalid private reduction on %qE"
 msgstr "ugyldig medlemsskabelonerklæring '%D'"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "antallet af resultater matcher ikke antallet af værdier"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr ""
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is promoted to `%s' when passed through `...'"
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "'%s' forfremmes til '%s' ved overbringelse gennem '...'"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, fuzzy, gcc-internal-format
 #| msgid "(so you should pass `%s' not `%s' to `va_arg')"
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(så du skal overbring '%s' ikke '%s' til 'va_arg')"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -22008,7 +22034,7 @@
 
 #: ipa-devirt.c:1229
 #, fuzzy, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "tidligere definition her"
 
 #: ipa-devirt.c:1235
@@ -22113,9 +22139,10 @@
 msgstr ""
 
 #: ipa-devirt.c:1576
-#, gcc-internal-format
-msgid "fields has different layout in another translation unit"
-msgstr ""
+#, fuzzy, gcc-internal-format
+#| msgid "no file specified with -fdump-translation-unit"
+msgid "fields have different layout in another translation unit"
+msgstr "ingen filer angivet med -fdump-translation-unit"
 
 #: ipa-devirt.c:1599
 #, gcc-internal-format
@@ -22523,197 +22550,197 @@
 msgid "multiple loop axes specified for routine"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, fuzzy, gcc-internal-format
 #| msgid "directives may not be used inside a macro argument"
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr "direktiver må ikke optræde inden i en makroparameter"
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, fuzzy, gcc-internal-format
 #| msgid "In construct"
 msgid "orphaned %qs construct"
 msgstr "I konstruktionen"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr ""
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, fuzzy, gcc-internal-format
 #| msgid "directives may not be used inside a macro argument"
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr "direktiver må ikke optræde inden i en makroparameter"
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid arguments"
 msgstr "ugyldig typeparameter"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, fuzzy, gcc-internal-format
 #| msgid "directives may not be used inside a macro argument"
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr "direktiver må ikke optræde inden i en makroparameter"
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr ""
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of `%s' attribute"
 msgid "invalid entry to %s structured block"
@@ -22720,7 +22747,7 @@
 msgstr "ugyldig parameter til egenskaben '%s'"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
@@ -22808,7 +22835,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "der mangler en parameter til tilvalget '-%s'"
@@ -22971,133 +22998,145 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
+#, fuzzy, gcc-internal-format
+#| msgid "-traditional is not supported in C++"
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "-traditional understøttes ikke i C++"
+
+#: opts.c:1015
+#, fuzzy, gcc-internal-format
+#| msgid "-traditional is not supported in C++"
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "-traditional understøttes ikke i C++"
+
+#: opts.c:1417
 #, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.c:1837
+#: opts.c:1844
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "ignorerer kommandolinjetilvalget '%s'"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "alignment must be a small power of two, not %d"
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "justering skal være en lille potens af to, ikke %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown stack check parameter %qs"
 msgstr "ukendt registernavn: %s"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "dwarf version %d is not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: »--param«-parametre skal være på formen NAVN=VÆRDI"
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "ugyldig »--param«-værdi %qs"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs"
 msgstr "ugyldig »--param«-værdi %qs"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "ugyldig »--param«-værdi %qs"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "målsystemet understøtter ikke fejlfindingsuddata"
 
-#: opts.c:2513
+#: opts.c:2520
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "fejlsøgningsformatet %qs er i modstrid med tidligere valg"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level %qs"
 msgid "unrecognized debug output level %qs"
 msgstr "ukendt fejlsøgningsuddataniveau %qs"
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "fejlsøgningsuddataniveau %qs er for højt"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "henter maksimumbegrænsning på kernefilens størrelse: %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "angiver kernefilens størrelsesbegrænsning til maksimum: %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "ukendt GCC-fejlfindingstilvalg: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: intet tilvalg -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -23445,7 +23484,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "register for %qD brugt til flere globale registervariabler"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "er i konflikt med %qD"
@@ -24055,13 +24094,13 @@
 msgid "error closing %s: %m"
 msgstr "fejl ved lukning af %s: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 #| msgid "%s from incompatible pointer type"
 msgid "self-tests incompatible with -E"
 msgstr "%s fra en henvisningstype der ikke er forenelig med målets"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -25055,50 +25094,50 @@
 msgid "in expansion of macro %qs"
 msgstr "ingen parametre givet til makroen '%s'"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`B' operand has multiple bits set"
 msgid "BB %i has multiple EH edges"
 msgstr "'B'-operanden har flere bit sat"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i too many fallthru edges"
 msgstr "forkert instruktion i fald-gennem-kant"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i has incorrect fallthru edge"
@@ -25203,33 +25242,33 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "in a call to built-in function %qD"
 msgstr "for mange parametre til funktionen '%s'"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "Ugyldig erklæring"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "mistet loopoptimering, looptælleren kan løbe over"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "within this loop"
@@ -25600,11 +25639,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -26620,7 +26659,7 @@
 msgid "type was previously declared %qE"
 msgstr "'%s' tidligere erklæret her"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -26920,7 +26959,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "adressen af '%D' vil altid være 'true'"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "foreslår paranteser omkring tildeling der er benyttet som boolsk værdi"
@@ -27609,67 +27648,67 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "ekstra typemodifikationer i formateringsparameter (parameter %d)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "'%s' forventer en konstant parameter"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "'%s' forventer en konstant parameter"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%<locus%> is not defined as a type"
 msgstr "\"%s\" er ikke defineret"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%<tree%> is not defined as a type"
 msgstr "\"%s\" er ikke defineret"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, fuzzy, gcc-internal-format
 #| msgid "args to be formatted is not '...'"
 msgid "args to be formatted is not %<...%>"
 msgstr "parametrene der skal formateres, er ikke '...'"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime-formater kan ikke formatere parametre"
@@ -27780,7 +27819,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr ""
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, fuzzy, gcc-internal-format
 #| msgid "possible start of unterminated string literal"
 msgid "unsupported non-standard concatenation of string literals"
@@ -27813,7 +27852,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid type for iteration variable %qE"
@@ -27831,25 +27870,25 @@
 msgid "%qE is not initialized"
 msgstr "manglende startværdi"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, fuzzy, gcc-internal-format
 #| msgid "missing '(' after predicate"
 msgid "missing controlling predicate"
 msgstr "manglende '(' efter udsagn"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid controlling predicate"
 msgstr "Ugyldigt kontroludtryk"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "missing ')' in expression"
 msgid "missing increment expression"
 msgstr "manglende ')' i udtryk"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid control expression"
 msgid "invalid increment expression"
@@ -28445,8 +28484,8 @@
 msgid "wrong type argument to %s"
 msgstr "forkert parametertype til %s"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overløb i konstant udtryk"
@@ -29186,7 +29225,7 @@
 msgid "this condition has identical branches"
 msgstr "betingelsen begyndte her"
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' cannot be used as a function"
 msgid "%<_Cilk_spawn%> may only be used inside a function"
@@ -29354,7 +29393,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "ukendt tilvalg -mdebug-%s"
@@ -29699,7 +29738,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "parameteren til 'asm' er ikke en konstant streng"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -29791,7 +29830,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "ukendt værdi %qs for -mtune"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
@@ -29886,9 +29925,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not a string constant"
 msgid "attribute %<target%> argument not a string"
@@ -29986,7 +30025,7 @@
 msgstr "ugyldig værdi '%s' for -mmemory-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -30181,237 +30220,237 @@
 msgid "insn addresses not freed"
 msgstr "præfiks forøgelsesadresse er ikke et register"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "this builtin is not supported for this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "vælger skal være en umiddelbar værdi"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, fuzzy, gcc-internal-format
 #| msgid "-msystem-v and -p are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-msystem-v og -p er indbyrdes uforenelige"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support APCS-32"
 msgid "target CPU does not support ARM mode"
 msgstr "målprocessoren understøtter ikke APCS-32"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "aktivering af tilbagesporingsunderstøttelse giver kun mening ved oversættelse for en Thumb"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "aktivering af interarbejdeunderstøttelse for kaldte objekter giver kun mening ved oversættelse for en Thumb"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g med -mno-apcs-frame giver måske ikke fornuftig fejlanalysering"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support unaligned accesses"
@@ -30419,148 +30458,148 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-mpcrel -fPIC is not currently supported on selected cpu"
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mpcrel -fPIC er i øjeblikket ikke understøttet på valgt cpu"
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic og -mapcs-reent er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS-genindtrædelig kode er ikke understøttet - ignoreret"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable og -msdata=%s er indbyrdes uforenelige"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "målprocessoren understøtter ikke interarbejde"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr ""
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to 8 or 32"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "strukturstørrelsesgrænse kan kun sættes til 8 eller 32"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "strukturstørrelsesgrænse kan kun sættes til 8 eller 32"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr ""
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= er ubrugelig uden -fpic"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "kan ikke bruge '%s' til PIC-register"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-fdata-sections understøttes ikke på målarkitekturen"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "målprocessoren understøtter ikke THUMB-instruktioner"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -30569,79 +30608,84 @@
 msgid "%qE attribute only applies to functions"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' must take either one or two arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "'%D' skal tage mod én eller to parametre"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to functions"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
+#, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, fuzzy, gcc-internal-format
 #| msgid "line number out of range"
 msgid "%s %wd out of range %wd - %wd"
 msgstr "linjenummer er uden for det gyldige interval"
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan ikke beregne virkelig placering af stakkede parametre"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "ingen lave registre er tilgængelige til at modtage værdier fra høje registre"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid vector type for attribute `%s'"
 msgid "invalid fpu for attribute(target(\"%s\"))"
@@ -30650,13 +30694,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
@@ -30764,178 +30808,190 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "`-%c' option must have argument"
 msgid "%qs function cannot have arguments"
 msgstr "tilvalget '-%c' skal have en parameter"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "function cannot be inline"
 msgid "%qs function cannot return a value"
 msgstr "funktion kan ikke indbygges"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "Antallet af registre der skal bruges til at overbringe heltalsparametre"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "sektionsegenskaber understøttes ikke på denne målarkitektur"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute does not apply to types"
 msgid "%qE attribute address out of range"
 msgstr "egenskaben '%s' kan ikke anvendes på typer"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, fuzzy, gcc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "integrerede funktioner understøttes ikke for denne returværditype"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, fuzzy, gcc-internal-format
 #| msgid "code model `%s' not supported in the %s bit mode"
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "kodemodellen %s er ikke understøttet i %s bit-tilstand"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "kun variabler uden startværdi kan placeres i .noinit-sektionen"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "kun variabler med startværdi kan placeres i programhukommelsesområdet"
+
+#: config/avr/avr.c:10160
+#, fuzzy, gcc-internal-format
+#| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "kun variabler med startværdi kan placeres i programhukommelsesområdet"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 #| msgid "MCU `%s' supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU '%s' understøttes kun for maskinkode"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "case label does not reduce to an integer constant"
 msgid "%s expects a compile time integer constant"
 msgstr "case-etiketten kan ikke reduceres til en heltalskonstant"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -31222,13 +31278,13 @@
 msgid "invalid IACC argument"
 msgstr "ugyldig IACC-parameter"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' expects a constant argument"
 msgid "%qs expects a constant argument"
 msgstr "'%s' forventer en konstant parameter"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "constant argument out of range for %qs"
@@ -31415,7 +31471,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodemodellen %qs er ikke understøttet i x32-tilstand"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodemodellen %s understøtter ikke PIC-tilstand"
@@ -31560,292 +31616,292 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "typen antages at være 'int' i erklæringen af '%s'"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-arrays understøttes ikke på målarkitekturen"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d er ikke mellem %d og 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s er ikke forenelig med den valgte ABI"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-instruktionssæt deaktiveret, bruger 387-beregninger"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-instruktionssæt deaktiveret, bruger SSE-beregninger"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unknown cpu: -mcpu=%s"
 msgid "unknown option for -mrecip=%s"
 msgstr "Ukendt processor: -mcpu=%s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "%s-instruktioner er ikke tilladt i %s-tjenesterutinen"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall og regparm er indbyrdes uforenelige"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-egenskaben kræver en heltalskonstant som parameter"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "parameter til %qE-egenskaben er større end %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall og cdecl er indbyrdes uforenelige"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall og fastcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl og thiscall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-egenskaben bruges til ikke-klasse metode"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 understøtter ikke egenskaben ms_abi"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue er ikke forenelig med den indlejrede funktion"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -31852,335 +31908,335 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "størrelse er ikke understøttet for heltalsregister"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "udvidede registre har ikke høje halvdele"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ikke-understøttet operandstørrelse for udvidede registre"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No case for %s"
 msgid "No dispatcher found for %s"
 msgstr "Ingen case for %s"
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %D"
 msgstr "'%D' er tidligere erklæret"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 #| msgid "argument to dss must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "parameter til dss skal være en 2 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "skifteværdi skal være en umiddelbar værdi"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option %s"
 msgid "%qE needs isa option %s"
 msgstr "ugyldigt tilvalg %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "maske skal være en umiddelbar værdi"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "ukorrekt instruktion:"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "fastcall og stdcall er indbyrdes uforenelige"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "uforenelig egenskab '%s' ignoreret"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "afbrydelsesservicerutiner kan ikke kodes i Thumb-tilstand"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown register name: %s"
 msgid "unknown asm flag output %qs"
 msgstr "ukendt registernavn: %s"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for make function"
 msgid "invalid type for asm flag output"
 msgstr "ugyldig type for make-funktion"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "versionen er ikke understøttet"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "ubenyttede parametre i formatering med $"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -32303,7 +32359,7 @@
 msgid "argument %qd is not a constant"
 msgstr "parameteren %qd er ikke en konstant"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, nul-henvisning"
@@ -32313,7 +32369,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: Ukendt tegnsætning »%c«"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND nul-henvisning"
@@ -32420,7 +32476,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread er kun tilgængelig på fido"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stakgrænseudtryk understøttes ikke"
@@ -32955,8 +33011,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
 msgid "bad builtin code"
@@ -33229,28 +33285,28 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute requires a void return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -33277,7 +33333,7 @@
 msgid "-g option disabled"
 msgstr "tilvalget -g deaktiveret"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
@@ -33421,168 +33477,168 @@
 msgid "junk at end of #pragma longcall"
 msgstr "ragelse i slutningen af #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr er forældet for lilleendet; brug opgave for ikke justerede indlæsninger og lagre"
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "vec_extract only accepts 2 arguments"
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_extract accepterer kun 2 parametre"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_insert accepterer kun 3 parametre"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_insert accepterer kun 3 parametre"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_insert accepterer kun 3 parametre"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s accepterer kun %d parametre"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s accepterer kun 1 parameter"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s accepterer kun 2 parametre"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract accepterer kun 2 parametre"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert accepterer kun 3 parametre"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 #| msgid "cast from `%T' to `%T' discards qualifiers from pointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "typeomtvingning fra '%T' til '%T' kasserer modifikationer på henvisningsmålets type"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid register in the instruction"
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "ugyldigt register i instruktionen"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, fuzzy, gcc-internal-format
 #| msgid "-maix64 requires PowerPC64 architecture remain enabled"
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-maix64 kræver at PowerPC64-arkitekturen forbliver aktiveret"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, fuzzy, gcc-internal-format
 #| msgid "Do not compile for v8plus ABI"
 msgid "not configured for SPE ABI"
 msgstr "Oversæt ikke for v8plus-ABI"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use PowerPC instruction set"
 msgid "not configured for SPE instruction set"
 msgstr "Benyt ikke PowerPC-instruktionssættet"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
 msgstr "stakgrænser understøttes ikke på målarkitekturen"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, fuzzy, gcc-internal-format
 #| msgid "Profiling is not supported on this target."
 msgid "SPE not supported in this target"
 msgstr "Profilering er ikke understøttet på målarkitekturen."
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple er ikke understøttet på lilleendede systemer"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring er ikke understøttet på lilleendede systemer"
@@ -33589,74 +33645,74 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "Udsend kode der er kompatibel med TI-værktøjer"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mdirect-move requires -mvsx"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-vector requires -mvsx"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode requires -mvsx"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, fuzzy, gcc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "-mtoc-fusion requires -mpower8-fusion"
@@ -33666,246 +33722,246 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode might need -mlra"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr "--resource påkræver -o"
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs er ikke et gyldigt tilvalg til præprocessoren"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. parameter skal være en 5 bit-konstant med fortegn"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "1. parameter til __builtin_altivec_predicate skal være en konstant"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "1. parameter til __builtin_altivec_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %s only accepts a string argument"
@@ -33912,7 +33968,7 @@
 msgstr "%s accepterer kun 1 parameter"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "cpu %s is an invalid argument to builtin %s"
@@ -33919,305 +33975,310 @@
 msgstr "#%s med ugyldig parameter"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "#%s with invalid argument"
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "#%s med ugyldig parameter"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. parameter skal være en 5 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "tal skal enten være 0 eller 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be in the range 0..15"
 msgstr "3. parameter skal være en 4 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' must be a 2-bit unsigned literal"
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "parameter til dss skal være en 2 bit-konstant uden fortegn"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third arg to `__builtin_prefetch' must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "en tredje parameter til '__builtin_prefetch' skal være en konstant"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "1. parameter til __builtin_spe_predicate skal være en konstant"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "1. parameter til __builtin_spe_predicate er uden for det gyldige interval"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "a -ifile option requires a -map option"
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "et '-ifile'-tilvalg kræver et '-map'-tilvalg"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "inline functions not supported for this return value type"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "integrerede funktioner understøttes ikke for denne returværditype"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, fuzzy, gcc-internal-format
 #| msgid "stack frame too big"
 msgid "stack frame too large"
 msgstr "stakramme for stor"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, fuzzy, gcc-internal-format
 #| msgid "-mips%d does not support 64 bit fp registers"
 msgid "-fsplit-stack uses register r29"
 msgstr "-mips%d understøtter ikke 64-bit kommatalsregistre"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC-målarkitektur er ikke understøttet på denne maskine"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering af 64 bit-kode for denne ABI"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "\"%s\" is not defined"
 msgid "%s\"%s\"%s is not allowed"
 msgstr "\"%s\" er ikke defineret"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mno-power9-vector turns off -mpower9-dform"
@@ -34410,6 +34471,7 @@
 msgstr "-mapcs-stack-check og -mno-apcs-frame er indbyrdes uforenelige"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, fuzzy, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-maix64 kræver at PowerPC64-arkitekturen forbliver aktiveret"
@@ -34501,7 +34563,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument `%s'"
 msgid "constant value required for builtin %qF argument %d"
@@ -34530,9 +34592,10 @@
 msgstr "--resource påkræver -o"
 
 #: config/s390/s390-c.c:889
-#, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
-msgstr ""
+#, fuzzy, gcc-internal-format
+#| msgid "--resource requires -o"
+msgid "%qF requires z14 or higher"
+msgstr "--resource påkræver -o"
 
 #: config/s390/s390-c.c:903
 #, gcc-internal-format
@@ -34552,9 +34615,10 @@
 msgstr "tvetydig konvertering af tabelindeks"
 
 #: config/s390/s390-c.c:966
-#, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
-msgstr ""
+#, fuzzy, gcc-internal-format
+#| msgid "`%s' is deprecated"
+msgid "%qs matching variant requires z14 or higher"
+msgstr "'%s' er forældet"
 
 #: config/s390/s390-c.c:972
 #, fuzzy, gcc-internal-format
@@ -34568,40 +34632,40 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for `%s'"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "konstant parameter uden for det gyldige interval for '%s'"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "unresolved overloaded builtin"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
@@ -34608,124 +34672,124 @@
 msgid "bad builtin icode"
 msgstr "ugyldig indbygget fcode"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "for mange parametre til funktionen"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, fuzzy, gcc-internal-format
 #| msgid "Total size of local variables exceeds architecture limit."
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Total størrelse af lokale variable overstiger arkitekturgrænsen."
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsize of '%D' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "%Jstørrelsen af '%D' er %d byte"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "fældetilstand understøttes ikke på Unicos/Mk"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, fuzzy, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "kodemodellen %s er ikke understøttet i PIC-tilstand"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware vector support not available on %s"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "Use hardware floating point instructions"
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Benyt hardware-kommatalsinstruktioner"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "parameter til '%s' skal være en 2 bit-konstant uden fortegn"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 #| msgid "argument to `%s' attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
@@ -34732,7 +34796,7 @@
 msgstr "parameter til egenskaben '%s' er større end %d"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_trap not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -34795,27 +34859,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-g er kun understøttet ved brug af GAS på denne processor,"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 er ikke tilladt med -m64"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "ugyldig værdi (%s) til tilvalget -mcmodel="
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= understøttes ikke på 32 bit-systemer"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "-fcall-saved-REG is not supported for out registers"
@@ -35125,22 +35190,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "ugyldig #pragma %s"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "booleske registre er påkrævet til kommatalsindstillingen"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "%s understøttes ikke af denne konfiguration"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "kun variabler uden startværdi kan placeres i .bss-sektionen"
@@ -35235,7 +35300,7 @@
 msgid "could not read the BRIG file"
 msgstr "kunne ikke finde specifikationsfilen %s\n"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument `%s'"
@@ -35673,9 +35738,9 @@
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%qD declared here"
@@ -35814,7 +35879,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -36968,7 +37033,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "mere end én datatype i erklæringen af '%s'"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
@@ -37129,17 +37194,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C understøtter ikke at blot 'complex' betyder 'double complex'"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C understøtter ikke komplekse heltalstyper"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -37193,7 +37258,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, fuzzy, gcc-internal-format
 #| msgid "garbage at end of #line"
 msgid "expected end of line"
@@ -37239,7 +37304,7 @@
 msgstr "ukendt registernavn: %s"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of unit `%s'"
 msgid "expected declaration specifiers"
@@ -37256,7 +37321,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored for methods"
@@ -37273,8 +37338,8 @@
 msgid "unexpected attribute"
 msgstr "uventet operand"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "sektionsegenskaben er ikke tilladt for '%s'"
@@ -37312,7 +37377,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -37342,7 +37407,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 #| msgid "_Pragma takes a parenthesized string literal"
 msgid "expected string literal"
@@ -37414,14 +37479,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "uventet operand"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutningen af enum-liste"
@@ -37568,7 +37633,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -37594,12 +37659,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -37613,17 +37678,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "uventet operand"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "tom krop i en else-sætning"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
@@ -37634,7 +37699,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous `else'"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -37657,7 +37722,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ugyldigt register i instruktionen"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -37852,18 +37917,18 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "operander til ?: har forskellige typer"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -37922,62 +37987,62 @@
 msgid "no type or storage class may be specified here,"
 msgstr "lagringsklasse angivet for typenavn"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "en dataområdeegenskab kan ikke angives for lokale variable"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "'#pragma once' i hovedfil"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
@@ -37992,13 +38057,13 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 #| msgid "']' expected, invalid type expression"
 msgid "expected integer expression before ')'"
@@ -38016,60 +38081,60 @@
 msgid "%qD is not a variable"
 msgstr "'%D' er ikke et navnerum"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a pointer-to-object type"
 msgid "%qD is not a pointer variable"
 msgstr "'%T' er ikke af en henvisning til objekt-type"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<none%>"
 msgstr "forventede %<new%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "forventede %<catch%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "for mange inddatafiler"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -38098,24 +38163,24 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "forventede %<throw%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "uventet operand"
@@ -38125,63 +38190,63 @@
 msgid "%<num_workers%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "for mange parametre"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "unexpected argument"
 msgstr "uventet operand"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%qs value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "parameteren til egenskaben '%s' er ikke en heltalskonstant"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "sammenlign mellem signed og unsigned heltalsudtryk"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "chunk size value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -38196,17 +38261,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -38226,19 +38291,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "ugyldig %%d-operand"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "ugyldig maske"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ugyldig roteringsinstruktion"
@@ -38249,69 +38314,69 @@
 msgid "invalid proc_bind kind"
 msgstr "ugyldig roteringsinstruktion"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s understøtter ikke %s"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of \"%s\" shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' skygger for en global erklæring"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "erklæring af '%s' der er en 'extern'-variabel, i begyndelseserklæring i 'for'-løkke"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma once in main file"
 msgid "%<#pragma acc %s data%> has no data movement clause"
@@ -38328,7 +38393,7 @@
 msgid "expected function name"
 msgstr "forventet funktion"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a function"
@@ -38339,47 +38404,47 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid #pragma %s"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ugyldig #pragma %s"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand for 'p' modifier"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ugyldig operand til 'p'-ændring"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -38389,29 +38454,29 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "for statement expected"
 msgstr "')' eller term forventet"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 #| msgid "')' or term expected"
 msgid "_Cilk_for statement expected"
 msgstr "')' eller term forventet"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "repeated declaration of automaton `%s'"
 msgid "expected iteration declaration or initialization"
@@ -38422,73 +38487,73 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "typedef-navn kan ikke klassemodificeres"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<point%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -38503,7 +38568,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -38513,32 +38578,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "uventet operand"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -38594,22 +38659,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parameteren er af en ufuldstændig type"
@@ -38624,54 +38689,54 @@
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "vectorlength must be an integer constant"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "angivet justering er ikke en potens af 2"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -38682,7 +38747,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected %<:%> or numeral"
@@ -39488,7 +39553,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "return type might be a candidate for a format attribute"
@@ -39853,7 +39918,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C forbyder 'goto *udtryk;'"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, fuzzy, gcc-internal-format
 #| msgid "function declared `noreturn' has a `return' statement"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -39865,7 +39930,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "kommaudtryk benyttet til at klargøre returværdi"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -39894,7 +39959,7 @@
 msgid "function returns address of label"
 msgstr "funktion returnerer adressen på en lokal variabel"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-størrelsen er ikke et heltal"
@@ -39911,7 +39976,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etiket befinder sig ikke inden i en switch-sætning"
@@ -39932,17 +39997,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sætning befinder sig ikke i en løkke"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
@@ -39954,7 +40019,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
@@ -40071,12 +40136,12 @@
 msgid "used vector type where scalar is required"
 msgstr "værdi af struct-type angivet hvor skalar er påkrævet"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -40087,28 +40152,28 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%s' has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %qs clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
@@ -40121,18 +40186,18 @@
 msgstr "bitfeltet '%s' er af en ufuldstændig type"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -40139,54 +40204,54 @@
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Intern oversætterfejl i %s ved %s:%d."
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
@@ -40210,7 +40275,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "brug af '%D' er tvetydigt"
@@ -40220,17 +40285,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -40250,20 +40315,20 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -40275,34 +40340,34 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -40324,55 +40389,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE er ikke en variable i %<depend%>-klausul"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD fremgår mere end en gang i motion-klausuller"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD fremgår mere end en gang i map-klausuller"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har ikke en mappable-type i %qs-klausul"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE er hverken en variabel eller et funktionsnavn i klausul %qs"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -40383,32 +40448,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -41003,167 +41068,167 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' as `this' argument of `%#D' discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "videregivelse af '%T' som 'this'-parameteren til '%#D' forkaster modifikationer"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, fuzzy, gcc-internal-format
 #| msgid "  in call to `%D'"
 msgid "  in call to %qD"
 msgstr "  i kald af '%D'"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "'%T' er en utilgængelig stamklasse til '%T'"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s `%+#D'"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "for mange parametre til %s '%+#D'"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktionsfunktioner kan ikke erklæres virtual"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call destructor `%T::~%T' without object"
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan ikke kalde destruktionsfunktion '%T::~%T' uden objekt"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "ingen passende funktion for kald til '%T::%D(%A)%#V'"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to `%D(%A)'"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen passende funktion for kald til '%D(%A)'"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "kald af flertydig '%D(%A)' er tvetydigt"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, fuzzy, gcc-internal-format
 #| msgid "cannot call member function `%D' without object"
 msgid "cannot call member function %qD without object"
 msgstr "kan ikke kalde medlemsfunktionen '%D' uden et objekt"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, fuzzy, gcc-internal-format
 #| msgid "passing `%T' chooses `%T' over `%T'"
 msgid "passing %qT chooses %qT over %qT"
 msgstr "videregivelse af '%T' vælger '%T' frem for '%T'"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, fuzzy, gcc-internal-format
 #| msgid "choosing `%D' over `%D'"
 msgid "choosing %qD over %qD"
 msgstr "vælger '%D' frem for '%D'"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, fuzzy, gcc-internal-format
 #| msgid "  for conversion from `%T' to `%T'"
 msgid "  for conversion from %qT to %qT"
 msgstr "  for konvertering fra '%T' til '%T'"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  fordi konverteringssekvensen for parameteren er bedre"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "standardparameter angivet i eksplicit specialisering"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr "candidate%s: %+#D"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ifølge ISO C++ er '%D' og '%D' tvetydigt selvom den værste konvertering for førstnævnte er bedre end den værste konvertering for den sidstnævnte"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert `%E' to `%T'"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "kunne ikke konvertere '%E' til '%T'"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "ugyldig const_cast af en højreværdi fra typen '%T' til typen '%T'"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
@@ -41275,19 +41340,19 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "kan ikke konvertere fra stamklassen '%T' til den nedarvede type '%T' via den virtuelle stamklasse '%T'"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, fuzzy, gcc-internal-format
 #| msgid "all member functions in class `%T' are private"
 msgid "all member functions in class %qT are private"
 msgstr "alle medlemsfunktioner i klassen '%T' er private"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' only defines a private destructor and has no friends"
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "'%#T' definerer kun en privat destruktionsfunktion og har ingen venner"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' only defines private constructors and has no friends"
 msgid "%q#T only defines private constructors and has no friends"
@@ -41294,295 +41359,295 @@
 msgstr "'%#T' definerer kun private konstruktionsfunktioner og har ingen venner"
 
 # %D er en funktion
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, fuzzy, gcc-internal-format
 #| msgid "no unique final overrider for `%D' in `%T'"
 msgid "no unique final overrider for %qD in %qT"
 msgstr "ingen unik endelig overskrivning af '%D' i '%T'"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' and `%#D' cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "'%#D' og '%#D' kan ikke flertydiggøres"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was hidden"
 msgid "%qD was hidden"
 msgstr "'%D' var skjult"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "  by `%D'"
 msgid "  by %qD"
 msgstr "  af '%D'"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "'%#D' er ugyldig; en anonym union kan kun have ikke-statiske datamedlemmer"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "private member `%#D' in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "privat medlem '%#D' i en anonym union"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 #| msgid "private member `%#D' in anonymous union"
 msgid "private member %q#D in anonymous struct"
 msgstr "privat medlem '%#D' i en anonym union"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "protected member %q#D in anonymous struct"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%#D' with non-integral type"
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field `%D' width not an integer constant"
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bredden af bitfeltet '%D' er ikke en heltalskonstant"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, fuzzy, gcc-internal-format
 #| msgid "negative width in bit-field `%D'"
 msgid "negative width in bit-field %q+D"
 msgstr "negativ bredde i bitfeltet '%D'"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, fuzzy, gcc-internal-format
 #| msgid "zero width for bit-field `%D'"
 msgid "zero width for bit-field %q+D"
 msgstr "en bredde på nul for bitfeltet '%D'"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of `%D' exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "bredden af '%D' overstiger typen"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is too small to hold all values of `%#T'"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "'%D' er for lille til at indeholde alle værdierne af '%#T'"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with constructor not allowed in union"
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "medlemmet '%#D' med en konstruktionsfunktion er ikke tilladt i en union"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with destructor not allowed in union"
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "medlemmet '%#D' med en destruktionsfunktion er ikke tilladt i en union"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, fuzzy, gcc-internal-format
 #| msgid "member `%#D' with copy assignment operator not allowed in union"
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "medlemmet '%#D' med en kopitildelingsoperator er ikke tilladt i en union"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' invalidly declared function type"
 msgid "field %q+D invalidly declared function type"
 msgstr "feltet '%D' er på ugyldig vis erklæret som en funktionstype"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' invalidly declared method type"
 msgid "field %q+D invalidly declared method type"
 msgstr "feltet '%D' er på ugyldig vis erklæret som en medlemsfunktionstype"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "member `%D' cannot be declared both virtual and static"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "medlemmet '%D' kan ikke afklæres både virtual og static"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "non-member `%s' cannot be declared `mutable'"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "'%s' som ikke er medlem, kan ikke erklæres 'mutable'"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, fuzzy, gcc-internal-format
 #| msgid "multiple fields in union `%T' initialized"
 msgid "multiple fields in union %qT initialized"
 msgstr "flere felter i union '%T' tildeles startværdi"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field `%#D' with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "felt '%#D' med samme navn som klassen"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has pointer data members"
 msgid "%q#T has pointer data members"
 msgstr "'%#T' har henvisningsdatamedlemmer"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override `%T(const %T&)'"
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  men overskriver ikke '%T(const %T&)'"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, fuzzy, gcc-internal-format
 #| msgid "  or `operator=(const %T&)'"
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eller 'operator=(const %T&)'"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, fuzzy, gcc-internal-format
 #| msgid "  but does not override `operator=(const %T&)'"
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  men overskriver ikke 'operator=(const %T&)'"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "assignment (not initialization) in declaration"
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "tildeling (ikke klargøring) i erklæring"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-virtual method `%D'"
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "startværdi angivet for ikke-virtuel medlemsfunktion '%D'"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%q+T is not literal because:"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 #| msgid "invalid in-class initialization of static data member of non-integral type `%T'"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "ugyldig tildeling af startværdi i klasse til statisk datamedlem af en ikke-heltalstype '%T'"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' has no non-static data member named `%D'"
 msgid "  non-static data member %qD has volatile type"
 msgstr "'%T' har intet ikke-statisk medlem ved navn '%D'"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "base class `%#T' has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "stamklassen '%#T' har en ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference `%#D' in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "ikke-statisk reference '%#D' i klasse uden en konstruktionsfunktion"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member `%#D' in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -41590,170 +41655,170 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, fuzzy, gcc-internal-format
 #| msgid "direct base `%T' inaccessible in `%T' due to ambiguity"
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "virtual base `%T' inaccessible in `%T' due to ambiguity"
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuel stamklasse '%T' er ikke tilgængelig i '%T' på grund af tvetydighed"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "offset of `%D' is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "afsættet for '%D' følger ikke ABI'en og kan ændre sig i en fremtidig version af GCC"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%s' is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "størrelsen af tabellen '%s' er for stor"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ugyldig brug af %<...%> med ikke-skive"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ugyldig brug af struktur med fleksibelt tabelmedlem"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "array member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "in the definition of %q#T"
 msgstr "omdefinering af '%#T'"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "fleksibelt tabelmedlem ikke i slutningen af struktur"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "fleksibelt tabelmedlem i ellers tom struktur"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "next member %q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "omdefinering af '%#T'"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "'%#T' har virtuelle funktioner, men ikke-virtuel destruktionsfunktion"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 #| msgid "class `%T' does not have any field named `%D'"
 msgid "type transparent %q#T does not have any fields"
 msgstr "klassen '%T' har ikke et felt ved navn '%D'"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "  eftersom typen '%T' har abstrakte virtuelle funktioner"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "forsøgte at afslutte struct, men blev stoppet af tidligere fortolkningsfejl"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, fuzzy, gcc-internal-format
 #| msgid "language string `\"%s\"' not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "sprogstrengen '\"%s\"' ikke genkendt"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, fuzzy, gcc-internal-format
 #| msgid "cannot resolve overloaded function `%D' based on conversion to type `%T'"
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "kan ikke benytte den flertydiggjorte funktion '%D' baseret på konvertering til typen '%T'"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, fuzzy, gcc-internal-format
 #| msgid "no matches converting function `%D' to type `%#T'"
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen passende ved konvertering af funktionen '%D' til typen '%#T'"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "converting overloaded function `%D' to type `%#T' is ambiguous"
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering af den flertydiggjorte funktion '%D' til typen '%T' er tvetydig"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, fuzzy, gcc-internal-format
 #| msgid "assuming pointer to member `%D'"
 msgid "assuming pointer to member %qD"
 msgstr "antager henvisning til medlemmet '%D'"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, fuzzy, gcc-internal-format
 #| msgid "(a pointer to member can only be formed with `&%E')"
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en henvisning til medlem kan kun dannes med '&%E')"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%E' from type `%T' to type `%T'"
 msgid "cannot convert %qE from type %qT to type %qT"
@@ -41764,13 +41829,13 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D"
 msgstr "omerklæring af '%#D'"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of `%D' from `%+#D'"
 msgid "changes meaning of %qD from %q#D"
@@ -41804,365 +41869,365 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%q+E is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to internal function %qE"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function `%D'"
 msgid "call to non-constexpr function %qD"
 msgstr "kald af ikke-funktion '%D'"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' implicitly declared before its definition"
 msgid "%qD used before its definition"
 msgstr "'%s' er underforstået erklæret efter dens definition"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "protocol `%s' has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokollen '%s' har cirkulær afhængighed"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "højreskiftsantal er negativ"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized array element"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%qE is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "accessing uninitialized member %qD"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing `void *' pointer"
 msgid "dereferencing a null pointer"
 msgstr "forsøg på at følge en 'void *'-henvisning"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array `%D' is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "excess elements in union initializer"
 msgid "%qD used in its own initializer"
 msgstr "for mange elementer i union-startværdi"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "'%s' er ikke en funktion,"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "`%+#D' is private"
 msgid "%q#D is volatile"
 msgstr "'%+#D' er privat"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "enum- og ikke enum-type i betinget udtryk"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "uventet adresseudtryk"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, fuzzy, gcc-internal-format
 #| msgid "invalid reinterpret_cast from type `%T' to type `%T'"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "ugyldig reinterpret_cast fra typen '%T' til typen '%T'"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "field `%D' declared static in union"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "feltet '%D' er erklæret statisk i union"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "størrelsen af tabel er ikke af et heltalligt konstantudtryk"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "tabelindekset i startværdien er ikke en konstant"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "Missing or invalid constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "Manglende eller ugyldigt konstant udtryk"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unexpected type for `id' (%s)"
 msgid "unexpected AST of kind %s"
@@ -43053,7 +43118,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  springer over klargøring af '%#D'"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -43069,7 +43134,7 @@
 msgid "%qD is not a type"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' used without template parameters"
 msgid "%qD used without template parameters"
@@ -44949,7 +45014,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "parameteren '%D' erklæret void"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template-name '%E' in a declarator"
 msgid "invalid use of template-name %qE without an argument list"
@@ -45475,14 +45540,14 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qT is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration `%#D' here"
 msgid "previous declaration here"
@@ -45493,8 +45558,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
@@ -45552,7 +45617,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidligere definition her"
@@ -45621,7 +45686,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, fuzzy, gcc-internal-format
 #| msgid "`operator=' should return a reference to `*this'"
 msgid "%<operator=%> should return a reference to %<*this%>"
@@ -45638,7 +45703,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "ingen return-sætning i en funktion der ikke returnerer void"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
@@ -45820,27 +45885,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bitfelt '%#D' med en ikke-heltalstype"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonym struct er ikke inden i en navngiven type"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonyme variabler af sammensatte typer i navnerumsvirkefelt skal erklæres static"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, fuzzy, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonym sammensat type uden medlemmer"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must return type `%T'"
 msgid "%<operator new%> must return type %qT"
@@ -45850,70 +45915,70 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' takes type `size_t' (`%T') as first parameter"
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "den første parameter til 'operator new' skal være af typen 'size_t' ('%T')"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, fuzzy, gcc-internal-format
 #| msgid "`operator delete' must return type `%T'"
 msgid "%<operator delete%> must return type %qT"
 msgstr "'operator delete' skal returnere typen '%T'"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, fuzzy, gcc-internal-format
 #| msgid "`operator delete' takes type `%T' as first parameter"
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "den første parameter til 'operator delete' skal være af typen '%T'"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -45923,53 +45988,53 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "'%#D' refererer ikke til den ikkemodificerede type, so den bruges ikke til sammenkædning"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%J'%F' declared `static' but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J'%F' erklæret 'static', men aldrig defineret"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%#D' with %L linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "tidligere erklæring af '%#D' med %L-kædning"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 #| msgid "inline function `%D' used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "indbygget funktion '%D' benyttet, men aldrig defineret"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, fuzzy, gcc-internal-format
 #| msgid "default argument missing for parameter %P of `%+#D'"
 msgid "default argument missing for parameter %P of %q+#D"
@@ -45977,12 +46042,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "use of deleted function %qD"
@@ -46322,7 +46387,7 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "ugyldig startværdi til virtuel medlemsfunktion '%D'"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member `%D'"
 msgid "uninitialized const member in %q#T"
@@ -46329,13 +46394,13 @@
 msgstr "konstant medlem '%D' uden startværdi"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "'%D' vil blive klargjort efter"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized reference member `%D'"
 msgid "uninitialized reference member in %q#T"
@@ -46448,7 +46513,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "%qT is not a class type"
@@ -46471,7 +46536,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
@@ -46675,24 +46740,24 @@
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to references"
 msgid "cannot capture %qE by reference"
 msgstr "kan ikke erklære %s til referencer"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type `%T'"
 msgid "capture by copy of incomplete type %qT"
 msgstr "kan ikke %s en henvisning til en ufuldstændig type '%T'"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -46750,120 +46815,120 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of `%D' will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det ABI-navnet for '%D' vil ændre sig i en fremtidig version af GCC"
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member `%#D', can't use default assignment operator"
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "ikke-statisk konstant medlem '%#D' kan ikke bruge standardtildelingsoperatoren"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member `%#D', can't use default assignment operator"
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "ikke-statisk referencemedlem '%#D' kan ikke bruge standardtildelingsoperatoren"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr ""
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, fuzzy, gcc-internal-format
 #| msgid "Only constructors can invoke constructors"
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "Kun konstruktionsfunktioner kan kalde konstruktionsfunktioner"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 #| msgid "member initializers for `%#D'"
 msgid "initializer for %q#D is invalid"
 msgstr "medlemsstartværdier for '%#D'"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, fuzzy, gcc-internal-format
 #| msgid "(use `=' to initialize static data members)"
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "(brug '=' for at klargøre statiske datamedlemmer)"
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "copying non-static data member %q#D of rvalue reference type"
@@ -46870,80 +46935,80 @@
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, fuzzy, gcc-internal-format
 #| msgid "(use `=' to initialize static data members)"
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "(brug '=' for at klargøre statiske datamedlemmer)"
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "defaulted declaration %q+D"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, fuzzy, gcc-internal-format
 #| msgid "cast does not match function type"
 msgid "does not match expected signature %qD"
 msgstr "typeomtvingelse passer ikke til funktionstype"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a template cannot be defaulted"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, fuzzy, gcc-internal-format
 #| msgid "`%#D' cannot be declared"
 msgid "%qD cannot be defaulted"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
@@ -47161,105 +47226,105 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "'%D' navngiver en konstruktionsfunktion"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, fuzzy, gcc-internal-format
 #| msgid "no members matching `%D' in `%#T'"
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "ingen medlemmer passer til '%D' i '%#T'"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' not in a namespace surrounding `%D'"
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "erklæring af '%D' er ikke i et navnerum der omgiver '%D'"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate type qualifiers in %s declaration"
 msgid "explicit qualification in declaration of %qD"
 msgstr "dobbelte typemodifikationer i %s-erklæring"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr "'%#D' kan ikke erklæres"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' declared as a friend"
 msgid "only here as a friend"
 msgstr "'%D' er erklæret som en ven"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' should have been declared inside `%D'"
 msgid "%qD should have been declared inside %qD"
 msgstr "'%D' skulle have været erklæret inden i '%D'"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "egenskabsdirektivet '%s' ignoreret"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, fuzzy, gcc-internal-format
 #| msgid "namespace alias `%D' not allowed here, assuming `%D'"
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "navnerumsalias '%D' er ikke tilladt her, antager '%D'"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "Angiv klassesti (forældet: benyt --classpath i stedet)"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr ""
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -47266,28 +47331,28 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -47307,7 +47372,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -47334,7 +47399,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "forespørgsel efter medlemmet '%D' i '%E' som er af en ikke-klassetype '%T'"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "'%#D' kan ikke erklæres"
@@ -47404,104 +47469,104 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "semikolon mangler efter erklæring af '%T'"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qE is not a class template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qE is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, fuzzy, gcc-internal-format
 msgid "invalid template-id"
 msgstr "ugyldig roteringsinstruktion"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, fuzzy, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, fuzzy, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, fuzzy, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, fuzzy, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qD as a type"
@@ -47508,666 +47573,672 @@
 msgstr "ugyldig brug af 'restrict'"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid combination of multiple type-specifiers"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, fuzzy, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, fuzzy, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "  (benyt 'typename %T::%D' hvis det er hvad du mener)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' does not declare a template type"
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, fuzzy, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr ""
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' does not declare a template type"
 msgid "%qE in %q#T does not name a template type"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "'%D' erklærer ikke en skabelonstype"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected multiplicative operand"
 msgid "expected string-literal"
 msgstr "uventet multiplikativ operand"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "Statement at %0 invalid in this context"
 msgid "a wide string is invalid in this context"
 msgstr "Sætning ved %0 er ugyldig i denne kontekst"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "floating point number exceeds range of '%s'"
 msgid "integer literal exceeds range of %qT type"
 msgstr "kommatal overskrider intervallet for '%s"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 #| msgid "floating point number exceeds range of '%s'"
 msgid "floating literal exceeds range of %qT type"
 msgstr "kommatal overskrider intervallet for '%s"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr ""
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr ""
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
 msgstr "tom erklæring"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected binary operator"
 msgstr "uventet operand"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<...%>"
 msgid "expected ..."
 msgstr "forventede %<...%>"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "binary expression in operand of fold-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "mismatched operator in fold-expression"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 #| msgid "-Wno-strict-prototypes is not supported in C++"
 msgid "fixed-point types not supported in C++"
 msgstr "-Wno-strict-prototypes er ikke understøttet i C++"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ forbyder krøllet parantes-grupper inden i udtryk"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, fuzzy, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected primary-expression"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, fuzzy, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, fuzzy, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "Advar om extern-erklæringer som ikke er ved filvirkefeltsniveauet"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, fuzzy, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected id-expression"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%s' shadows a member of `this'"
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "erklæring af '%s' skygger for et medlem af 'this'"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, fuzzy, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "skabelons-id '%D' benyttet som erklærer"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or union type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "'%T' er ikke af en klasse- eller union-type"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "ufuldstændig type '%T' kan ikke bruges til at navngive et virkefelt"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "%qD is not a template"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, fuzzy, gcc-internal-format
 #| msgid "label must be followed by statement"
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr "etiketten skal efterfølges af en sætning"
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "forkert parametertype til bitkomplement"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ forbyder sammensatte konstanter"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "braced list index is not allowed with array notation"
 msgstr "-client_name er ikke tilladt med -dynamiclib"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
 msgstr "ugyldig brug af '%D"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a member of `%T'"
 msgid "%<%D::%D%> is not a class member"
 msgstr "'%D::%D' er ikke et medlem af '%T'"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, fuzzy, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected address expression"
 msgid "expected expression-list or type-id"
 msgstr "uventet adresseudtryk"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "brug af ældre type typeomtvingning"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "foreslår paranteser omkring && inden i ||"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid expression statement"
 msgid "lambda-expression in template-argument"
 msgstr "Ugyldig udtrykssætning"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer for lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "  `%#D' declared here"
 msgid "%q#D declared here"
 msgstr "  '%#D' erklæret her"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C90 understøtter ikke komplekse typer"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "default argument specified for lambda parameter"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate %<mutable%>"
 msgstr "'volatile' optræder mere end én gang"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected labeled-statement"
 msgstr "tom krop i en else-sætning"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 #| msgid "case label `%E' not within a switch statement"
 msgid "case label %qE not within a switch statement"
 msgstr "case-etiket '%E' befinder sig ikke inden i en switch-sætning"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, fuzzy, gcc-internal-format
 #| msgid "In statement function"
 msgid "compound-statement in constexpr function"
 msgstr "I sætningsfunktion"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
 msgstr "tom krop i en else-sætning"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "udtrykket er af en ufuldstændig type"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with Cilk Plus for loop"
 msgstr "break-sætning befinder sig ikke i en løkke- eller switch-konstruktion"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ forbyder beregnede goto'er"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "uventet operand"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flere erklæringer '%T' og '%T'"
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "tom erklæring"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+#| msgid "invalid initializer for bit string"
+msgid "invalid initializer for structured binding declaration"
+msgstr "ugyldig startværdi til bitstreng"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
@@ -48174,120 +48245,120 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in friend function declarations"
 msgid "decl-specifier invalid in condition"
 msgstr "lagringsklasseanvisninger er ugyldige i vennefunktionserklæringer"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' invalid in `%#T'"
 msgid "%qD invalid in lambda"
 msgstr "'%D' ugyldig i '%#T'"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "funktionen '%D' kan ikke erklæres friend"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "kun konstruktionsfunktioner har stamklasseklargøringer"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member `%D'"
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "manglende startværdi for medlemmet '%D'"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "forældet stamklasseklargøring"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "expected suffix identifier"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type modifier within pointer declarator"
 msgid "invalid encoding prefix in literal operator"
 msgstr "ugyldig typemodifikation i erklæring af henvisning"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -48294,396 +48365,396 @@
 msgstr "uventet operand"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, fuzzy, gcc-internal-format
 #| msgid "keyword `export' not implemented, and will be ignored"
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "det reserverede ord 'export' er ikke implementeret og vil blive ignoreret"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "uventet operand"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "objektet '%E' kan ikke bruges som skabelonsparameter"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "uventet operand"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "skabelons-id '%D' i erklæring af primær skabelon"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "uventet operand"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D' after"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplicit instantiering af '%#D' efter"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "skabelonsspecialisering med C-kædning"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, fuzzy, gcc-internal-format
 #| msgid "sigof type specifier"
 msgid "expected type specifier"
 msgstr "sigof-typeangivelse"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C forbyder forhåndsparametererklæringer"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "expected template-id for type"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on uninstantiated type"
 msgid "attributes ignored on uninstantiated type"
 msgstr "ugyldig operation på uudskiftet type"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "størrelse i tabel-new skal være en heltalstype"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "unnamed scoped enum is not allowed"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktivér automatisk skabelonsinstantiering"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' in `%D' which does not enclose `%D'"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "erklæring af '%D' i '%D' som ikke omgiver '%D'"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ekstra modifikation '%T::' af medlemmet '%D' ignoreret"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, fuzzy, gcc-internal-format
 #| msgid "multiple definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "flere definitioner af '%#T'"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ forbyder %s af en enum"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a namespace"
 msgid "%qD is not a namespace-name"
 msgstr "'%D' er ikke et navnerum"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "function with nested functions cannot be inline"
 msgid "a nested namespace definition cannot be inline"
 msgstr "funktion med indlejrede funktioner kan ikke indbygges"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 msgid "nested identifier required"
 msgstr "uventet operand"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 #| msgid "namespace `%T' undeclared"
 msgid "namespace %qD entered"
 msgstr "navnerummet '%T' er ikke erklæret"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, fuzzy, gcc-internal-format
 #| msgid "Min/max instructions not allowed"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Min/max-instruktioner ikke tilladt"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "navnerum '%D' ikke tilladt i using-erklæring"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: funktionsdefinitionen er ikke omdannet\n"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, fuzzy, gcc-internal-format
 #| msgid "empty scalar initializer"
 msgid "expected initializer"
 msgstr "tom skalarstartværdi"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, fuzzy, gcc-internal-format
 #| msgid "initializer specified for non-member function `%D'"
 msgid "initializer provided for function"
 msgstr "startværdi angivet for ikke-medlemsfunktion '%D'"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, fuzzy, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "egenskaber i parametertabelerklæring ignoreret"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "funktionen '%s' omerklæret som inline"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array bound is not an integer constant"
 msgstr "tabelindeks er ikke et heltal"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, fuzzy, gcc-internal-format
 #| msgid "`%D::%D' is not a template"
 msgid "%<%T::%E%> is not a type"
 msgstr "'%D::%D' er ikke en skabelon"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -48692,7 +48763,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ugyldig erklærer"
@@ -48699,358 +48770,358 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Ugyldig erklæring"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "tom erklæring"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is a namespace"
 msgid "%qD is a namespace"
 msgstr "'%D' er et navnerum"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "uventet operand"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate case value"
 msgid "duplicate cv-qualifier"
 msgstr "case-værdi optræder mere end én gang"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "multiple ref-qualifiers"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 #| msgid "multiple `virtual' specifiers"
 msgid "duplicate virt-specifier"
 msgstr "mere end én 'virtual'-angivelse"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "ugyldig brug af '%T'"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "uventet operand"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "skabelonsparametre kan ikke være venner"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "'%D' kan ikke have standardparametre"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillader ikke udpegede startværdier"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "'%s' er erklæret inline efter dens definition"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "kan ikke finde filen for klassen %s"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid class name in declaration of %qD"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "eksplicit specialisering følger ikke efter 'template <>'"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "tidligere definition af '%#T'"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "uventet operand"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "friend-erklæringen er ikke i klassedefinitionen"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, fuzzy, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "bruger 'typename' uden for en skabelon"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "Generér ikke kode til at kontrollere undtagelsesspecifikationer"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to variables"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "egenskaben '%s' kan kun anvendes på variabler"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected attribute before %<...%>"
 msgstr "uventet operand"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "overløb i konstant udtryk"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of `%D'"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ugyldig omerklæring af '%D'"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "for få skabelonsparameterlister angivet i erklæring af '%D'"
@@ -49059,442 +49130,442 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, fuzzy, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "for mange skabelonsparameterlister angivet i erklæring af '%D'"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver understøttes ikke længere"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "Aktiver multiply-instruktioner"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching concept for template-introduction"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template `%#D' in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "ugyldig erklæring af medlemsskabelon '%#D' i lokal klasse"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "skabelon med C-kædning"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "invalid explicit specialization"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of `%#D'"
 msgid "template declaration of %<typedef%>"
 msgstr "skabelonserklæring af '%#D'"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "erklæring erklærer ikke noget"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization here"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "eksplicit specialisering her"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "'>>' skulle have været '> >' i skabelonsklassenavn"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> før %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 understøtter ikke %<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "duplikere %qD"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "duplikere %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "forventede %<new%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "forventede %<delete%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "forventede %<return%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "forventede %<extern%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "forventede %<static_assert%>"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "forventede %<decltype%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "forventede %<operator%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "forventede %<class%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "forventede %<template%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "forventede %<namespace%>"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "forventede %<using%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "forventede %<asm%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "forventede %<try%>"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "forventede %<catch%>"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "forventede %<throw%>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "forventede %<__label__%>"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "forventede %<@try%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "forventede %<@synchronized%>"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "forventede %<@throw%>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "forventede %<__transaction_atomic%>"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "forventede %<__transaction_relaxed%>"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "forventede %<::%>"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "forventede %<...%>"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "forventede %<*%>"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "forventede %<~%>"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "forventede %<:%> or %<::%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "forventede %<class%>, %<typename%>, eller %<template%>"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' tag used in naming `%#T'"
 msgid "%qs tag used in naming %q#T"
 msgstr "'%s'-mærke benyttet i navngivning af '%#T'"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "'%s' tidligere erklæret her"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "'%#D' omerklæret som en anden form for symbol"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "%Hslutningen af filen læst inden i standardparameter"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, fuzzy, gcc-internal-format
 #| msgid "Class or interface declaration expected"
 msgid "objective-c++ method declaration is expected"
 msgstr "Klasse- eller grænsefladeerklæring forventet"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "sektionsegenskaben kan ikke angives for lokale variabler"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, fuzzy, gcc-internal-format
 #| msgid "invalid register name `%s' for register variable"
 msgid "invalid type for instance variable"
 msgstr "ugyldigt registernavn '%s' for registervariabel"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, fuzzy, gcc-internal-format
 #| msgid "Identifier expected"
 msgid "identifier expected after %<@protocol%>"
 msgstr "Kaldenavn forventet"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored for `%s'"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "'%s'-egenskaben ignoreret for '%s'"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "ugyldig typeparameter"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid identifier `%s'"
 msgid "invalid reduction-identifier"
 msgstr "ugyldigt kaldenavn '%s'"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, fuzzy, gcc-internal-format
 #| msgid "register variable `%s' used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "registervariabel '%s' benyttet i indlejret funktion"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "ikke tilstrækkelig information om typen"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "en global registervariabel følger en funktionsdefinition"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "ugyldig startværdi"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected side-effects in address"
 msgid "expected id-expression (arguments)"
 msgstr "uventede bivirkninger i adresse"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -49501,70 +49572,70 @@
 msgstr "'%D' er ikke en medlemsskabelonfunktion"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of #pragma GCC java_exceptions"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "ragelse i slutningen af #pragma GCC java_exceptions"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "ugyldige begrænsninger for operand"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 #| msgid "braced-group within expression allowed only inside a function"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "sætningsblokke i udtryk er kun tilladt inde i en funktion"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "profilering understøttes ikke endnu"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 msgid "expected variable-name"
 msgstr "uventet operand"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
@@ -49671,7 +49742,7 @@
 msgid "candidate is: %#D"
 msgstr "candidate%s: %+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
@@ -50322,138 +50393,156 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+#| msgid "`%E' is not a valid template argument"
+msgid "the address of %qD is not a valid template argument"
+msgstr "'%E' er ikke en gyldig skabelonsparameter"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+#| msgid "`%E' is not a valid template argument"
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "'%E' er ikke en gyldig skabelonsparameter"
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+#| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
+
+#: cp/pt.c:6672
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "string literal %E is not a valid template argument because it is the address of an object with static linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "strengkonstanten %E er ikke en gyldig skabelonsparameter fordi den er adressen af et objekt med statisk kædning"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not a valid template argument"
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "'%E' er ikke en gyldig skabelonsparameter"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, fuzzy, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "'%D' blev ikke erklæret i dette virkefelt"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring attributes in template argument %qE"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "ugyldig standardparameter i skabelon"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "ugyldig brug af 'restrict'"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, fuzzy, gcc-internal-format
 #| msgid "to refer to a type member of a template parameter, use `typename %E'"
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "benyt 'typename %E' for at referere til et typemedlem af en skabelonsparameter"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a constant of type `%T', got `%T'"
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  forventede en konstant af typen '%T', modtog '%T'"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected a type, got %qE"
 msgstr "  forventede en type, modtog '%E'"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%T'"
 msgid "  expected a type, got %qT"
 msgstr "  forventede en type, modtog '%T'"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a class template, got `%T'"
 msgid "  expected a class template, got %qT"
 msgstr "  forventede en klasseskabelon, modtog '%T'"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type `%D', got `%D'"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  forventede en skabelon af typen '%D', modtog '%D'"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for `%D'"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "type/værdi-konflikt ved %d. parameter i skabelonsparameterliste for '%D'"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got `%E'"
 msgid "  expected %qD but got %qD"
@@ -50461,114 +50550,114 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in nontype parameter pack"
 msgstr "typerne i betingelsesudtrykket passer ikke sammen"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument `%E' to `%T'"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunne ikke konvertere skabelonsparameteren '%E' til '%T'"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "forkert antal skabelonsparametre (%d, skulle være %d)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "provided for `%D'"
 msgid "provided for %qD"
 msgstr "angivet for '%D'"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of `%#D'"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "standardparameter givet til %d. parameter for '%#D'"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, fuzzy, gcc-internal-format
 #| msgid "provided for `%D'"
 msgid "provided for %q+D"
 msgstr "angivet for '%D'"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function template"
 msgid "%q#D is not a function template"
 msgstr "'%D' er ikke en funktionsskabelon"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, fuzzy, gcc-internal-format
 #| msgid "non-template type `%T' used as a template"
 msgid "non-template type %qT used as a template"
 msgstr "ikke-skabelonstype '%T' benyttet som skabelon"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, fuzzy, gcc-internal-format
 #| msgid "for template declaration `%D'"
 msgid "for template declaration %q+D"
 msgstr "til skabelonserklæring '%D'"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "internal gcc abort"
 msgid "template constraint failure"
 msgstr "intern GCC-afbrydelse"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "'%T' er ikke en skabelon"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for `%#D'"
 msgid "  when instantiating default argument for call to %D"
@@ -50587,311 +50676,311 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, fuzzy, gcc-internal-format
 #| msgid "sizeof applied to a function type"
 msgid "variable %qD has function type"
 msgstr "sizeof benyttet på en funktionstype"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "ugyldig parametertype '%T'"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "i erklæringen '%D'"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, fuzzy, gcc-internal-format
 #| msgid "function returns an aggregate"
 msgid "function returning an array"
 msgstr "funktion returnerer en værdi af en sammensat type"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' declared as function returning a function"
 msgid "function returning a function"
 msgstr "'%s' er erklæret som en funktion der returnerer en funktion"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member function of non-class type `%T'"
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "opretter henvisning til medlemsfunktion af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "danner reference til void"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming pointer to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type `%T'"
 msgid "forming reference to reference type %qT"
 msgstr "danner %s til referencetypen '%T'"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming pointer to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids qualified function types"
 msgid "forming reference to qualified function type %qT"
 msgstr "ISO C forbyder funktionsreturtype med modifikationer"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type `%T'"
 msgid "creating pointer to member of non-class type %qT"
 msgstr "opretter henvisning til medlem af typen '%T' der ikke er en klasse"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member reference type %qT"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type `%T'"
 msgid "creating pointer to member of type void"
 msgstr "opretter henvisning til medlemsreference af typen '%T'"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, fuzzy, gcc-internal-format
 #| msgid "creating array of `%T'"
 msgid "creating array of %qT"
 msgstr "opretter tabel af '%T'"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class, struct, or union type"
 msgid "%qT is not a class, struct, or union type"
 msgstr "'%T' er ikke en class-, struct- eller union-type"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "unavngiven klargøring af '%T' som ikke har nogen stamklasser"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, fuzzy, gcc-internal-format
 #| msgid "non-empty initializer for array of empty elements"
 msgid "empty initializer in lambda init-capture"
 msgstr "en startværdi der ikke er tom, tildeles til en tabel med tomme elementer"
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, fuzzy, gcc-internal-format
 #| msgid "use of `%s' in template"
 msgid "use of %qs in template"
 msgstr "brug af '%s' i skabelon"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, fuzzy, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "'%D' benyttes som en type, men er ikke defineret som en type"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, fuzzy, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "  (benyt 'typename %T::%D' hvis det er hvad du mener)"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, fuzzy, gcc-internal-format
 #| msgid "missing static field `%s'"
 msgid "using invalid field %qD"
 msgstr "manglende statisk felt '%s'"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "ugyldig brug af void-udtryk"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "'%s' ikke erklæret her (ikke i en funktion)"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qT is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a class or namespace"
 msgid "%qD is not a class or namespace"
 msgstr "'%T' er ikke en klasse eller et navnerum"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "skabelonsparameter '%T' benytter anonym type"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "standardparameter for '%#D' har typen '%T'"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "skabelonsparameter '%T' er en variabelt ændret type"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "størrelsen af medlemmet '%D' er ikke konstant"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, fuzzy, gcc-internal-format
 #| msgid "  trying to instantiate `%D'"
 msgid "  trying to instantiate %qD"
 msgstr "  ved forsøg på at instantiere '%D'"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for `%#T'"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig klasseskabelonsinstantiering for '%#T'"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-template %q#D"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "'%#D' er ikke et statisk medlem af '%#T'"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for `%D' found"
 msgid "no matching template for %qD found"
 msgstr "ingen passende skabelon for '%D' fundet"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#D'"
 msgid "explicit instantiation of %q#D"
 msgstr "eksplicit instantiering af '%#D'"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#D'"
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "'%#D' er blevet eksplicit instantieret mere end én gang"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `extern' on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af 'extern' ved eksplicitte instantieringer"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template `%#D'"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "eksplicit instantiering af ikke-skabelon '%#D'"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type `%T'"
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplicit instantiering af '%T' der ikke er en skabelonstype"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%#T' before definition of template"
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplicit instantiering af '%T' før definering af skabelonen"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of `%s' on explicit instantiations"
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ forbyder brugen af '%s ved eksplicitte instantieringer"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate explicit instantiation of `%#T'"
 msgid "duplicate explicit instantiation of %q#T"
@@ -50904,103 +50993,103 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of `%D' but no definition available"
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplicit instantiering af '%D', men ingen definition tilgængelig"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating `%D'"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "skabelonsinstantieringsdybden overskrider maksimum på %d (benyt -ftemplate-depth-NN for at forøge maksimum) ved instantiering af '%D'"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "ugyldig catch-parameter"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 #| msgid "`%#T' is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'%#T' er ikke en gyldig type for en skabelonsparameterkonstant "
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, fuzzy, gcc-internal-format
 #| msgid "brace-enclosed initializer used to initialize `%T'"
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "startværdi i krøllede paranteser benyttet til at klargøre '%T'"
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "ikke-skabelon benyttet som skabelon"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "skabelonsparameter %d er ugyldig"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "funktion overvejes ikke for indbygning"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, fuzzy, gcc-internal-format
 #| msgid "%s as integer rather than floating due to prototype"
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%s som heltal i stedet for kommatal på grund af prototypen"
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid method declaration, return type required"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Ugyldig metodeerklæring, returtype påkrævet"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "instruktion tilfredsstiller ikke sine begrænsninger:"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -51180,164 +51269,164 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  eftersom '%#D' er erklæret i stamklassen"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous `else'"
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "%Hforeslår eksplicitte krøllede paranteser for at undgå tvetydig 'else'"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, fuzzy, gcc-internal-format
 #| msgid "type of asm operand `%E' could not be determined"
 msgid "type of asm operand %qE could not be determined"
 msgstr "typen af asm-operanden '%E' kunne ikke afgøres"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member `%D' in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "ugyldig brug af medlemmet '%D' i statisk medlemsfunktion"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "parameter til egenskaben '%s' er større end %d"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, fuzzy, gcc-internal-format
 #| msgid "`this' is unavailable for static member functions"
 msgid "%<this%> is unavailable for static member functions"
 msgstr "'this' er ikke tilgængelig for statiske medlemsfunktioner"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' in non-member function"
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ugyldig brug af 'this' i ikke-medlemsfunktion"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `this' at top level"
 msgid "invalid use of %<this%> at top level"
 msgstr "ugyldig brug af 'this' ved øverste niveau"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, fuzzy, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ugyldige modifikationer for ikke-medlemsfunktionstype"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type `%T' does not match destructor name `~%T'"
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "den modificerede type '%T' passer ikke til destruktionsfunktionsnavnet '~%T'"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, fuzzy, gcc-internal-format
 #| msgid "`%E' is not of type `%T'"
 msgid "%qE is not of type %qT"
 msgstr "'%E' er ikke af typen '%T'"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, fuzzy, gcc-internal-format
 #| msgid "template type parameters must use the keyword `class' or `typename'"
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "skabelonstypeparametre skal begynde med 'class' eller 'typename'"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ugyldig brug af skabelonstypeparameter"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, fuzzy, gcc-internal-format
 #| msgid "definition of `%#T' inside template parameter list"
 msgid "definition of %q#T inside template parameter list"
 msgstr "definition af '%#T' inden i skabelonsparameterliste"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type `%T'"
 msgid "invalid definition of qualified type %qT"
 msgstr "ugyldig definition af modificeret type '%T'"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ugyldig stamklasseangivelse"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 #| msgid "protected member `%#D' in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "beskyttet medlem '%#D' i en anonym union"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' not declared"
 msgid "%qD is not captured"
 msgstr "'%D' ikke erklæret"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter from containing function"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "use of %s from containing function"
 msgid "use of parameter outside function body"
 msgstr "brug af %s fra indeholdende funktion"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "skabelonsparameter er påkrævet for '%T'"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace `%D' as expression"
 msgid "use of namespace %qD as expression"
 msgstr "brug af navnerummet '%D' som udtryk"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "use of class template %qT as expression"
@@ -51344,24 +51433,24 @@
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, fuzzy, gcc-internal-format
 #| msgid "request for member `%D' is ambiguous in multiple inheritance lattice"
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "forespørgsel efter medlemmet '%D' er tvetydigt i det multiple nedarvningsnet"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "størrelsen af tabellen '%D' er ikke af et heltalligt konstantudtryk"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, fuzzy, gcc-internal-format
 #| msgid "type of `%E' is unknown"
 msgid "type of %qE is unknown"
 msgstr "typen af '%E' er ukendt"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a template type"
 msgid "%qT is not an enumeration type"
@@ -51368,309 +51457,309 @@
 msgstr "'%T' er ikke en skabelonstype"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "lagringsklasseanvisninger er ugyldige i parametererklæringer"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ugyldig brug af ikke-statisk felt '%D'"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "brug af '%D' er tvetydigt"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "invalid return type for function `%#D'"
 msgid "%qE has const type for %<reduction%>"
 msgstr "ugyldig returtype for funktionen '%#D'"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in clause %qs"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable `%s' is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "instansvariablen '%s' er erklæret privat"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> static expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "%s rotate count is negative"
 msgid "%<gang%> static value must be positive"
 msgstr "%s-roteringsantal er negativt"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<gang%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<vector%> length expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<worker%> num expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%qs expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "angivet justering er ikke en potens af 2"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "left argument must be a slice"
 msgid "%<worker%> num value must be positive"
 msgstr "venstre parameter skal være en skive"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "klargøringsliste behandlet som et sammensat udtryk"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' is not a valid class name"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "'%s' er et ugyldigt klassenavn"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "for mange inddatafiler"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<grainsize%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<priority%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 #| msgid "predicate must be an identifier"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "udsagn skal være et kaldenavn"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "variablen til tabel-delete er hverken af en henvisnings- eller en tabeltype"
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<tile%> argument needs integral type"
 msgstr "skive-slutning skal være heltal"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 #| msgid "verification error at PC=%d"
 msgid "static assertion failed"
 msgstr "verifikationsfejl ved PC=%d"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "erklæring uden static af '%s' følger static-erklæring"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, fuzzy, gcc-internal-format
 #| msgid "use of class template `%T' as expression"
 msgid "argument to decltype must be an expression"
 msgstr "brug af klasseskabelonen '%T' som udtryk"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s kan ikke finde adressen af flertydiggjort funktion"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
@@ -51677,18 +51766,18 @@
 msgstr "venstreoperanden til kommaudtrykket har ingen virkning"
 
 # flertalsform unødvendig
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, fuzzy, gcc-internal-format
 #| msgid "template argument `%E' involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "skabelonsparameter '%E' involverer skabelonsparameter"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported arg to `__builtin_return_address'"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -51706,121 +51795,121 @@
 msgid "lambda-expression in a constant expression"
 msgstr "overløb i konstant udtryk"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "den udbedte init_priority er ikke en heltalskonstant"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, fuzzy, gcc-internal-format
 #| msgid "can only use `%s' attribute on file-scope definitions of objects of class type"
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "kan kun bruge egenskaben '%s' på filvirkefeltsdefinitioner af objekter af klassetype"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "den udbedte init_priority er uden for det gyldige interval"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "den udbedte init_priority er reserveret til intern brug"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute is not supported on this platform"
 msgid "%qE attribute is not supported on this platform"
 msgstr "egenskaben '%s' er ikke understøttet på denne platform"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%D' as %s"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "erklæring af '%D' som %s"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute requires an integer constant argument"
 msgid "the %qE attribute requires arguments"
 msgstr "egenskaben '%s' kræver en heltalskonstant som parameter"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `%s' attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "parameteren til egenskaben '%s er ikke en strengkonstant"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "'%T::%D' er ikke en gyldig erklærer"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "`%T' is not a valid expression"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "'%T' er ikke et gyldigt udtryk"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute only applies to function types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "egenskaben '%s' kan kun anvendes sammen med funktionstyper"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "egenskaben '%s' kan kun anvendes med klassedefinitioner"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 #| msgid "storage class `%D' applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "lagringsklasse '%D' anvendt på skabelonsinstantiering"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "'%s'-egenskaben kan kun anvendes sammen med funktioner"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, fuzzy, gcc-internal-format
 #| msgid "two `u's in integer constant"
 msgid "zero as null pointer constant"
 msgstr "to 'u'-endelser i heltalskonstant"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_*-kontrol: mislykkedes i %s, ved %s:%d"
@@ -52586,119 +52675,119 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ugyldig omdannelse til typen '%T' fra typen '%T'"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' for argument `%P' to `%D'"
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "kan ikke konvertere '%T' til '%T' for parameter '%P' til '%D'"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in return"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert `%T' to `%T' in %s"
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "kan ikke konvertere '%T' til '%T' i %s"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "return type `%#T' is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "returtype '%#T' er ufuldstændig"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, fuzzy, gcc-internal-format
 #| msgid "Warn about functions which might be candidates for format attributes"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Advar om funktioner som kan være kandidater til formateringsegenskaber"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, fuzzy, gcc-internal-format
 #| msgid "function might be possible candidate for `%s' format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktion er en mulig kandidat til '%s'-formateringsegenskab"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of `%+D'"
 msgid "in passing argument %P of %qD"
 msgstr "i overbringelse af parameter %P af '%+D'"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerer reference til midlertidig variabel"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "reference til ikke-venstreværdi returneret"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable `%D' returned"
 msgid "reference to local variable %qD returned"
 msgstr "reference til den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of label %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable `%D' returned"
 msgid "address of local variable %qD returned"
 msgstr "adresse af den lokale variabel '%D' returneret"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerer en værdi fra en destruktionsfunktion"
@@ -52705,45 +52794,45 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "kan ikke returnere fra en håndtering af en funktions-try-blok i en konstruktionsfunktion"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerer en værdi fra en konstruktionsfunktion"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "'return' uden nogen værdi i en funktion der ikke returnerer void"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "manglende startværdi"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new kan ikke bruges på en referencetype"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "'return' med en værdi i en funktion der returnerer void"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, fuzzy, gcc-internal-format
 #| msgid "`operator new' must not return NULL unless it is declared `throw()' (or -fcheck-new is in effect)"
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
@@ -52750,12 +52839,12 @@
 msgstr "'operator new' må ikke returnere NULL medmindre den er erklæret 'throw()' (eller -fcheck-new er benyttet)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -56911,87 +57000,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -57186,12 +57275,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -57994,456 +58083,471 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "typeangivelsen '%s' er ikke tilladt efter struct eller class"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr ""
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "no description yet"
 msgid "$ descriptor at %L"
 msgstr "ingen beskrivelse endnu"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr ""
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "zero width in %s format"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "bredde på nul i %s-formatering"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr ""
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unrecognized format specifier"
 msgid "Period required in format specifier %s at %L"
 msgstr "ukendt formateringsanvisning"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unrecognized format specifier"
 msgid "Period required in format specifier at %L"
 msgstr "ukendt formateringsanvisning"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing class name"
 msgid "Missing comma at %L"
 msgstr "Manglende klassenavn"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "null format string"
 msgid "%s in format string at %L"
 msgstr "formateringsstreng er nul"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Extraneous characters in format at %L"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr ""
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing formal parameter term"
 msgid "Missing format label at %C"
 msgstr "Manglende formel parameterterm"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid base-class specification"
 msgid "Invalid value for %s specification at %C"
 msgstr "ugyldig stamklasseangivelse"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "after previous specification in `%#D'"
 msgid "Duplicate %s specification at %C"
 msgstr "efter tidligere specifikation i '%#D'"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "Duplicate %s label specification at %C"
 msgstr "etiketten '%s' er blevet erklæret mere end én gang"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr ""
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr ""
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr ""
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "`%D' is not a member of type `%T'"
 msgid "%s tag at %L must be of type %s"
 msgstr "'%D' er ikke et medlem af typen '%T'"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr ""
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr ""
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr ""
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "Missing %A specifier in statement at %0"
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "No UNIT= specifier in I/O control list at %0"
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr "Inge UNIT=-angivelse i I/O-kontrolliste ved %0"
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr ""
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr ""
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "UNIT number missing in statement at %L"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported VXT statement at %0"
 msgid "FLUSH statement at %C"
 msgstr "Ikke-understøttet VXT-sætning ved %0"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing formal parameter term"
 msgid "Missing format with default unit at %C"
 msgstr "Manglende formel parameterterm"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parse error in method specification"
 msgid "Duplicate format specification at %C"
 msgstr "tolkningsfejl i medlemsfunktionsangivelsen"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate initialization of %D"
 msgid "Duplicate NML specification at %C"
 msgstr "%D tildelt startværdi mere end én gang"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unsupported FORMAT specifier at %0"
 msgid "UNIT not specified at %L"
 msgstr "Ikke-understøttet FORMAT-angivelse ved %0"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "ERR tag label %d at %L not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "END tag label %d at %L not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "EOR tag label %d at %L not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "FORMAT label %d at %L not defined"
 msgstr "etiketten '%D' er benyttet, men ikke defineret"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "\"%s\" må ikke optræde i makroparameterliste"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected variable in READ statement at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid expression statement"
 msgid "Expected expression in %s statement at %C"
@@ -58450,86 +58554,86 @@
 msgstr "Ugyldig udtrykssætning"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at '%s' token"
 msgid "Syntax error in %s statement at %C"
 msgstr "syntaksfejl ved symbolet '%s'"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extraneous comma in FORMAT statement at %0"
 msgid "Expected comma in I/O list at %C"
 msgstr "Ekstra komma i FORMAT-sætning ved %0"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -59471,266 +59575,266 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "Manglende %A-angivelse i sætning ved %0"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing comma in FORMAT statement at %0"
 msgid "Renaming operators in USE statements at %C"
 msgstr "Manglende komma i FORMAT-sætning ved %0"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 #| msgid "Label %A already defined at %1 when redefined at %0"
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Etiket %A er allerede defineret ved %1 ved omdefinering ved %0"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "forward declaration of `%#T'"
 msgid "SUBMODULE declaration at %C"
 msgstr "forhåndserklæring af '%#T'"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "RETURN statement at %0 invalid within a main program unit"
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "RETURN-sætning ved %0 ugyldig inden i en hovedprogramenhed"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Spurious number in FORMAT statement at %0"
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Mystisk tal i FORMAT-sætning ved %0"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Fejl ved skrivning af uddatafilen %s.\n"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, fuzzy, gcc-internal-format
 #| msgid "format string arg not a string type"
 msgid "unquote_string(): got bad string"
 msgstr "formateringsstrengsparameter er ikke af en strengtype"
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "can't open %s for writing: %m"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "kan ikke åbne %s til skrivning: %m"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "%s: error writing file `%s': %s\n"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: fejl ved skrivning til filen '%s': %s\n"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: kan ikke slette filen '%s': %s\n"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "%s: warning: can't rename file `%s' to `%s': %s\n"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: advarsel: kan ikke omdøbe filen '%s' til '%s': %s\n"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file `%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: kan ikke slette hjælpeinformationsfilen '%s': %s\n"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs at %C already declared"
 msgstr "Symboler har en indledende understreg"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 #| msgid "Symbols have a leading underscore"
 msgid "Symbol %qs already declared"
 msgstr "Symboler har en indledende understreg"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: kan ikke åbne filen '%s' til at læse fra: %s\n"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr ""
@@ -62174,7 +62278,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -63691,450 +63795,440 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "uforenelig afledt type i PARAMETER ved %L"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variablen %qs ved %L kan ikke have PARAMETER-attributten"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 #| msgid "data member `%D' cannot be a member template"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "datamedlem '%D' kan ikke være en medlemsskabelon"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%D' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "etiketten '%D' er defineret, men ikke benyttet"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -65253,12 +65347,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "miljøvariablen DJGPP er ikke defineret"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr ""
@@ -67664,11 +67758,6 @@
 #~ msgid "Use little-endian byte order"
 #~ msgstr "Benyt lilleendet byteordning"
 
-#, fuzzy
-#~| msgid "Generate fused multiply/add instructions"
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "Generér sammensatte gang/addér-instruktioner"
-
 #~ msgid "Compare the results of several data dependence analyzers."
 #~ msgstr "Sammenlign resultaterne for flere dataafhængighedsanalyseprogrammer."
 
@@ -69106,9 +69195,6 @@
 #~ msgid "-ffunction-sections may affect debugging on some targets"
 #~ msgstr "-ffunction-sections kan have indflydelse på fejlfinding på nogle målarkitekturer"
 
-#~ msgid "invalid initializer for bit string"
-#~ msgstr "ugyldig startværdi til bitstreng"
-
 #~ msgid "volatile register variables don't work as you might wish"
 #~ msgstr "registervariable erklæret volatile virker ikke som du måske ønsker"
 
Index: gcc/po/tr.po
===================================================================
--- gcc/po/tr.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/tr.po	(.../branches/gcc-7-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 5.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2015-09-11 20:22+0300\n"
 "Last-Translator: Nilgün Belma Bugüner <nilgun@fide.org>\n"
 "Language-Team: Turkish <gnu-tr-u12a@lists.sourceforge.net>\n"
@@ -209,13 +209,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "gerçel sayı sabit yanlış kullanılmış"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -597,18 +597,18 @@
 "Çeviri hatalarını <gnu-tr@belgeler.org> adresine bildiriniz.\n"
 "\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, fuzzy, c-format
 #| msgid "Processing spec %c%s%c, which is '%s'\n"
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "'%4$s' %1$c%2$s%3$c özelliği işleniyor\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Hedef: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr ""
@@ -615,49 +615,49 @@
 "%s\n"
 "seçenekleriyle yapılandırıldı.\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Evre modeli: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, fuzzy, c-format
 #| msgid "gcc version %s\n"
 msgid "gcc version %s %s\n"
 msgstr "gcc %s sürümü\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, fuzzy, c-format
 #| msgid "gcc driver version %s executing gcc version %s\n"
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "gcc sürücüsü %s sürümü gcc %s sürümünü çalıştırıyor\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "kurulum: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "programlar: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "kitaplıklar: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -666,16 +666,16 @@
 "\n"
 "Hata raporlama işlemleri için:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "©"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -685,7 +685,7 @@
 "Hiçbir garantisi yoktur; hatta SATILABiLiRLiĞi veya ŞAHSi KULLANIMINIZA\n"
 "UYGUNLUĞU için bile garanti verilmez.\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -694,7 +694,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -701,7 +701,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -709,7 +709,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -721,18 +721,18 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+#| msgid "  -n, --no-output                 Do not create an output file\n"
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -n, --no-output                 Bir çıktı dosyası üretilmez\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 #| msgid "  -v, --version                   Print version number, then exit\n"
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -v, --version                   Sürüm bilgilerini gösterir ve çıkar\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -n, --no-output                 Bir çıktı dosyası üretilmez\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -748,14 +748,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -783,31 +783,31 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -f, --function                      Print function level info\n"
 msgstr "  -h, --help                      Bu yardım iletisini gösterir ve çıkar\n"
 
-#: gcov-tool.c:422
+#: gcov-tool.c:421
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr "  -h, --help                      Bu yardım iletisini gösterir ve çıkar\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:422
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr "  -h, --help                      Bu yardım iletisini gösterir ve çıkar\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:423
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -o, --object                        Print object level info\n"
 msgstr "  -h, --help                      Bu yardım iletisini gösterir ve çıkar\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -894,20 +894,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Bu yardım iletisini gösterir ve çıkar\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Her temel blok için bilgi verilir\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Çıktıda dallanma olasılıkları da içerilir\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, fuzzy, c-format
 #| msgid ""
 #| "  -c, --branch-counts             Given counts of branches taken\n"
@@ -917,17 +912,22 @@
 "                                    rather than percentages\n"
 msgstr "  -c, --branch-counts             Yüzde yerine dallanma sayısı alınır\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, fuzzy, c-format
 #| msgid "  --help                   Display this information\n"
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  --help                   Bu yardım iletisini gösterir\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Her işlev için özet çıktılar\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Bu yardım iletisini gösterir ve çıkar\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1122,82 +1122,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s: çizge '%s' için çözümlenebilir değil\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Çalıştırılan satırlar:%s / %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Çalıştırılacak satır yok\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s '%s'\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Çalıştırılan dallar:%s / %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "En az bir kere alındı:%s / %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Dal yok\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Çalıştırılan çağrılar: %s / %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Çağrı yok\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s: '%s' için satır yok\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "çağrı   %2d %s döndürdü\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "%2d. çağrı hiç çalıştırılmadı\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "%2d. dal %s%s kere alındı\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "%2d. dal hiç çalıştırılmadı\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "%2d. mutlak %s kere alındı\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "%2d. mutlak hiç çalıştırılmadı\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "%s kaynak dosyası açılamıyor\n"
@@ -1312,109 +1312,109 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[iptal edildi]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.c:1372
+#: opts.c:1379
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are target specific"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.c:1375
+#: opts.c:1382
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options control compiler warning messages"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.c:1378
+#: opts.c:1385
 #, fuzzy
 #| msgid "Perform loop optimizations"
 msgid "The following options control optimizations"
 msgstr "Döngü eniyilemeleri uygulanır"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are language-independent"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.c:1384
+#: opts.c:1391
 #, fuzzy
 #| msgid "The --param option recognizes the following as parameters:\n"
 msgid "The --param option recognizes the following as parameters"
 msgstr "--param seçeneğinde belirtilebilecek parametreler:\n"
 
-#: opts.c:1390
+#: opts.c:1397
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are specific to just the language "
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.c:1392
+#: opts.c:1399
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are supported by the language "
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.c:1403
+#: opts.c:1410
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are not documented"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.c:1405
+#: opts.c:1412
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options take separate arguments"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.c:1407
+#: opts.c:1414
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options take joined arguments"
 msgstr "Bu seçenekler dile bağımlıdir:\n"
 
-#: opts.c:1418
+#: opts.c:1425
 #, fuzzy
 #| msgid "The following options are language-independent:\n"
 msgid "The following options are language-related"
@@ -3107,8 +3107,8 @@
 msgid "<command-line>"
 msgstr "<komut-satırı>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
@@ -3129,7 +3129,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "terim eksik"
@@ -3152,8 +3152,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -3169,18 +3169,18 @@
 msgstr "%%r değeri geçersiz"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "%%R değeri geçersiz"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "%%N değeri geçersiz"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "%%P değeri geçersiz"
@@ -3190,7 +3190,7 @@
 msgid "invalid %%h value"
 msgstr "%%h değeri geçersiz"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "%%L değeri geçersiz"
@@ -3211,7 +3211,7 @@
 msgstr "%%U değeri geçersiz"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "%%s değeri geçersiz"
@@ -3221,7 +3221,7 @@
 msgid "invalid %%C value"
 msgstr "%%C değeri geçersiz"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "%%E değeri geçersiz"
@@ -3232,7 +3232,7 @@
 msgstr "bilinmeyen yerdeğişim unspec"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "%%xn kodu geçersiz"
@@ -3300,7 +3300,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "geçersiz terim çıktı kodu"
@@ -3311,30 +3311,30 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "terim olarak UNSPEC geçersiz"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "geçersiz %%f terimi"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "isnatlı Thumb komutu"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "koşullu dizilimde isnatlı komut"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3342,7 +3342,7 @@
 msgid "invalid operand for code '%c'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, fuzzy, c-format
 #| msgid "instruction never exectued"
 msgid "instruction never executed"
@@ -3349,111 +3349,111 @@
 msgstr "komut hiç çalıştırılmadı"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 #, fuzzy
 #| msgid "output operand %d must use %<&%> constraint"
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "çıktı terimi %d %<&%> kısıtını kullanmalı"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 #, fuzzy
 #| msgid "bad address, not (reg+disp):"
 msgid "bad address, not an I/O address:"
 msgstr "hatalı adres, (reg+disp) değil:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 #, fuzzy
 #| msgid "address offset not a constant"
 msgid "bad address, not a constant:"
 msgstr "adres mesafesi bir sabit değil"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "hatalı adres, (reg+disp) değil:"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "hatalı adres, post_inc veya pre_dec değil:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "derleyici iç hatası.  Hatalı adres:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "Derleyici iç hatası.  Bilinmeyen kip:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "geçersiz komut:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "yanlış komut:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "bilinmeyen taşıma komutu:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "hatalı kaydırma komutu:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "derleyici iç hatası.  Yanlış kaydırma:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 #| msgid "unsupported combination: %s"
 msgid "unsupported fixed-point conversion"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 #, fuzzy
 #| msgid "Perform variable tracking"
 msgid "variable"
 msgstr "Değişken izleme uygulanır"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "%q+D parametresinin yeniden tanımlanması"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 #| msgid "%q+#D previously defined here"
 msgid "structure field"
 msgstr "%q+#D evvelce burada tanımlanmış"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 #| msgid "creating array of %qT"
 msgid "return type of function"
 msgstr "%qT dizisi oluşturulması"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 #, fuzzy
 #| msgid "PRINT_OPERAND null pointer"
 msgid "pointer"
@@ -3478,7 +3478,7 @@
 msgstr "const_double terim geçersiz"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3702,100 +3702,100 @@
 msgid "bad output_condmove_single operand"
 msgstr "output_condmove_single terimi hatalı"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "terim olarak UNSPEC geçersiz"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "asm çıktısı %d içinde geçersiz sol değer"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "terim, kod `%c' için geçersiz"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "operand is neither a constant nor a condition code, invalid operand code 'c'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "terim ne bir sabit ne de bir koşul kodu, geçersiz terim kodu 'c'"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "terim kodu `%c' geçersiz"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "kısıtlar terim için geçersiz"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "bilinmeyen komut kipi"
 
@@ -3834,7 +3834,7 @@
 msgid "invalid %%P operand"
 msgstr "%%P terimi geçersiz"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "%%p değeri geçersiz"
@@ -3892,7 +3892,7 @@
 msgstr "sonradan arttırımlı adres bir yazmaç değil"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "hatalı adres"
 
@@ -3929,7 +3929,7 @@
 msgstr "adres geçersiz"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "adres geçersiz"
 
@@ -4024,316 +4024,316 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Sınırını belirlemek için kabukta `%s' çalıştırmayı deneyin.\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "-mvsx requires hardware floating point"
 msgstr "Donanım kayan nokta aritmetiği kullanılır"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-f%s ile -msdata=%s uyumsuz."
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "-mvsx needs indexed addressing"
 msgstr "İndisli adresleme kapatılır"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-f%s ile -msdata=%s uyumsuz."
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Kıymetsiz baytın başta olduğu kod üretilir"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "hatalı test"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "%%H değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "%%f değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "%%F değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "%%G değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "%%j kodu geçersiz"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "%%J kodu geçersiz"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "%%k değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "%%K değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "%%O değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "%%q değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "%%T değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "%%u değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "%%v değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "%%x değeri geçersiz"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, fuzzy, c-format
 #| msgid "invalid punctuation %qc in constraint"
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "kısıt içindeki `%qc' işareti geçersiz"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 #, fuzzy
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "%2$qT mutlak sınıf türündeki %1$qE ifadesi throw ifadesi içinde kullanılamaz"
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Her işlev için tek çıkış noktası üretilmez"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "aşağıdakiler için yeniden yüklemeler üretilemiyor:"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "adres çözümlenemez"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "'O' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "'b' değiştirici için terim geçersiz"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "geçersiz terim çıktı kodu"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, fuzzy, c-format
 #| msgid "invalid expression as operand"
 msgid "invalid expression - try using an output modifier"
 msgstr "terim olarak ifade geçersiz"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "'o' değiştiricisi için terim geçersiz"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec argümanı prototipsiz işleve aktarıldı"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "dönüş değerinde gösterici hedefleri farklı signed'lıkta"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 #, fuzzy
 #| msgid "target format does not support infinity"
 msgid "binary operator does not support vector bool operand"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4359,43 +4359,43 @@
 msgid "created and used with different endianness"
 msgstr "farklı bayt sıralaması ile oluşturulup kullanılmış"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "geçersiz %%Y terimi"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "geçersiz %%A terimi"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "geçersiz %%B terimi"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "geçersiz %%C terimi"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "geçersiz %%D terimi"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "geçersiz %%f terimi"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "geçersiz %%s terimi"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4578,30 +4578,30 @@
 msgid "bad test"
 msgstr "hatalı test"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "%%D değeri geçersiz"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "mask geçersiz"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "%%d değeri geçersiz"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "%%t/%%b değeri geçersiz"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "adreste yazmaç yok"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "adres mesafesi bir sabit değil"
 
@@ -4624,8 +4624,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> umuluyordu"
@@ -4647,8 +4647,8 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<(%>"
@@ -4655,7 +4655,7 @@
 msgstr "%<{%> umuluyordu"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4687,7 +4687,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4696,7 +4696,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4709,7 +4709,7 @@
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
@@ -4717,7 +4717,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> umuluyordu"
@@ -4727,7 +4727,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
@@ -4742,25 +4742,25 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "%2$qT mutlak sınıf türündeki %1$qE ifadesi throw ifadesi içinde kullanılamaz"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4770,20 +4770,20 @@
 msgid "expected %<.%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4792,18 +4792,18 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> umuluyordu"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<}%>"
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -4815,7 +4815,7 @@
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -4827,11 +4827,11 @@
 msgid "expected label"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "1. aday:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "2. aday:"
 
@@ -5090,11 +5090,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "adaylar:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -5292,93 +5292,93 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "%L'deki fiili argüman sözde INTENT = OUT/INOUT eşleşmesine tanımlanabilir olmalıdır"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "Pozitif genişlik gerekli"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "Negatif olmayan genişlik gerekli"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 #| msgid "Unexpected end of format string"
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Umulmadık biçim dizgesi sonu"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "Umulmadık biçim dizgesi sonu"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 #, fuzzy
 #| msgid "zero width in %s format"
 msgid "Zero width in format descriptor"
 msgstr "%s biçiminde sıfır uzunluk"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "Öndeki sol parantez eksik"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 #| msgid "template argument required for %<%s %T%>"
 msgid "Left parenthesis required after %<*%>"
 msgstr "%<%s %T%> için şablon argüman gerekli"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "Beklenmedik P düzenleme tanımlayıcı"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "P tanımlayıcı rehber katsayı gerektirir"
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-#| msgid "Missing right paren at %C"
-msgid "Right parenthesis expected at %C"
-msgstr "%C'de sağ parantez eksik"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 #, fuzzy
 #| msgid "Positive width required"
 msgid "Positive width required with T descriptor"
 msgstr "Pozitif genişlik gerekli"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 #, fuzzy
 #| msgid "Expected P edit descriptor"
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "Beklenmedik P düzenleme tanımlayıcı"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "Pozitif üstel genişlik gerekli"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+#| msgid "Missing right paren at %C"
+msgid "Right parenthesis expected at %C"
+msgstr "%C'de sağ parantez eksik"
+
+#: fortran/io.c:1040
 #, fuzzy
 #| msgid "unrecognized format specifier"
 msgid "Period required in format specifier"
 msgstr "tanınmayan biçim belirteci"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -5388,75 +5388,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "%C'deki ifadede sözdizimi hatası"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Beklenmeyen dosyasonu"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Tamsayı üstten taşması"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "İsim çok uzun"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "İsim hatalı"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Umulmadık isim"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "Umulmadık sol parantez"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "Sağ parantez umuluyordu"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Tamsayı umuluyordu"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Dizge umuluyordu"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum(): Enum yok"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Tamsayı dizgesi umuluyordu"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "Tamsayı dönüşümünde hata"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Gerçel sayı dizgesi umuluyordu"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "İfade türü umuluyordu"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "Hatalı işleç"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "Beklenmeyen modül sonu"
 
@@ -5753,12 +5753,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -6154,7 +6154,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 ve -m64 birlikte kullanılamayabilir"
 
@@ -9978,7 +9978,7 @@
 msgstr "Dolaysız TLS konumlarının bit genişliği belirtilir"
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 #, fuzzy
 #| msgid "Schedule code for given CPU"
@@ -10257,7 +10257,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
 msgid "Use LRA instead of reload."
@@ -10564,7 +10564,7 @@
 msgid "Use 80-bit long double."
 msgstr "128 bitlik long double kullanılır"
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 #| msgid "Use 64-bit long double"
@@ -10571,7 +10571,7 @@
 msgid "Use 64-bit long double."
 msgstr "64 bitlik long double kullanılır"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy
 #| msgid "Use 128-bit long double"
@@ -11963,117 +11963,117 @@
 msgid "64 bit ABI."
 msgstr "64 bitlik ABI"
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr ""
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 #, fuzzy
 #| msgid "Additional debug prints"
 msgid "Additional debug prints."
 msgstr "Ek hata ayıklama iletileri çıktılar"
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 #, fuzzy
 #| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
 msgstr "ESA/390 mimarisi"
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 #| msgid "Specify if floating point hardware should be used"
 msgid "Enable decimal floating point hardware support."
 msgstr "Eğer kayan nokta donanımı kulanılmalıysa belirtilir"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "Enable hardware floating point."
 msgstr "Donanım kayan nokta aritmetiği kullanılır"
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 #| msgid "Use hardware quad FP instructions"
 msgid "Use hardware transactional execution instructions."
 msgstr "Donanım bazlı quad fp komutları kullanılır"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 #, fuzzy
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 #, fuzzy
 #| msgid "Use packed stack layout"
 msgid "Use packed stack layout."
 msgstr "Paketlenmiş yığıt yerleşimi kullanılır"
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 #, fuzzy
 #| msgid "Use bras for executable < 64k"
 msgid "Use bras for executable < 64k."
 msgstr "64k'dan küçük çalıştırılabilirler için bras kullanılır"
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "Donanım kayan nokta aritmetiği kullanılır"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 #, fuzzy
 #| msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered"
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "Bir yakalama komutu tetiklenmeden önce yığıt boyutuna kalan azami bayt sayısını belirler"
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 #, fuzzy
 #| msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit"
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "Yığıt boyutu için verilen sınırın aşıldığı saptandığı sırada işlev önbilgisindeki ek kodu çıktılar"
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 #| msgid "Generate string instructions for block moves"
 msgid "Use the mvcle instruction for block moves."
 msgstr "Blok hareketleri için dizge komutları üretilir"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 #, fuzzy
 #| msgid "Warn if a function uses alloca or creates an array with dynamic size"
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "Bir işlev alloca kullanırsa ya da değişken boyutlu dizi oluşturursa uyarır"
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 #, fuzzy
 #| msgid "Warn if a single function's framesize exceeds the given framesize"
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "Tek işlevlik çalışma çerçevesi belirtileni aşarsa uyarır"
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 #, fuzzy
 #| msgid "z/Architecture"
 msgid "z/Architecture."
 msgstr "z/Mimari"
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -12135,11 +12135,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -12439,108 +12439,126 @@
 msgstr "UltraSPARC Görsel Komut Kümesi eklentileri kullanılır"
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 #, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "UltraSPARC Görsel Komut Kümesi eklentileri kullanılır"
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 #, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "UltraSPARC Görsel Komut Kümesi eklentileri kullanılır"
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
 #, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Kayan noktalı çarpma/toplama komutları üretilir"
+
+#: config/sparc/sparc.opt:102
+#, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "UltraSPARC Görsel Komut Kümesi eklentileri kullanılır"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 #, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "UltraSPARC Görsel Komut Kümesi eklentileri kullanılır"
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 #| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "Göstericiler 64 bittir"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 #| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "Göstericiler 32 bittir"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "64-bit ABI kullanılır"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "32-bit ABI kullanılır"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 #, fuzzy
 #| msgid "Use stack bias"
 msgid "Use stack bias."
 msgstr "Yığıt sapması kullanır"
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 #, fuzzy
 #| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Çift-sözcüklü kopyalarda daha kuvvetli hizalama için struct (yapı) kullanılır"
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 #, fuzzy
 #| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Çevirici ve ilintileyicide kuyruk çağrı komutlarını eniyiler"
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 #, fuzzy
 #| msgid "Generate code for the M*Core M210"
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr "M*Core M210 için kod üretilir"
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "Verilen işlemcinin özellikleri ve zamanlama kodu kullanılır"
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 #, fuzzy
 #| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
 msgstr "Belirtilen SPARC-V9 kod modeli kullanılır"
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "Enable debug output."
 msgstr "Hata ayıklamalı çıktı etkinleştirilir"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr ""
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -18464,7 +18482,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -19005,7 +19023,7 @@
 msgstr "İfade türü umuluyordu"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -19372,155 +19390,155 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 #| msgid "invalid operation on uninstantiated type"
 msgid "invalid comparison of non-ordered type"
 msgstr "örneklenmemiş tür üzerindeki işlem geçersiz"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 #, fuzzy
 #| msgid "%Hduplicate class will only be compiled once"
 msgid "slice can only be compared to nil"
 msgstr "%Hyinelenmiş sınıf sadece bir kere derlenecek"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 #, fuzzy
 #| msgid "%qs can only be specified for functions"
 msgid "map can only be compared to nil"
 msgstr "%qs sadece işlevler için belirtilebilir"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 #, fuzzy
 #| msgid "%Hduplicate class will only be compiled once"
 msgid "func can only be compared to nil"
 msgstr "%Hyinelenmiş sınıf sadece bir kere derlenecek"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operation (%s)"
 msgstr "%%R için terim geçersiz"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 #| msgid "invalid operation on uninstantiated type"
 msgid "invalid comparison of non-comparable type"
 msgstr "örneklenmemiş tür üzerindeki işlem geçersiz"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 #| msgid "invalid operation on uninstantiated type"
 msgid "invalid comparison of generated struct"
 msgstr "örneklenmemiş tür üzerindeki işlem geçersiz"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of generated array"
 msgstr "sol değersiz dizi kullanımı geçersiz"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of non-comparable array"
 msgstr "sol değersiz dizi kullanımı geçersiz"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 #, fuzzy
 #| msgid "Warn about implicit conversion"
 msgid "need explicit conversion"
 msgstr "Dolaylı dönüşümlerde uyarır"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, fuzzy, c-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot use type %s as type %s"
 msgstr "%qT türü %qT türüne dönüştürülemiyor"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 #, fuzzy
 #| msgid "invalid receiver type %qs"
 msgid "different receiver types"
 msgstr "alıcı tür %qs geçersiz"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "different number of parameters"
 msgstr "%q+D parametresinin yeniden tanımlanması"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 #, fuzzy
 #| msgid "invalid parameter type %qT"
 msgid "different parameter types"
 msgstr "geçersiz parametre türü %qT"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "%2$qE işlevinin %1$d. argümanı için tür uyumsuz"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 #, fuzzy
 #| msgid "error while parsing methods"
 msgid "type has no methods"
 msgstr "yöntemler çözümlenirken hata"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, fuzzy, c-format
 #| msgid "ambiguous abbreviation %s"
 msgid "ambiguous method %s%s%s"
 msgstr "belirsiz kısaltma %s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, fuzzy, c-format
 #| msgid "missing argument to \"%s\""
 msgid "missing method %s%s%s"
 msgstr "\"%s\" için argüman eksik"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -19707,7 +19725,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
@@ -19775,29 +19793,29 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "%qE özniteliği için vektör türü geçersiz"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -19805,7 +19823,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
@@ -19813,13 +19831,13 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to %<__builtin_frame_address%>"
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%<__builtin_frame_address%>'e aktarılan argüman geçersiz"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%>'in ikinci argümanı 1 olmalı"
@@ -19826,67 +19844,67 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "hedef biçim sonsuzu desteklemiyor"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> işlev içinde sabit sayıda argümanla kullanılmış"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> argümansız çağrılmış"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function %<va_start%>"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "%<va_start%> işlevine çok az argüman verilmiş"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfirst argument of %D must be a pointer, second integer constant"
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%H%D için ilk argüman bir gösterici, ikinci argüman sabit olmalıdır"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%H%D için son argüman 0 .. 3 arasında bir tamsayı sabit değil"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -20848,12 +20866,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F işlevi tanımlanmadan kullanılmış"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
@@ -20959,13 +20977,13 @@
 msgid "cannot find '%s'"
 msgstr "'%s' bulunamıyor"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "pex_init failed: %m"
 msgstr "pex_init başarısız"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -20976,7 +20994,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
@@ -21202,7 +21220,7 @@
 msgid "error writing %qs"
 msgstr "%qs yazılırken hata"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "%s açılamıyor"
@@ -21285,17 +21303,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -21410,13 +21428,13 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%q+D işlevinin yeniden bildirimi inline öznitelikli değil"
 
-#: expr.c:10811
+#: expr.c:10809
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared with attribute noinline"
 msgid "%Kcall to %qs declared with attribute warning: %s"
@@ -21434,13 +21452,13 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "%q+D boyutu %wd bayttan fazla"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open final insn dump file %qs: %m"
 msgstr "döküm dosyası %qs açılamadı: %s"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not close final insn dump file %qs: %m"
@@ -21457,7 +21475,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "karşılaştırma bit alanının genişliğinden dolayı daima %d"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -21487,7 +21505,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "fold sınaması: özgün ağac fold tarafından değiştirildi"
@@ -21498,7 +21516,7 @@
 msgid "total size of local objects too large"
 msgstr "%Jyerel nesnelerin toplam boyutu çok büyük"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> içindeki kısıt imnkansız"
@@ -21605,71 +21623,77 @@
 msgid "input file %qs is the same as output file"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, fuzzy, gcc-internal-format
+#| msgid "no input file specified"
+msgid "output filename may not be empty"
+msgstr "girdi dosyası belirtilmedi"
+
+#: gcc.c:4501
+#, fuzzy, gcc-internal-format
 #| msgid "warning: -pipe ignored because -save-temps specified"
 msgid "-pipe ignored because -save-temps specified"
 msgstr "UYARI: -save-temps belirtildiğinden -pipe yoksayıldı"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, fuzzy, gcc-internal-format
 #| msgid "warning: '-x %s' after last input file has no effect"
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "UYARI: son girdi dosyasından sonraki '-x %s' etkisiz"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "switch '%s' does not start with '-'"
 msgid "switch %qs does not start with %<-%>"
 msgstr "switch '%s' '-' ile başlamıyor"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open temporary response file %s"
 msgstr "döküm dosyası %qs açılamadı: %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot create temporary file"
 msgid "could not write to temporary response file %s"
 msgstr "geçici dosya oluşturulamıyor"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot create temporary file"
 msgid "could not close temporary response file %s"
 msgstr "geçici dosya oluşturulamıyor"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' invalid"
 msgid "spec %qs invalid"
 msgstr "spec '%s' geçersiz"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' has invalid '%%0%c'"
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "spec '%s' geçersiz '%%0%c' içeriyor"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' has invalid '%%W%c"
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "spec '%s' geçersiz '%%W%c içeriyor"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' has invalid '%%x%c'"
 msgid "spec %qs has invalid %<%%x%c%>"
@@ -21678,254 +21702,254 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, fuzzy, gcc-internal-format
 #| msgid "spec failure: '%%*' has not been initialized by pattern match"
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "belirtim aksaması: '%%*' kalıp eşleştirerek ilklendirilemedi"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, fuzzy, gcc-internal-format
 #| msgid "spec failure: unrecognized spec option '%c'"
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "belirtim aksaması: belirtim seçeneği '%c' anlaşılamadı"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown spec function %qs"
 msgstr "bilinmeyen '%s' spec işlevi"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function '%s'"
 msgid "error in args to spec function %qs"
 msgstr "'%s' spec işlevi için argümanlar hatalı"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "bozuk spec işlevi ismi"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "spec işlevi için argüman belirtilmedi"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "belirtim işlevinin argümanları bozuk"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, fuzzy, gcc-internal-format
 #| msgid "braced spec '%s' is invalid at '%c'"
 msgid "braced spec %qs is invalid at %qc"
 msgstr "kaşlı ayraçlı spec '%s' '%c'de geçersiz"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "braced spec body '%s' is invalid"
 msgid "braced spec body %qs is invalid"
 msgstr "kaşlı ayraçlı spec gövdesi '%s' geçersiz"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s: çıktı dosyası '%s' açılamadı\n"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s: çıktı dosyası '%s' açılamadı\n"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr ""
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "belirtim aksaması: SYSROOT_SUFFIX_SPEC için argüman sayısı birden fazla"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "belirtim aksaması: SYSROOT_HEADERS_SUFFIX_SPEC için argüman sayısı birden fazla.."
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized command line option %<-%s%>"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr ""
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "girdi dosyası yok"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify -o with -c or -S with multiple files"
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "çok sayıda dosya -o seçeneğinin -c veya -S ile birlikte kullanımı ile belirtilemez"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: %s derleyici bu sistemde kurulu değil"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr ""
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always %d"
 msgid "comparing final insns dumps"
 msgstr "karşılaştırma sonucu daima %d"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "field %qs not found"
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "alan %qs yok"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: ilintileme yapılmadığından ilintileyici girdi dosyası kullanılmadı"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "%s dili tanınmıyor"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 #| msgid "multilib spec '%s' is invalid"
 msgid "multilib spec %qs is invalid"
 msgstr "multilib spec '%s' geçersiz"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, fuzzy, gcc-internal-format
 #| msgid "multilib exclusions '%s' is invalid"
 msgid "multilib exclusions %qs is invalid"
 msgstr "multilib dışlaması olarak '%s' geçersiz"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select '%s' is invalid"
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib seçimi '%s' geçersiz"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select '%s' is invalid"
 msgid "multilib select %qs is invalid"
 msgstr "multilib seçimi '%s' geçersiz"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, fuzzy, gcc-internal-format
 #| msgid "multilib exclusion '%s' is invalid"
 msgid "multilib exclusion %qs is invalid"
 msgstr "multilib dışlaması olarak '%s' geçersiz"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable DJGPP not defined"
 msgid "environment variable %qs not defined"
 msgstr "ortam değişkeni DJGPP atanmamış"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number `%s'"
 msgid "invalid version number %qs"
 msgstr "geçersiz sürüm numarası `%s'"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "%%:version-compare için çok az argüman belirtildi"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "%%:version-compare için çok fazla argüman belirtildi"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, fuzzy, gcc-internal-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "%%:version-compare içindeki '%s' işleci bilinmiyor"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %%:version-compare"
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "%%:version-compare için çok fazla argüman belirtildi"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %%:version-compare"
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "%%:version-compare için çok fazla argüman belirtildi"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to %%:version-compare"
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "%%:version-compare için çok az argüman belirtildi"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %%:version-compare"
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "%%:version-compare için çok fazla argüman belirtildi"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to %%:replace-extension"
 msgstr "işlev için çok az argüman belirtildi"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %%:debug-level-gt"
@@ -22087,9 +22111,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -22521,247 +22545,247 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "using result of function returning %<void%>"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "asm çıktısı %d içinde geçersiz sol değer"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "bellek girdisi %d doğrudan adreslenebilir değil"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qD not declared"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qD bildirilmemiş"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "%s kapatılırken hata: %m"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%H%qE bildirilmemiş (bu işlevde ilk kullanımı)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "%<inline%> bildirimli %q+D değişkeni"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should be private"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qE should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be linear"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qE should not be private"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "%s variable %qE is private in outer context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD şablon bildirimi geçersiz"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, fuzzy, gcc-internal-format
 #| msgid "incoming edge count does not match number of PHI arguments"
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "gelen ayrıt sayısı PHI argüman sayısı ile uyuşmuyor"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimpleme başarısız"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT %<...%> üzerinden aktarılırken %qT'ye yükseltgenir"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(bu durumda %<va_arg%>'a %qT değil %qT akarılmalı)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Bu kodun bitiminde uygulama çıkacak"
@@ -23012,7 +23036,7 @@
 #: ipa-devirt.c:1229
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "%Jönceden burada tanımlı"
 
 #: ipa-devirt.c:1235
@@ -23114,9 +23138,10 @@
 msgstr ""
 
 #: ipa-devirt.c:1576
-#, gcc-internal-format
-msgid "fields has different layout in another translation unit"
-msgstr ""
+#, fuzzy, gcc-internal-format
+#| msgid "Different kind type parameters in pointer assignment at %L"
+msgid "fields have different layout in another translation unit"
+msgstr "%L'deki gösterici atamasında parametreler farklı çeşit türlerinde"
 
 #: ipa-devirt.c:1599
 #, gcc-internal-format
@@ -23528,194 +23553,194 @@
 msgid "multiple loop axes specified for routine"
 msgstr "veri türü ismi için saklama sınıfı belirtildi"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr ""
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr ""
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "invalid IACC argument"
 msgid "invalid arguments"
 msgstr "IACC argümanı geçersiz"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid exit from %s structured block"
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid entry to %s structured block"
@@ -23722,7 +23747,7 @@
 msgstr "%qs özniteliğinin argümanı geçersiz"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
@@ -23810,7 +23835,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "komut satırı seçeneği %qs bu yapılandırmada desteklenmiyor"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "missing argument to %qs"
@@ -23984,138 +24009,148 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.c:1837
+#: opts.c:1844
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "komut satırı seçeneği \"%s\" tanınmıyor"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "HSA has not been enabled during configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "yapı hizalama ikinin küçük bir üssü olmalı %d değil"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter %qs"
 msgid "unknown stack check parameter %qs"
 msgstr "parametre %qs kullanılmamış"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "dwarf version %d is not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: --param seçeneğinin argümanları iSiM=DEĞER biçiminde olmalı"
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "--param değeri %qs geçersiz"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs"
 msgstr "--param değeri %qs geçersiz"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "--param değeri %qs geçersiz"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "hedef sistem hata ayıklama çıktısını desteklemiyor"
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "\"%s\" hata ayıklama biçimi önceki seçimle çelişiyor"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "hata ayıklama çıktı seviyesi \"%s\" tanınmıyor"
 
-#: opts.c:2533
+#: opts.c:2540
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "hata ayıklama çıktılama seviyesi %s çok yüksek"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "core dosyasının boyu azami sınıra getiriliyor: %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "core dosyasının boyut sınırı azami değere ayarlanıyor: %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "tanınmayan gcc hata ayıklama seçeneği: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr ""
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -24482,7 +24517,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "yazmaç iki genel yazmaç değişkeni için kullanılmış"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -25117,13 +25152,13 @@
 msgid "error closing %s: %m"
 msgstr "%s kapatılırken hata: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "self-tests incompatible with -E"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -26131,53 +26166,53 @@
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i yakalanamıyor ama EH ayrıtları var"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i can not throw but has an EH edge"
 msgstr "BB %i yakalanamıyor ama EH ayrıtları var"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "BB %i son deyiminin bölgesi yanlış belirlenmiş"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unnecessary EH edge %i->%i"
 msgid "Incorrect EH edge %i->%i"
 msgstr "gereksiz EH ayrıtı %i->%i"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i too many fallthru edges"
 msgstr "düşen ayrıtta yanlış komut"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i has incorrect edge"
 msgstr "BB %i son deyiminin bölgesi yanlış belirlenmiş"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i has incorrect fallthru edge"
@@ -26283,36 +26318,36 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "in a call to built-in function %qD"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "in a call to function %qD declared here"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, fuzzy, gcc-internal-format
 #| msgid "cannot optimize loop, the loop counter may overflow"
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "döngü en iyilenemez, döngü sayacının taşma olasılığı var"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "operation on %qE may be undefined"
 msgid "iteration %s invokes undefined behavior"
 msgstr "%qE ifadesinde işlem tanımsız olabilir"
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "within this loop"
@@ -26681,11 +26716,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -27717,7 +27752,7 @@
 msgid "type was previously declared %qE"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -28004,7 +28039,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD adresi, daima %<true%> olarak değerlendirilecek"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "atamayı sarmalayan parantezler muhtemelen doğruluk değeri olarak kullanılmış"
@@ -28659,66 +28694,66 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "biçim argümanında (%d. argüman) fazladan tür niteleyiciler"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%s%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%q.*s biçiminin %<%s%s%> türünde olması umuluyor, ama %d. argüman %qT türünde"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%qs için bir sabit argüman beklenir"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%q.*s biçiminin %<%T%s%> türünde olması umuluyor, ama %d. argüman %qT türünde"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%qs için bir sabit argüman beklenir"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> bir tür olarak tanımlı değil"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%>, %<long%> veya %<long long%> olarak tanımlı değil"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> bir tür olarak tanımlı değil"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> bir tür olarak tanımlı değil"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> bir tür olarak tanımlı değil"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> bir gösterici türü olarak tanımlı değil"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "biçimlenecek argümanlar %<...%> değil"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime biçimleri argümanları biçimleyemez"
@@ -28826,7 +28861,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr ""
@@ -28858,7 +28893,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, fuzzy, gcc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid type for iteration variable %qE"
@@ -28876,24 +28911,24 @@
 msgid "%qE is not initialized"
 msgstr "ilklendirici yok"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid controlling predicate"
 msgstr "koşullu terim geçersiz"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, fuzzy, gcc-internal-format
 #| msgid "assignment suppression"
 msgid "missing increment expression"
 msgstr "atama engelleme"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, fuzzy, gcc-internal-format
 #| msgid "invalid truth-value expression"
 msgid "invalid increment expression"
@@ -29475,8 +29510,8 @@
 msgid "wrong type argument to %s"
 msgstr "abs'a yanlış türde argüman"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "sabit ifadesinde taşma"
@@ -30215,7 +30250,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<_Cilk_spawn%> may only be used inside a function"
@@ -30387,7 +30422,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "-mdebug-%s seçeneği bilinmiyor"
@@ -30730,7 +30765,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%qd argümanı bir sabit değil"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -30823,7 +30858,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "-mmacosx-version-min için %qs değeri bilinmiyor"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
@@ -30923,9 +30958,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "spec '%s' geçersiz"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -31015,7 +31050,7 @@
 msgstr "-mmemory-latency için değer %qs hatalı"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -31206,239 +31241,239 @@
 msgid "insn addresses not freed"
 msgstr "ön arttırımlı adres bir yazmaç değil"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "this builtin is not supported for this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "seçici bir anlık değer olmalı"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, fuzzy, gcc-internal-format
 #| msgid "-fpic and -mapcs-reent are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-fpic ve -mapcs-reent uyumsuz"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support ARM mode"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "geri izleme desteğinin etkinleştirilmesi sadece Thumb komut seti için derleme yapılırken anlamlidir"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "çağrılan ile birlikte çalışma desteğinin etkinleştirilmesi sadece Thumb için derleme esnasında anlamlıdır"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g ile -mno-apcs-frame anlamlı hata ayıklama bilgisi vermeyebilir"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, fuzzy, gcc-internal-format
 #| msgid "can not use -mtp=cp15 with -mthumb"
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "-mtp=cp15, -mthumb ile kullanılamaz"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "assert: %s %s ile uyumlu atanıyor"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "target CPU does not support unaligned accesses"
@@ -31446,150 +31481,150 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC is not currently supported on the 68000 or 68010"
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-fPIC su an 68000 veya 68010 için desteklenmiyor"
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check ile -mno-apcs-frame uyumsuz"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic ve -mapcs-reent uyumsuz"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS yeniden girişli kod desteklenmiyor. Yoksayıldi"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable ile -msdata=%s uyumsuz"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt, düzgün işlem için ABI uyumlu bir AAPCS gerektiriyor"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi bir iwmmxt yetenekli işlemci gerektiriyor"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "hedef işlemci beraber çalışmayı desteklemiyor"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard ve VFP"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard ve VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "veri yapısı boyut sınırı sadece %s ye ayarlanabilir"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "veri yapısı boyut sınırı sadece %s ye ayarlanabilir"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr ""
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register=, -fpic olmaksızın kullanışsız"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "PIC yazmacı için '%s' kullanılamıyor"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition bu mimaride çalışmaz"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "hedef işlemci THUMB komutlarını desteklemiyor"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -31598,79 +31633,84 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to functions"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qs özniteliği sadece işlevlere uygulanır"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE özniteliği sadece genel nesnelerde etkilidir"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qs özniteliği sadece işlev türlerine uygulanır"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "yığıttaki parametrenin gerçek konumu hesaplanamıyor"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Beklenmeyen modül sonu"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "yüksek yazmaçları çekmeye elverişli düşük yazmaç yok"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for attribute(target(\"%s\"))"
@@ -31679,13 +31719,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
@@ -31793,183 +31833,195 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
 msgstr "işlev bir değer ile donmuyor"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%qs appears to be a misspelled signal handler"
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs imlası bozuk bir sinyal eylemcisi gibi görünüyor"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "Tamsayı argümanları aktarmada kullanılan yazmaçların sayısı"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D not supported"
 msgid "writing to address space %qs not supported"
 msgstr "%q+D zayıf bildirimi desteklenmiyor"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE özniteliği sadece değişkin işlevlere uygulanır"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported on this platform"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute address out of range"
 msgstr "%qs özniteliği veri türlerine uygulanmaz"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "bu hedefte -fdata-sections desteklenmiyor"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "%2$s bit kipinde %1$qs kod modeli desteklenmiyor"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "static IO declaration for %q+D needs an address"
 msgstr "%q+D bildirimi bir parametreyi gölgeliyor"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "IO definition for %q+D needs an address"
 msgstr "%q+D'nin önceki tanımı buradaydı"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr ".noinit alanına sadece ilklendirilmiş değişkenler yerleştirilebilir"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "program bellek alanına sadece ilklendirilmiş değişkenler yerleştirilebilir"
+
+#: config/avr/avr.c:10160
+#, fuzzy, gcc-internal-format
+#| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "program bellek alanına sadece ilklendirilmiş değişkenler yerleştirilebilir"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU `%qs' sadece sembolik çevirici için desteklenir"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "conversion from address space %qs to address space %qs"
 msgstr "%s den %s e dönüşüm (%L'de)"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of module in string constant"
 msgid "%s expects a compile time integer constant"
 msgstr "Dizge sabitinde umulmadık modül sonu"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -32272,12 +32324,12 @@
 msgid "invalid IACC argument"
 msgstr "IACC argümanı geçersiz"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs için bir sabit argüman beklenir"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "sabit argüman %qs için aralık dışında"
@@ -32474,7 +32526,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "PIC kipinde %s kod modeli desteklenmiyor"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "code model %s not supported in PIC mode"
 msgid "code model %s does not support PIC mode"
@@ -32618,319 +32670,319 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "bu hedefte -fprefetch-loop-arrays desteklenmiyor"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-mpreferred-stack-boundary=%d is not between %d and 12"
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mpreferred-stack-boundary=%d, %d ile 12 arasında değil"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, fuzzy, gcc-internal-format
 #| msgid "-msseregparm used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "-msseregparm SSE etkin değilken kullanılmış"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE komut kümesi iptal edildi, 387 aritmetiği kullanılıyor"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 komut kümesi iptal edildi, SSE aritmetiği kullanılıyor"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, fuzzy, gcc-internal-format
 #| msgid "unwind tables currently require either a frame pointer or -maccumulate-outgoing-args for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "birbirlerini etkilemeyenler tabloları doğruluk için ya bir çerçeve göstericisi ya da -maccumulate-outgoing-args gerektirir"
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "bilinmeyen -m%s= seçeneği belirtilmiş: '%s'"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ACCESS specification at %L was already specified"
 msgid "option(\"%s\") was already specified"
 msgstr "ACCESS belirtimi %L'de zaten belirtilmiş"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use a stack protection method for every function"
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "Her işlev için bir yığıt koruma yöntemi kullanılır"
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall ve regparm öznitelikleri uyumlu değil"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qs özniteliğine argüman %d den büyük"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall ve cdecl öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qT çağrısı"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "multilib desteklenmiyor"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, fuzzy, gcc-internal-format
 #| msgid "-march=%s is not compatible with the selected ABI"
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "-march=%s seçilen ABI ile uyumsuz"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE etkin değilken SSE vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör argümanı ABI'yi değiştirir"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX etkin değilken MMX vektör dönüşü ABI'yi değiştirir"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE etkin değilken SSE yazmaç argümanı"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, fuzzy, gcc-internal-format
 #| msgid "SSE register return with SSE disabled"
 msgid "x87 register return with x87 disabled"
 msgstr "SSE etkin değilken SSE yazmaç dönüşü"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 etkin değilken sseregparm öznitelikli %qD çağrısı"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -32937,335 +32989,335 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "ek yazmaçların yüksek yarıları yok"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ek yazmaç için desteklenmeyen terim boyutu"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %D"
 msgstr "%q+D bildiriminin önceki bildirimi"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return bu hedefte desteklenmiyor"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "-ffpe-trap seçeneğinin argümanı geçersiz: %s"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 2-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 #| msgid "shift must be an immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "shift bir anlık değer olmalı"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the last argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 1-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "yanlış komut:"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "Ağaç düğümlerinin paylaşımı yanlış"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "last argument must be an immediate"
 msgstr "mask bir anlık değer olmalı"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "yanlış komut:"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs özniteliği sadece değişkenlere uygulanır"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "fastcall ve stdcall öznitelikleri uyumsuz"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "%qs uyumsuz özniteliği yoksayıldı"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "sistem kesmesi Servis İşlemleri Thumb kipinde kodlanamaz"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, fuzzy, gcc-internal-format
 #| msgid "standard conversions are not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown machine mode %qs"
 msgid "unknown asm flag output %qs"
 msgstr "%qs makine kipi bilinmiyor"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for asm flag output"
 msgstr "tür argümanı geçersiz"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "desteklenmeyen birleşim: %s"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "$ tarzı biçimde kullanılmamış argümanlar"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33400,7 +33452,7 @@
 msgid "argument %qd is not a constant"
 msgstr "%qd argümanı bir sabit değil"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, boş gösterici"
@@ -33410,7 +33462,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: '%c' noktalaması bilinmiyor"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND boş gösterici"
@@ -33523,7 +33575,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "yığıt sınırlama ifadesi desteklenmiyor"
@@ -34062,8 +34114,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
 msgid "bad builtin code"
@@ -34337,29 +34389,29 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ özniteliğine özdevinimli saklatım sınıfında izin verilmez"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -34384,7 +34436,7 @@
 msgid "-g option disabled"
 msgstr "-g seçeneği iptal edildi"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "hizalama (%u) %s için genel ortak veri azami hizalamasını aşıyor.  %u kullanılıyor"
@@ -34528,170 +34580,170 @@
 msgid "junk at end of #pragma longcall"
 msgstr "'#pragma longcall' sonunda karışıklik"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "vec_mul only accepts 2 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "vec_adde only accepts 3 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "vec_addec only accepts 3 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "%s only accepts %d arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "%s only accepts 1 argument"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "%s only accepts 2 arguments"
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "%2$qE işlevinin %1$d. argümanın aktarımı gösterici hedef türündeki niteleyicileri iptal ediyor"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-m%s not supported in this configuration"
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "-m%s bu yapılandırmada desteklenmiyor"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "AltiVec yerleşiği için parametre birleşimi geçersiz"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 seçeneği PowerPC64 mimarisini gerektirir, etkinleştiriliyor"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 64 bitlik Darwin için desteklenmiyor; kurulu C ve C++ kütüphaneleri ile uyumsuz"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, fuzzy, gcc-internal-format
 #| msgid "not configured for ABI: '%s'"
 msgid "not configured for SPE ABI"
 msgstr "ABI için yapılandırılmadı: '%s'"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use PowerPC instruction set"
 msgid "not configured for SPE instruction set"
 msgstr "PowerPC komut kümesi kullanılmaz"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "AltiVec not supported in this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "SPE not supported in this target"
 msgstr "bu hedefte yığıt sınırları desteklenmiyor"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple kıymetsiz baytın başta olduğu sistemlerde desteklenmez"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring kıymetsiz baytın başta olduğu sistemlerde desteklenmez"
@@ -34698,76 +34750,76 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, fuzzy, gcc-internal-format
 #| msgid "Emit code compatible with TI tools"
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "TI araçları ile uyumlu kod üretilir"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d requires -mpaired-single"
 msgid "-mcrypto requires -maltivec"
 msgstr "-mips3d seçeneği -mpaired-single gerektirir"
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mdirect-move requires -mvsx"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-vector requires -mvsx"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode requires -mvsx"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d requires -mpaired-single"
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "-mips3d seçeneği -mpaired-single gerektirir"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -34776,248 +34828,248 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode might need -mlra"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr "--resource, -o gerektirir"
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, fuzzy, gcc-internal-format
 #| msgid "-mips3d requires -mpaired-single"
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr "-mips3d seçeneği -mpaired-single gerektirir"
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 #| msgid "\"%s\" is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "\"%s\" önişlemci için geçerli bir seçenek değil"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından döndürüldü: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmaçındaki değer döndürülemez, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "AltiVec komutları iptal edildiğinden vektör yazmacındaki argüman aktarılamaz, komutları etkinleştirmek için -maltivec kullanın"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektörü başvurusu tarafından aktarıldı: bir uyumluluk garanti etmeksizin standartdışı ABI eklentisi"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %s already processed"
 msgstr "Girdi dosyaları evvelce önişlemden geçirilmiş kabul edilir"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "1. argüman 5 bitlik bir işaretli sabit olmalı"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "__builtin_altivec_predicate'in 1. argümanı bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "__builtin_altivec_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%q+D takes only zero or two arguments"
 msgid "builtin %s only accepts a string argument"
@@ -35024,7 +35076,7 @@
 msgstr "%q+D ya iki argüman alır ya da hiç almaz"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "cpu %s is an invalid argument to builtin %s"
@@ -35031,308 +35083,313 @@
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "3. argüman 4 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "2. argüman 5 bitlik bir işaretsiz sabit olmalı"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "sayı 0 ya da 1 olmalı"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "%L'deki ATANH argümanı -1 .. 1 aralığının içinde kalmalı"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "Altivec yerleşiği %qF için çözümlenmemiş aşırı yükleme"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "dss argümanı 2 bitlik işaretsiz bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "%<__builtin_prefetch%> için 3. argüman bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "__builtin_spe_predicate'in 1. argümanı bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "__builtin_spe_predicate'in 1. argümanı bir sabit olmalı"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "__builtin_spe_predicate'in 1. argümanı aralık dışında"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "bu yerleşik işlev sadece fr450 üzerinde kullanılabilir"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "yerleşik işlev `%q+D işlev olarak bildirilmemiş"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "command line option %qs is not supported by this configuration"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "komut satırı seçeneği %qs bu yapılandırmada desteklenmiyor"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "yığıt çerçevesi çok büyük"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 esnek dizi üyelerini desteklemez"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma extern_prefix not supported on this target"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma extern_prefix bu hedefte desteklenmiyor"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "bu ABI için 64 bitlik profilleme kodu yok"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<long double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec türlerde %<complex%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, fuzzy, gcc-internal-format
 #| msgid "use of boolean types in AltiVec types is invalid"
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "AltiVec türlerde mantıksal türlerin kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "AltiVec türlerde %<long%> kullanımı 64 bitlik kod için geçersiz"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec türlerde %<long%> kullanımı önerilmiyor; %<int%> kullanın"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "AltiVec türlerde %<long long%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "AltiVec türlerde %<double%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid use of %<::%>"
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "%<::%> kullanımı geçersiz"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s\"%s\"%s is invalid"
 msgstr "spec '%s' geçersiz"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -35525,6 +35582,7 @@
 msgstr "-mapcs-stack-check ile -mno-apcs-frame uyumsuz"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 seçeneği PowerPC64 mimarisi gerektirir"
@@ -35617,7 +35675,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
 msgid "constant value required for builtin %qF argument %d"
@@ -35647,7 +35705,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -35669,7 +35727,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -35684,40 +35742,40 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "sabit argüman %qs için aralık dışında"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "unresolved overloaded builtin"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin fcode"
@@ -35724,123 +35782,123 @@
 msgid "bad builtin icode"
 msgstr "hatalı yerleşik fcode"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to builtin function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "yerleşik işleve aktarılan argüman geçersiz"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Yerel değişkenlerin toplam boyutu mimarinin izin verdigi sınırı aşıyor"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs çerçevi boyutu "
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs özdevimli yığıt tahsisi kullanıyor"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture kipi %s üzerinde desteklenmiyor"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "ESA/390 kipinde 64 bitlik ABI desteklenmiyor."
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware vector support not available on %s"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Restrict the use of hardware floating-point instructions to 32-bit operations"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Donanım kayan nokta komutlarının kullanımını 32 bitlik işlemlerle sınırlar"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float bir arada desteklenmiyor"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "yığıt boyutunun yığıt koruma değerinden büyük olması gerekir"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "yığıt boyutu 64k'dan büyük olmamalıdır"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard, -mstack-size uyguluyor"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "\"%s\" için argüman sıfır ya da pozitif bir tamsayı olmalı"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
@@ -35847,7 +35905,7 @@
 msgstr "%qs özniteliğine argüman %d den büyük"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -35911,27 +35969,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "static TPF-OS'da desteklenmiyor"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s bu yapılandırma ile desteklenmiyor"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 ile -m64 bir arada olmaz"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "-mcmodel= seçeneğinin değeri (%s) hatalı"
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= 32 bitlik sistemlerde desteklenmiyor"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "-fcall-saved-REG is not supported for out registers"
@@ -36240,22 +36299,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "#pragma %s geçersiz"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "mantıksal yazmaçlar kayan nokta seçeneği için gerekli"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "-f%s seçeneği CONST16 komutları ile desteklenmiyor"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "PIC gerekli ama  CONST16 komutları ile desteklenmiyor"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "sadece ilklendirilmemiş değişkenler .bss bölümüne yerleştirilebilir"
@@ -36349,7 +36408,7 @@
 msgid "could not read the BRIG file"
 msgstr "belirtim dosyası %s bulunamadı\n"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -36776,9 +36835,9 @@
 msgstr "%q+D yaftası tanımlı ama kullanılmamış"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -36920,7 +36979,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -38076,7 +38135,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "bildirim belirteçleri içinde iki veya daha fazla veri türü"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> GCC için çok uzun"
@@ -38232,17 +38291,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C salt %<complex%>i %<double complex%> anlamında desteklemez"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C karmaşık tamsayı türleri desteklemez"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -38295,7 +38354,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -38340,7 +38399,7 @@
 msgstr "bilinmeyen yazmaç ismi: %s"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "bildirim belirteçleri umuluyordu"
@@ -38357,7 +38416,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -38375,8 +38434,8 @@
 msgid "unexpected attribute"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -38418,7 +38477,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
@@ -38448,7 +38507,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 %<long long%>'u desteklemez"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "dizge sabiti umuluyordu"
@@ -38520,14 +38579,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "betimleyici umuluyordu"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "sembolik sabitler listesinin sonunda virgul"
@@ -38667,7 +38726,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<,%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -38693,12 +38752,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -38712,18 +38771,18 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "deyim umuluyordu"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an if-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%Hif deyiminin gövdesi boş"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, fuzzy, gcc-internal-format
 #| msgid "%Hempty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
@@ -38734,7 +38793,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -38756,7 +38815,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "komuttaki yazmaç geçersiz"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -38950,18 +39009,18 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "?: için terimler farklı türde"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -39019,35 +39078,35 @@
 msgid "no type or storage class may be specified here,"
 msgstr "%qs için saklatım sınıfı belirtilmiş"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> sonrasında %<(%> eksik - yoksayıldı"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
@@ -39054,33 +39113,33 @@
 msgstr "%Jadres alanı özelliği işlevler için belirtilemez"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for, while or do statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, fuzzy, gcc-internal-format
 #| msgid "malformed #pragma GCC pch_preprocess, ignored"
 msgid "%<#pragma GCC pch_preprocess%> must be first"
@@ -39097,13 +39156,13 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected integer expression before ')'"
@@ -39121,61 +39180,61 @@
 msgid "%qD is not a variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bir şablon değil"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "collapse argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<none%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses without modifier"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -39205,25 +39264,25 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<grainsize%> value must be positive"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 #| msgid "%s at %L must be a scalar"
 msgid "%<priority%> value must be non-negative"
 msgstr "%s' (%L'de) bir değişmez olmalıdır"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<tofrom%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<scalar%>"
@@ -39234,63 +39293,63 @@
 msgid "%<num_workers%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments for format"
 msgid "too many %<static%> arguments"
 msgstr "biçim için argüman sayısı çok fazla"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "Expected attribute bit name"
 msgid "unexpected argument"
 msgstr "Öznitelik bit ismi umuluyordu"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%qs value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qs öznitelik argümanı bir tamsayı sabit değil"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 #| msgid "comparison between signed and unsigned integer expressions"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "işaretli ve işaretsiz tamsayı ifadeler arasında karşılaştırma"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "chunk size value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid schedule kind"
@@ -39306,17 +39365,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -39337,19 +39396,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "geçersiz %%d terimi"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "mask geçersiz"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -39361,74 +39420,74 @@
 msgid "invalid proc_bind kind"
 msgstr "geçersiz döngü komutu"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid output file"
 msgid "%qs is not valid for %qs"
 msgstr "%qs geçerli bir çıktı dosyası değil"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a nested class of %qT"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qT %qT'nin alt sınıfı değil"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD shadows a global declaration"
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD bildirimi bir global bildirimi gölgeliyor"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is a variably modified type"
 msgid "invalid OpenACC clause at file scope"
 msgstr "%qT değişkene göre değişen türde"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<for%> döngüsünün ilk bildiriminde %<extern%> değişken %q+D bildirimi"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "dizge sabiti umuluyordu"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -39445,7 +39504,7 @@
 msgid "expected function name"
 msgstr "umulmadık düğüm"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -39457,47 +39516,47 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 #| msgid "malformed %<#pragma align%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma align%> bozuk"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operation on %<__fpreg%>"
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<__fpreg%> üzerinde geçersiz işlem"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -39508,29 +39567,29 @@
 msgid "expected %<(%> or end of line"
 msgstr "Beklenmeyen modül sonu"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "for statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 #| msgid "%s statement expected at %L"
 msgid "_Cilk_for statement expected"
 msgstr "%s deyimi %L'de umuluyordu"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration declaration or initialization"
@@ -39541,76 +39600,76 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "tek parametre olarak %<void%> yeterli olmayabilir"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -39626,7 +39685,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> %D bildiriminden önce görünmeli, yoksayılıyor"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -39636,34 +39695,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "%<{%> umuluyordu"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -39720,25 +39779,25 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, fuzzy, gcc-internal-format
 #| msgid "%Jparameter %u has incomplete type"
 msgid "%<threadprivate%> %qE has incomplete type"
@@ -39755,56 +39814,56 @@
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "yığıt boyutu ikinin üstel katlarında olmalı"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "seçici 0..%wi aralığında bir tamsayı sabit olmalı"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -39815,7 +39874,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or numeral"
@@ -40587,7 +40646,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "ilklendirmede sol taraf bir biçim özniteliği adayı olabilir"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
@@ -40924,7 +40983,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C %<goto *expr;%> kullanımına izin vermez"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> olarak bildirilmiş işlev %<return%> deyimi içeriyor"
@@ -40934,7 +40993,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -40962,7 +41021,7 @@
 msgid "function returns address of label"
 msgstr "işlev yerel değişkenin adresi ile dönüyor"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch miktarı bir tamsayı değil"
@@ -40978,7 +41037,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case etiketi bir switch deyimi içinde değil"
@@ -40998,17 +41057,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue deyimi bir döngü içinde değil"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with OpenMP for loop"
@@ -41020,7 +41079,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
@@ -41132,12 +41191,12 @@
 msgid "used vector type where scalar is required"
 msgstr "doğrudan değer gereken yerde yapı türünde değer kullanılmış"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -41148,28 +41207,28 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "%qs bit alanı geçersiz tür içeriyor"
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bir üye şablon işlevi değil"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %qs clause"
@@ -41182,19 +41241,19 @@
 msgstr "girdi dosyası sayısı çok fazla"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -41201,56 +41260,56 @@
 msgstr "array new içindeki boyut bütünleyici türde olmalı"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "zero length array section in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Dizi bölümlerini yordam girdisinde sürekli bir blokun içine kopyalar"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have pointer or array type"
@@ -41273,7 +41332,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction not found for %qE"
@@ -41284,17 +41343,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -41314,20 +41373,20 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -41339,34 +41398,34 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -41389,60 +41448,60 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' is not a valid class name"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "'%s' geçerli bir sınıf ismi değil"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not declare a template type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bir şablon türü bildirmiyor"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bir işlev şablonu değil"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -41453,32 +41512,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -42067,165 +42126,165 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "%2$q#D işlevinin %<this%> parametresi olarak %1$qT aktarımı niteleyicileri iptal ediyor"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  %qD çağrısında"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to %s %q+#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "%s %q+#D için argümanlar çok fazla"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "kurucular virtual olarak bildirilemez"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "%<%T::%s(%A)%#V%> çağrısı ile eşleşen işlev yok"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> çağrısı ile eşleşen bir işlev yok"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "aşırı yüklü %<%s(%A)%> çağrısı belirsiz"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from constructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from destructor"
 msgstr "%qT %qD isminde statik olmayan bir üyeye sahip değil"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "üye işlev %qD nesne olmaksızın çağrılamaz"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "%qT aktarımı %qT türünü %qT türü üzerinden seçiyor"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD %qD üzerinden,"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  %qT türünden %qT türüne dönüşüm için seçiliyor,"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  çünkü argüman için dönüşüm süreci daha iyi"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, fuzzy, gcc-internal-format
 #| msgid "default argument specified in explicit specialization"
 msgid "default argument mismatch in overload resolution"
 msgstr "doğrudan özelleştirmede öntanımlı argüman belirtilmiş"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 1: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 #| msgid "candidate is: %+#D"
 msgid " candidate 2: %q#F"
 msgstr "aday: %+#D"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "İlkinin en kotü dönüşümü ikincisinden daha iyi olsa bile ISO C++ bunlar belirsizdir der:"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "%qE %qT türüne dönüştürülemedi"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "%qT türündeki sabit olmayan başvurunun geçici %qT türünden ilklendirilmesi geçersiz"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "%qT türündeki başvurunun %qT türündeki ifadeden ilklendirilmesi geçersiz"
@@ -42333,297 +42392,297 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "taban %qT türünden türetilmiş %qT türüne dönüşüm sanal taban %qT üzerinden yapılamaz"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "sınıf %qT içindeki tüm üye işlevler 'private'"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T sadece private bir yıkıcı tanımlıyor ve kardeşleri yok"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T sadece private kurucular tanımlıyor ve kardeşleri yok"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD için %qT içinde eşsiz bir son değiştirici yok"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D,"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  %q+D tarafından gizlendi"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D geçersiz; bir anonim union sadece statik olmayan veri üyeleri içerebilir"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "anonim union içinde private üye %q+#D"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous struct"
 msgstr "anonim union içinde private üye %q+#D"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous struct"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bit-alanı %q+#D tümleyen türde değil"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bit alanı %q+D için genişlik bir tamsayı sabit değil"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bit alanı %q+D için genişlik negatif"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bit alanı %q+D için sıfır genişlik"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D kendi türünden geniş"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D alanı %#T türünün tüm değerlerini tutmak için çok küçük"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "union içinde kuruculu üye %q+#D olamaz"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "union içinde yıkıcılı üye %q+#D olamaz"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "union içinde kopya atama isleçli üye %q+#D olamaz"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D bir union üyesi olduğundan static olmayabilir"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "%q+D alanı ile geçersiz olarak işlev türü bildirildi"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "%q+D alanı ile geçersiz olarak yöntem türü bildirildi"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute on unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "paketsiz POD olmayan %q+#D alanı üzerinde paketli öznitelik yoksayılıyor"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "üye olmayan %qs, %<mutable%> olarak bildirilemez"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "union %qT içinde çok sayıda alan ilklendirildi"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "%q+#D alanı sınıf ile aynı isimde"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T gösterici veri üyeleri içeriyor"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  ama %<%T(const %T&)%>ye değiştirilmiyor"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  ya da %<operator=(const %T&)%> içeriyor"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  ama %<operator=(const %T&)%>ye değiştirilmiyor"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "sanal olmayan yöntem %q+D için ilklendirici belirtilmiş"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a base of %qT"
 msgid "%q+T is not literal because:"
 msgstr "%qT %qT tabanında değil"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static data member %q+D"
 msgid "  non-static data member %qD has volatile type"
 msgstr "static olmayan veri üyesi %q+D kullanımı geçersiz"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "taban sınıf %q#T bir sanal olmayan yıkıcıya sahip"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "bir kurucu olmaksızın sınıf içinde static olmayan başvuru %q+#D"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -42631,166 +42690,166 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "doğrudan taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "sanal taban %qT belirsizlikten dolayı %qT içinde erişilebilir değil"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D alanının göreli konumu ABI-uyumlu değil ve bu GCC'nin gelecek sürümünde değişebilir"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "%qs dizisinin boyutu çok büyük"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> at top level"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "esnek dizi üyeli yapı kullanımı geçersiz"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "parameter %qD declared void"
 msgid "array member %q#D declared here"
 msgstr "parametre %qD void olarak bildirilmiş"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%Jesnek dizi yapının son üyesi değil"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%Jbaşka bir boş yapı içinde esnek dizi"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "next member %q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T sınıfın yeniden tanımı"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions but non-virtual destructor"
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T sanal olmayan kuruculu sanal işlevler içeriyor"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "sınıf %qT %qD isminde alan içermiyor"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "%qs türü sanal üye işlevlere sahip"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "yapı tamamlanmaya çalışılırken önceki ayrıştırma hatalarından dolayı kesildi"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "dil dizgesi %<\"%E\"%> tanınmıyor"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, fuzzy, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "%2$qT türüne dönüşüme dayalı aşırı yüklü %1$qD işlevi çözümlenemiyor"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "%qD işlevinin %q#T türüne dönüşümü için eşleşme yok"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "aşırı yüklü %qD işlevinin %q#T türüne dönüşümü belirsiz"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "%qD üyesine gösterici varsayılıyor"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(bir üye göstericisi sadece %<&%E%> ile şekillendirilebilir)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE ifadesi %qT türünden %qT türüne dönüştürülemez"
@@ -42800,12 +42859,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D yeniden bildirimi"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -42838,382 +42897,382 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "işlev %q+#D için soyut dönüş değeri türü geçersiz"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "%q#T has virtual base classes"
 msgstr "%qs türü sanal üye işlevlere sahip"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%Jtaban sınıf %q#T kopyalama kurucusunda doğrudan ilklendirilmiş olmalı"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is normally a non-static function"
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%q+D normalde bir static olmayan işlevdir"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%q+E is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "expression %qE does not designate a constexpr function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
 msgstr "işlev olmayan %qD ye çağrı"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D tanımlanmadan önce prototipsiz kullanılmış"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokol %qs döngüsel bağımlılık içeriyor"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "sağa kaydırma sayısı negatif"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is not an integer"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "dizi indisi bir tamsayı değil"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> gösterici ilişkilendirmesi"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "no field %qD found in union being initialized"
 msgid "%qD used in its own initializer"
 msgstr "ilklendirilen union içinde %qD diye bir alan yok"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%q#D is not const"
 msgstr "%q+D bir işlev değil,"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D private'dir"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD bu etki alanında bildirilmemiş"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "%qD dizisinin boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "koşullu ifade içinde enum ve enum olmayan türler"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "statement is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "ifade umuluyordu"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%H%qE burada bildirilmemiş (bir işlev içinde değil)"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "size of array is not an integral constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "dizi boyutu bir tümleyen sabit ifadesi değil"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "ilklendiricide sabit olmayan dizi indisi"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -44095,7 +44154,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  %q+#D ilklendirmesi atlanıyor"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -44111,7 +44170,7 @@
 msgid "%qD is not a type"
 msgstr "%qD bir şablon değil"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD şablon parametreleri olmaksızın kullanılmış"
@@ -45912,7 +45971,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "%<inline%> bildirimli %q+D parametresi"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "bir argüman listesi olmaksızın %qE şablon isminin kullanımı geçersiz"
@@ -46399,13 +46458,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD bildirildiği sınıf ile aynı isimde"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT bir şablon değil"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -46416,8 +46475,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
@@ -46469,7 +46528,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
@@ -46538,7 +46597,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>, %<*this%> için bir başvuru döndürmeli"
@@ -46554,7 +46613,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "void olmayan dönüşlü işlevde `return' deyimi yok"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
@@ -46721,27 +46780,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "%qD dizisinin boyutu tümlemeyen %qT türünde"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonim yapı isimli türün içinde değil"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "isim alanı bağlamındaki anonim kümeler static olmalıdır"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "üyesiz anonim union"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> %qT türünde dönmeli"
@@ -46750,68 +46809,68 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, fuzzy, gcc-internal-format
 #| msgid "second parameter of %<va_start%> not last named argument"
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<va_start%>'in ikinci parametresi isimli son argüman değil"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> ilk parametreyi %<size_t%> (%qT) türünde alir"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> %qT türünde dönmeli"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> ilk parametreyi %qT türünde alır"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -46821,50 +46880,50 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D niteliksiz türe başvurmuyor, dolasıyla ilintileme için kullanılmaz"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%<static%> olarak bildirilen `%q+F hiç tanımlanmamış"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%2$qL ilintili önceki %1$q+#D bildirimi"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "satıriçi işlev %q+D tanımlanmadan kullanılmış"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "%2$q+#D'nin %1$P. parametresi için öntanımlı argüman eksik"
@@ -46871,12 +46930,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "use of deleted function %qD"
@@ -47203,7 +47262,7 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "üye %qs için ilk değer geçersiz"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
@@ -47210,13 +47269,13 @@
 msgstr "ilklendirilmemiş sabit üyesi %qD"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "%q+D sonradan ilklendirilmiş olacak"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
@@ -47324,7 +47383,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qT is not a class type"
@@ -47345,7 +47404,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "static olmayan veri üyesi %qD kullanımı geçersiz"
@@ -47551,24 +47610,24 @@
 msgid "because the array element type %qT has variable size"
 msgstr "bileşik sabit değişken boyuta sahip"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot capture %qE by reference"
 msgstr "%q#T türüne başvuru bildirilemez"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot %s a pointer to incomplete type %qT"
 msgid "capture by copy of incomplete type %qT"
 msgstr "%s içi boş %qT türüne bir gösterici olamaz"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> was not captured for this lambda function"
@@ -47624,122 +47683,122 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(%<-fpermissive%> kullanırsaniz, G++ kodunuzu kabul edecek ama bildirilmemiş isim kullanımına izin vermek artık önerilmiyor)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "%<?:%> için ortadaki terim olmadığından yorumlanamadı"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD' nin anlamlandırılmış ismi GCC'nin gelecek sürümünde değişecek"
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q#D, can't use default assignment operator"
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "statik olmayan sabit üye %q#D, öntanımlı atama işleci kullanamaz"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member %q#D, can't use default assignment operator"
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "statik olmayan referans üye %q#D, öntanımlı atama işleci kullanamaz"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsynthesized method %qD first required here "
 msgid "synthesized method %qD first required here "
 msgstr "%Hbireştirilmiş %qD yöntemi önce burada gerekli"
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, fuzzy, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "%1$J%<const%> %3$qT türü ile ilklendirilmemiş üye %2$qD"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, fuzzy, gcc-internal-format
 #| msgid "Constructor can't be %s"
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "Kurucu %s olmayabilir"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "initializer for %q#D is invalid"
 msgstr "%qT için ilklendirici {} içinde olmalı"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "invalid access to non-static data member %qD of NULL object"
 msgid "copying non-static data member %q#D of rvalue reference type"
@@ -47746,79 +47805,79 @@
 msgstr "NULL nesnenin static olmayan veri üyesi  %qD'ye erişim geçersiz"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 #| msgid "repeated using declaration %q+D"
 msgid "defaulted declaration %q+D"
 msgstr "%q+D bildirimi kullanılarak yinelenmiş"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, fuzzy, gcc-internal-format
 #| msgid "array does not match the region tree"
 msgid "does not match expected signature %qD"
 msgstr "dizi bölge ağacıyla eşleşmiyor"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "a template cannot be defaulted"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be declared"
 msgid "%qD cannot be defaulted"
 msgstr "%q+#D bildirilemez"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, fuzzy, gcc-internal-format
 #| msgid "file ends in default argument"
 msgid "defaulted function %q+D with default argument"
@@ -48025,101 +48084,101 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, fuzzy, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "%3$q#T içinde %<%1$T::%2$D%> ile eşleşen bir üye yok"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD bildirimi %qD'yi kuşatan isim alanında değil"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD bildiriminde doğrudan niteleme"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "%qD has not been declared"
 msgid "%qD has not been declared within %D"
 msgstr "%qD bildirilmemişti"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a friend"
 msgstr "%q+D bir kardeş olarak bildirilmiş"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD %qD içinde bildirilmeliydi"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs özniteliği bir tamsayı sabit argüman gerektirir"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%qD öznitelik yönergesi yoksayıldı"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "burada isim alanı rumuzu %qD kullanılamaz, %qD varsayılıyor"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "Önerilmiyor; yerine -Wextra kullanın"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "kesin kullanım sadece isimalanı kapsamında anlamlıdır"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, fuzzy, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "%3$qD isim alanını kapsamayan %2$qD isim alanında doğrudan %1$qD bildirimi"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -48126,28 +48185,28 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX, pop_everything () işlevine giriyor\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX, pop_everything () işlevini bırakıyor\n"
@@ -48168,7 +48227,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -48195,7 +48254,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "sınıf olmayan %2$qT türündeki %1$qD üyesi için istek"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -48265,117 +48324,117 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(belki de %qT bildiriminden sonra bir ; yoktur)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a template"
 msgid "%qE is not a class template"
 msgstr "%qE bir şablon değil"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE bir şablon değil"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "geçersiz şablon kimliği"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a function call cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an increment cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of destructor %qD as a type"
@@ -48382,685 +48441,691 @@
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, fuzzy, gcc-internal-format
 #| msgid "invalid definition of qualified type %qT"
 msgid "invalid combination of multiple type-specifiers"
 msgstr "nitelikli tür %qT tanımı geçersiz"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE bir türü isimlendirmiyor"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE bir türü isimlendirmiyor"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(belki de %<typename %T::%E%> demek istiyordunuz)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in namespace %qE does not name a type"
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE %qE isim alanında bir türü isimlendirmiyor"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE %qE isim alanında bir türü isimlendirmiyor"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has no default constructor to call"
 msgid "and %qT has no template constructors"
 msgstr "%qs türü için çağrılacak öntanımlı kurucu yok"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in class %qT does not name a type"
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE %qT sınıfında bir türü isimlendirmiyor"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in class %qT does not name a type"
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE %qT sınıfında bir türü isimlendirmiyor"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected string-literal"
 msgstr "dizge sabiti umuluyordu"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "a wide string is invalid in this context"
 msgstr "bu bağlamda"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "integer constant is too large for %qs type"
 msgid "integer literal exceeds range of %qT type"
 msgstr "tamsayı sabit %qs türü için oldukça büyük"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %<%s%>"
 msgid "floating literal exceeds range of %qT type"
 msgstr "gerçel sayı sabit %<%s%> aralığı dışında"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr ""
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, fuzzy, gcc-internal-format
 #| msgid "unable to find a register to spill in class %qs"
 msgid "unable to find numeric literal operator %qD"
 msgstr "%qs sınıfı içinde dökülecek bir yazmaç bulunamadı"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
 msgstr "boş bildirim"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected binary operator"
 msgstr "beklenmeyen terim"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected ..."
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "binary expression in operand of fold-expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "conditional expression in operand of fold-expression"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "mismatched operator in fold-expression"
 msgstr "koşullu ifadede tür uyumsuzluğu"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe not supported"
 msgid "fixed-point types not supported in C++"
 msgstr "-pipe desteklenmiyor"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ da kaşlı ayracla gruplanmış ifadelere izin verilmez"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "statement-expressions are allowed only inside functions"
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "deyim ifadelerine sadece işlevlerin içinde izin verilir"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "bu kapsamda %<this%> kullanılamaz"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "Objective-C declarations may only appear in global scope"
 msgid "a template declaration cannot appear at block scope"
 msgstr "Objective-C bildirimleri sadece genel etki alanında görünebilir"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "yerel değişken %qD bu kapsamda görünemez"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a class or namespace"
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%2$qT üyesi olarak %<~%1$T%> bildirimi"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef ismi %qD yıkıcı bildiricisi olarak kullanılmış"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "belirteç niteleyici listesi umuluyordu"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is not an enumeration type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "içi boş %qT türü alt isim belirtecinde kullanılmış"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bir şablon değil"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected nested-name-specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in casts"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for %qs attribute"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "%qs özniteliği için belirtilen argüman sayısı yanlış"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 #| msgid "wrong type argument to bit-complement"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "bit-tümler için yanlış türde argüman"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ birleşik sabitlere izin vermez"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "braced list index is not allowed with array notation"
 msgstr "-client_name ile -dynamiclib birarada olmaz"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "%<%D::%D%> is not a member of %qT"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%>, %qT'nin bir üyesi değil"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "parantezli tür kimliğinden sonra dizi sınırı yasak"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "tür kimliğini sarmalayan parantezleri kaldırmayı deneyin"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "eski tarz tür dönüşümü"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, fuzzy, gcc-internal-format
 #| msgid "suggest parentheses around && within ||"
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "|| içindeki && çevresinde parantezler önerilir"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 #| msgid "parse error in template argument list"
 msgid "lambda-expression in template-argument"
 msgstr "şablon argüman listesinde çözümleme hatası"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Beklenmeyen modül sonu"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qD "
 msgstr "salt-okunur değişken %qD için eksiltme"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "burada bildirilmiş %q+D"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C90 karmaşık türleri desteklemez"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "%<volatile%> yinelenmiş"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case etiketi %qE bir switch deyimi içinde değil"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> %qT içinde kurucu isimlendiriyor"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, fuzzy, gcc-internal-format
 #| msgid "Discover pure and const functions"
 msgid "compound-statement in constexpr function"
 msgstr "Saf ve sabit işlevler keşfedilir"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "ifade deyimi boş tür içeriyor"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "bildirim veya deyim umuluyordu"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 #| msgid "break statement not within loop or switch"
 msgid "break statement used with Cilk Plus for loop"
 msgstr "break deyimi switch ya da döngü içinde değil"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ hesaplanmış goto'lara izin vermez"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "fazladan %<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "karışık bildirimler ve işlev tanımları yasaktır"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "boş bildirim"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
 #, fuzzy, gcc-internal-format
+#| msgid "invalid initial value for member %qs"
+msgid "invalid initializer for structured binding declaration"
+msgstr "üye %qs için ilk değer geçersiz"
+
+#: cp/parser.c:13220
+#, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> sadece bir sınıf içinde belirtilebilir"
@@ -49067,123 +49132,123 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "pure-specifier on function-definition"
 msgid "decl-specifier invalid in condition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D %q#T içinde geçersiz"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "sınıf tanımı kardeş olarak bildirilemeyebilir"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, fuzzy, gcc-internal-format
 #| msgid "only constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "temel ilklendiricileri sadece kurucular alır"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "uye %qD için ilklendirici eksik"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D statik bildirimi statik olmayan bildirimi izliyor"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "artık tarih olmuş eski tarz temel sınıf ilklendiricisi"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (bir nitelikli üye ilklendirici örtük olarak bir tür olduğundan)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conditional operand"
 msgid "invalid encoding prefix in literal operator"
 msgstr "koşullu terim geçersiz"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -49190,75 +49255,75 @@
 msgstr "beklenmeyen terim"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "%<export%> anahtar sözcüğü gerçekleştirilmedi ve yoksayılacak"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid constrained type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter packs cannot have default arguments"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> bir şablon argüman listesi başlatamaz"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ile %<[%> aynı şeyi gösterir. %<<%> ile %<::%> arasında boşluk bırakın"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use -fpermissive G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(-fpermissive kullanırsanız G++ kodunuzu kabul edecek)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "şablon argüman listesinde çözümleme hatası"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
@@ -49265,331 +49330,331 @@
 msgstr "deyim umuluyordu"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "bir şablon olduğunu belirtmek için %<%T::template %D%> kullanın"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "C ilintileme ile şablon özelleştirmesi"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C ileriye dönük parametre bildirimlerine izin vermez"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "İfade türü umuluyordu"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Umulmadık isim"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "declaration %qD does not declare anything"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "attributes ignored on uninstantiated type"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "attributes ignored on template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 #| msgid "expression in new-declarator must have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new bildirimli ifade bütünleyici ya da numaralama türünde olmalı"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Özdevinimli şablon örneklenimi etkin olur"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%3$qD'yi kapsamayan %2$qD etki alanı içinde %1$qD türünde bildirim"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 #| msgid "extra qualification ignored"
 msgid "extra qualification not allowed"
 msgstr "fazladan niteleme yoksayıldı"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "çok sayıda %q#T tanımı"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids %sing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ bir enum'um %s-lenmesine izin vermez"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD bir isim alanı ismi değil"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Bir satıriçi işlev satıriçi olamadığında uyarır"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "nested identifier required"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "isim alanı %qD'nin ifade olarak kullanımı"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<#pragma%> burada kullanılamaz"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "using bildiriminde bir şablon kimliği bulunamaz"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 #| msgid "%s: function definition not converted\n"
 msgid "a function-definition is not allowed here"
 msgstr "%s: işlev tanımı dönüştürülmedi\n"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "bir işlev tanımında bir asm belirtimine izin verilmez"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function %qs"
 msgid "initializer provided for function"
 msgstr "kardeş işlev %qs ilklendirilemiyor"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "parantezli ilklendiriciden sonraki öznitelikler yoksayıldı"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "işlev %q+D 'inline' olarak yeniden bildirilmiş"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -49598,7 +49663,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
@@ -49606,377 +49671,377 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "işlev bildirimi geçersiz"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD bir isim alanıdır"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "beklenmeyen terim"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "cv-niteleyici yinelenmiş"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "missing template arguments after %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "%qD kullanımı geçersiz"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<virtual%> in template declaration of %q#D"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "%<virtual%> kullanımı %q#D şablon bildiriminde geçersiz"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "betimleyici umuluyordu"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "öntanımlı argümanlara sadece işlev parametresi olarak izin verilir"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, fuzzy, gcc-internal-format
 #| msgid "template parameters cannot be friends"
 msgid "template parameter pack cannot have a default argument"
 msgstr "şablon parametreleri kardeş olamazlar"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "parameter pack cannot have a default argument"
 msgstr "%qD öntanımlı argümanlara sahip olamaz"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tasarlanmış ilkendiricilere izin vermez"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "%C'deki işlev bildiriminden sonra umulmayan döküntü"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "sınıf %s için dosya bulunamıyor"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD bildirimindeki sınıf ismi geçersiz"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "bir doğrudan özelleştirme %<template <>%> ile öncelenmeli"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "function template %qD redeclared as a class template"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T türünde önceden tanım"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "sınıf ismi umuluyordu"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, fuzzy, gcc-internal-format
 #| msgid "a class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "bir kardeş bildirilirken bir sınıf anahtarı kullanılmalıdır"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "kardeş bildirimi bir sınıf veya işlevi isimlendirmiyor"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "işlev tanımında pure belirteci"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, fuzzy, gcc-internal-format
 #| msgid "cannot use %<::%> in parameter declaration"
 msgid "expected %<;%> at end of member declaration"
 msgstr "parametre bildiriminde %<::%> kullanılamaz"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "şablonlar dışında %<typename%> kullanımına izin verilmez"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%<typename%> anahtar sözcüğüne bu bağlamda izin verilmez (taban sınıfı örtük olarak bir türdür)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 #| msgid "Generate code to check exception specifications"
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "Olağan dışılık belirtimlerini sınayacak kod üretilir"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<this%> in non-member function"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s özniteliği ile %s özniteliği %L'de çelişiyor"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "betimleyici veya %<(%> umuluyordu"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "bildirim belirteçleri veya %<...%> umuluyordu"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a requires expression cannot appear outside a template"
 msgstr "%s bir sabit ifadesinde görünemez"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "yeniden %q+D bildirimi geçersiz"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "şablon parametresi listesi çok az"
@@ -49985,476 +50050,476 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "şablon parametresi listesi çok fazla"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "isimli dönüş değerleri artık desteklenmiyor"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "Enable fused multiply/add instructions"
 msgid "empty introduction-list"
 msgstr "Birleşik çarpma/toplama komutları etkinleştirilir"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, fuzzy, gcc-internal-format
 #| msgid "invalid declaration of member template %q#D in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "yerel sınıf içinde %q#D üye şablonu bildirimi geçersiz"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C ilintilemeli şablon"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %qs"
 msgid "template declaration of %<typedef%>"
 msgstr "%qs şablon bildirimi"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "bildirim hiçbir şey bildirmiyor"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, fuzzy, gcc-internal-format
 #| msgid "explicit specialization in non-namespace scope %qD"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "isim alanı olmayan %qD kapsamında doğrudan özelleştirme"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> alt şablon argüman listesinde %<> >%> olmalıydı"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "sahte  %<>>%>, bir şablon argüman listesini sonlandırmak için %<>%> kullanın"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, fuzzy, gcc-internal-format
 #| msgid "%<__thread%> before %<extern%>"
 msgid "%<__thread%> before %qD"
 msgstr "%<extern%> öncesinde %<__thread%>"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support %<long long%>"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ %<long long%> desteklemez"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 #| msgid "both %<short%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "bildirim belirteçlerinde hem %<short%> hem de %<char%>"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE yinelenmiş"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "%qs yinelenmiş"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "deyim umuluyordu"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "%<{%> umuluyordu"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> veya %<...%> umuluyordu"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<,%>, %<;%> veya %<}%> umuluyordu"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs yaftası %q#T isimlemesinde kullanılmış"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "%q+#D evvelce burada bildirilmiş"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD farklı erişimle tekrar bildirilmiş"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%<template%> (bir belirsizlik giderici olarak) sadece şablonlarda kullanılabilir"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "öntanımlı argüman içinde dosya sonu"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "yanlış yere konmuş %<@%D%> Nesnel-C++ oluşumu"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> bir argüman olarak bir tür belirtmeli"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Nesnel-C++ seçici ismi geçersiz"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "bildirim belirteçleri umuluyordu"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%Jbölüm özniteliği yerel değişkenler için belirtilmiş olamaz"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, fuzzy, gcc-internal-format
 #| msgid "illegal reference type specified for instance variable %qs"
 msgid "invalid type for instance variable"
 msgstr "gerçekleme değişkeni %qs için ilişkilendirme türü kuraldışı"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> sonrasında betimleyici umuluyordu"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE özniteliği %qE için yoksayıldı"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tür argümanı geçersiz"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<wait%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 #| msgid "Initialization at %C is not allowed in a PURE procedure"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "%C'de ilklendirmeye bir PURE işlevinde izin verilmez"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "iteration variable %qD should not be reduction"
 msgstr "yazmaç değişkeni %qD iç işlevde kullanılmış"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, fuzzy, gcc-internal-format
 #| msgid "not enough type information"
 msgid "not enough for loops to collapse"
 msgstr "tür bilgisi yetersiz"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "bir işlev tanımıda özniteliklere izin verilmez"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "geçersiz ilklendirici"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "ifade umuluyordu"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -50461,74 +50526,74 @@
 msgstr "%qD bir üye şablon işlevi değil"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, fuzzy, gcc-internal-format
 #| msgid "junk at end of %<#pragma pack%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma pack%> sonunda döküntü"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "kısıtlar terim için geçersiz"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC memregs must precede any function decls"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC memregs bir işlev bildirimi ile öncelenmeli"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "modüller arası eniyilemeler henüz C++ için gerçeklenmedi"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "%C'de değişken ismi umuluyordu"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "%<,%> veya %<;%> umuluyordu"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
@@ -50626,7 +50691,7 @@
 msgid "candidate is: %#D"
 msgstr "aday: %+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
@@ -51260,131 +51325,149 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+#| msgid "partial specialization %qT does not specialize any template arguments"
+msgid "the address of %qD is not a valid template argument"
+msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+#| msgid "partial specialization %qT does not specialize any template arguments"
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "kısmi özelleştirme %qT hiç bir şablon argümanını özelleştirmiyor"
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+#| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
+
+#: cp/pt.c:6672
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "cv nitelemesinde çeliştiğinden dolayı %qE %qT türü için geçerli bir şablon argümanı değildir"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil cunku o bir sol taraf terimi değil"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not a constant pointer"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir sabit göstericisi değildir"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qD nesnesi için harici ilintileme yok"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü o bir göstericidir"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "yerine %qE kullanmayı deneyin"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE %qT türü için geçerli bir şablon argümanı değil çünkü %qT türündedir"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "standart uzlaşımlara bu bağlam içinde izin verilmez"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes on template argument %qT"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "applying attributes to template parameters is not implemented"
 msgid "ignoring attributes in template argument %qE"
 msgstr "özniteliklerin şablon parametrelerine uygulanması gerçeklenmedi"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of constructor as a template"
 msgid "invalid use of destructor %qE as a type"
 msgstr "kurucunun şablon olarak kullanımı geçersiz"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "bir şablon parametresinin bir tür üyesine basvurmak için %<typename %E%> kullanın"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, fuzzy, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  %qT türünde bir sabit umulurken %qT alındı"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  bir sınıf sablonu umulurken %qE alındı"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  bir tür umulurken %qE alındı"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  bir tür umulurken %qT alındı"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  bir sınıf sablonu umulurken %qT alındı"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  %qD türünde bir şablon umulurken %qD alındı"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "%2$qD için şablon parametre listesindeki %1$d. argümanda tür/değer uyumsuzluğu"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
@@ -51392,110 +51475,110 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in conditional expression"
 msgid "type mismatch in nontype parameter pack"
 msgstr "koşullu ifadede tür uyumsuzluğu"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "şablon argümanı %qE %qT'ye dönüştürülemedi"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "yanlış sayıda şablon argümanı (%d yerine %d olmalıydı)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "%q+D için sağlanmış"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "öntanımlı argüman %2$q#D bildiriminin %1$d. parametresi için"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "%q+D için sağlanmış"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bir işlev şablonu değil"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "şablon olarak şablon olmayan tür %qT kullanılmış"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "%q+D şablon bildirimi için"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "dahili tutarlılık hatası"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "use of invalid variable template %qE"
 msgstr "%qD bir şablon değil"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %qD örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -51514,289 +51597,289 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, fuzzy, gcc-internal-format
 #| msgid "variable %qD has initializer but incomplete type"
 msgid "variable %qD has function type"
 msgstr "%qD değişkeni ilklendiricili ama içi boş türde"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "geçersiz parametre türü %qT"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "%q+D bildiriminde"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "bir dizi döndüren işlev"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "bir işlev döndüren işlev"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye işlev göstericisi oluşturulması"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "void'e referans oluşturuluyor"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "%s %qT referans türünde şekilleniyor"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "%2$qT işlev türüne ekli %1$qV niteleyicileri yoksayılıyor"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "sınıf olmayan %qT türünde üye göstericisi oluşturulması"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "%qT üye referans türünde gösterici oluşturulması"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "void türünde üyeye gösterici oluşturulması"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "%qT dizisi oluşturulması"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ne bir class, ne struct, ne de union türünde"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT bir enum türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT bir sınıf türü olmayan %qT türüne çözümleniyor"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "şablonda %qs kullanımı"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "%qE bağımlı ismi bir tür olarak çözümlenmedi ama örneklenim onun bir tür olmasını istiyor"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "eğer bu bir tür anlamındaysa %<typename %E%> deyin"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "geçersiz alan %qD kullanımı"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of void expression"
 msgid "invalid use of pack expansion expression"
 msgstr "void ifade kullanımı geçersiz"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, fuzzy, gcc-internal-format
 #| msgid "%<...%> as arguments.)"
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> kabul edeceği varsayılacak.)"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a type"
 msgid "use %<%T::%D%> instead"
 msgstr "%<%T::%D%> bir tür değil"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D tanımlandıktan sonra satıriçi bildirilmiş"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bir sınıf ya da isim alanı değil"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ne bir sınıf ne de isim alanı"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT anonim türdür/tür kullanır"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for %q#D has type %qT"
 msgid "template argument for %qD uses local type %qT"
 msgstr "%q#D için öntanımlı argüman %qT türünde"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT değişkene göre değişen türde"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "bütünleyen ifade %qE bir sabit değil"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  %qD örneklenmeye çalışılıyor"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T için sınıf şablonu örneklenimi belirsiz"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, fuzzy, gcc-internal-format
 #| msgid "%q#D is not a non-static data member of %qT"
 msgid "%qD is not a static data member of a class template"
 msgstr "%q#D %qT'nin bir static olmayan üyesi değildir"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD için eşleşen bir şablon yok"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "yinelenmiş doğrudan %q#D örneklenimi"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids the use of %<extern%> on explicit instantiations"
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %<extern%> kullanımına izin vermez"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "şablon olmayan %q#D'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "şablon olmayan tür %qT'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "şablon tanımından önce %q#T'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ doğrudan örneklenimlerde %qE kullanımına izin vermez"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "yinelenmiş doğrudan %q#T örneklenimi"
@@ -51808,102 +51891,102 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "bir tanımlama olmadan %qD'nin doğrudan örneklenimi"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "%d lik azami şablon örneklenim derinliği %q+D örnekleniminde aşılıyor (azami değeri arttırmak için -ftemplate-depth-NN kullanın)"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "invalid template non-type parameter"
 msgstr "yakalama parametresi geçersiz"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bir şablon sabiti parametresi için geçerli bir tür değildir"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "şablon olarak şablon olmayan %qD kullanılmış"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "%d. şablon argümanı geçersiz"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "işlev satıriçine alınma sırasında görmezden gelinir"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 #| msgid "invalid covariant return type for %q+#D"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "%q+#D için ortak değişen dönüş türü geçersiz"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, fuzzy, gcc-internal-format
 #| msgid "unable to emulate %qs"
 msgid "unable to deduce %qT from %qE"
 msgstr "%qs öykünümü mümkün değil"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "komut kendi kısıtlarını gözönüne almıyor:"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -52076,177 +52159,177 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  `%q+#D' taban sınıfta bildirildiğinden"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "%Hanlamca belirsiz %<else%>den kaçınmak için kaşlı ayraçlar önerilir"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "asm terimi %qE'nin türü saptanamadı"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, fuzzy, gcc-internal-format
 #| msgid "Objective-C declarations may only appear in global scope"
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "Objective-C bildirimleri sadece genel etki alanında görünebilir"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "statik üye işlevde üye %q+D kullanımı geçersiz"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "yıkıcıların argümanı olmaz"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "statik üye işlevlerde %<this%> kullanılmaz"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "üye olmayan işlevde %<this%> kullanımı geçersiz"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "tepe seviyede %<this%> kullanımı geçersiz"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "sözde yıkıcı isminde niteleyen etki alanı geçersiz"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "yetkin tür %qT, yıkıcı ismi ~%qT ile eslesmiyor"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE %qT türünde değil"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, fuzzy, gcc-internal-format
 #| msgid "compound literal has variable size"
 msgid "compound literal of non-object type %qT"
 msgstr "bileşik sabit değişken boyuta sahip"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "şablon türü parametrelerde %<class%> ya da %<typename%> sözcüğü kullanılmalı"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "bir şablonun şablon parametresinin öntanımlı değeri olarak %qT türünün kullanımı geçersiz"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "bir şablonun şablon parametresi için öntanımlı argüman geçersiz"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "şablon parametre listesi içinde %q#T tanımı"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "nitelikli tür %qT tanımı geçersiz"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "taban sınıf belirtimi geçersiz"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anonim union içinde protected üye %q+#D"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a template"
 msgid "%qD is not captured"
 msgstr "%qD bir şablon değil"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "iceren işlevden %<auto%> kullanımı"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "iceren işlevden parametre kullanımı"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter from containing function"
 msgid "use of parameter outside function body"
 msgstr "iceren işlevden parametre kullanımı"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "missing template arguments"
 msgstr "tür argümanı geçersiz"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "%qD şablon parametresi %qT türündeyse butunleyen ya da sırali türde olmadığından bir butunleyen sabit ifadesinde kullanılmaz"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "isim alanı %qD'nin ifade olarak kullanımı"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "sınıf sablonu %qT'nin ifade olarak kullanımı"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "uye %qD için istek çoklu miras kafesi içinde belirsiz"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD bir sabit ifadesinde bulunamaz"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE türü bilinmiyor"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -52253,330 +52336,330 @@
 msgstr "%qT bir şablon türü değil"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "saklatım sınıfı belirteçleri parametre bildiriminde geçersiz"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "static olmayan üye işlev %qD kullanımı geçersiz"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%qD ile ilişkilendirme belirsiz"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "vektör silme işlemi için tür ne gösterici ne de dizi"
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<restrict%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%<restrict%> kullanımı geçersiz"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not an accessible base of %qT"
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qT erişilebilir bir %qT tabanı değil"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 #| msgid "instance variable %qs is declared private"
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "gerçeklenim değişkeni %qs private olarak bildirilmiş"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> static expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> static value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<gang%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<vector%> length expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<worker%> num expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "Expression at %L must be scalar"
 msgid "%qs expression must be integral"
 msgstr "%L'deki ifade değişmez olmalı"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "%s tag at %L must be of type %s"
 msgid "%<gang%> num value must be positive"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "%<vector%> length value must be positive"
 msgstr "yığıt boyutu ikinin üstel katlarında olmalı"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%s ifade listesi bilesik ifade olarak ele alıniyor"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD değişken sayıda argümana sahip olmamalı"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "template %qE in clause %qs"
 msgstr "girdi dosyası sayısı çok fazla"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<grainsize%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<priority%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 #| msgid "STAT expression at %C must be a variable"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%C'deki STAT ifadesi bir değişken olmalıdır"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> bir gösterici türü olarak tanımlı değil"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CRIS-port assertion failed: "
 msgid "static assertion failed: %s"
 msgstr "CRIS-port olumlaması başarısız: "
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, fuzzy, gcc-internal-format
 #| msgid "non-static declaration of %q+D follows static declaration"
 msgid "non-constant condition for static assertion"
 msgstr "%q+D statik olmayan bildirim statik bildirimi izliyor"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of SELECT statement at %L must be a scalar expression"
 msgid "argument to decltype must be an expression"
 msgstr "%L'deki SELECT deyiminin argümanı bir sabit ifadesi olmalı"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s aşırı yüklü işlevin adresini çözümleyemiyor"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "virgüllü ifadenin sol terimi etkisiz"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "şablon argümanı %qE şablon parametre(ler)ini içine alıyor"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -52593,121 +52676,121 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Sabit ifadesinde tür hatalı"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE özniteliği veri türlerinde yoksayılır"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "istenen init_priority bir tamsayı sabit değil"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "%qE özniteliği sadece sınıf türünde nesnelerin dosya bağlamı tanımlarında kullanılabilir"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "istenen init_priority aralık dışında"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "istenen init_priority iç kullanim için ayrilmiştir"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "bu platformda %qE özniteliği desteklenmiyor"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "%2$s olarak %1$qD bildirimi"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "the %qE attribute requires arguments"
 msgstr "%qE özniteliği isimli argümanları olan prototipler gerektirir"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qs özniteliğinin argümanı bir dizge sabiti değil"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> geçerli bir bildirici değil"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE özniteliği sınıf türleri dışında yoksayılır"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%qE özniteliği sadece sınıf tanımlarına uygulanabilir"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 #| msgid "storage class %qD applied to template instantiation"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "saklama sınıfı %qD şablon örneklenimine uygulanmış"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE özniteliği sadece işlevlere uygulanır"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "dizi sınırı bir tamsayı sabit değil"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* denetimi: %2$s dosyasının %3$d. satırındaki %1$s içinde başarısız"
@@ -53457,115 +53540,115 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "%qT'ye %qT'den dönüşüm geçersiz"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "%4$qD işlevinin %3$qP. argümanı için %1$qT türü %2$qT türüne dönüştürülemez"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in return"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "%qT %qT'ye %s içinde dönüştürülemez"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "dönüş türü %q#T bir içi boş türdür"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE işlevinin %1$d. argümanı bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "dönüş türü bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "işlev çağrısı argümanı bir biçim özniteliği için aday olabilir"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "atamada sol taraf bir biçim özniteliği adayı olabilir"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "%2$q+D işlevinin %1$P. argümanına aktarımda"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "geçiciye başvuru dönüyor"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "sag yansiz dönüşluye referans"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "yerel değişken %q+D'ye referans donduruldu"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "yerel değişken %q+D adresi donduruldu"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "bir yıkıcıdan değer donuyor"
@@ -53572,58 +53655,58 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "bir kurucunun bir işlev deneme blokunun bir tutamagından dondurulemez"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "kurucudan bir değer dondurulemez"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "%qT donduren işlevde değer içermeyen return"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "ilklendirici yok"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "new türleri bir dönüş türünde tanımlanamayabilir"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, fuzzy, gcc-internal-format
 #| msgid "Inconsistent ranks for operator at %L and %L"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "%L ve %L'de işliçler için sıralar uyumsuz"
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "'void' dönüşlu işlevde değer içeren `return' deyimi"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%>', %<throw()%> olarak bildirilmedikce (ya da -fcheck-new etkinken) NULL donmemeli"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -57980,88 +58063,88 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Değişken '%s' (%L'de) ifade içinde görünemez"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -58268,12 +58351,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L'de tanımlanmış atamanın ikinci argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ilk argümanı INTENT(IN) olmalıdır"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı INTENT(IN) olmalıdır"
@@ -59124,566 +59207,581 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "%C'de biçim belirtimi yinelenmiş"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: X descriptor requires leading space count at %C"
 msgid "X descriptor requires leading space count at %L"
 msgstr "Ek: %C'de X tanımlayıcı rehber boşluk sayısı gerektirir"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: $ descriptor at %C"
 msgid "$ descriptor at %L"
 msgstr "Ek: %C'de $ tanımlayıcı"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "$ must be the last specifier"
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ son belirteç olmalı"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %C"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Ek: %C'de L tanımlayıcısından sonraki pozitif genişlik eksik"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %C"
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Ek: %C'de L tanımlayıcısından sonraki pozitif genişlik eksik"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %C"
 msgid "%<G0%> in format at %L"
 msgstr "Biçim dizgesi içinde %s (%C'de)"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Positive width required"
 msgid "Positive width required in format specifier %s at %L"
 msgstr "Pozitif genişlik gerekli"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unrecognized format specifier"
 msgid "Period required in format specifier %s at %L"
 msgstr "tanınmayan biçim belirteci"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unrecognized format specifier"
 msgid "Period required in format specifier at %L"
 msgstr "tanınmayan biçim belirteci"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing comma at %C"
 msgid "Missing comma at %L"
 msgstr "Ek: %C'de virgül eksik"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s in format string at %C"
 msgid "%s in format string at %L"
 msgstr "Biçim dizgesi içinde %s (%C'de)"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Non-character in FORMAT tag at %L"
 msgid "Extraneous characters in format at %L"
 msgstr "Ek: %L'deki FORMAT etiketindeki değer karakter değil"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Format statement in module main block at %C."
 msgid "Format statement in module main block at %C"
 msgstr "%C'deki main modülü bloku içinde biçim beyanı"
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "%C'deki ENTRY deyimi bir INTERFACE bloku içindeymiş gibi görünmüyor"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "%C'de biçim yaftası eksik"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Duplicate %s specification at %C"
 msgid "Invalid value for %s specification at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "%s belirtimi %C'de yinelenmiş"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable tag cannot be INTENT(IN) at %C"
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "%C'de değişken etiketi INTENT(IN) olamaz"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable tag cannot be assigned in PURE procedure at %C"
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "Değişken etiketi %C'deki PURE yordamında atanamaz"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "%s etiket belirtimi %C'de yinelenmiş"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "%L'de FORMAT etiketindeki sabit ifadesi öntanımlı CHARACTER türünde olmalıdır"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "%L'de FORMAT etiketindeki sabit ifadesi öntanımlı CHARACTER türünde olmalıdır"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Obsolete: ASSIGNED variable in FORMAT tag at %L"
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "Atıl: %L'da FORMAT etiketinde ASSIGNED değişkeni"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L has not been assigned a format label"
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "'%s' değişkeni (%L'de) bir biçim yaftası atamamış"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Non-character in FORMAT tag at %L"
 msgid "Non-character in FORMAT tag at %L"
 msgstr "Ek: %L'deki FORMAT etiketindeki değer karakter değil"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Character array in FORMAT tag at %L"
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "Ek: %L'de FORMAT etiketinde karakter dizisi"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Character array in FORMAT tag at %L"
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "Ek: %L'de FORMAT etiketinde karakter dizisi"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Character array in FORMAT tag at %L"
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "Ek: %L'de FORMAT etiketinde karakter dizisi"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "%s etiketi (%L'de) %s türünde olmalı"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s tag at %L must be of type %s or %s"
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "%s etiketi (%L'de) ya %s ya da %s türünde olmalıdır"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "%s' etiketi (%L'de) bir değişmez olmalı"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: IOMSG tag at %L"
 msgid "IOMSG tag at %L"
 msgstr "Fortran 2003: %L'de IOMSG etiketi"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 95 requires default INTEGER in SIZE tag at %L"
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Fortran 95 %L'de SIZE etiketinde öntanımlı INTEGER gerektirir"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad INTENT specification at %C"
 msgid "NEWUNIT specifier at %L"
 msgstr "%C'deki INTENT belirtimi hatalı"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: CONVERT tag at %L"
 msgid "CONVERT tag at %L"
 msgstr "Ek: %L'de CONVERT etiketi"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Fortran 2003: %C'de FLUSH deyimi"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 #| msgid "Expecting %s statement at %C"
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "%s deyimi umuluyordu (%C'de)"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression in %s statement at %C"
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "%s deyiminde ifade umuluyordu (%C'de)"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' in %s statement at %C is not a loop name"
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "İsim '%s' %s deyimi içindeki bir döngü ismi değil (%C'de)"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "%C'deki PURE yordamda OPEN deyimine izin verilmez"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "%L'deki INQUIRE deyimi ya FILE ya da UNIT belirteci gerektir"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "%C'deki PURE yordamda CLOSE deyimine izin verilmez"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "%L'deki ASSIGNED GOTO deyimi bir INTEGER değişken gerektirir"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "PURE yordamda %s deyimine izin verilmez (%C'de)"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number missing in statement at %L"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "%L'de CASE deyimindeki ifade %s türünde olmalı"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003: %C'de FLUSH deyimi"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing format with default unit at %C"
 msgstr "%C'de biçim yaftası eksik"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "%C'de UNIT belirtimi yinelenmiş"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "%C'de biçim belirtimi yinelenmiş"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "'%s' simgesi '%s' isim alanında INTENT(IN)'dir (%C'de)"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "%C'de NML belirtimi yinelenmiş"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "'%s' simgesi %C'de bir NAMELIST grup ismi olmalıdır"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-I- specified twice"
 msgid "UNIT not specified at %L"
 msgstr "-I- iki kere belirtilmiş"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "%L'deki UNIT belirtimi ya bir INTEGER ifadesi ya da bir CHARACTER değişkeni olmalıdır"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Invalid form of PROGRAM statement at %C"
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "%C'deki PROGRAM deyiminin biçimi geçersiz"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "%L'de vektör indisli iç birim"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Harici IO UNIT %L'de bir dizi olamaz"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Comma before output item list at %C is an extension"
 msgid "Comma before i/o item list at %L"
 msgstr "EK: %C'deki çıktı öğe listesinden önceki virgül bir ifadedir"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR etiketi %d. yaftada (%L'de) tanımsız"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END etiketi %d. yaftada (%L'de) tanımsız"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR etiketi %d. yaftada (%L'de) tanımsız"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT etiketi %d. yaftada (%L'de) tanımsız"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "%C'deki G/C yineleyicide sözdizimi hatası"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "%C'deki READ deyiminde değişken umuluyordu"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "%s deyiminde ifade umuluyordu (%C'de)"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s deyiminde sözdizimi hatası (%C'de)"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Intrinsic at %L does not exist"
 msgid "Internal file at %L with namelist"
 msgstr "%L'deki yerleşik mevcut değil"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "KIND parameter of %s at %L must be an initialization expression"
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "%s'in KIND parametresi %L'de bir ilklendirme ifadesi olmalıdır"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "%C'de PRINT isim listesi bir ifadedir"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "%C'deki G/C listesinde virgül umuluyordu"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "%C'deki PRINT deyimi PURE yordamı içinde olamaz"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "%C'deki INQUIRE deyimi PURE yordamı içinde olamaz"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "%C'deki IOLENGTH etiketi INQUIRE deyimi içinde geçersiz"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "%L'deki INQUIRE deyimi hem FILE hem de UNIT belirtecini içeremez"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "%L'deki INQUIRE deyimi ya FILE ya da UNIT belirteci gerektir"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "%L'deki SELECT deyiminin argümanı %s olamaz"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "%L'deki INQUIRE deyimi ya FILE ya da UNIT belirteci gerektir"
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "END tag at %C not allowed in output statement"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "%C'deki END etiketine çıktı deyiminde izin verilmez"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement not allowed in PURE procedure at %C"
 msgid "WAIT statement not allowed in PURE procedure at %C"
@@ -60666,276 +60764,276 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "%C'deki USE deyiminde soysal belirtim eksik"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Renaming operators in USE statements at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 #| msgid "Global name '%s' at %L is already being used as a %s at %L"
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Genel isim '%s' (%L'de), zaten %s (%L'de) olarak kullanılıyor"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in data declaration at %C"
 msgid "SUBMODULE declaration at %C"
 msgstr "%C'deki veri bildiriminde sözdizimi hatası"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "%C'deki ENTRY deyimi bir içerilmiş altyordamın içinde görünemez"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "%C'deki SAVE deyiminde sözdizimi hatası"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "Reading module %s at line %d column %d: %s"
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "%s modülünün okunması (%d. satır %d. sütun): %s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "Writing module %s at line %d column %d: %s"
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "%s modülünün yazılması (%d. satır %d. sütun): %s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, fuzzy, gcc-internal-format
 #| msgid "Module %s at line %d column %d: %s"
 msgid "Module %qs at line %d column %d: %s"
 msgstr "%s modülü (%d. satır %d. sütun): %s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Modul dosyasına yazarken hata: %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Başvurulan '%s' işleci (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Başvurulan '%s' yerleşik işleci (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Modül dosyası`%s' yazmak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Modül dosyası `%s' yazmak için açılırken hata: %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file '%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: `%s' silinemiyor: %s\n"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Modül dosyası`%s' yazmak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete aux info file '%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: yardımcı bilgi dosyası `%s' silinemiyor: %s\n"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs at %C already declared"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L is not included in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "%L'deki yerleşik '%s' seçilmiş standartta bulunmuyor"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 #| msgid "Component '%s' at %C already declared at %L"
 msgid "Symbol %qs already declared"
 msgstr "'%s' bileşeni (%C'deki) zaten %L'de bildirilmiş"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Başvurulan '%s' simgesi (%L'de), '%s' modülünde yok"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%s deyimi bir döngü içinde değil (%C'de)"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Modül dosyası`%s' okumak için açılamıyor (%C'de): %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building!"
@@ -63523,7 +63621,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "'%s' özel işlevi (%L'de) çözümlenemiyor"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -65154,473 +65252,463 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "'%s' ('%s'in bileşeni) %L'de sabit dizi sınırlarına sahip olmalı"
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s'at %C is not allowed."
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "'%s' tahmini boyutlu dizisine '%s' isim listesinde izin verilmiyor (%C'de)."
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
+#: fortran/resolve.c:13903
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, fuzzy, gcc-internal-format
 #| msgid "PRIVATE symbol '%s' cannot be member of PUBLIC namelist at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "'%s' PRIVATE simgesi %L'de PUBLIC isim listesi üyesi olamaz"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or assumed shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametre dizisi '%s' %L'de özdevinimli veya tahmini biçimli olamaz"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Örtük olarak  PARAMETER türlü '%s' %L'de sonraki bir IMPLICIT türle eşleşmiyor"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L'de PARAMETER içindeki türetilmiş tür uyumsuz"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, fuzzy, gcc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE özniteliği '%s' içinde NAMELIST özniteliği ile çelişiyor (%L'de)"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L'deki tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Tahmini boyutlu dizi bir sözde argüman olmalı"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L'deki simge bir DUMMY değişken değil"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, fuzzy, gcc-internal-format
 #| msgid "Character-valued statement function '%s' at %L must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter değerli deyim işlevi '%s'  %L'de sabit uzunlukta olmalı"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Türetilmiş %qs türü %L'de tanımlanmamış olan %qs türündedir."
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot have the POINTER attribute"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%C'deki döngü değişkeni POINTER özniteliğinde olamaz"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC işlev '%s' %L'de PRIVATE '%s' türünde olamaz"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) sözde argüman %qs %L'de ASSUMED SIZE olduğundan bir öntanımlı ilklerdiriciye sahip olamaz"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Sözde argüman '%s' (%L'de) INTENT(OUT) olamaz"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L cannot have an initializer"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "işlev sonucu '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "'%s' dizisi %L'de ertelenmiş bir biçimde olamaz"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Ayrılabilir '%s' dizisi %L'de ertelenmiş bir biçimde olmalı"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L'deki sözde yordama ELEMENTAL yordamında izin verilmez"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s."
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "İsim listesinin ismi %s USE ilişkisiyle %s yapılamaz"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA öğesi %qs %L'de COMMON içinde olmalıdır"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Sözde '%s'  %L'de bir ilklendiriciye sahip olamaz"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "DATA deyiminde %L'de sabit olmayan dizi bölümü"
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L'deki DATA deyiminde değerden çok değişken var"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L'deki DATA deyiminde değişkenden çok değer var"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılmamış"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "%d yaftası %L'de tanımlanmış ama kullanılamıyor"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de bir EQUIVALENCE nesnesi olarak SEQUENCE özniteliğine sahip olmalı"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initializer cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Türetilmiş tür değişkeni '%s' %L'de öntanımlı ilklendiriciyle bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Türetilmiş tür değişkeni %qs %L'de gösterici bileşen(ler)le bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L'deki EQUIVALENCE deyiminde söz dizimi hatası"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Ortak blok üyesi %qs %L'de, %qs pure yordamındaki bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%qs isimli sabiti %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Sınırları sabit olmayan %qs dizisi %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Yapı bileşeni %qs %L'de bir EQUIVALENCE nesnesi olamaz"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L'deki altdizge sıfır uzunlukta"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs %L'de hiç IMPLICIT tür içermiyor"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Yerleşik işleç arayüzü %qs %L'de bir FUNCTION olmalı"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Kullanıcı işleci yordamı %qs %L'de tahmini karakter uzunluğunda olamaz"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kullanıcı işleci yordamı %qs %L'de için en azından bir argüman bulunmalı"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ilk argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L'deki işleç arayüzünün ikinci argümanı isteğe bağlı olamaz"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L'deki işleç arayüzünün en fazla iki argümanı olmalı"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -66795,12 +66883,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "%L'de LOG'un karmaşık argümanı sıfır olamaz"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "Hatalı GÇ tabantürü (%d)"
@@ -68535,9 +68623,6 @@
 #~ msgid "All functions default to the far section"
 #~ msgstr "Her işlev kendi bölümüne yerleştirilir"
 
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "Kayan noktalı çarpma/toplama komutları üretilir"
-
 #~ msgid "Warn if deprecated empty statements are found"
 #~ msgstr "Önerilmeyen boş deyimler bulunduğunda uyarır"
 
Index: gcc/po/be.po
===================================================================
--- gcc/po/be.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/be.po	(.../branches/gcc-7-branch)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 3.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2002-05-17 15:54+0200\n"
 "Last-Translator: Ales Nyakhaychyk <nyakhaychyk@i18n.linux.by>\n"
 "Language-Team: Belarusian <i18n@tut.by>\n"
@@ -193,13 +193,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -492,64 +492,64 @@
 " other options on to these processes the -W<letter> options must be used.\n"
 msgstr ""
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr ""
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, fuzzy, c-format
 #| msgid "libraries: %s\n"
 msgid "Target: %s\n"
 msgstr "бібліятэкі: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr ""
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr ""
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, fuzzy, c-format
 #| msgid "gcc version %s\n"
 msgid "gcc version %s %s\n"
 msgstr "версія gcc %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr ""
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr ""
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "праграмы: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "бібліятэкі: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -558,16 +558,16 @@
 "\n"
 "Інструкцыі для паведамленняў аб памылках глядзіце тут:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr ""
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr ""
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -574,7 +574,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -583,7 +583,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -590,7 +590,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -598,7 +598,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -610,16 +610,16 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -o <файл>                Памясціць вывад у <файл>\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -dumpversion             Адлюстраваць версію кампілятара\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -o <файл>                Памясціць вывад у <файл>\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -635,14 +635,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -670,27 +670,27 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
+#: gcov-tool.c:420
+#, fuzzy, c-format
+msgid "    -f, --function                      Print function level info\n"
+msgstr "  --help                   Адлюстраваць гэту інфармацыю\n"
+
 #: gcov-tool.c:421
 #, fuzzy, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr "  --help                   Адлюстраваць гэту інфармацыю\n"
 
 #: gcov-tool.c:422
 #, fuzzy, c-format
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr "  --help                   Адлюстраваць гэту інфармацыю\n"
 
 #: gcov-tool.c:423
 #, fuzzy, c-format
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -o, --object                        Print object level info\n"
 msgstr "  --help                   Адлюстраваць гэту інфармацыю\n"
 
 #: gcov-tool.c:424
-#, fuzzy, c-format
-msgid "    -o, --object                        Print object level info\n"
-msgstr "  --help                   Адлюстраваць гэту інфармацыю\n"
-
-#: gcov-tool.c:425
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -764,21 +764,16 @@
 msgstr ""
 
 #: gcov.c:658
-#, fuzzy, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  --help                   Адлюстраваць гэту інфармацыю\n"
-
-#: gcov.c:659
 #, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr ""
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr ""
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -785,17 +780,22 @@
 "                                    rather than percentages\n"
 msgstr ""
 
-#: gcov.c:663
+#: gcov.c:662
 #, fuzzy, c-format
 #| msgid "  --help                   Display this information\n"
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  --help                   Адлюстраваць гэту інфармацыю\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr ""
 
+#: gcov.c:664
+#, fuzzy, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  --help                   Адлюстраваць гэту інфармацыю\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -985,47 +985,47 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr ""
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr ""
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr ""
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr ""
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr ""
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, fuzzy, c-format
 #| msgid ""
 #| "\n"
@@ -1035,37 +1035,37 @@
 "\n"
 " Выбары для %s:\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr ""
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr ""
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, fuzzy, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, fuzzy, c-format
 #| msgid "cannot find source %s"
 msgid "Cannot open source file %s\n"
@@ -1177,89 +1177,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr ""
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr ""
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr ""
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr ""
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr ""
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr ""
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr ""
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr ""
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr ""
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr ""
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr ""
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr ""
 
@@ -2843,8 +2843,8 @@
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
@@ -2863,7 +2863,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "прапушчан ініцыялізатар"
@@ -2884,8 +2884,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2901,18 +2901,18 @@
 msgstr "нерэчаіснае значэньне %%r"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "нерэчаіснае значэньне %%R"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "нерэчаіснае значэньне %%N"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "нерэчаіснае значэньне %%P"
@@ -2922,7 +2922,7 @@
 msgid "invalid %%h value"
 msgstr "нерэчаіснае значэньне %%h"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "нерэчаіснае значэньне %%L"
@@ -2943,7 +2943,7 @@
 msgstr "нерэчаіснае значэньне %%U"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "нерэчаіснае значэньне %%v"
@@ -2953,7 +2953,7 @@
 msgid "invalid %%C value"
 msgstr "нерэчаіснае значэньне %%C"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "нерэчаіснае значэньне %%E"
@@ -2964,7 +2964,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "нерэчаіснае значэньне %%xn"
@@ -3028,7 +3028,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr ""
@@ -3038,30 +3038,30 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "нерэчаісны %%-код"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, fuzzy, c-format
 #| msgid "invalid %%f operand"
 msgid "invalid shift operand"
 msgstr "нерэчаісны %%f аперанд"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3069,109 +3069,109 @@
 msgid "invalid operand for code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr ""
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr ""
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr ""
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr ""
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr ""
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr ""
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr ""
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr ""
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 #, fuzzy
 msgid "invalid insn:"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr ""
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr ""
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr ""
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr ""
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 #| msgid "unsupported version"
 msgid "unsupported fixed-point conversion"
 msgstr "непадтрымліваемая версія"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 msgid "function parameter"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 #| msgid "structure"
 msgid "structure field"
 msgstr "структура"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 #| msgid "return type of `%s' is not `int'"
 msgid "return type of function"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr ""
 
@@ -3194,7 +3194,7 @@
 msgstr "нерэчаісны %%c аперанд"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3419,89 +3419,89 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr ""
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of asm flag output"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "нерэчаісны %%-код"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr ""
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr ""
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, fuzzy, c-format
 #| msgid "invalid %%c operand"
 msgid "invalid constraints for operand"
 msgstr "нерэчаісны %%c аперанд"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "невядомы рэжым машыны \"%s\""
@@ -3544,7 +3544,7 @@
 msgid "invalid %%P operand"
 msgstr "нерэчаісны %%-код"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr ""
@@ -3600,7 +3600,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "дрэнны адрас"
 
@@ -3637,7 +3637,7 @@
 msgstr "нерэчаісны адрас"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "нерэчаісны адрас"
 
@@ -3730,286 +3730,286 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "-mvsx requires hardware floating point"
 msgstr "Выкарыстоўваць апаратную \"плаваючую кропку\""
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%e value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "нерэчаіснае значэньне %%O"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, fuzzy, c-format
 #| msgid "invalid %%x/X value"
 msgid "invalid %%x value"
 msgstr "нерэчаіснае значэньне %%x/X"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Стварыць код для DLL"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, fuzzy, c-format
 msgid "cannot decompose address"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr ""
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "too few arguments to function"
 msgid "vector argument passed to unprototyped function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4035,43 +4035,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "нерэчаісны %%Y аперанд"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "нерэчаісны %%A аперанд"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "нерэчаісны %%B аперанд"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "нерэчаісны %%C аперанд"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "нерэчаісны %%D аперанд"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "нерэчаісны %%f аперанд"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, fuzzy, c-format
 msgid "invalid %%s operand"
 msgstr "нерэчаісны %%-код"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4236,33 +4236,33 @@
 msgid "bad test"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "нерэчаісная маска"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, fuzzy, c-format
 #| msgid "invalid %%Q value"
 msgid "invalid %%d value"
 msgstr "дрэннае %%Q значэнне"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, fuzzy, c-format
 #| msgid "invalid %%x/X value"
 msgid "invalid %%t/%%b value"
 msgstr "нерэчаіснае значэньне %%x/X"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 #, fuzzy
 msgid "no register in address"
 msgstr "невядомая назва рэгістра: %s"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr ""
 
@@ -4283,8 +4283,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr ""
@@ -4306,14 +4306,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr ""
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr ""
@@ -4344,7 +4344,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr ""
@@ -4352,7 +4352,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr ""
@@ -4362,7 +4362,7 @@
 msgstr ""
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr ""
@@ -4369,7 +4369,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr ""
@@ -4379,7 +4379,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr ""
@@ -4392,24 +4392,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr ""
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr ""
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4417,18 +4417,18 @@
 msgid "expected %<.%>"
 msgstr ""
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr ""
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr ""
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -4436,17 +4436,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr ""
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr ""
@@ -4455,7 +4455,7 @@
 msgid "(anonymous)"
 msgstr ""
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr ""
@@ -4464,11 +4464,11 @@
 msgid "expected label"
 msgstr ""
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr ""
 
@@ -4704,11 +4704,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4888,80 +4888,80 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr ""
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr ""
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 msgid "Unexpected element %qc in format string at %L"
 msgstr ""
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr ""
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr ""
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr ""
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 msgid "Left parenthesis required after %<*%>"
 msgstr ""
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr ""
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr ""
 
-#: fortran/io.c:726
-#, c-format
-msgid "Right parenthesis expected at %C"
-msgstr ""
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr ""
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr ""
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr ""
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, c-format
+msgid "Right parenthesis expected at %C"
+msgstr ""
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr ""
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -4971,77 +4971,77 @@
 msgid "Syntax error in expression at %C"
 msgstr ""
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr ""
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr ""
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr ""
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr ""
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr ""
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr ""
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr ""
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr ""
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr ""
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr ""
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr ""
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr ""
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr ""
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 #, fuzzy
 #| msgid "invalid declarator"
 msgid "Bad operator"
 msgstr "нерэчаісны абвяшчальнік"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr ""
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr ""
 
@@ -5312,12 +5312,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5687,7 +5687,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr ""
 
@@ -8673,7 +8673,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 #, fuzzy
 #| msgid "Generate code for given CPU"
@@ -8909,7 +8909,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr ""
 
@@ -9161,7 +9161,7 @@
 msgid "Use 80-bit long double."
 msgstr ""
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 #| msgid "Use 64 bit float"
@@ -9168,7 +9168,7 @@
 msgid "Use 64-bit long double."
 msgstr "Выкарыстоўваць 64-х бітны float"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr ""
@@ -10259,91 +10259,91 @@
 msgid "64 bit ABI."
 msgstr ""
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr ""
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr ""
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr ""
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 msgid "Enable decimal floating point hardware support."
 msgstr ""
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "Enable hardware floating point."
 msgstr "Выкарыстоўваць апаратную \"плаваючую кропку\""
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 msgid "Use hardware transactional execution instructions."
 msgstr ""
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr ""
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr ""
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr ""
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "Выкарыстоўваць апаратную \"плаваючую кропку\""
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr ""
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr ""
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 msgid "Use the mvcle instruction for block moves."
 msgstr ""
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr ""
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr ""
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr ""
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -10395,11 +10395,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -10639,84 +10639,100 @@
 msgstr ""
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr ""
+
+#: config/sparc/sparc.opt:102
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 msgid "Pointers are 64-bit."
 msgstr ""
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 msgid "Pointers are 32-bit."
 msgstr ""
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64 bit float"
 msgid "Use 64-bit ABI."
 msgstr "Выкарыстоўваць 64-х бітны float"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32 bit int"
 msgid "Use 32-bit ABI."
 msgstr "Выкарыстоўваць 32-х бітны int"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr ""
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr ""
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr ""
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 #, fuzzy
 #| msgid "Generate code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "Генерыраваць код для дадзенага ЦП"
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr ""
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 msgid "Enable debug output."
 msgstr ""
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr ""
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -15331,7 +15347,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -15752,7 +15768,7 @@
 msgstr ""
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, gcc-internal-format
 msgid "expected integer"
 msgstr ""
@@ -16059,134 +16075,134 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 msgid "invalid comparison of non-ordered type"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 msgid "invalid operation (%s)"
 msgstr "Нерэчаісны выбар %s"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 msgid "invalid comparison of non-comparable type"
 msgstr ""
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 #| msgid "invalid use of `restrict'"
 msgid "invalid comparison of generated struct"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 msgid "invalid comparison of generated array"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr ""
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr ""
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr ""
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr ""
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 #, fuzzy
 #| msgid "invalid parameter type `%T'"
 msgid "different parameter types"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, fuzzy, c-format
 #| msgid "no data type for mode `%s'"
 msgid "incompatible type for method %s%s%s"
 msgstr "няма тыпа дадзеных для рэжыма \"%s\""
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, fuzzy, c-format
 #| msgid "no data type for mode `%s'"
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "няма тыпа дадзеных для рэжыма \"%s\""
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, fuzzy, c-format
 #| msgid "missing field '%s' in '%s'"
 msgid "missing method %s%s%s"
 msgstr "прапушчана поле '%s' у '%s'"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -16366,7 +16382,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function `%s'"
 msgid "too few arguments to function %<va_start%>"
@@ -16431,29 +16447,29 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_saveregs not supported by this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -16461,7 +16477,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr ""
@@ -16468,12 +16484,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
@@ -16480,17 +16496,17 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, fuzzy, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, fuzzy, gcc-internal-format
 #| msgid "`va_start' used in function with fixed args"
 msgid "%<va_start%> used in function with fixed args"
@@ -16498,50 +16514,50 @@
 "`va_start' выкарыстоўвываецца ў функцыі з нязьменнай\n"
 "           колькасьцю аргументаў"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, fuzzy, gcc-internal-format
 #| msgid "`__builtin_next_arg' called without an argument"
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "\"__buitin_next_arg\" выклікаецца без аргумента"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr ""
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -17473,13 +17489,13 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, fuzzy, gcc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "%q+F used but never defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -17579,12 +17595,12 @@
 msgid "cannot find '%s'"
 msgstr "нельга знайсці \"%s\""
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr ""
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s: "
 msgid "%s: %m"
@@ -17595,7 +17611,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17814,7 +17830,7 @@
 msgid "error writing %qs"
 msgstr "памылка запісу ў %s"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "can't open %s"
 msgid "cannot open %s"
@@ -17897,17 +17913,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -18018,12 +18034,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -18039,12 +18055,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "не магу знайсці крыніцу %s\n"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "не магу знайсці крыніцу %s\n"
@@ -18059,7 +18075,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -18089,7 +18105,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18100,7 +18116,7 @@
 msgid "total size of local objects too large"
 msgstr "памер масіва \"%s\" вельмі вялікі"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, fuzzy, gcc-internal-format
 #| msgid "impossible operator '%s'"
 msgid "impossible constraint in %<asm%>"
@@ -18202,65 +18218,70 @@
 msgid "input file %qs is the same as output file"
 msgstr ""
 
-#: gcc.c:4498
+#: gcc.c:4476
+#, fuzzy, gcc-internal-format
+msgid "output filename may not be empty"
+msgstr "не зададзены ўваходзячыя файлы"
+
+#: gcc.c:4501
 #, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr ""
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr ""
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr ""
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Could not open data file %s.\n"
 msgid "could not open temporary response file %s"
 msgstr "Немагчыма адчыніць файл з дадзенымі %s.\n"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot create temporary file"
 msgid "could not write to temporary response file %s"
 msgstr "немагчыма стварыць часовы файл"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "cannot create temporary file"
 msgid "could not close temporary response file %s"
 msgstr "немагчыма стварыць часовы файл"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr ""
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr ""
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr ""
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr ""
@@ -18268,237 +18289,237 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr ""
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, fuzzy, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "невядомы рэжым машыны \"%s\""
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function `%s'"
 msgid "error in args to spec function %qs"
 msgstr "вельмі шмат аргумэнтаў у функцыі `%s'"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr ""
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, fuzzy, gcc-internal-format
 #| msgid "too few arguments to function"
 msgid "no arguments for spec function"
 msgstr "не хапае аргументаў у функцыі"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr ""
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr ""
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr ""
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr ""
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Could not open data file %s.\n"
 msgid "%s: could not open compare-debug file %s"
 msgstr "Немагчыма адчыніць файл з дадзенымі %s.\n"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr ""
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr ""
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "Нераспазнаны выбар \"%s\""
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr ""
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, fuzzy, gcc-internal-format
 msgid "no input files"
 msgstr "няма ўваходзячых файлаў"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr ""
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: %s кампілятар не ўсталяваны на гэтай сістэме"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr ""
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr ""
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "Бібліятэка lib%s не знойдзена"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "мова %s не распазнана"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr ""
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr ""
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr ""
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr ""
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, fuzzy, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to %%:version-compare"
 msgstr "не хапае аргументаў у функцыі"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to %%:version-compare"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr ""
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr ""
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to %%:replace-extension"
 msgstr "не хапае аргументаў у функцыі"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %%:debug-level-gt"
@@ -18650,9 +18671,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "called from here"
 msgid "declared here"
@@ -19069,227 +19090,227 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr ""
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr ""
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr ""
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr ""
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr ""
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -19526,7 +19547,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
 #: ipa-devirt.c:1235
@@ -19626,7 +19647,7 @@
 
 #: ipa-devirt.c:1576
 #, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr ""
 
 #: ipa-devirt.c:1599
@@ -20012,200 +20033,200 @@
 msgid "multiple loop axes specified for routine"
 msgstr ""
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, fuzzy, gcc-internal-format
 #| msgid "In construct"
 msgid "orphaned %qs construct"
 msgstr "У канструкцыі"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr ""
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "invalid arguments"
 msgstr "няма аргументаў"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr ""
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "нявернае выкарыстанне \"restict\""
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
@@ -20291,7 +20312,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr ""
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -20451,133 +20472,143 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.c:1649
+#: opts.c:1656
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr ""
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.c:1837
+#: opts.c:1844
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts.c:2078
+#: opts.c:2085
 #, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr ""
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr ""
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "unused parameter `%s'"
 msgid "unknown stack check parameter %qs"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-pipe is not supported"
 msgid "dwarf version %d is not supported"
 msgstr "-pipe не падтрымліваецца"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr ""
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param option: %s"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "нерэчаісны выбар --param : %s"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param option: %s"
 msgid "invalid --param name %qs"
 msgstr "нерэчаісны выбар --param : %s"
 
-#: opts.c:2382
+#: opts.c:2389
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param option: %s"
 msgid "invalid --param value %qs"
 msgstr "нерэчаісны выбар --param : %s"
 
-#: opts.c:2504
+#: opts.c:2511
 #, fuzzy, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "section of `%s' conflicts with previous declaration"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "секцыя \"%s\" канфліктуе з папярэдняй дэкларацыяй"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "нераспазнаны выбар \"-%s\""
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr ""
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr ""
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr ""
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -20925,7 +20956,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr ""
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr ""
@@ -21538,12 +21569,12 @@
 msgid "error closing %s: %m"
 msgstr "памылка запісу ў %s"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr ""
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -22467,47 +22498,47 @@
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -22608,32 +22639,32 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr ""
@@ -22991,11 +23022,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -23975,7 +24006,7 @@
 msgid "type was previously declared %qE"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -24252,7 +24283,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
@@ -24889,62 +24920,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr ""
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr ""
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -25047,7 +25078,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr ""
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr ""
@@ -25077,7 +25108,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -25093,22 +25124,22 @@
 msgid "%qE is not initialized"
 msgstr "прапушчан ініцыялізатар"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "нерэчаісны ініцыялізатар"
@@ -25664,8 +25695,8 @@
 msgid "wrong type argument to %s"
 msgstr "не хапае аргументаў у функцыі"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -26346,7 +26377,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "\"%s\" звычайна функцыя"
@@ -26510,7 +26541,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
@@ -26836,7 +26867,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr ""
@@ -26916,7 +26947,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr ""
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
@@ -27002,9 +27033,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr ""
@@ -27090,7 +27121,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27265,238 +27296,238 @@
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 7"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 3"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of selector should be in 0 to 1"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "the range of mask should be in 0 to 255"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
@@ -27503,141 +27534,141 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr ""
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr ""
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr ""
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr ""
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr ""
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr ""
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr ""
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, fuzzy, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -27645,72 +27676,77 @@
 msgid "%qE attribute only applies to functions"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr ""
@@ -27718,13 +27754,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
@@ -27823,165 +27859,176 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "virtual functions cannot be friends"
 msgid "%qs function cannot have arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "%qs function cannot return a value"
 msgstr "функцыя не вяртае тып string"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "\"%s\" звычайна функцыя"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr ""
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr ""
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr ""
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr ""
+
+#: config/avr/avr.c:10160
+#, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr ""
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr ""
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr ""
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr ""
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -28267,12 +28314,12 @@
 msgid "invalid IACC argument"
 msgstr "нерэчаіснае значэньне %%C"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr ""
@@ -28452,7 +28499,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s does not support %s"
 msgid "code model %s does not support PIC mode"
@@ -28584,288 +28631,288 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr ""
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "невядомая назва рэгістра: %s\n"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr ""
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr ""
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "%s does not support %s"
 msgid "X32 does not support ms_abi attribute"
 msgstr "%s не падтрымлівае %s"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -28872,300 +28919,300 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr ""
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of `%D'"
 msgid "previous declaration of %D"
 msgstr "папярэдняе абвяшчэньне `%D'"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr ""
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr ""
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr ""
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "Нерэчаісны выбар %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr ""
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported version"
 msgid "unsupported simdlen %d"
 msgstr "непадтрымліваемая версія"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -29289,7 +29336,7 @@
 msgid "argument %qd is not a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr ""
@@ -29299,7 +29346,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr ""
@@ -29404,7 +29451,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -29914,8 +29961,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr ""
@@ -30168,27 +30215,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -30213,7 +30260,7 @@
 msgid "-g option disabled"
 msgstr ""
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
@@ -30351,158 +30398,158 @@
 msgid "junk at end of #pragma longcall"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 #| msgid "Do not generate char instructions"
 msgid "not configured for SPE instruction set"
 msgstr "Не генерыраваць сімвальныя інструкцыі"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, fuzzy, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr ""
@@ -30509,67 +30556,67 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -30578,515 +30625,520 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, fuzzy, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, gcc-internal-format
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, fuzzy, gcc-internal-format
 #| msgid "%s is too large"
 msgid "stack frame too large"
 msgstr "%s - вельмі вялікі"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -31275,6 +31327,7 @@
 msgstr ""
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr ""
@@ -31366,7 +31419,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -31393,7 +31446,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -31414,7 +31467,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -31427,164 +31480,164 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_args_info' out of range"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "argument of `__builtin_args_info' out of range"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "аргумент `__builtin_args_info' выйшаў за межы"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is %d bytes"
 msgid "frame size of %qs is %wd bytes"
 msgstr "памер \"%s\" - %d байт"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "-pipe не падтрымліваецца"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 #| msgid "first argument of `%s' should be `int'"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "першым аргументам \"%s\" павінен быць \"int\""
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "памер \"%s\" больш чам %d байт"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
@@ -31641,27 +31694,27 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr ""
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr ""
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr ""
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr ""
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
-msgstr ""
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+msgid "-mcmodel= is not supported on 32-bit systems"
+msgstr "__buitin_saveregs не падтрымліваецца гэтай мэтай"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
@@ -31951,22 +32004,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "сімвальная канстанта вельмі доўгая"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr ""
@@ -32054,7 +32107,7 @@
 msgid "could not read the BRIG file"
 msgstr "не магу знайсці крыніцу %s\n"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -32466,9 +32519,9 @@
 msgstr "адмеціна `%D' вызначана, але не выкарыстоўваецца"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
@@ -32605,7 +32658,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -33684,7 +33737,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, fuzzy, gcc-internal-format
 #| msgid "`long long long' is too long for GCC"
 msgid "%<long long long%> is too long for GCC"
@@ -33838,17 +33891,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не падтрымлівае просты \"complex\" у значэнні \"double complex\""
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не падтрымлівае комлексныя цэлалікавыя тыпы"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -33898,7 +33951,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr ""
@@ -33941,7 +33994,7 @@
 msgstr "невядомая назва рэгістра: %s"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration specifiers"
@@ -33958,7 +34011,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "\"%s\" атрыбут ігнарыруецца"
@@ -33974,8 +34027,8 @@
 msgid "unexpected attribute"
 msgstr ""
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr ""
@@ -34013,7 +34066,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -34043,7 +34096,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr ""
@@ -34109,14 +34162,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr ""
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr ""
@@ -34254,7 +34307,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -34279,12 +34332,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -34298,18 +34351,18 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr ""
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "suggest braces around empty body in an %<else%> statement"
@@ -34320,7 +34373,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -34340,7 +34393,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -34520,18 +34573,18 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -34587,61 +34640,61 @@
 msgid "no type or storage class may be specified here,"
 msgstr ""
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr ""
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr ""
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr ""
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr ""
@@ -34656,13 +34709,13 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %qs clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr ""
@@ -34677,54 +34730,54 @@
 msgid "%qD is not a variable"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "\"%s\" звычайна функцыя"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, gcc-internal-format
 msgid "expected %<none%>"
 msgstr ""
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr ""
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 #| msgid "too many input files"
 msgid "too many %<if%> clauses"
 msgstr "вельмі шмат уваходзячых файлаў"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -34752,22 +34805,22 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr ""
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr ""
@@ -34777,59 +34830,59 @@
 msgid "%<num_workers%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to function"
 msgid "too many %<static%> arguments"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "no arguments"
 msgid "unexpected argument"
 msgstr "няма аргументаў"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr ""
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%-code"
 msgid "invalid schedule kind"
@@ -34845,17 +34898,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -34875,19 +34928,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid %%d operand"
 msgid "invalid depend kind"
 msgstr "нерэчаісны %%d аперанд"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "нерэчаісная маска"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr ""
@@ -34897,68 +34950,68 @@
 msgid "invalid proc_bind kind"
 msgstr "Нерэчаісны выбар %s"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr ""
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, fuzzy, gcc-internal-format
 #| msgid "complex invalid for `%s'"
 msgid "%qs is not valid for %qs"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr ""
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr ""
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -34973,7 +35026,7 @@
 msgid "expected function name"
 msgstr ""
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD does not refer to a function"
@@ -34984,42 +35037,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -35029,27 +35082,27 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr ""
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -35059,72 +35112,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr ""
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -35139,7 +35192,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -35149,32 +35202,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr ""
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr ""
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -35229,22 +35282,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "\"%s\" мае незавершаны тып"
@@ -35259,52 +35312,52 @@
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr ""
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr ""
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr ""
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr ""
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -35314,7 +35367,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr ""
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr ""
@@ -36034,7 +36087,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -36363,7 +36416,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C не падтрымлівае \"goto *expr;\""
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function declared %<noreturn%> has a %<return%> statement"
@@ -36374,7 +36427,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -36399,7 +36452,7 @@
 msgid "function returns address of label"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
@@ -36414,7 +36467,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -36434,17 +36487,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -36454,7 +36507,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
@@ -36560,12 +36613,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -36575,25 +36628,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr ""
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr ""
@@ -36604,70 +36657,70 @@
 msgstr ""
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr ""
@@ -36687,7 +36740,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -36697,17 +36750,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -36727,18 +36780,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -36750,32 +36803,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr ""
@@ -36795,55 +36848,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -36853,32 +36906,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr ""
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -37430,154 +37483,154 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr ""
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr ""
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr ""
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "  for conversion from %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr ""
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -37679,272 +37732,272 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr ""
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr ""
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr ""
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr ""
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr ""
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr ""
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr ""
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr ""
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr ""
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr ""
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr ""
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr ""
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -37951,156 +38004,156 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of `%s' is larger than %d bytes"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr ""
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "in the definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr ""
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "redefinition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr ""
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr ""
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr ""
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, fuzzy, gcc-internal-format
 #| msgid "language %s not recognized"
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "мова %s не распазнана"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr ""
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr ""
@@ -38110,13 +38163,13 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of `%#D'"
 msgid "declaration of %q#D"
 msgstr "абвяшчэньне `%#D'"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -38146,335 +38199,335 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr ""
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "can't initialize friend function `%s'"
 msgid "call to internal function %qE"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr ""
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr ""
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr ""
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr ""
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "%qD used in its own initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%q#D is not const"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr ""
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr ""
@@ -39285,7 +39338,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "ініцыялізацыя"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -39300,7 +39353,7 @@
 msgid "%qD is not a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -40965,7 +41018,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -41420,13 +41473,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
@@ -41436,8 +41489,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "памер \"%s\" - %d байт"
@@ -41488,7 +41541,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "папярэдняе вызначэньне"
@@ -41552,7 +41605,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
@@ -41568,7 +41621,7 @@
 msgid "no return statements in function returning %qT"
 msgstr ""
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
@@ -41726,27 +41779,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "бітавае поле \"%s\" мае нерэчаісны тып"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -41755,67 +41808,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -41824,48 +41877,48 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 #| msgid "label `%D' used but not defined"
 msgid "inline function %qD used but never defined"
 msgstr "адмеціна `%D' выкарыстоўвываецца, але ня вызначана"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "аргумент для \"%s\" прапушчан"
@@ -41872,12 +41925,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
@@ -42187,18 +42240,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "прапушчан ініцыялізатар"
@@ -42299,7 +42352,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "\"%s\" мае незавершаны тып"
@@ -42319,7 +42372,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "нявернае выкарыстанне \"restict\""
@@ -42515,22 +42568,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr ""
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -42585,186 +42638,186 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr ""
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr ""
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "complex нерэчаісны для \"%s\""
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr ""
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "пустое абвяшчэнне"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr ""
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "YYDEBUG не вызначан."
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -42959,98 +43012,98 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, gcc-internal-format
 msgid "only here as a friend"
 msgstr ""
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr ""
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute ignored"
 msgid "%qD attribute directive ignored"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, fuzzy, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr ""
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr ""
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -43057,27 +43110,27 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -43097,7 +43150,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -43122,7 +43175,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -43182,102 +43235,102 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "Не магу знайсці дэкларацыю інтэрфейса для \"%s\""
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, fuzzy, gcc-internal-format
 msgid "invalid template-id"
 msgstr "Нерэчаісны выбар %s"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, fuzzy, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, fuzzy, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qD as a type"
@@ -43284,636 +43337,641 @@
 msgstr "нявернае выкарыстанне \"restict\""
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr ""
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr ""
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, fuzzy, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr ""
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr ""
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr ""
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr ""
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr ""
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr ""
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr ""
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr ""
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr ""
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr ""
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 msgid "expected binary operator"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, gcc-internal-format
 msgid "expected ..."
 msgstr ""
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr ""
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr ""
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr ""
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 #| msgid "-pipe is not supported"
 msgid "fixed-point types not supported in C++"
 msgstr "-pipe не падтрымліваецца"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr ""
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr ""
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, fuzzy, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr ""
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr ""
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr ""
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr ""
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%D'"
 msgid "invalid use of %qD"
 msgstr "нерэчаіснае выкарыстаньне `%D'"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr ""
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr ""
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr ""
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr ""
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr ""
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C89 does not support complex types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C89 не падтрымлівае комлексныя тыпы"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments specified for `%s' attribute"
 msgid "default argument specified for lambda parameter"
 msgstr "памылковая колькасьць аргументаў, зададзеных для атрыбута `%s'"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "паўтарэнне \"%s\""
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected labeled-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr "вельмі шмат аргументаў у функцыі"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected selection-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr ""
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, fuzzy, gcc-internal-format
 #| msgid "empty body in an else-statement"
 msgid "expected iteration-statement"
 msgstr "пустое цела ў else-выражэнні"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr ""
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 #| msgid "multiple declarations `%T' and `%T'"
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "неаднолькавае абвяшчэньне `%T' і `%T'"
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr "нерэчаісны ініцыялізатар"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
@@ -43920,112 +43978,112 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr ""
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr ""
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected operator"
@@ -44032,370 +44090,370 @@
 msgstr "нераспазнаны аператар %s"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr ""
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr ""
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr ""
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr ""
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids label declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C не дазваляе дэкларацыі метак (label)"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr ""
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr ""
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr ""
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr ""
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr ""
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr ""
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "multiple definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids an empty source file"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C не дазваляе пусты ізыходны файл"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, fuzzy, gcc-internal-format
 #| msgid "`%D' is not a function,"
 msgid "%qD is not a namespace-name"
 msgstr "`%D' - гэта ня функцыя,"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr ""
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, gcc-internal-format
 msgid "nested identifier required"
 msgstr ""
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr ""
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, fuzzy, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr ""
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "\"%s\" - гэта не пачатак дэкларацыі"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "expected initializer"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr ""
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -44404,7 +44462,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "нерэчаісны абвяшчальнік"
@@ -44411,344 +44469,344 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 #| msgid "Invalid declaration"
 msgid "qualified-id in declaration"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declarator"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr ""
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr ""
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr ""
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate cv-qualifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr ""
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `volatile'"
 msgid "duplicate virt-specifier"
 msgstr "паўтарэнне \"volatile\""
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "невыкарыстаемы параметр \"%s\""
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `%T'"
 msgid "invalid use of %qT"
 msgstr "нерэчаіснае выкарыстаньне `%T'"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr ""
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr ""
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "віртуальныя функцыі не могуць быць сяброўскімі"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr ""
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr ""
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr ""
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "немагчыма знайсьці файл для кляса %s"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, fuzzy, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr ""
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of `%#T'"
 msgid "previous definition of %q#T"
 msgstr "папярэдняе вызначэньне `%#T'"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr ""
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr ""
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Нерэчаіснае абвяшчэнне"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "невыкарыстаемы параметр \"%s\""
@@ -44757,497 +44815,497 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "-pipe не падтрымліваецца."
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty introduction-list"
 msgstr "пустое абвяшчэньне"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "пустое абвяшчэнне"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "ініцыялізацыя"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr ""
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not support `long long'"
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ не падтрымлівае \"long long\""
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qD"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate `%s'"
 msgid "duplicate %qs"
 msgstr "паўтарэньне `%s'"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr ""
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr ""
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr ""
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr ""
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr ""
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, fuzzy, gcc-internal-format
 #| msgid "unregistered operator %s"
 msgid "expected %<operator%>"
 msgstr "нераспазнаны аператар %s"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr ""
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr ""
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr ""
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr ""
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr ""
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr ""
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr ""
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr ""
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr ""
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "нехапае аргументаў у функцыі \"%s\""
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mode for gen_tst_reg"
 msgid "invalid type for instance variable"
 msgstr "нерэчаісны рэжым для gen_tst_reg"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr ""
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "\"%s\" атрыбут ігнарыруецца"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid type for property"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr ""
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "нерэчаісны ініцыялізатар"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr ""
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr ""
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr ""
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr ""
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr ""
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, gcc-internal-format
 msgid "expected variable-name"
 msgstr ""
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
@@ -45341,7 +45399,7 @@
 msgid "candidate is: %#D"
 msgstr ""
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr ""
@@ -45923,123 +45981,138 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
 #, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6634
+#, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6641
+#, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr ""
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr ""
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr ""
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of `restrict'"
 msgid "invalid use of destructor %qE as a type"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr ""
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr ""
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr ""
@@ -46046,102 +46119,102 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr ""
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr ""
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr ""
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 msgid "provided for %qD"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, fuzzy, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "дэструктару неабходны \"%#D\""
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "пустое абвяшчэнне"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr ""
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr ""
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "нехапае аргументаў у функцыі \"%s\""
@@ -46159,275 +46232,275 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter type `%T'"
 msgid "invalid parameter type %qT"
 msgstr "нерэчаісны тып парамэтра `%T'"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, fuzzy, gcc-internal-format
 #| msgid "in declaration `%D'"
 msgid "in declaration %q+D"
 msgstr "у абвяшчэньні  `%D'"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, fuzzy, gcc-internal-format
 #| msgid "function does not return string type"
 msgid "function returning an array"
 msgstr "функцыя не вяртае тып string"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "\"%s\" не абвешчан (першае выкарыстанне ў гэтай функцыі)"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr ""
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr ""
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr ""
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr ""
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr ""
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr ""
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "\"%s\" мае незавершаны тып"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr ""
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for `%#D' has type `%T'"
 msgid "template argument for %qD uses local type %qT"
 msgstr "звычайны аргумэнт для `%#D' мае тып `%T'"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr ""
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 msgid "%s %#S"
 msgstr ""
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "паўторнае абвяшчэнне меткі \"%s\""
@@ -46439,92 +46512,92 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr ""
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr ""
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr ""
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
@@ -46685,466 +46758,466 @@
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, fuzzy, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "тып параметра \"%s\" не аб'яўлены"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "памер \"%s\" больш чам %d байт"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr ""
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "не магу ініцыялізаваць сяброўскую функцыю \"%s\""
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr ""
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, fuzzy, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "нявернае выкарыстанне \"restict\""
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "параметр \"%s\" ініцыялізаваны"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "памер масіва \"%s\" адмоўны"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "\"%s\" мае незавершаны тып"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr ""
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr ""
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr ""
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr ""
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr ""
@@ -47159,107 +47232,107 @@
 msgid "lambda-expression in a constant expression"
 msgstr ""
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "атрыбуты секцыі не падтрымліваюцца для гэтай мэты"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr ""
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент `__builtin_args_info' павінен быць канстантай"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr ""
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "сімвальная канстанта вельмі доўгая"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr ""
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr ""
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "\"%s\" звычайна функцыя"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr ""
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -47949,103 +48022,103 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "Нерэчаісны выбар \"%s\""
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr ""
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "converting from `%T' to `%T'"
 msgid "cannot convert %qT to %qT"
 msgstr "пераўтварэньне з `%T' у `%T'"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr ""
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr ""
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr ""
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "вяртаемы тып \"%s\" не \"int\""
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "аргумент для \"%s\" прапушчан"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -48052,56 +48125,56 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr ""
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "прапушчан ініцыялізатар"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr ""
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -52074,87 +52147,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -52342,12 +52415,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -53124,514 +53197,529 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr ""
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr ""
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr ""
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr ""
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing class name"
 msgid "Missing comma at %L"
 msgstr "Прапушчана назва класа"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr ""
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr ""
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr ""
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr ""
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "Нерэчаісная спецыфікацыя! Памылка ў cc."
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "duplicate label declaration `%s'"
 msgid "Duplicate %s label specification at %C"
 msgstr "паўторнае абвяшчэньне адмеціны `%s'"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr ""
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr ""
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr ""
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr ""
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr ""
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr ""
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr ""
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr ""
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr ""
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr ""
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr ""
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr ""
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr ""
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "няма папярэдняга аб'яўлення для \"%s\""
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr ""
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "ERR tag label %d at %L not defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "END tag label %d at %L not defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "EOR tag label %d at %L not defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' used but not defined"
 msgid "FORMAT label %d at %L not defined"
 msgstr "адмеціна `%s' выкарыстоўвываецца, але ня вызначана"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr ""
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr ""
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr ""
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -54528,260 +54616,260 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr ""
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr ""
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr ""
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in declaration `%D'"
 msgid "SUBMODULE declaration at %C"
 msgstr "у абвяшчэньні  `%D'"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr ""
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr ""
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "error writing to %s"
 msgid "Error writing modules file: %s"
 msgstr "памылка запісу ў %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: немагчыма знішчыць файл \"%s\": %s\n"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't change mode of file `%s': %s\n"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: немагчыма зьмяніць рэжым файла `%s': %s\n"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't delete file `%s': %s\n"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: немагчыма знішчыць файл \"%s\": %s\n"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "%s: can't open file `%s' for reading: %s\n"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: немагчыма адчыніць файл `%s' для чытаньня: %s\n"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr ""
@@ -57158,7 +57246,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -58649,449 +58737,439 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but not used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "label `%s' defined but not used"
 msgid "Label %d at %L defined but cannot be used"
 msgstr "адмеціна `%s' вызначана, але ня выкарыстоўваецца"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -60183,12 +60261,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr ""
Index: gcc/po/ru.po
===================================================================
--- gcc/po/ru.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/ru.po	(.../branches/gcc-7-branch)
@@ -12,7 +12,7 @@
 msgstr ""
 "Project-Id-Version: gcc 6.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2016-05-25 15:46+0300\n"
 "Last-Translator: Pavel Maryanov <acid@jack.kiev.ua>\n"
 "Language-Team: Russian <gnu@d07.ru>\n"
@@ -209,13 +209,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "некорректное использование плавающей константы"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -604,62 +604,62 @@
 "Ключи, начинающиеся с -g, -f, -m, -O, -W, или --param автоматически\n"
 "передаются процессам, запускаемым %s. Для передачи ключей этим процессам, используйте ключи -W<буква>.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Обработка спецификации (%s), т.е. '%s'\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Целевая архитектура: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Параметры конфигурации: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Модель многопоточности: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc версия %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "драйвер gcc версия %s; %sисполняет gcc версия %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "установка: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "программы: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "библиотеки: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -668,16 +668,16 @@
 "\n"
 "Инструкции по составлению и отправке отчётов об ошибках см. на:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "(C)"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -688,7 +688,7 @@
 "коммерческую ценность и применимость для каких-либо целей.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -701,7 +701,7 @@
 "==================\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -710,7 +710,7 @@
 "Используйте \"-Wl,КЛЮЧ\", чтобы передать \"КЛЮЧ\" компоновщику.\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -721,7 +721,7 @@
 "=================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -735,18 +735,18 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+#| msgid "  -n, --no-output                 Do not create an output file\n"
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -n, --no-output                 Не создавать выходной файл\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 #| msgid "  -v, --version                   Print version number, then exit\n"
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -v, --version                   Показать номер версии и выйти\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -n, --no-output                 Не создавать выходной файл\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -762,14 +762,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -797,31 +797,31 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -f, --function                      Print function level info\n"
 msgstr "  -h, --help                      Показать эту справку и выйти\n"
 
-#: gcov-tool.c:422
+#: gcov-tool.c:421
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr "  -h, --help                      Показать эту справку и выйти\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:422
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr "  -h, --help                      Показать эту справку и выйти\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:423
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -o, --object                        Print object level info\n"
 msgstr "  -h, --help                      Показать эту справку и выйти\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -910,20 +910,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Показать эту справку и выйти\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Показать сведения для всех блоков\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Вывести вероятности переходов\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, fuzzy, c-format
 #| msgid ""
 #| "  -c, --branch-counts             Given counts of branches taken\n"
@@ -935,16 +930,21 @@
 "  -c, --branch-counts             При счётчиках переходов, заданных\n"
 "                                    в абсолютных, а не в процентных значениях\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          Показывать информацию о выполнении\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Вывести сводки для всех функций\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Показать эту справку и выйти\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1139,82 +1139,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s:неразрешимый граф для '%s'\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Выполнено строк:%s из %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Нет выполняемых строк\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s '%s'\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Выполнено переходов:%s из %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "Переход выполнен хотя бы однажды:%s из %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Переходов нет\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Выполнено вызовов:%s из %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Вызовов нет\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s:нет строк для '%s'\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "вызов   %2d вернул %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "вызов  %2d ни разу не исполнялся\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "переход %2d выполнен %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "переход %2d ни разу не исполнялся\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "безусловный переход %2d выполнен %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "безусловный переход %2d ни разу не выполнялся\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "Ошибка открытия исходного файла %s\n"
@@ -1328,92 +1328,92 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
 #
-#: opts.c:1171
+#: opts.c:1178
 #, fuzzy, c-format
 #| msgid "(%s %s %s %s %s"
 msgid "%s  Same as %s."
 msgstr "(%s %s %s %s %s"
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[по умолчанию]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[включено]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[выключено]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Не найдено ключей с требуемыми характеристиками\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, fuzzy, c-format
 #| msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end\n"
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Не найдено.  Задайте --help=%s для вывода *всех* ключей, поддерживаемых для языка %s\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Все ключи с требуемыми характеристиками уже выведены\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "Следующие ключи не зависят от целевой архитектуры"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "Следующие ключи контролируют предупреждения компилятора"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "Следующие ключи контролируют оптимизацию"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "Следующие ключи не зависят от входного языка"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "Ключ --param позволяет задать следующие параметры"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "Следующие ключи зависят только от языка "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "Следующие ключи поддерживаются языком "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "Следующие ключи не документированы"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "Следующие ключи принимают раздельные аргументы"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "Следующие ключи принимают объединенные аргументы"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "Следующие ключи относятся к исходному языку"
 
@@ -3103,8 +3103,8 @@
 msgid "<command-line>"
 msgstr "<command-line>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Неподдерживаемый операнд для кода '%c'"
@@ -3124,7 +3124,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "отсутствует операнд"
@@ -3147,8 +3147,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "некорректный код операнда '%c'"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "'%%&' использовано без локальной динамической TLS ссылки"
@@ -3164,18 +3164,18 @@
 msgstr "некорректное значение %%r"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "некорректное значение %%R"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "некорректное значение %%N"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "некорректное значение %%P"
@@ -3185,7 +3185,7 @@
 msgid "invalid %%h value"
 msgstr "некорректное значение %%h"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "некорректное значение %%L"
@@ -3206,7 +3206,7 @@
 msgstr "некорректное значение %%U"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "некорректное значение %%s"
@@ -3216,7 +3216,7 @@
 msgid "invalid %%C value"
 msgstr "некорректное значение %%C"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "некорректное значение %%E"
@@ -3227,7 +3227,7 @@
 msgstr "некорректное unspec-перемещение"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "некорректный код %%xn"
@@ -3295,7 +3295,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "неверный код выходного операнда"
@@ -3306,29 +3306,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "некорректный операнд UNSPEC"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "некорректный оператор сдвига"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "предикативная инструкция для архитектуры Thumb"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "предикативная инструкция в условной последовательности"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3336,112 +3336,112 @@
 msgid "invalid operand for code '%c'"
 msgstr "недопустимый операнд для кода '%c'"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "инструкция никогда не выполняется"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, fuzzy, c-format
 #| msgid "Unsupported operand for code '%c'"
 msgid "obsolete Maverick format code '%c'"
 msgstr "Неподдерживаемый операнд для кода '%c'"
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "для операнда адреса требуются ограничения одного из регистров X, Y или Z"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "операнды для %T/%t должны быть reg + const_int:"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr "некорректный адрес, не I/O адрес:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr "некорректный адрес, не константа:"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "некорректный адрес, не (reg+disp)"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "некорректный адрес, не post_inc или pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "внутренняя ошибка компилятора: некорректный адрес:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "внутренняя ошибка компилятора: неизвестный режим:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "недопустимая инструкция:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "некорректная инструкция:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "некорректная инструкция перемещения:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "некорректная инструкция сдвига:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "Внутренняя ошибка компилятора: некорректный сдвиг:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 #| msgid "invalid types in fixed-point conversion"
 msgid "unsupported fixed-point conversion"
 msgstr "неверные типы в преобразовании с фиксированной точкой"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 #, fuzzy
 #| msgid "Loop variable"
 msgid "variable"
 msgstr "Переменная цикла"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "повторное определение параметра %q+D"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 #| msgid "struct defined here"
 msgid "structure field"
 msgstr "структура определена здесь"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 #| msgid "creating array of functions"
 msgid "return type of function"
 msgstr "создание массива функций"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 #, fuzzy
 #| msgid "null pointer"
 msgid "pointer"
@@ -3466,7 +3466,7 @@
 msgstr "некорректный операнд const_double"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3688,97 +3688,97 @@
 msgid "bad output_condmove_single operand"
 msgstr "некорректный операнд для output_condmove_single"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "некорректный операнд UNSPEC"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 #| msgid "invalid type for make function"
 msgid "invalid use of asm flag output"
 msgstr "некорректный тип для make функции"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "недопустимый размер операнда для кода '%c'"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "недопустимый размер операнда для кода '%c'"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "недопустимый тип операнда для кода '%c'"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "недопустимый размер операнда для кода '%c'"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "операнд не является кодом условия, неверный код операнда 'D'"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "операнд не является кодом условия, неверный код операнда 'D'"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "операнд не является ссылкой на память со смещением, неверный код операнда 'H'"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "операнд не является кодом условия, неверный код операнда 'Y'"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "некорректный код операнда '%c'"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "некорректные ограничения для операнда"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "некорректный режим инструкции"
 
@@ -3816,7 +3816,7 @@
 msgid "invalid %%P operand"
 msgstr "неверный операнд для кода %%P"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "неверное значение для кода %%p"
@@ -3870,7 +3870,7 @@
 msgstr "постинкрементный адрес - не регистр"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "некорректный адрес"
 
@@ -3903,7 +3903,7 @@
 msgstr "инструкция содержит некорректный адрес !"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "некорректный адрес"
 
@@ -3996,293 +3996,293 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Попробуйте выполнить '%s' в командной строке, чтобы увеличить его размер.\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx требует аппаратной реализации плавающей арифметики"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "ключи -mvsx и -mpaired несовместимы"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr "для -mvsx требуется индексная адресация"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "ключи -mvsx и -mno-altivec несовместимы"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec отменяет vsx"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "ключ --resource требует задания -o"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Генерировать код для обратного (little endian) порядка байт"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "ключ --resource требует задания -o"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr "некорректная пересылка"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "некорректное %%H значение"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "недопустимое значение для кода %%f"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "недопустимое значение для кода %%F"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "недопустимое значение для кода %%G"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "недопустимое значение для кода %%j"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "недопустимое значение для кода %%J"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "недопустимое значение для кода %%k"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "недопустимое значение для кода %%K"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "недопустимое значение для кода %%O"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "недопустимое значение для кода %%q"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "недопустимое значение для кода %%T"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "недопустимое значение для кода %%u"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "недопустимое значение для кода %%v"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "неверное значение для кода %%x"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "некорректное значение %%y, попробуйте использовать ограничитель 'Z'"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Не генерировать одну выходную точку для каждой функции"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "ошибка при генерации загрузок операндов на регистры для:"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "символьные ссылки на память поддерживаются только для z10 или более поздних версий"
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "ошибка при декомпозиции адреса"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "некорректный оператор сравнения для 'E' модификатора вывода"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "некорректная ссылка для 'J' модификатора вывода"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "некорректный адрес для 'O' модификатора вывода"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "некорректный адрес для 'R' модификатора вывода"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "ожидалась ссылка на память для 'S' модификатора вывода"
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "некорректный адрес для 'S' модификатора вывода"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "ожидалось выражении из регистров и памяти для 'N' модификатора вывода"
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "ожидался регистр или выражение памяти для модификатора вывода 'M'"
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "некорректная константа для модификатора вывода '%c'"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "некорректная константа - попытайтесь использовать модификатор вывода"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 #| msgid "invalid constant for output modifier '%c'"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "некорректная константа для модификатора вывода '%c'"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "некорректное выражение - попытайтесь использовать модификатор вывода"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "некорректное выражение для модификатора вывода '%c'"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "Аргумент AltiVec передан в функцию без прототипа"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "при возврате результата указуемые типы различаются знаковостью"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4308,43 +4308,43 @@
 msgid "created and used with different endianness"
 msgstr "создан с одним значением endianness, а используется с другим"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "некорректный операнд для %%Y"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "некорректный операнд для %%A"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "некорректный операнд для %%B"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "некорректный %%C операнд"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "некорректный %%D операнд"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "некорректный операнд для %%f"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "некорректный операнд для %%s"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4517,30 +4517,30 @@
 msgid "bad test"
 msgstr "Некорректная проверка"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "неверное значение для кода %%D"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "некорректная маска"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "неверное значение для кода %%d"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "неверное значение для кода %%t/%%b"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "не задан регистр в адресе"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "адресное смещение - не константа"
 
@@ -4561,8 +4561,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "ожидалось %<;%>"
@@ -4584,14 +4584,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "ожидалась %<(%>"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "ожидалась %<,%>"
@@ -4622,7 +4622,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "ожидалась %<)%>"
@@ -4630,7 +4630,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "ожидалась %<]%>"
@@ -4640,7 +4640,7 @@
 msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "ожидалась %<}%>"
@@ -4647,7 +4647,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "ожидалась %<{%>"
@@ -4657,7 +4657,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "ожидалось %<:%>"
@@ -4672,24 +4672,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "выражение %qE, имеющее тип абстрактного класса %qT, нельзя использовать в throw-выражении"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "ожидалось %<while%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4697,18 +4697,18 @@
 msgid "expected %<.%>"
 msgstr "ожидалась %<.%>"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "ожидалось %<@end%>"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "ожидалось %<>%>"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "ожидалась %<,%> или %<)%>"
@@ -4716,17 +4716,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "ожидалось %<=%>"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "ожидалось %<[%>"
@@ -4735,7 +4735,7 @@
 msgid "(anonymous)"
 msgstr "(anonymous)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "ожидалось %<<%>"
@@ -4746,11 +4746,11 @@
 msgid "expected label"
 msgstr "ожидался канал"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "кандидат 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "кандидат 2:"
 
@@ -4990,11 +4990,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%s:%d:   в раскрытии константного выражения %qs"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "претенденты:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "кандидат"
@@ -5172,85 +5172,85 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "фактический аргумент для INTENT = OUT/INOUT"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "Ширина должна быть положительная"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "Требуется неотрицательная ширина"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 #| msgid "Unexpected element '%c' in format string at %L"
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Неожиданный элемент '%c' в строке формата в %L"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "Неожиданное окончание строки формата"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr "Нулевая ширина в дескрипторе формата"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "Отсутствует открывающая скобка"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 #| msgid "Left parenthesis required after '*'"
 msgid "Left parenthesis required after %<*%>"
 msgstr "Левая скобка требуется после '*'"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "Ожидался P дескриптор редактирования"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "P дескриптор требует предшествующий масштабный множитель"
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-#| msgid "Missing right parenthesis at %C"
-msgid "Right parenthesis expected at %C"
-msgstr "Отсутствует правая скобка в %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr "Запятая требуется после P дескриптора"
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr "Положительная ширина требуется с T дескриптором"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "E спецификатор не допускается с g0 дескриптором"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "Положительная ширина экспоненты требуется"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+#| msgid "Missing right parenthesis at %C"
+msgid "Right parenthesis expected at %C"
+msgstr "Отсутствует правая скобка в %C"
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr "Точка требуется в спецификаторе формата"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr "%s тег"
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr "внутреннее устройство в WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s тег с INQUIRE"
@@ -5260,75 +5260,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "Синтаксическая ошибка в выражении в %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Неожиданный конец файла"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Переполнение при вычислении целочисленного выражения"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "Имя слишком длинное"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Некорректное имя"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Ожидалось имя"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "Ожидалась открывающая скобка"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "Ожидалась закрывающая скобка"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Ожидалось целочисленное значение"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Ожидалась строка"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum(): перечисление не найдено"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "Ожидалось имя атрибутного бита"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Ожидалась integer строка"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "Ошибка при преобразовании целого"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Ожидалась real строка"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "Ожидался тип выражения"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "Некорректный оператор"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "Некорректный тип в константном выражении"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "Неожиданный конец модуля"
 
@@ -5610,12 +5610,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Фактическая длина строки меньше декларированной для формального аргумента '%s' (%ld/%ld)"
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Цель переотображения ранга слишком мала (%ld < %ld)"
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -6002,7 +6002,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 и -m64 несовместимы"
 
@@ -9986,7 +9986,7 @@
 msgstr "Битовый размер смещений для непосредственных TLS"
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 #, fuzzy
 #| msgid "Schedule code for given CPU"
@@ -10293,7 +10293,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
 msgid "Use LRA instead of reload."
@@ -10608,7 +10608,7 @@
 msgid "Use 80-bit long double."
 msgstr "Использовать 128-битное представление long double"
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 #| msgid "Use 64-bit long double"
@@ -10615,7 +10615,7 @@
 msgid "Use 64-bit long double."
 msgstr "Использовать 64-битное представление long double"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy
 #| msgid "Use 128-bit long double"
@@ -12023,119 +12023,119 @@
 msgid "64 bit ABI."
 msgstr "64-битный ABI"
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 #, fuzzy
 #| msgid "Maintain backchain pointer"
 msgid "Maintain backchain pointer."
 msgstr "Сохранять указатель на вызванную функцию"
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 #, fuzzy
 #| msgid "Additional debug prints"
 msgid "Additional debug prints."
 msgstr "Выводить отладочную печать"
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 #, fuzzy
 #| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
 msgstr "архитектура ESA/390"
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 #| msgid "Enable decimal floating point hardware support"
 msgid "Enable decimal floating point hardware support."
 msgstr "Использовать аппаратную реализацию десятичной плавающей арифметики"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 #| msgid "Enable hardware floating point"
 msgid "Enable hardware floating point."
 msgstr "Использовать аппаратную реализацию плавающей арифметики"
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Use hardware transactional execution instructions."
 msgstr "Использовать аппаратные инструкции плавающей арифметики"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 #, fuzzy
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют на %s"
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 #, fuzzy
 #| msgid "Use packed stack layout"
 msgid "Use packed stack layout."
 msgstr "Использовать компактную раскладку в стеке"
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 #, fuzzy
 #| msgid "Use bras for executable < 64k"
 msgid "Use bras for executable < 64k."
 msgstr "Использовать команду bras, если выполняемый файл < 64Кб"
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 #| msgid "Disable hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "Не использовать аппаратную реализацию плавающей арифметики"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 #, fuzzy
 #| msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered"
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "Максимальное число байт до границы стека, при достижении которого будет выполнена команда trap"
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 #, fuzzy
 #| msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit"
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "Генерировать в прологе код, обеспечивающий выполнение trap при переполнении стека"
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 #| msgid "Generate string instructions for block moves"
 msgid "Use the mvcle instruction for block moves."
 msgstr "Генерировать строковые команды для блочных пересылок"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 #, fuzzy
 #| msgid "Warn if a function uses alloca or creates an array with dynamic size"
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "Предупреждать, если функция использует alloca или создаёт массив изменяемого размера"
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 #, fuzzy
 #| msgid "Warn if a single function's framesize exceeds the given framesize"
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "Предупреждать, если размер окна функции превосходит заданное значение"
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 #, fuzzy
 #| msgid "z/Architecture"
 msgid "z/Architecture."
 msgstr "z/Архитектура"
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 #, fuzzy
 #| msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 0."
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
@@ -12201,11 +12201,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr "Известные ARM CPUs (для использования с -mcpu= и -mtune= опциями):"
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr "Известные ARM архитектуры (для использования с -march= опцией):"
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr "Известные ARM FPUs (для использования с -mfpu= опцией):"
 
@@ -12514,110 +12514,132 @@
 msgstr "Использовать расширения UltraSPARC Visual Instruction Set version 1.0"
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 #, fuzzy
 #| msgid "Use UltraSPARC Fused Multiply-Add extensions"
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "Использовать расширения UltraSPARC Fused Multiply-Add "
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 #, fuzzy
 #| msgid "Use UltraSPARC Fused Multiply-Add extensions"
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "Использовать расширения UltraSPARC Fused Multiply-Add "
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
 #, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Генерировать плавающие команды умножения с накоплением"
+
+#: config/sparc/sparc.opt:102
+#, fuzzy
 #| msgid "Use UltraSPARC Population-Count instruction"
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "Использовать инструкцию UltraSPARC Population-Count"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 #, fuzzy
 #| msgid "Use UltraSPARC Population-Count instruction"
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "Использовать инструкцию UltraSPARC Population-Count"
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 #| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "Генерировать код с 64-битными указателями"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 #| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "Генерировать код с 32-битными указателями"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "Использовать 64-битный ABI"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "Использовать 32-битный ABI"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 #, fuzzy
 #| msgid "Use stack bias"
 msgid "Use stack bias."
 msgstr "Использовать смещение в стеке"
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 #, fuzzy
 #| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Использовать более строгое выравнивание структур для копирования двойными словами"
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 #, fuzzy
 #| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Оптимизировать хвостовые команды вызова в ассемблере и компоновщике"
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "Использовать свойства указанного процессора и планировать код для него"
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 #, fuzzy
 #| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
 msgstr "Использовать указанную модель кодирования SPARC-V9"
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "Enable debug output."
 msgstr "Включить отладочную выдачу"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "Включить строгую проверку возврата структуры 32-битного psABI"
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 #, fuzzy
 #| msgid "Enable workaround for single erratum of AT697F processor"
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr "Включить обход для single erratum AT697F процессора"
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 #, fuzzy
 #| msgid "Enable workaround for single erratum of AT697F processor"
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr "Включить обход для single erratum AT697F процессора"
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+#, fuzzy
+#| msgid "Enable workaround for single erratum of AT697F processor"
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr "Включить обход для single erratum AT697F процессора"
+
+#: config/sparc/sparc.opt:250
+#, fuzzy
+#| msgid "Enable workaround for single erratum of AT697F processor"
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr "Включить обход для single erratum AT697F процессора"
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr "Задать действующую модель памяти для программы."
 
@@ -18561,7 +18583,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -19099,7 +19121,7 @@
 msgstr "ожидался булевый тип"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -19393,132 +19415,132 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr "range клаузула должна иметь тип массива, вырезки, строки, отображения или канала"
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 msgid "invalid comparison of non-ordered type"
 msgstr "некорректное сравнение неупорядоченного типа"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr "вырезка может сравниваться только с nil"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr "отображение может сравниваться только с nil"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr "функция может сравниваться только с nil"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, c-format
 msgid "invalid operation (%s)"
 msgstr "некорректная операция (%s)"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 msgid "invalid comparison of non-comparable type"
 msgstr "некорректное сравнение несравнимого типа"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 #| msgid "invalid comparison of non-comparable struct"
 msgid "invalid comparison of generated struct"
 msgstr "некорректное сравнение несравнимой структуры"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr "некорректное сравнение несравнимой структуры"
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 #| msgid "invalid comparison of non-comparable array"
 msgid "invalid comparison of generated array"
 msgstr "некорректное сравнение несравнимого массива"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr "некорректное сравнение несравнимого массива"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 #, fuzzy
 #| msgid "multiple value function call in single value context"
 msgid "multiple-value function call in single-value context"
 msgstr "вызов функции со множеством значений в контексте одного значения"
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr "нужно явное преобразование"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr "невозможно использовать тип %s как тип %s"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr "разные типы приемников"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr "разное число параметров"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr "разные типы параметров"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr "разные varargs"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr "разное число результатов"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr "разные типы результатов"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "нужно явное преобразование; отсутствует метод %s%s%s"
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "несовместимый тип для метода %s%s%s"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "несовместимый тип для метода %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr "указатель на интерфейсный тип не имеет методов"
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr "тип не имеет методов"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "неоднозначный метод %s%s%s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "отсутствует метод %s%s%s"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, fuzzy, c-format
 #| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "метод %s%s%s требует указателя"
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, fuzzy, c-format
 #| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s is marked go:nointerface"
@@ -19702,7 +19724,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "слишком мало аргументов в вызове функции %<va_start%>"
@@ -19766,28 +19788,28 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "недопустимая модель памяти в вызове %<__atomic_load%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "недопустимая модель памяти в вызове %<__atomic_store%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "неконстантный аргумент 1 в вызове __atomic_always_lock_free"
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "нецелочисленный аргумент 1 в вызове __atomic_is_lock_free"
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return не поддерживается для этой платформы"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -19795,7 +19817,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kнекорректное использование %<__builtin_va_arg_pack ()%>"
@@ -19802,12 +19824,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kнекорректное использование %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "второй аргумент %<__builtin_longjmp%> должен быть 1"
@@ -19814,64 +19836,64 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "целевой формат не поддерживает бесконечные значения"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "целевой формат не поддерживает бесконечные значения"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> в функции с фиксированным числом аргументов"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "неверное число аргументов в вызове функции %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "вызов %<__builtin_next_arg%> без аргумента"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "неверное число аргументов в вызове функции %<__builtin_next_arg%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "второй аргумент %<va_start%> не является последним явным аргументом"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "неопределенное поведение, т.к. второй параметр %<va_start%> продекларирован с классом памяти %<register%>"
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%Kпервый аргумент %D должен быть указателем, второй - целой константой"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%Kпоследний аргумент %D не является целой константой от 0 до 3"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kпопытка освобождения объекта %qD, не находящегося в динамической памяти"
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kпопытка освобождения объекта, не находящегося в динамической памяти"
@@ -20821,12 +20843,12 @@
 msgstr "атрибут %<weakref%> игнорируется, поскольку переменная инициализирована"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F используется, но нигде не определена"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
@@ -20924,12 +20946,12 @@
 msgid "cannot find '%s'"
 msgstr "не удалось найти '%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "ошибка в pex_init: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -20939,7 +20961,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "должна быть установлена COLLECT_LTO_WRAPPER"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -21155,7 +21177,7 @@
 msgid "error writing %qs"
 msgstr "ошибка записи %qs"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "ошибка открытия %s"
@@ -21236,17 +21258,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "множественные программы индивидуальности для EH поддерживаются только если ассемблер поддерживает директиву .cfi_personality"
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) найден в расположении переменной"
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -21356,12 +21378,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kвызов %qs, объявленной с атрибутом error: %s"
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kвызов %qs, объявленной с атрибутом warning: %s"
@@ -21376,12 +21398,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "размер кадра %wd байт больше чем %wd байт"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "ошибка открытия дамп-файла прохода final %qs: %m"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "ошибка закрытия дамп-файла прохода final %qs: %m"
@@ -21396,7 +21418,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "при данной ширине битового поля результат сравнения - всегда %d"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "предполагается что при упрощении проверки диапазона не произошло переполнение"
@@ -21426,7 +21448,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "предполагается, что при комбинировании констант вокруг сравнения не произошло переполнение"
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "проверка fold: исходное дерево изменено функцией fold"
@@ -21436,7 +21458,7 @@
 msgid "total size of local objects too large"
 msgstr "общий размер локальных объектов слишком велик"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "некорректное ограничение в %<asm%>"
@@ -21537,62 +21559,68 @@
 msgid "input file %qs is the same as output file"
 msgstr "%qs не является корректным выходным файлом"
 
-#: gcc.c:4498
+#: gcc.c:4476
+#, fuzzy, gcc-internal-format
+#| msgid "no input file specified"
+msgid "output filename may not be empty"
+msgstr "не задано ни одного входного файла"
+
+#: gcc.c:4501
 #, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "ключ -pipe игнорируется, т.к. задан ключ -save-temps"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "%<-x %s%> не имеет смысла за последним входным файлом"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr "не найден скрипт компоновки по умолчанию %qs в пути поиска библиотек"
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "ключ %qs не начинается с %<-%>"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr "ключ, сгенерированный программой spec, состоит из одного знака %<-%>"
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "не удалось открыть временный файл ответа %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "не удалось записать во временный файл ответа %s"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "не удалось закрыть временный файл ответа %s"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "спецификация %qs некорректна"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "спецификация %qs имеет некорректный %<%%0%c%>"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "спецификация %qs имеет некорректный %<%%W%c%>"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "спецификация %qs имеет некорректный %<%%x%c%>"
@@ -21600,232 +21628,232 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "ошибка спецификации: элемент %<%%*%> не инициализирован при сопоставлении"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "ошибка спецификации: неопознанный ключ %qc"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "неизвестная функция %qs в спецификации"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "ошибка в аргументах spec-функции %qs"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "некорректное имя spec-функции"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "не заданы аргументы spec-функции"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "некорректные аргументы spec-функции"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "ошибка в спецификации %qs в скобках на символе %qc"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "ошибка в спецификации %qs в скобках"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s: не удалось определить длину файла %s для сравнения результатов компиляции с отладочной информацией и без"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr "%s: ошибка -fcompare-debug (длина)"
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s: ошибка открытия файла %s для сравнения результатов компиляции с отладочной информацией и без"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "%s: ошибка -fcompare-debug"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "ошибка спецификации: задано более одного аргумента для SYSROOT_SUFFIX_SPEC"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "ошибка спецификации: задано более одного аргумента для SYSROOT_HEADERS_SUFFIX_SPEC"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "некорректный ключ %<-fdump-%s%>"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command line option %<-%s%>"
 msgstr "некорректный ключ %<-fdump-%s%>"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "суффикс системных заголовков не сконфигурирован"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "не заданы входные файлы"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "нельзя использовать -o с, -S или -E и несколькими файлами"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: компилятор %s не установлен"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "повторная компиляция с -fcompare-debug"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr "во время повторной компиляции для -fcompare-debug"
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr "сравнение финальных дампов компилятора"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "-fuse-linker-plugin, но %s не найден"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: входные файлы компоновки не использованы, поскольку компоновка не выполнялась"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "некорректное задание языка %s"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "описание мультибиблиотеки %qs некорректно"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "исключения %qs в мультибиблиотеке некорректны"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select %qs is invalid"
 msgid "multilib select %qs %qs is invalid"
 msgstr "выбор мультибиблиотеки %qs некорректен"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "выбор мультибиблиотеки %qs некорректен"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "исключение %qs в мультибиблиотеке некорректно"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "переменная окружения %qs не определена"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "некорректный номер версии %qs"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "слишком мало аргументов в %%:version-compare"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "слишком много аргументов в %%:version-compare"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "Неизвестный оператор %qs в %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "слишком много аргументов в %%:compare-debug-dump-opt"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "слишком много аргументов в %%:compare-debug-self-opt"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "слишком мало аргументов в %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "слишком много аргументов в %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr "аргумент %%:compare-debug-auxbase-opt заканчивается не .gk"
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to %%:replace-extension"
 msgstr "слишком мало аргументов функции"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %%:debug-level-gt"
@@ -21985,9 +22013,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "объявлено здесь"
@@ -22418,245 +22446,245 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "использование результат функции, возвращающей %<void%>"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "неверное lvalue-выражение в выходном операторе %d оператора asm"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "входное значение %d должно быть в памяти"
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "невозможна прямая адресация к входной позиции памяти %d"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 #| msgid "threadprivate variable %qE used in untied task"
 msgid "threadprivate variable %qE used in target region"
 msgstr "частная переменная потока %qE использована в безымянной задаче"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing task"
 msgid "enclosing target region"
 msgstr "объемлющая задача"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "частная переменная потока %qE использована в безымянной задаче"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "объемлющая задача"
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qE not specified in enclosing parallel"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE не задано в объемлющей конструкции parallel"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "enclosing task"
 msgid "enclosing %qs"
 msgstr "объемлющая задача"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, fuzzy, gcc-internal-format
 #| msgid "%qE not specified in enclosing parallel"
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE не задано в объемлющей конструкции parallel"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE не описан (первое использование в этой функции)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "переменная %q+D декларирована со спецификатором %<inline%>"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
 #
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%Hитерационная переменная %qE есть unsigned"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "итерационная переменная %qE должна быть private"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "итерационная переменная %qE не должна быть firstprivate"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "итерационная переменная %qE не должна быть редукцией"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qE should not be reduction"
 msgid "iteration variable %qE should not be linear"
 msgstr "итерационная переменная %qE не должна быть редукцией"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qE should not be firstprivate"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "итерационная переменная %qE не должна быть firstprivate"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qE should be private"
 msgid "iteration variable %qE should not be private"
 msgstr "итерационная переменная %qE должна быть private"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE встречается более одного раза в конструкции данных"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qE is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s переменная %qE является частной для внешнего контекста"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s переменная %qE является частной для внешнего контекста"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "некорректная template-декларация %qD"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "ordered область должна быть тесно вложена внутри области цикла с ordered клаузулой"
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "число результатов не соответствует числу значений"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "ожидалось %<}%> перед %<else%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "преобразование в gimple завершилось неуспешно"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT преобразован к %qT при передаче через %<...%>"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(поэтому %<va_arg%> нужно передать %qT, а не %qT)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "при достижении этого кода выполнение программы завершится аварийно"
@@ -22908,7 +22936,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
 #: ipa-devirt.c:1235
@@ -23013,7 +23041,7 @@
 #: ipa-devirt.c:1576
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr "%q+D декларировано здесь, позднее в единице компиляции"
 
 #: ipa-devirt.c:1599
@@ -23430,205 +23458,205 @@
 msgid "multiple loop axes specified for routine"
 msgstr "класс хранения задан для имени типа"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region may not be closely nested inside of critical or explicit task region"
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr "ordered область не может быть тесно вложена внутри critical, или explicit task области"
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr ""
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid arguments"
 msgstr "некорректный аргумент PHI"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, fuzzy, gcc-internal-format
 #| msgid "barrier region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "область барьера не может быть тесно вложена внутри work-sharing. critical, ordered, master или explicit task области"
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "work-sharing region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "work-sharing область не может быть тесно вложена внутри work-sharing, critical, ordered, master или explicit task области"
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, fuzzy, gcc-internal-format
 #| msgid "master region may not be closely nested inside of work-sharing or explicit task region"
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr "master область не может быть тесно вложена внутри work-sharing или explicit task области"
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr "ordered область должна быть тесно вложена внутри области цикла с ordered клаузулой"
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind before %<decltype%>"
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr "некорректный тип планирования перед %<decltype%>"
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr "ordered область должна быть тесно вложена внутри области цикла с ordered клаузулой"
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region may not be closely nested inside of critical or explicit task region"
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr "ordered область не может быть тесно вложена внутри critical, или explicit task области"
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr "ordered область должна быть тесно вложена внутри области цикла с ordered клаузулой"
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, fuzzy, gcc-internal-format
 #| msgid "critical region may not be nested inside a critical region with the same name"
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr "critical область не может быть вложена внутри critical области с тем же именем"
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "некорректный выход из OpenMP структурного блока"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -23635,7 +23663,7 @@
 msgstr "некорректный вход в OpenMP структурный блок"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid branch to/from an OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
@@ -23724,7 +23752,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "ключ %qs для этой конфигурации не поддерживается"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "отсутствует аргумент для %qs"
@@ -23888,136 +23916,148 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
+#, fuzzy, gcc-internal-format
+#| msgid "transactional memory is not supported with non-call exceptions"
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "транзакционная память не поддерживается с non-call исключениями"
+
+#: opts.c:1015
+#, fuzzy, gcc-internal-format
+#| msgid "transactional memory is not supported with non-call exceptions"
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "транзакционная память не поддерживается с non-call исключениями"
+
+#: opts.c:1417
 #, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr "неопознанный include_flags 0x%x передан print_specific_help"
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "неизвестный аргумент ключа --help=: %q.*s"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "неизвестный аргумент ключа --help=: %q.*s"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "аргумент --help %q.*s неоднозначен, требуется уточнение"
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "неизвестный аргумент ключа --help=: %q.*s"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 #| msgid "LTO support has not been enabled in this configuration"
 msgid "HSA has not been enabled during configuration"
 msgstr "Поддержка LTO в данной конфигурации отсутствует"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "выравнивание структуры должно быть небольшой степенью двойки, а не %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "unknown stack check parameter \"%s\""
 msgid "unknown stack check parameter %qs"
 msgstr "неизвестный параметр проверки стека \"%s\""
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "версия dwarf %d не поддерживается"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: аргументы --param должны иметь вид ИМЯ=ЗНАЧЕНИЕ"
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "некорректное значение ключа --param %qs"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs"
 msgstr "некорректное значение ключа --param %qs"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "некорректное значение ключа --param %qs"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "целевая платформа не поддерживает вывод отладочной информации"
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "отладочный формат \"%s\" противоречит предыдущему выбору"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "некорректный уровень отладочной информации \"%s\""
 
-#: opts.c:2533
+#: opts.c:2540
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "уровень отладочной информации %s слишком высок"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "исходный максимальный размер core-файла: %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "установлен максимальный размер core-файла: %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "некорректный ключ отладки: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: ключа -%s не существует"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -24373,7 +24413,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "регистр %qD назначен для нескольких глобальных регистровых переменных"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "конфликтует с %qD"
@@ -24999,13 +25039,13 @@
 msgid "error closing %s: %m"
 msgstr "ошибка закрытия %s: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is incompatible with %qs"
 msgid "self-tests incompatible with -E"
 msgstr "%qs несовместим с %qs"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -25938,47 +25978,47 @@
 msgid "in expansion of macro %qs"
 msgstr "%s:%d:   в раскрытии константного выражения %qs"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "блок %i имеет множественные EH-дуги"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr "блок %i не может выдавать исключений, но имеет EH-дугу"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "в последнем операторе блока %i некорректно установлен lp"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "в блоке %i отсутствует EH-дуга"
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "некорректная EH-дуга %i->%i"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "в блоке %i отсутствует дуга"
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "в блоке %i слишком много сквозных дуг"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "блок %i содержит некорректную дугу"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "блок %i содержит некорректную сквозную дугу"
@@ -26080,35 +26120,35 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "in a call to built-in function %qD"
 msgstr "некорректный аргумент встроенной функции"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared weak"
 msgid "in a call to function %qD declared here"
 msgstr "inline функция %q+D объявлена weak"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, fuzzy, gcc-internal-format
 #| msgid "cannot optimize loop, the loop counter may overflow"
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "невозможно оптимизировать циклы, в которых счётчик выходит за границы"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "within this loop"
@@ -26466,11 +26506,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -27469,7 +27509,7 @@
 msgid "type was previously declared %qE"
 msgstr "тип был ранее декларирован как %qE"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -27752,7 +27792,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "адрес %qD всегда будет иметь значение %<истина%>"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "присваивание, используемое как логическое выражение, рекомендуется "
@@ -28391,62 +28431,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "избыточные квалификаторы типа в аргументе форматирования (аргумент %d)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> ожидает аргумент типа %<%s%s%>, но аргумент %d имеет тип %qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> ожидает соответствующий %<%s%s%> аргумент"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> ожидает аргумент типа %<%T%s%>, но аргумент %d имеет тип %qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> ожидает соответствующий %<%T%s%> аргумент"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> не определен как тип"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> не определен как %<long%> или %<long long%>"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "имя %<locus%> не определено как тип"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> не определен как тип"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "имя %<tree%> не определено как тип"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "имя %<tree%> не определено как указательный тип"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "аргументы, подлежащие форматированию, должны соответствовать %<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "форматы strftime нельзя использовать для форматирования аргументов"
@@ -28547,7 +28587,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "дублированные %<@%> перед строкой Objective-C"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "неподдерживаемая нестандартная конкатенация строковых литералов"
@@ -28578,7 +28618,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "в %<#pragma omp atomic capture%> используются две различные переменные для памяти"
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "некорректный тип итерационной переменной %qE"
@@ -28594,22 +28634,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE не инициализирован"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "отсутствует управляющий предикат"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "некорректный управляющий предикат"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "отсутствует инкрементальное выражение"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "некорректное инкрементальное выражение"
@@ -29168,8 +29208,8 @@
 msgid "wrong type argument to %s"
 msgstr "неверный аргумент типа для %s"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "переполнение при вычислении константного выражения"
@@ -29854,7 +29894,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<_Cilk_spawn%> may only be used inside a function"
@@ -30025,7 +30065,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "некорректный ключ -mdebug-%s"
@@ -30359,7 +30399,7 @@
 msgstr "аргумент должен быть константой"
 
 #
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "index mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -30456,7 +30496,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "неизвестное значение %s для ключа -mfpu"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "ключ -mcpu=%s несовместим с ключом -march=%s"
@@ -30555,9 +30595,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "%s\"%s\"%s некорректно"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -30646,7 +30686,7 @@
 msgstr "некорректное значение %qs для -mmemory-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -30835,238 +30875,238 @@
 msgid "insn addresses not freed"
 msgstr "некорректный адрес, не register:"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "this builtin is not supported for this target"
 msgstr "вложенные функции не поддерживаются для этой платформы"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "селектор должен быть непосредственным значением"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "маска должна быть непосредственным значением"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "аргумент атрибута %qE должен быть между 0 и 255"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
 #
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -G are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "ключи -fPIC и -G несовместимы"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "целевой процессор не поддерживает режим ARM"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "поддержка backtrace имеет смысл только для Thumb"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "-mcallee-super-interworking имеет смысл только при компиляции для Thumb"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g с -mno-apcs-frame может создать проблемы при отладке"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "недопустимо использовать -mtp=cp15 с 16-битным Thumb"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "позиционно-независимый RTP несовместим с Thumb"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "целевой процессор не поддерживает команды THUMB"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "целевой процессор не поддерживает невыровненные доступы"
@@ -31073,145 +31113,145 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-mpcrel -fPIC is not currently supported on selected cpu"
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mpcrel -fPIC в настоящее время не поддерживается на выбранном процессоре"
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "целевой процессор не поддерживает interworking"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "ключ -mapcs-stack-check несовместим с -mno-apcs-frame"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "ключи -fpic и -mapcs-reent несовместимы"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "реентерабельный код APCS не поддерживается. Ключ игнорируется."
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "ключи -mrelocatable и -msdata=%s несовместимы"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt требует AAPCS совместимого ABI для правильной работы"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "для работы с iwmmxt ABI требуется процессор с поддержкой iwmmxt"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS не поддерживает -mcaller-super-interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS не поддерживает -mcaller-super-interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 и нет ldrh"
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mflat-abi=hard и VFP"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mflat-abi=hard и VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "граница размера структуры может быть только 8, 32 или 64"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "граница размера структуры может быть только 8 или 32"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "позиционно-независимый RTP несовместим с -msingle-pic-base"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= не имеет смысла без -fpic"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "использование '%s' как PIC-регистра невозможно"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition не поддерживается на этой архитектуре"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "целевой процессор не поддерживает команды THUMB"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "non-AAPCS производный PCS вариант"
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "вариантные функции должны использовать базовый AAPCS вариант"
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS вариант"
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 аппаратный плавающий VFP ABI"
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -31219,79 +31259,84 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE атрибут применим только к функциям"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "атрибут %qE применим только к функциям, а не к %s"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD не может иметь переменное число аргументов"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "атрибут %qE применим только к функциям, а не к %s"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "атрибут %qE для не классовых типов игнорируется"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute has no effect on unit local functions"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "атрибут %qE не действует для локальных функций"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "атрибут %qE допустим только для функций"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "невозможно вычислить фактическое положение параметра в стеке"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Неожиданный конец модуля"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "нет свободных low-регистров для выталкивания high-регистров"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid fpu for attribute(target(\"%s\"))"
@@ -31300,13 +31345,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) неизвестен"
@@ -31412,176 +31457,188 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr "атрибуты функций %qs и %qs не воздействуют на %qs функцию"
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs функция не может иметь аргументы"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs функция не может возвращать значение"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%qs appears to be a misspelled %s handler"
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs возможно искаженный %s обработчик"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
+#, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
 #, fuzzy, gcc-internal-format
 #| msgid "'builtin_return_address' contains only 2 bytes of address"
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "'builtin_return_address' содержит только 2 байта адреса"
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "смещение указателя от символа, возможно, некорректно"
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "доступ к памяти данных с адресом программной памяти"
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "доступ к программной памяти с адресом памяти данных"
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "фиксированный регистр %s использован для передачи параметра функции"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "запись в адресное пространство %qs не поддерживается"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "атрибут %qE применим только к переменным и функциям"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported for R8C target"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "атрибут %qE не поддерживается для R8C платформы"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE атрибут применим только к переменным"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "аргументом атрибута %qE должна быть целая константа"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute has no effect"
 msgid "%qE attribute address out of range"
 msgstr "атрибут %qE не действует"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE атрибут применим только к переменным"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "вложенные функции не поддерживаются для этой платформы"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, fuzzy, gcc-internal-format
 #| msgid "code model %qs not supported in the %s bit mode"
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "модель кодирования %s не поддерживается в %s-битном режиме"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "указатель в адресное пространство %qs должен быть const в %qT"
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "указатель в адресное пространство %qs должен быть const в %s %q+D"
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "переменная %q+D должна быть const чтобы ее можно было поместить в доступную только на чтение секцию посредством %qs"
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "static IO declaration for %q+D needs an address"
 msgstr "декларация %q+D перекрывает параметр"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "IO definition for %q+D needs an address"
 msgstr "здесь было предыдущее определение %q+D"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "только неинициализированные переменные могут размещаться в секции .noinit"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
+#, fuzzy, gcc-internal-format
+#| msgid "uninitialized variable %q+D put into program memory area"
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "неинициализированная переменная %q+D помещена в область программной памяти"
+
+#: config/avr/avr.c:10160
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "неинициализированная переменная %q+D помещена в область программной памяти"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 #| msgid "%qE incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "несовместимый атрибут %qE игнорируется"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU %qs поддерживается только для ассемблера"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "conversion from address space %qs to address space %qs"
 msgstr "Преобразование из %s в %s в %L"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s ожидает целую константу времени компиляции"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s ожидает длинную целую константу времени компиляции в качестве первого аргумента"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -31868,12 +31925,12 @@
 msgid "invalid IACC argument"
 msgstr "некорректный IACC аргумент"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "для %qs требуется константный аргумент"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "константный аргумент для %qs вне диапазона"
@@ -32070,7 +32127,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "модель кода %qs не поддерживается в режиме x32"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "модель кода %s не поддерживает PIC режим"
@@ -32218,303 +32275,303 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s игнорируется в 64-битном режиме"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary не поддерживается для этой целевой платформы"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d не между %d и %d"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d не между %d и 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry несовместимо с SEH"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "межмодульные оптимизации не реализованы для C++"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s используется без SSE включения"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s используется без SSE включения"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "набор команд SSE отменен, используется арифметика 387"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "набор команд 387 отменен, используется арифметика SSE"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "опробование стека требует %saccumulate-outgoing-args%s для корректной работы"
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry не поддерживается для 32 бит в комбинации с -fpic"
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry несовместимо с SEH"
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "неизвестная опция для -mrecip=%s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") уже было задано"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "инструкции с 2-байтным кодом операции не допускаются в 64-битном VLIW режиме"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Use a stack protection method for every function"
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "Использовать защиту стека для каждой функции"
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "атрибуты fastcall и regparm несовместимы"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "атрибуты regparam и thiscall несовместимы"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE атрибут требует целый константный аргумент"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "аргумент для %qE атрибута больше чем %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "атрибуты fastcall и cdecl несовместимы"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "атрибуты fastcall и stdcall несовместимы"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "атрибуты fastcall и thiscall несовместимы"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "атрибуты stdcall и cdecl несовместимы"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "атрибуты stdcall и fastcall несовместимы"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "атрибуты stdcall и thiscall несовместимы"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "атрибуты cdecl и thiscall несовместимы"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "атрибут %qE используется не для метода класса"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "вызов %qD с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "вызов %qT с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "не поддерживает мультибиблиотеку"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue несовместим с вложенной функцией"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "векторный аргумент AVX без включения AVX изменяет ABI"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE векторный аргумент без включения SSE изменяет ABI"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "результат - вектор SSE без включения SSE изменяет ABI"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "аргумент - вектор MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "возврат вектора MMX без включения MMX изменяет ABI"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI для передачи структуры с элементом flexible array изменен в GCC 4.4"
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI для передачи объединения с long double изменен в GCC 4.4"
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE регистровый возврат с выключенным SSE"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE регистровый аргумент с выключенным SSE"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 регистровый возврат с выключенным x87"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, fuzzy, gcc-internal-format
 #| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "вызов %qD с атрибутом sseregparm без включения SSE/SSE2"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI для передачи параметров с %d-байтным выравниванием изменен в GCC 4.6"
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "атрибут ms_hook_prologue несовместим с -mfentry для 32 бит"
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack не поддерживает fastcall с вложенной функцией"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 2 register  parameters for a nested function"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -32522,325 +32579,325 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack не поддерживает 3-регистровые параметры"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "некорректный размер операнда для расширенного регистра"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "расширенные регистры не имеют верхних половин"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "некорректный размер операнда для расширенного регистра"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, fuzzy, gcc-internal-format
 #| msgid "non-integer operand used with operand code '%c'"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "нецелый операнд использован с кодом операнда '%c'"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
 #
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 #| msgid "static linking is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "статическая компоновка не поддерживается"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<=%> (after %<getter%> attribute) before %qE"
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr "отсутствует %<=%> (после атрибута %<getter%>) перед %qE"
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %D"
 msgstr "предыдущая декларация %q+D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "вложенные функции не поддерживаются для этой платформы"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "аргумент %qs должен быть 2-битным беззнаковым литералом"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Аргумент для -ffpe-trap некорректен: %s"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "последний аргумент должен быть 2-битным непосредственным"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "пятый аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "третий аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "последний аргумент должен быть 32-битным непосредственным"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "последний аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "последний аргумент должен быть 1-битным непосредственным"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "последний аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "следующий за последним аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "последний аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "аргумент должен быть константой"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "некорректная инструкция:"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "недопустимое разделение узлов дерева"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "последний аргумент должен быть 4-битным непосредственным"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "последний аргумент должен быть 5-битным непосредственным"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "последний аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "последний аргумент должен быть 32-битным непосредственным"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE требует неизвестную isa опцию"
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE требует isa опцию %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "последний аргумент должен быть непосредственным"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be scale 1, 2, 4, 8"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "последний аргумент должен быть степенью 1, 2, 4, 8"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, fuzzy, gcc-internal-format
 #| msgid "last argument must be scale 1, 2, 4, 8"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "последний аргумент должен быть степенью 1, 2, 4, 8"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "некорректная инструкция:"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "последний аргумент должен быть 8-битным непосредственным"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "атрибут %qE допустим только для 32 бит"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "аргумент атрибута %qE не ноль и не один"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "атрибуты ms_abi и sysv_abi несовместимы"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "несовместимый атрибут %qE игнорируется"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "подпрограммы Service Routines для прерываний не могут использоваться в режиме Thumb"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Аргумент по значению в %L не допускается в этом контексте"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown IRA algorithm %qs"
 msgid "unknown asm flag output %qs"
 msgstr "неизвестный алгоритм раскраски %qs"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for make function"
 msgid "invalid type for asm flag output"
 msgstr "некорректный тип для make функции"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown architecture '%s'"
 msgid "Unknown architecture specific memory model"
 msgstr "неизвестная архитектура '%s'"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "неподдерживаемая комбинация: %s"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "неподдерживаемый тип аргумента для внутренней функции"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -32966,7 +33023,7 @@
 msgid "argument %qd is not a constant"
 msgstr "аргумент %qd не константа"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "нулевой указатель в вызове PRINT_OPERAND_ADDRESS"
@@ -32976,7 +33033,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: некорректный символ пунктуации '%c'"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "нулевой указатель в вызове PRINT_OPERAND"
@@ -33078,7 +33135,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread доступен только на fido"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "выражение для границы стека не поддерживается"
@@ -33609,8 +33666,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr "некорректный встроенный code"
@@ -33887,29 +33944,29 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "атрибут %qE для типов игнорируется"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "атрибут __BELOW100__ не допускается для класса памяти auto"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -33934,7 +33991,7 @@
 msgid "-g option disabled"
 msgstr "ключ -g игнорируется"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "выравнивание (%u) для %s превышает максимальное выравнивание для глобальных общих данных. Используется %u"
@@ -34079,165 +34136,165 @@
 msgid "junk at end of #pragma longcall"
 msgstr "мусор в конце #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "vec_extract only accepts 2 arguments"
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_extract принимает только 2 аргумента"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_insert принимает только 3 аргумента"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_insert принимает только 3 аргумента"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_insert принимает только 3 аргумента"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s принимает только %d аргументов"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s принимает только 1 аргумент"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s принимает только 2 аргумента"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract принимает только 2 аргумента"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert принимает только 3 аргумента"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "передача arg %d от %qE отменяет квалификаторы frompointer указуемого типа"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ifunc is not supported in this configuration"
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "ifunc в данной конфигурации не поддерживается"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "недопустимая комбинация параметров для AltiVec встроенной функции"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr "-mrecip требует -ffinite-math или -ffast-math"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr "-mrecip требует -fno-trapping-math или -ffast-math"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr "-mrecip требует -freciprocal-math или -ffast-math"
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "ключ -m64 требует архитектуры PowerPC64, включается"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "ключ -malign-power не поддерживается для 64-битного Darwin; он несовместим с установленными библиотеками C и C++"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr "не сконфигурировано для SPE ABI"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use PowerPC instruction set"
 msgid "not configured for SPE instruction set"
 msgstr "Не использовать систему команд PowerPC"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "target attribute или pragma изменяет SPE ABI"
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec не поддерживается на этой целевой платформе"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "SPE не поддерживается на этой целевой платформе"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "ключ -mmultiple не поддерживается для систем little endian"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "ключ -mstring не поддерживается для систем little endian"
@@ -34244,74 +34301,74 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "ключ -mcmodel несовместим с другими опциями toc"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mdirect-move requires -mvsx"
 msgstr "ключ --resource требует задания -o"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-vector requires -mvsx"
 msgstr "ключ --resource требует задания -o"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode requires -mvsx"
 msgstr "ключ --resource требует задания -o"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "-msingle-float option equivalent to -mhard-float"
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "опция -msingle-float эквивалентна -mhard-float"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "ключ --resource требует задания -o"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "ключ --resource требует задания -o"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -34320,244 +34377,244 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode might need -mlra"
 msgstr "ключ --resource требует задания -o"
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "target attribute или pragma изменяет размер long double"
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, fuzzy, gcc-internal-format
 #| msgid "-msingle-float option equivalent to -mhard-float"
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr "опция -msingle-float эквивалентна -mhard-float"
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr "неизвестный тип (%s) ABI библиотеки векторизации для ключа -mveclibabi="
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "target attribute или pragma изменяет AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "target attribute или pragma изменяет darwin64 ABI"
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "target attribute или pragma изменяет плавающие одинарной точности"
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "target attribute или pragma изменяет плавающие двойной точности"
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "неверный ключ препроцессора %qs"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "ABI для передачи параметров с %d-байтным выравниванием изменен в GCC 4.6"
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC вектор, возвращенный по ссылке: нестандартное расширение ABI без гарантий совместимости"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "возврат значения в векторном регистре невозможен, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI для передачи параметров с %d-байтным выравниванием изменен в GCC 4.6"
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "передача аргумента в векторном регистре невозможна, поскольку инструкции altivec отключены, используйте -maltivec для их включения"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI для передачи структуры с элементом complex float изменен в GCC 4.4"
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC вектор, переданный по ссылке: нестандартное расширение ABI без гарантий совместимости"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "внутренняя ошибка: встроенная функция %s уже обработана"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "аргумент 1 должен быть 5-битным знаковым литералом"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "аргумент 1 должен быть 5-битным знаковым литералом"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "аргумент 1 __builtin_altivec_predicate должен быть константой"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "аргумент 1 __builtin_altivec_predicate вне диапазона"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s игнорируется в 64-битном режиме"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "аргумент 1 __builtin_spe_predicate вне диапазона"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %s only accepts a string argument"
@@ -34564,7 +34621,7 @@
 msgstr "%s принимает только 1 аргумент"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "cpu %s is an invalid argument to builtin %s"
@@ -34571,297 +34628,302 @@
 msgstr "%qs некорректный аргумент для -mcpu="
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "%qs некорректный аргумент для -mcpu="
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "аргумент 3 должен быть 4-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "аргумент 3 должен быть 2-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a map"
 msgid "argument 1 must be 0 or 2"
 msgstr "аргумент 1 должен быть отображением"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "аргумент 3 должен быть 1-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "аргумент 2 должен быть 5-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "число должно быть 0 или 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range 0..15"
 msgstr "аргумент %d от %qE должен быть в диапазоне %d...%d"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "аргумент %qs должен быть 2-битным беззнаковым литералом"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "неразрешенная перегрузка Altivec builtin %qF"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "аргумент dss должен быть 2-битным беззнаковым литералом"
 
 #
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, fuzzy, gcc-internal-format
 #| msgid "second argument to %<__builtin_expect%> must be a constant"
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr "второй аргумент %<__builtin_expect%> должен быть константой"
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "третий аргумент %<__builtin_prefetch%> должен быть константой"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "аргумент 1 __builtin_paired_predicate должен быть константой"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "аргумент 1 __builtin_paired_predicate вне диапазона"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "аргумент 1 __builtin_spe_predicate должен быть константой"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "аргумент 1 __builtin_spe_predicate вне диапазона"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "Встроенная функция %s допустима только для процессора cell"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mvsx option"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "Встроенная функция %s требует опцию -mvsx"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "Встроенная функция %s требует опцию --maltivec"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "Встроенная функция %s требует опцию --mpaired"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "Встроенная функция %s требует опцию -mspe"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "Встроенная функция %s требует опцию --mpaired"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "Встроенная функция %s требует опцию --mpaired"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mspe option"
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "Встроенная функция %s требует опцию -mspe"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mspe option"
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "Встроенная функция %s требует опцию -mspe"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mspe option"
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "Встроенная функция %s требует опцию -mspe"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -maltivec option"
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "Встроенная функция %s требует опцию --maltivec"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "Встроенная функция %s требует опцию --mpaired"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Builtin function %s requires the -mpaired option"
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "Встроенная функция %s требует опцию --mpaired"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "Встроенная функция %s не поддерживается с текущими опциями"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "внутренняя ошибка: встроенная функция %s имела неожиданный тип результата %s"
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "внутренняя ошибка: встроенная функция %s, аргумент %d имел неожиданный тип аргумента %s"
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "кадр стека слишком велик"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, fuzzy, gcc-internal-format
 #| msgid "-fsplit-stack does not support 3 register parameters"
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack не поддерживает 3-регистровые параметры"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target для этой машины не поддерживается"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "отсутствует профилирование 64-битного кода для этого ABI"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Вы не можете брать адрес вложенной функции, если Вы используете опцию -mno-pointers-to-nested-functions."
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "использование %<long double%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "использование типов boolean в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "использование %<complex%> в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "использование типов decimal floating point в типах AltiVec некорректно"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "использование %<long%> в типах AltiVec некорректно для 64-битного кода без -mvsx"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "использование %<long%> в типах AltiVec не рекомендуется; используйте %<int%>"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "использование %<long long%> в типах AltiVec некорректно без -mvsx"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "использование %<double%> в типах AltiVec некорректно без -mvsx"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "выдается инструкция микрокода %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "выдается условная инструкция микрокода %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "некорректный процессор \"%s\" для %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s не допускается"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s некорректно"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -35052,6 +35114,7 @@
 msgstr "ключ -mas100-syntax несовместим с -gdwarf"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "для -m64 требуется процессор PowerPC64"
@@ -35144,7 +35207,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -35173,7 +35236,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -35195,7 +35258,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -35210,162 +35273,162 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "константный аргумент для %qs вне диапазона"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "константный аргумент для %qs вне диапазона"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "константный аргумент для %qs вне диапазона"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<неразрешенный тип перегруженной функции>"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "некорректный встроенный icode"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "некорректный аргумент встроенной функции"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "суммарный размер локальных переменных превышает архитектурный предел"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "размер кадра функции %qs равен %wd байт, что превышает предоставленный пользователем лимит стека в %d байт.  Добавлен безусловный trap."
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "размер кадра функции %qs равен %wd байт, что больше половины размера стека. Динамическая проверка не будет надежной. Для этой функции проверка не сгенерирована."
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "размер кадра %qs равен %wd байт"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs использует динамическое размещение стека"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<mwords-little-endian%> is deprecated and will be removed in a future release"
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr "%<mwords-little-endian%> не рекомендуется и не будет поддерживаться в будущих версиях"
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%<mwords-little-endian%> is deprecated and will be removed in a future release"
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr "%<mwords-little-endian%> не рекомендуется и не будет поддерживаться в будущих версиях"
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "режим z/Architecture не поддерживается на %s"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-битный ABI в режиме ESA/390 не поддерживается"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют на %s"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют на %s"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "аппаратные инструкции десятичной плавающей точки отсутствуют в режиме ESA/390"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "ключ -mhard-dfp не может быть использован вместе с -msoft-float"
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "сочетание ключей -mbackchain -mpacked-stack -mhard-float не поддерживается"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "размер стека должен быть больше чем охраняющее значение стека"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "размер стека должен быть больше чем 64k"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "ключ -mstack-guard влечет использование ключа -mstack-size"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "аргумент %qs должен быть неотрицательным целым числом"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
@@ -35372,7 +35435,7 @@
 msgstr "аргумент для %qE атрибута больше чем %d"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -35430,27 +35493,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax поддерживается только для RTP PIC"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s для этой конфигурации не поддерживается"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "ключ -mlong-double-64 несовместим с -m64"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "некорректное значение (%s) для ключа -mcmodel"
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "ключ -mcmodel= на 32-битных системах не поддерживается"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "-fcall-saved-REG не поддерживается для выходных регистров"
@@ -35738,22 +35802,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "некорректная константа в %<#pragma pack%> - директива проигнорирована"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "запрошены булевы регистры и ключ аппаратной плавающей математики"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "-f%s не поддерживается с командами CONST16"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "PIC не поддерживается с командами CONST16"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "в секции .bss размещаются только неинициализированные данные"
@@ -35842,7 +35906,7 @@
 msgid "could not read the BRIG file"
 msgstr "не удалось записать файл отзыва %s"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
@@ -36256,9 +36320,9 @@
 msgstr "метка %qD определена здесь"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD объявлено здесь"
@@ -36392,7 +36456,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> не допускается нигде кроме прототипа функции"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -37454,7 +37518,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "два или более типа в декларации"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "GCC не поддерживает тип %<long long long%>"
@@ -37603,17 +37667,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C не поддерживает %<complex%> как эквивалент %<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C не поддерживает целочисленные комплексные типы"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -37666,7 +37730,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "ожидался конец строки"
@@ -37708,7 +37772,7 @@
 msgstr "неизвестное имя типа %qE"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "ожидались спецификаторы декларации"
@@ -37724,7 +37788,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "ожидалось %<;%>, идентификатор или %<(%>"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "префиксные атрибуты для методов игнорируются"
@@ -37739,8 +37803,8 @@
 msgid "unexpected attribute"
 msgstr "неожиданный атрибут"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -37783,7 +37847,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> можно задавать только для переменных или деклараций функций"
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "ожидалось %<,%> или %<;%>"
@@ -37811,7 +37875,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 не поддерживает %<_Static_assert%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "ожидался строковый литерал"
@@ -37879,14 +37943,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "ожидался идентификатор"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "запятая в конце списка значений перечислимого типа"
@@ -38022,7 +38086,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "ожидалось %<}%> перед %<else%>"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> без предшествующего %<if%>"
@@ -38048,12 +38112,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr "метка может быть частью оператора, а декларация не является оператором"
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -38067,17 +38131,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "ожидался оператор"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<if%>"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "рекомендуется заключать в фигурные скобки пустое тело в операторе %<else%>"
@@ -38087,7 +38151,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "используйте фигурные скобки во избежание неоднозначной трактовки %<else%>"
@@ -38107,7 +38171,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "некорректная переменная-итератор в быстром перечислении"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -38297,17 +38361,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "операнды %<__builtin_complex%> имеют разные типы"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "неверное число аргументов в вызове аргументов в вызове %<__builtin_shuffle%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -38362,64 +38426,64 @@
 msgid "no type or storage class may be specified here,"
 msgstr "в этом месте не может указываться ни тип, ни класс хранения,"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "неизвестный атрибут свойства"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "отсутствует %<=%> (после атрибута %<getter%>)"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "отсутствует %<=%> (после атрибута %<setter%>)"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "атрибут %<setter%> может быть задан только один раз"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "имя setter должно заканчиваться %<:%>"
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "атрибут %<getter%> может быть задан только один раз"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> может использоваться только в составных операторах"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC option%> is not a string"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC option%> не является строковым литералом"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> может использоваться только в конструкции %<#pragma omp sections%>"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "ожидался оператор for"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
@@ -38435,12 +38499,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression before %s'%c'"
 msgid "expected integer expression before ')'"
@@ -38457,59 +38521,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD не переменная"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD не переменная"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<none%>"
 msgstr "ожидалось %<new%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "ожидалось %<none%> или %<shared%>"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "ожидалось %<;%>, %<,%> или %<)%>"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "ожидалось %<catch%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -38539,25 +38603,25 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L must be nonnegative"
 msgid "%<priority%> value must be non-negative"
 msgstr "'%s' в %L должен быть неотрицательным"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "ожидалось %<throw%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>"
 msgid "expected %<scalar%>"
@@ -38569,65 +38633,65 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "слишком много аргументов"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected attribute"
 msgid "unexpected argument"
 msgstr "неожиданный атрибут"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "аргумент атрибута %qE не целая константа"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "ожидалось %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> или %<max%>"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "в декларации заданы спецификаторы %<long%> и %<void%>"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<runtime%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "расписание %<auto%> не имеет параметра %<chunk_size%>"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "некорректный тип планирования"
@@ -38644,13 +38708,13 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
@@ -38657,7 +38721,7 @@
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
 #
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -38681,19 +38745,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "некорректный тип планирования"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "некорректная маска"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -38705,34 +38769,34 @@
 msgid "invalid proc_bind kind"
 msgstr "некорректный тип планирования"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs не является корректным для %qs"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs следует использовать вместе с %qs"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, fuzzy, gcc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "array section in %<#pragma acc declare%>"
@@ -38739,19 +38803,19 @@
 msgstr "Секция массива в '%s' вызове в %L"
 
 #
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "некорректное использование %<--%> на булевой переменной %qD"
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "invalid OpenACC clause at file scope"
 msgstr "некорректный тип в декларации"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
@@ -38758,24 +38822,24 @@
 msgstr "декларация %<extern%> переменной %qD в заголовке %<for%>-цикла"
 
 #
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "некорректное использование %<--%> на булевой переменной %qD"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<@end%> before %<#pragma%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "ожидалось %<@end%> перед %<#pragma%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC option%> is not a string"
 msgid "%<#pragma acc %s data%> has no data movement clause"
@@ -38792,7 +38856,7 @@
 msgid "expected function name"
 msgstr "ожидалась функция"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -38804,46 +38868,46 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, fuzzy, gcc-internal-format
 #| msgid "an asm-specification is not allowed on a function-definition"
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma GCC pch_preprocess%> должна быть первой"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "некорректный формат %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "некорректный оператор для %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
@@ -38854,28 +38918,28 @@
 msgid "expected %<(%> or end of line"
 msgstr "ожидалось %<(%> или конец строки"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "ожидался оператор for"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "ожидался оператор for"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "ожидалась декларация итерации или инициализация"
@@ -38885,76 +38949,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "недостаточно аккуратно вложенные циклы"
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "сливаемые циклы не являются идеально вложенными"
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "итерационная переменная %qD не должна быть firstprivate"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%>, как единственный параметры не может содержать квалификаторы"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> может использоваться только в составных операторах"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> before %qE"
 msgid "expected %<for%> after %qs"
 msgstr "ожидалось %<;%> перед %qE"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "ожидалось %<using%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -38970,7 +39034,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> должна предшествовать декларации %D, игнорируется"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -38980,34 +39044,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "ожидалось %<try%>"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "ожидалось %<decltype%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -39068,23 +39132,23 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "ожидалось %<#pragma omp section%> или %<}%>"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE объявлена %<threadprivate%> после первого использования"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "автоматическая переменная %qE не может быть %<threadprivate%>"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE имеет неполный тип"
@@ -39100,57 +39164,57 @@
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "размер стека должен быть точной степенью 2"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "селектор должен быть целой константой в диапазоне 0..%wi"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "ожидалась конструкция %<#pragma omp%>"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "некорректно употреблять %<#pragma%>"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> без включения транзакционной памяти"
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> внутри %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "внешний %<__transaction_cancel%> не внутри внешнего %<__transaction_atomic%>"
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  либо %<transaction_may_cancel_outer%> функция"
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> не внутри %<__transaction_atomic%>"
@@ -39161,7 +39225,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> before numeric constant"
 msgid "expected %<:%> or numeral"
@@ -39906,7 +39970,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "левой части инициализации, вероятно, можно задать атрибут format"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "тип результата, вероятно, может быть задан с атрибутом format"
@@ -40235,7 +40299,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "в ISO C операторы вида %<goto *expr;%> запрещены"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "функция декларированная с атрибутом %<noreturn%> содержит оператор %<return%>"
@@ -40246,7 +40310,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "транзакционное выражение не может присутствовать в константном выражении"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -40273,7 +40337,7 @@
 msgid "function returns address of label"
 msgstr "функция возвращает адрес локальной переменной"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "в операторе switch задано не целое"
@@ -40288,7 +40352,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case-метка не является целочисленным константным выражением"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-метка вне оператора switch"
@@ -40308,17 +40372,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "оператор continue вне цикла"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "оператор break использован с OpenMP для цикла"
@@ -40329,7 +40393,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "оператор break вне цикла или оператора switch"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
@@ -40436,12 +40500,12 @@
 msgid "used vector type where scalar is required"
 msgstr "векторный тип использован в контексте, где допустимо только скалярное значение"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -40452,27 +40516,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "слишком много конструкций %qs"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD не является шаблонным элементом-функцией"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -40485,19 +40549,19 @@
 msgstr "слишком много конструкций %qs"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -40504,58 +40568,58 @@
 msgstr "размер в new для массива должен иметь целочисленный тип"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "Array section in '%s' call at %L"
 msgid "zero length array section in %qs clause"
 msgstr "Секция массива в '%s' вызове в %L"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "используется массив переменного размера"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, fuzzy, gcc-internal-format
 #| msgid "for increment expression has no effect"
 msgid "for pointer type length expression must be specified"
 msgstr "for инкрементное выражение не имеет эффекта"
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "При входе в процедуру копировать секции массивов в последовательный блок"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qE does not have pointer or array type"
@@ -40577,7 +40641,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE имеет недопустимый тип для %<reduction(%s)%>"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -40588,17 +40652,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "используется массив переменного размера"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE должно быть %<threadprivate%> для %<copyin%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -40618,18 +40682,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE не является переменной в конструкции %qs"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -40642,33 +40706,33 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE не является переменной в конструкции %<firstprivate%>"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE не является переменной в конструкции %<lastprivate%>"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -40692,64 +40756,64 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE встречается более одного раза в конструкции данных"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE не является переменной в конструкции %qs"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, fuzzy, gcc-internal-format
 #| msgid "Array section not permitted in '%s' call at %L"
 msgid "array section does not have mappable type in %qs clause"
 msgstr "Секция массива не разрешена в '%s' вызове в %L"
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE не является переменной в конструкции %qs"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE не является переменной в конструкции %qs"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE встречается более одного раза в конструкции данных"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -40761,32 +40825,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE является предопределенным %qs для %qs"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -41376,84 +41440,84 @@
 msgid "use of multiversioned function without a default"
 msgstr "подразумеваемая функция %q+D с подразумеваемым аргументом"
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "передача %qT как аргумент %<this%> %q#D отменяет квалификаторы"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  в вызове %qD"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT не является базовым для %qT"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "вывод %qT как %qT"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (вы можете отключить это посредством -fno-deduce-init-list)"
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "слишком много аргументов для конструктора %q#D"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "константа ссылается на себя"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "вызов не функции %qD"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "невозможно вызвать конструктор %<%T::%D%> непосредственно"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, fuzzy, gcc-internal-format
 #| msgid "  for a function-style cast, remove the redundant %<::%D%>"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  для приведения типов в функциональном стиле удалите лишние %<::%D%>"
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "нет подходящей функции для вызова %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "нет подходящей функции для вызова %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "нет соответствующей функции для вызова %<%D(%A)%>"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "вызов перегруженной %<%s(%A)%> имеет неоднозначную трактовку"
 
 #
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from non-static data member initializer"
@@ -41460,7 +41524,7 @@
 msgstr "инициализаторы нестатических элементов данных"
 
 #
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from constructor"
@@ -41467,75 +41531,75 @@
 msgstr "инициализаторы нестатических элементов данных"
 
 #
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member initializers"
 msgid "pure virtual %q#D called from destructor"
 msgstr "инициализаторы нестатических элементов данных"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "некорректный вызов элемента-функции %qD без объекта"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "при передаче %qT предпочтение отдается %qT, а не %qT"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "предпочтение отдается %qD (а не %qD)"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  при преобразовании из %qT в %qT,"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  поскольку это дает лучшую последовательность преобразований аргумента"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "несоответствие подразумеваемого аргумента при разрешении перегрузки"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " кандидат 1: %q+#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " кандидат 2: %q+#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ говорит здесь о неоднозначности, хотя худшее преобразование для первого лучше, чем худшее преобразование для второго:"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "ошибка преобразования %qE из %qT в %qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "временная граница %qD сохраняется, пока существует конструктор"
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "некорректная инициализация неконстантной ссылки типа %qT из rvalue типа %qT"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "некорректная инициализация ссылки типа %qT из выражения типа %qT"
@@ -41643,296 +41707,296 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "ошибка вывода из %<final%> base %qT в производном типе %qT"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "все элементы-функции в классе %qT - частные (private)"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "в %q#T определен только private деструктор и нет друзей"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "в %q#T определен только private конструктор и нет друзей"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "отсутствует уникальное переопределение %qD в %qT"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D не может быть перегружено"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D marked final, but is not virtual"
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D помечен как final, но не является virtual"
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D marked override, but does not override"
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D помечен как override, но не делается override"
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D скрыто"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  методом %q+D"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D некорректно; анонимное объединение может иметь только нестатические элементы данных"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D некорректно; анонимная структура может иметь только нестатические элементы данных"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "private-элемент %q+#D в анонимном объединении"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous struct"
 msgid "private member %q#D in anonymous struct"
 msgstr "private-элемент %q+#D в анонимной структуре"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "protected-элемент %q+#D в анонимном объединении"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous struct"
 msgid "protected member %q#D in anonymous struct"
 msgstr "protected-элемент %q+#D в анонимной структуре"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "битовое поле %q+#D с нецелым типом"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ширина битового поля %q+D не является целой константой"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "отрицательная ширина битового поля %q+D"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "нулевая ширина битового поля %q+D"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "ширина поля %q+D превышает ширину его типа"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D слишком мало для представления всех значений типа %q#T"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "элемент %q+#D с конструктором не допускается в объединении"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "элемент %q+#D с деструктором не допускается в объединении"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "элемент %q+#D с операцией присваивания путем копирования не допускается в объединении"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D может быть не статическим, поскольку это элемент объединения"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "нестатический элемент данных %qD имеет тип Java класса"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "поле %q+D ошибочно декларировано с типом функции"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "поле %q+D ошибочно декларировано с типом метода"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "атрибут packed проигнорирован для неупакованного не-POD поля %q+#D"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "недопустимая декларация не-элемента %qs как %<mutable%>"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "инициализация нескольких полей в объединении %qT"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "поле %q+#D с тем же именем, что и класс"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q+#T содержит элементы данных типа указатель"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  но не переопределяет %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  или %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  но не переопределяет %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "выравнивание %qD больше чем в исходной декларации"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "инициализатор задан для невиртуального метода %q+D"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "метод перебивает оба метода %<transaction_pure%> и %qE"
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "описанный метод %qE перебивает метод %qE"
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "объемлющий класс constexpr нестатической функции-элемента %q+#D не является литеральным типом"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T не является литералом, поскольку:"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T имеет нетривиальный деструктор"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr "  %q+T не агрегат, не имеет тривиальный подразумеваемый конструктор и и не имеет constexpr конструктор, который не является конструктором copy или move"
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  базовый класс %qT %q+T не литерал"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  нестатический элемент данных %q+D имеет нелитеральный тип"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "  non-static data member %q+D has non-literal type"
 msgid "  non-static data member %qD has volatile type"
 msgstr "  нестатический элемент данных %q+D имеет нелитеральный тип"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "базовый класс %q#T имеет невиртуальный деструктор"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "нестатическая ссылка %q+#D в классе без конструктора"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -41940,165 +42004,165 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D декларировано принимать константные ссылки, но неявная декларация будет принимать неконстантные"
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "непосредственная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "виртуальная база %qT недоступна в %qT из-за неоднозначности"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "смещение %q+D несовместимо с ABI и может измениться в будущих версиях GCC"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "размер массива %qE слишком велик"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<...%> with non-slice"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "некорректное использование %<...%> с non-slice"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "неверное употребление структуры с регулируемым элементом-массивом"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D декларировано здесь"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "регулируемый элемент-массив - не последний элемент структуры"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "регулируемый элемент-массив в структуре, которая иначе была бы пустой"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "регулируемый элемент-массив - не последний элемент структуры"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "регулируемый элемент-массив в структуре, которая иначе была бы пустой"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D декларировано здесь"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T содержит виртуальные функции, но невиртуальный деструктор"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 #| msgid "type transparent class %qT does not have any fields"
 msgid "type transparent %q#T does not have any fields"
 msgstr "в типе прозрачного класса %qT нет никаких полей"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "type transparent класс %qT имеет базовые классы"
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "в типе прозрачного класса %qT есть виртуальные функции"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "вывод из взятого в скобки списка инизиализатора требует #include <initializer_list>"
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "не удалось завершить структуру из-за предыдущих грамматических ошибок"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "некорректная строка %<\"%E\"%>, задающая язык"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "ошибка при выборе перегруженной функции %qD при преобразовании к типу %qT"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "нет способа для преобразования функции %qD к типу %q#T"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "преобразование перегруженной функции %qD к типу %q#T неоднозначно"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "предполагается указатель на элемент %qD"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(указатель на элемент можно получить только при помощи %<&%E%>)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "недостаточная информация о типе"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "ошибка преобразования %qE из типа %qT в тип %qT"
@@ -42108,12 +42172,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "декларация %q#D"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -42146,365 +42210,365 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "некорректный тип результата %qT constexpr функции %q+D"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T имеет виртуальные базовые классы"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr "constexpr конструктор не имеет пустое тело"
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%> конструктор для объединения %qT должен инициализировать в точности один нестатический элемент данных"
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "неинициализированный элемент %qD в %<constexpr%> конструкторе"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "тело constexpr функции %qD не return-statement"
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not usable as a constexpr function because:"
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%q+D не может использоваться как constexpr функция поскольку:"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E не есть константное выражение"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function %qE"
 msgstr "внутренняя функция"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "выражение %qE не обозначает constexpr функцию"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "вызов non-constexpr функции %qD"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 #| msgid "%qD called in a constant expression"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD вызвана в константном выражении"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD вызвана в константном выражении"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD использована до своего определения"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "вызов имеет циклическую зависимость"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "глубина обработки constexpr превышает максимум %d (задайте -fconstexpr-depth= чтобы увеличить максимум)"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "сдвиг вправо на отрицательное число позиций"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "левый операнд операции `запятая' не имеет побочных эффектов"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "индекс массива вне диапазона границ массива"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "индекс массива вне диапазона границ массива"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "доступ по указателю %<void *%>"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "mutable %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "обращение к элементу %qD вместо инициализированного элемента %qD в константном выражении"
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "отсутствует инициализатор для элемента %qD"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "доступ по указателю %<void *%>"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "обращение к значению %qE через %qT glvalue в константном выражении"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "значение %qD не может использоваться в константном выражении"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD использована в своем собственном инициализаторе"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D не есть const"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D переменная"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD не была инициализирована константным выражением"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD не была декларирована %<constexpr%>"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "глубина обработки constexpr превышает максимум %d (задайте -fconstexpr-depth= чтобы увеличить максимум)"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "expression %qE is not a constant-expression"
 msgid "expression %qE is not a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "элемент инициализатора не является константным выражением"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "неожиданное выражение %qE вида %s"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT не может быть типом полного константного выражения поскольку он имеет mutable sub-objects"
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, fuzzy, gcc-internal-format
 #| msgid "%qT cannot be the type of a complete constant expression because it has mutable sub-objects"
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT не может быть типом полного константного выражения поскольку он имеет mutable sub-objects"
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from pointer type %qT to arithmetic type %qT in a constant-expression"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "преобразование из указательного типа %qT в арифметический тип %qT в constant-expression"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "выражение %qE имеет побочные эффекты"
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast от типа %qT к типу %qT отбрасывает квалификаторы"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of объекта %qE с поточно-локальным или автоматическим хранением не есть константное выражение"
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression не есть константное выражение поскольку %qE полиморфного типа"
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "temporary of non-literal type %qT in a constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "временная нелитерального типа %qT в константном выражении"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F объявлена %<static%>, но нигде не определена"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qE не описан здесь (не в функции)"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized member %qD in %<constexpr%> constructor"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "неинициализированный элемент %qD в %<constexpr%> конструкторе"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "division by zero is not a constant-expression"
 msgid "division by zero is not a constant expression"
 msgstr "деление на ноль не есть константное выражение"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "неконстантная инициализация массива"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE не есть константное выражение"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "неожиданное AST вида %s"
@@ -43347,7 +43411,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  пропускает инициализацию %q+#D"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "некорректный выход из OpenMP структурного блока"
@@ -43362,7 +43426,7 @@
 msgid "%qD is not a type"
 msgstr "%qD не является типом"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "использование %qD без параметров шаблона"
@@ -45086,7 +45150,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "параметр декларирован %<auto%>"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "некорректное использование имени шаблона %qE без списка аргументов"
@@ -45557,13 +45621,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD имеет то же имя, что и класс, в котором он(а) декларируется"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT не является шаблоном"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -45574,8 +45638,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "ссылка на %qD противоречива"
@@ -45626,7 +45690,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "scoped/unscoped рассогласование в enum %q#T"
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "предыдущее определение здесь"
@@ -45693,7 +45757,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> должен возвращать ссылку на %<*this%>"
@@ -45709,7 +45773,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "в функции, которая должна возвращать значение, отсутствует оператор return"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
@@ -45873,28 +45937,28 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "ширина битового поля %qD имеет нецелочисленный тип %qT"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a static data member of a class template"
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD не является статическим элементом данных шаблона класса"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "анонимная структура не внутри именованного типа"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "анонимные агрегатные данные в области видимости пространства имён должны быть статическими"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "безымянное объединение без элементов"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> должен возвращать тип %qT"
@@ -45903,71 +45967,71 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "первый аргумент %<operator new%> не может иметь значение по умолчанию"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> имеет %<size_t%> (%qT) в качестве первого параметра"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> должен иметь результат типа %qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> имеет первый параметр типа %qT"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT имеет поле %qD, использующее анонимное пространство имён"
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT объявлен с большей областью видимости, чем тип его поля %qD"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT наследован от %qT, использующего анонимное пространство имён"
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT объявлен с большей областью видимости, чем родитель %qT"
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using anonymous type, is used but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -45977,52 +46041,52 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare variable %q#D with linkage"
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "анонимный тип без привязки использован для декларации переменной %q#D с привязкой"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, fuzzy, gcc-internal-format
 #| msgid "anonymous type with no linkage used to declare function %q#D with linkage"
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "анонимный тип без привязки использован для декларации функции %q#D с привязкой"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D не ссылается на неквалифицированный тип, поэтому не используется для связывания"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D, declared using local type %qT, is used but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, декларированное посредством локального типа %qT, используется, но не определяется"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "тип %qT без привязки использован для декларации переменной %q#D с привязкой"
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "тип %qT без привязки использован для декларации функции %q#D с привязкой"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "inline функция %q+D использована, но нигде не определена"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "отсутствует аргумент по умолчанию для параметра %P функции %q+#D"
@@ -46029,12 +46093,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "преобразование lambda, использующей %<...%>, к указателю на функцию"
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "использование удаленной функции %qD"
@@ -46355,19 +46419,19 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "некорректный инициализатор для элемента массива %q#D"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "неинициализированный const элемент в %q#T"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
 msgid "%q#D should be initialized"
 msgstr "%qD должен быть инициализирован"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "неинициализированный ссылочный элемент в %q#T"
@@ -46469,7 +46533,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "массив должен быть инициализирован инициализатором в фигурных скобках"
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT не является классовым типом"
@@ -46489,7 +46553,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "некорректное использование нестатической функции-элемента %qD"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "некорректное использование нестатического элемента %qD"
@@ -46698,23 +46762,23 @@
 msgid "because the array element type %qT has variable size"
 msgstr "составной литерал имеет переменный размер"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "невозможно захватить %qE по ссылке"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of incomplete type %q#T"
 msgid "capture by copy of incomplete type %qT"
 msgstr "некорректное использование неполного типа %q#T"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "уже захваченное %qD в lambda выражении"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> не было захвачено для этой lambda функции"
@@ -46769,121 +46833,121 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(с ключом %<-fpermissive%>, G++ примет данный код, но разрешение использовать недекларированные имена будет отменено в дальнейших версиях)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "разборка typeof, используйте decltype взамен"
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "разборка __underlying_type"
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "разборка неизвестного типа с фиксированной точкой"
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "разборка %C"
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "опущен средний операнд %<?:%> операнд не может быть разобран"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "строковый литерал в сигнатуре шаблона функции"
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, fuzzy, gcc-internal-format
 #| msgid "-fabi-version=6 (or =0) avoids this error with a change in mangling"
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (или =0) избегает этой ошибки изменением в разборке"
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "кодированное имя %qD изменится в будущих версиях GCC"
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "нестатический константный элемент %q#D, использование операции присваивания по умолчанию недопустимо"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "нестатический элемент-ссылка %q#D, использование операции присваивания по умолчанию недопустимо"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr "синтезированный метод %qD впервые потребовался здесь "
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "элемент объединения %q+D с нетривиальным %qD"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted constructor calls non-constexpr %q+D"
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "подразумеваемый конструктор вызывает non-constexpr %q+D"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %q+#D is invalid"
 msgid "initializer for %q#D is invalid"
 msgstr "инициализатор для %q+#D некорректен"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted default constructor does not initialize %q+#D"
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "подразумеваемый конструктор не инициализирует %q+#D"
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "copying non-static data member %q#D of rvalue reference type"
@@ -46890,79 +46954,79 @@
 msgstr "нестатический элемент данных %qD имеет тип Java класса"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "подразумеваемый конструктор не инициализирует нестатические элементы данных"
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "тип замыкания lambda имеет удаленный подразумеваемый конструктор"
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "тип замыкания lambda имеет удаленный оператор присваивания с копированием"
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q+#D неявно продекларирован как удаленный поскольку %qT декларирует перемещающий конструктор или оператор присваивания с перемещением"
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is implicitly deleted because the default definition would be ill-formed:"
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q+#D является неявно удаленным поскольку подразумеваемое определение будет синтаксически некорректным:"
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "подразумеваемая декларация %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr "не соответствует ожидаемой сигнатуре %qD"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 #, fuzzy
 #| msgid "function %q+D defaulted on its first declaration with an exception-specification that differs from the implicit declaration %q#D"
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr "функция %q+D подразумевается при ее первой декларации со спецификацией обработки исключений, которая отличается от неявной декларации %q#D"
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr "явно подразумеваемая функция %q+D не может быть декларирована как constexpr поскольку неявная декларация не есть constexpr:"
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "шаблон не может быть подразумеваемым"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD не может быть подразумеваемым"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "подразумеваемая функция %q+D с подразумеваемым аргументом"
@@ -47162,97 +47226,97 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> обозначает конструктор в %qT"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "нет элементов, соответствующих %<%T::%D%>, в %q#T"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "декларация %qD вне пространства имён, объемлющего %qD"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "явные квалификаторы в декларации %qD"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %D"
 msgstr "%qE не был декларирован"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a friend"
 msgstr "%q+D декларировано как friend"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD следовало объявить внутри %qD"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD атрибут требует единственный NTBS аргумент"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD атрибут не имеет смысла поскольку элементы анонимного пространства имен получают локальные символы"
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "атрибут %qD игнорируется"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "использование пространства имён %qD здесь недопустимо; предполагается %qD"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "Этот ключ устарел; используйте -Wextra."
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "strong имеет смысл только в пределах namespace"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "текущее пространство имен %qD не включает строго используемое пространство имен %qD"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "максимальное число %d пространств имен просмотрено для %qE"
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "suggested alternative:"
 #| msgid_plural "suggested alternatives:"
@@ -47259,7 +47323,7 @@
 msgid "suggested alternative: %qs"
 msgstr "предлагаемый вариант:"
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -47267,28 +47331,28 @@
 msgstr[1] "предлагаемые варианты:"
 msgstr[2] "предлагаемые варианты:"
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr "зависимый от аргумента просмотр находит %q+D"
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, fuzzy, gcc-internal-format
 #| msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr "вывод из взятого в скобки списка инизиализатора требует #include <initializer_list>"
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX вход в pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX выход из pop_everything ()\n"
@@ -47308,7 +47372,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -47333,7 +47397,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "запрос элемента %qE в неклассовом типе %qT"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> не был декларирован"
@@ -47393,697 +47457,697 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(возможно, пропущена точка с запятой после определения %qT)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a template"
 msgid "%qE is not a class template"
 msgstr "%qE не является шаблоном"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE не является шаблоном"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "некорректный идентификатор шаблона"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 #| msgid "floating-point literal cannot appear in a constant-expression"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "плавающий литерал не может появляться в константном выражении"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "приведение к типу, отличному от целого или перечисления, не может появляться в константном выражении"
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "оператор %<typeid%> не может присутствовать в константном выражении"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "неконстантные составные литералы не могут присутствовать в константном выражении"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "вызов функции не может присутствовать в константном выражении"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "инкремент не может присутствовать в константном выражении"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "декремент не может присутствовать в константном выражении"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "ссылка на массив не может присутствовать в константном выражении"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "адрес метки не может присутствовать в константном выражении"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "вызовы перегруженных операторов не могут присутствовать в константном выражении"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "присваивание не может присутствовать в константном выражении"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "операция запятая не может присутствовать в константном выражении"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "вызов конструктора не может присутствовать в константном выражении"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "транзакционное выражение не может присутствовать в константном выражении"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%qs не может присутствовать в константном выражении"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "некорректное использование деструктора %qD в качестве типа"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "некорректная комбинация спецификаторов типа"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE не является именем типа"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE не является именем типа"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<concept%> only available with -fconcepts"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(возможно, подразумевалось %<typename %T::%E%>)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in namespace %qE does not name a type"
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE в пространстве имен %qE не именует тип"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE в пространстве имен %qE не именует тип"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%E%> именует конструктор, а не тип"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "и %qT не имеет шаблонных конструкторов"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr "требуется %<typename%> перед %<%T::%E%> поскольку %qT зависимый контекст"
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in %q#T does not name a type"
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE в %q#T не именует тип"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE в %q#T не именует тип"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr "ожидался строковый литерал"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr "противоречивые определенные пользователем литеральные суффиксы %qD и %qD в строковом литерале"
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr "широкая строка недопустима в данном контексте"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr "невозможно найти оператор символьного литерала %qD с аргументом %qT"
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "integer literal exceeds range of %qT type"
 msgstr "плавающая константа превышает диапазон для %qT"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "floating literal exceeds range of %qT type"
 msgstr "плавающая константа превышает диапазон для %qT"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant truncated to zero"
 msgid "floating literal truncated to zero"
 msgstr "констaнтa с плавающей точкой усечена до нуля"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr "невозможно найти оператор числового литерала %qD"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "невозможно найти оператор строкового литерала %qD с аргументами %qT, %qT"
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "ожидалась декларация"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "expected operator"
 msgid "expected binary operator"
 msgstr "ожидался оператор"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<...%>"
 msgid "expected ..."
 msgstr "ожидалось %<...%>"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "binary expression in operand of fold-expression"
 msgstr "%s - список выражений рассматривается как составное выражение"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "a transaction expression cannot appear in a constant-expression"
 msgid "conditional expression in operand of fold-expression"
 msgstr "транзакционное выражение не может присутствовать в константном выражении"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in vector shift expression"
 msgid "mismatched operator in fold-expression"
 msgstr "несоответствие типов в векторном выражении сдвига"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "типы с фиксированной точкой не поддерживаются в C++"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ запрещает конструкции в фигурных скобках внутри выражений"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "операторы-выражения не допустимы вне функций и списков аргументов шаблона"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "ожидалось primary-expression"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "%<this%> недопустим в данном контексте"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "декларация шаблона не может появляться в блоке"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "локальная переменная %qD недопустима в данном контексте"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "ожидалось id-выражение"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "область видимости %qT до %<~%> не является именем класса"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "декларация %<~%T%> как элемента %qT"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-имя %qD использовано как декларатор деструктора"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "суффиксы литеральных операторов без предшествующего %<_%> зарезервированы для будущей стандартизации"
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ожидался unqualified-id"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "найдено %<:%> во вложенном спецификаторе имени, ожидалось %<::%>"
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype обработано до %qT, что не является классом или перечислимым типом"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "неполный тип %qT использован во вложенном спецификаторе имени"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 #| msgid "expected nested-name-specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "ожидался вложенный спецификатор имени"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD не является шаблоном"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "ожидался вложенный спецификатор имени"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "типы нельзя определять в приведении типов"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "типы нельзя определять в %<typeid%> выражении"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "неверное число аргументов в вызове аргументов в вызове %<__builtin_shuffle%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to %<__builtin_complex%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "неверное число аргументов в вызове %<__builtin_complex%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "в ISO C++ составные литеральные конструкции запрещены"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "braced list index is not allowed with array notation"
 msgstr "-client_name нельзя использовать с -dynamiclib"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "некорректное использование %qD"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> не является элементом класса"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "нескалярный тип"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ не допускает %<alignof%> с не-типом"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "типы не могут быть определены в %<noexcept%> выражениях"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "типы не могут быть определены в new-выражении"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "граница массива не допускается после идентификатора типа в скобках"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "попробуйте убрать скобки вокруг идентификатора типа"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Ожидался тип выражения"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "типы не могут быть определены в new-type-id"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "выражение в деклараторе new должно иметь целый или перечислимый тип"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "использование устаревшей конструкции для приведения типа"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "оператор %<>>%> трактуется в C++11 как две правые угловые скобки"
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "рекомендуется окружать скобками выражение %<>>%>"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ не допускает ?: с опущенным средним операндом"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "lambda-expression в необрабатываемом контексте"
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in unevaluated context"
 msgid "lambda-expression in template-argument"
 msgstr "lambda-expression в необрабатываемом контексте"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "ожидался конец capture-list"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "явное by-copy capture %<this%> избыточно с by-copy capture умолчанием"
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "capture непеременной %qD "
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D declared here"
 msgid "%q#D declared here"
 msgstr "%q+#D декларировано здесь"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "capture переменной  %qD с неавтоматическим сроком хранения"
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "явное by-copy capture %qD избыточно с by-copy capture умолчанием"
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "явное by-reference capture %qD избыточно с by-reference capture умолчанием"
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, fuzzy, gcc-internal-format
 #| msgid "variadic templates only available with -std=c++11 or -std=gnu++11"
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "вариантные шаблоны доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C90 не поддерживает комплексные типы"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "задан аргумент по умолчанию для lambda-параметра"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "повторное употребление %<volatile%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "атрибуты после инициализатора в скобках проигнорированы"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ожидался помеченный оператор"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-метка %qE вне оператора switch"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "требуется %<typename%> перед %qE поскольку %qT зависимый контекст"
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> обозначает конструктор, а не тип"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr "составной оператор в constexpr функции"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++11 %<constexpr%> доступно только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "ожидался selection-statement"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "типы нельзя определять в условиях"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "range-based %<for%> выражение типа %qT имеет неполный тип"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr "range-based %<for%> выражение типа %qT имеет %<end%> элемент без %<begin%>"
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr "range-based %<for%> выражение типа %qT имеет %<begin%> элемент без %<end%>"
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "противоречивые begin/end типы в range-based %<for%> операторе: %qT и %qT"
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "ожидался iteration-statement"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "unrestricted объединения допустимы только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 #| msgid "break statement used with OpenMP for loop"
 msgid "break statement used with Cilk Plus for loop"
 msgstr "оператор break использован с OpenMP для цикла"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<goto%> in %<constexpr%> function"
@@ -48090,70 +48154,76 @@
 msgstr "составной оператор в constexpr функции"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ не поддерживает вычисляемые goto"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "ожидался оператор перехода"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "избыточная %<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> не в начале блока"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "противоречивый вывод для %qT: %qT и затем %qT"
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "смешивание деклараций и определений функций запрещено"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "типы нельзя определять в exception-declarations"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "пустая декларация"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+#| msgid "invalid initializer for member function %qD"
+msgid "invalid initializer for structured binding declaration"
+msgstr "некорректный инициализатор для элемента-функции %qD"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> использовано вне класса"
@@ -48160,129 +48230,129 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> меняет смысл в C++11; пожалуйста удалите его"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-specifier некорректен в условии"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D некорректно в %q#T"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "определение класса не должно содержать friend"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "шаблоны не могут быть %<virtual%>"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "некорректная linkage-specification"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "типы нельзя определять в %<decltype%> выражениях"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in a new-type-id"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "типы не могут быть определены в new-type-id"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "некорректное использование %<auto%> в операторе преобразования"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "некорректное использование %<auto%> в операторе преобразования"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "только конструкторы берут инициализаторы элементов"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "невозможно расширить инициализатор для элемента %<%D%>"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer для %qD следует за constructor delegation"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "constructor delegation следует за mem-initializer для %qD"
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "устаревший стиль инициализатора базового класса"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (инициализатор квалифицированного элемента неявно является типом)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, fuzzy, gcc-internal-format
 #| msgid "missing space between %<\"\"%> and suffix identifier"
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "отсутствует пробел между %<\"\"%> и суффикс-идентификатором"
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "ожидался суффикс-идентификатор"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "ожидалась пустая строка после ключевого слова %<operator%>"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in ternary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "неверные операнды тернарной операции"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "ожидался оператор"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "ключевое слово %<export%> не реализовано; игнорируется"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template non-type parameter"
 msgid "invalid constrained type parameter"
@@ -48289,374 +48359,374 @@
 msgstr "некорректный нетиповый параметр шаблона"
 
 #
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid catch parameter"
 msgid "cv-qualified type parameter"
 msgstr "некорректный catch параметр"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of template template parameter %qT"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "некорректное использование шаблона параметра шаблона %qT"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "pack параметр шаблона %qD не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "pack параметры шаблона не могут иметь аргументы по умолчанию"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "ожидался template-id"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "список аргументов шаблона не должен начинаться с %<<::%>"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> - альтернативное написание %<[%>. Вставьте пробел между %<<%> и %<::%>"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(если вы используете %<-fpermissive%> G++ примет ваш код)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "ошибка разбора в списке аргументов шаблона"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "ожидалось template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "не шаблон %qD использован как шаблон"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "используйте нотацию %<%T::template %D%> для указания о том, что это шаблон"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ожидался pack параметр перед %<...%>"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "ожидался template-argument"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "некорректный нетиповый аргумент шаблона"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "явная конкретизация не должна использовать %<inline%> спецификатор"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "явная конкретизация не должна использовать %<constexpr%> спецификатор"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "специализация шаблона с привязкой C"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "ожидался спецификатор типа"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, fuzzy, gcc-internal-format
 #| msgid "defaulted and deleted functions only available with -std=c++11 or -std=gnu++11"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "сведенные к подразумеваемым и удаленные функции доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "в ISO C упреждающие декларации параметров запрещены"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "ожидался template-id для типа"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "ожидалось имя типа"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "elaborated-type-specifier для scoped enum не должен использовать ключевое слово %<%D%>"
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "декларация %qD ничего не декларирует"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "атрибуты игнорируются для неконкретизированного типа"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "атрибуты игнорируются для конкретизации шаблона"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "атрибуты игнорируются для elaborated-type-specifier который не является forward декларацией"
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD является шаблоном перечисления"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 #| msgid "%qD does not have integral or enumeration type"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD не имеет целый или перечислимый тип"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%> определение здесь не допускается"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "ожидалось %<;%> или %<{%>"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "невозможно добавить enumerator список к конкретизации шаблона"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "декларация %qD в пространстве имен %qD, которое не включает %qD"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "декларация %qD в %qD, который не объемлет %qD"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "избыточная квалификация не допускается"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "повторное определение %q#T"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ запрещает инкрементирование enum"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier без имени"
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier должен использовать простой идентификатор"
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD не есть namespace-name"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "ожидалось namespace-name"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<namespace%> определение здесь не допускается"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, fuzzy, gcc-internal-format
 #| msgid "inline namespaces only available with -std=c++11 or -std=gnu++11"
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "inline namespaces доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Предупреждать об inline-функциях, подстановка которых невозможна"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier before %qE"
 msgid "nested identifier required"
 msgstr "ожидался идентификатор перед %qE"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "использование пространства имён %qD в качестве выражения"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> определение здесь не допускается"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "идентификатор шаблона недопустим в using-декларации"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, fuzzy, gcc-internal-format
 #| msgid "lambda expressions only available with -std=c++11 or -std=gnu++11"
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "lambda-выражения доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "декларациям доступа следует предпочесть using-declarations; предлагается: добавьте ключевое слово %<using%>"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "типы нельзя определять в алиасных декларациях шаблонов"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, fuzzy, gcc-internal-format
 #| msgid "compound-statement in constexpr function"
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "составной оператор в constexpr функции"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition здесь не допускается"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "спецификация asm не допускается при определении функции"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "ожидался конструктор, деструктор или преобразование типа"
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "ожидался инициализатор"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "инициализатор задан для функции"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "атрибуты после инициализатора в скобках проигнорированы"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "функция %q+D повторно декларирована как inline"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "граница массива не является целой константой"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "невозможно определить элемент зависимого typedef %qT"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> не является типом"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "некорректное использование конструктора как шаблона"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "используйте %<%T::%D%> вместо %<%T::%D%> для именования конструктора в имени с квалификатором"
@@ -48665,7 +48735,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "некорректная декларация"
@@ -48672,281 +48742,283 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type in declaration"
 msgid "qualified-id in declaration"
 msgstr "некорректный тип в декларации"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "ожидалась декларация"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD является пространством имён"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "невозможно сформировать указатель на элемент не класса %q#T"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ожидался ptr-operator"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "повторный cv-qualifier"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "повторный cv-qualifier"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "повторный virt-specifier"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 #| msgid "in template argument for type %qT "
 msgid "missing template arguments after %qT"
 msgstr "в аргументе шаблона для типа %qT "
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "некорректное использование %qT"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "типы нельзя определять в аргументах шаблона"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 #| msgid "invalid non-type template argument"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "некорректный нетиповый аргумент шаблона"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "ожидался type-specifier"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "ожидалось %<,%> или %<...%>"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "типы нельзя определять в типах параметров"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "аргументы по умолчанию разрешены только для параметров функций"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameter pack %qD не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "pack параметр шаблона не может иметь аргумент по умолчанию"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameter pack не может иметь подразумеваемый аргумент"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ не поддерживает назначенные инициализаторы"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ не поддерживает C99 назначенные инициализаторы"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "ожидалось class-name"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "ожидалось %<;%> после определения класса"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "ожидалось %<;%> после определения структуры"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "ожидалось %<;%> после определения объединения"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "ожидалось %<{%> или %<:%>"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "невозможно задать %<override%> для класса"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "global квалификация имени класса некорректна"
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "квалифицированное имя не именует класс"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "некорректное имя класса в декларации %qD"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "перед явной специализацией должно быть %<template <>%>"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "шаблон функции %qD редекларирован как шаблон класса"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "невозможно разрешить typename type"
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "предыдущее определение %q+#T"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "ожидалось class-key"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "в C++03 class-key должен использоваться при декларировании friend"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "в декларации friend нет имени класса или функции"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "спецификатор pure в определении функции"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "ожидалось %<;%> в конце декларации элемента"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ожидалось %<;%> в конце декларации элемента"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "некорректный спецификатор pure (только %<= 0%> допускается)"
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "инициализатор в фигурных скобках здесь не допускается"
 
-#: cp/parser.c:23680
-#, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+#: cp/parser.c:23703
+#, fuzzy, gcc-internal-format
+#| msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> задано более одного раза в base-specified"
 
-#: cp/parser.c:23700
-#, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+#: cp/parser.c:23723
+#, fuzzy, gcc-internal-format
+#| msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr "более одного спецификатора access в base-specified"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "ключевое слово %<typename%> не допускается вне шаблонов"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "ключевое слово %<typename%> запрещено в этом контексте (базовый класс неявно является типом)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "типы нельзя определять в exception-specification"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "из-за различных спецификаций исключений"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, fuzzy, gcc-internal-format
 #| msgid "dynamic exception specifications are deprecated in C++0x; use %<noexcept%> instead"
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "динамические спецификации исключений не рекомендуются в C++0x; использийте вместо этого %<noexcept%>"
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
@@ -48953,74 +49025,74 @@
 msgstr "некорректное использование %<auto%> в операторе преобразования"
 
 #
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not %<constexpr%>"
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%qD не есть %<constexpr%>"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "типы нельзя определять в exception-declarations"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "атрибут %qE конфликтует с атрибутом %s"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier before string constant"
 msgid "expected an identifier for the attribute name"
 msgstr "ожидался идентификатор перед строковой константой"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected attribute before %qE"
 msgid "expected attribute before %<...%>"
 msgstr "неожиданный атрибут перед %qE"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, fuzzy, gcc-internal-format
 #| msgid "C++0x auto only available with -std=c++11 or -std=gnu++11"
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++0x auto доступны только с -std=c++11 или -std=gnu++11"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, fuzzy, gcc-internal-format
 #| msgid "%<@required%> is not available in Objective-C 1.0"
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<@required%> недоступно в Objective-C 1.0"
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, fuzzy, gcc-internal-format
 #| msgid "a transaction expression cannot appear in a constant-expression"
 msgid "a requires expression cannot appear outside a template"
 msgstr "транзакционное выражение не может присутствовать в константном выражении"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "специализация элемента %<%T::%E%> требует %<template<>%> синтаксис"
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "некорректная декларация %<%T::%E%>"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "недостаточно списков параметров шаблонов"
@@ -49029,440 +49101,440 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "слишком много списков параметров шаблонов"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "именованные возвращаемые значения больше не поддерживаются"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, fuzzy, gcc-internal-format
 #| msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "шаблон литерального оператора %qD имеет некорректный список параметров. Ожидался нетиповый pack аргумент шаблона <char...>"
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "шаблон литерального оператора %qD имеет некорректный список параметров. Ожидался нетиповый pack аргумент шаблона <char...>"
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "Включить инструкции умножения"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "некорректная декларация шаблона элемента в локальном классе"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "шаблон с привязкой C"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "некорректная явная специализация"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "шаблонная декларация %<typedef%>"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "декларация ничего не описывает"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "явная специализация шаблона не может иметь класс хранения"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> должно быть %<> >%> внутри списка аргументов вложенного шаблона"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "ошибочное использование %<>>%>, используйте %<>%> для завершения списка аргументов шаблона"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "некорректное использование %qD в спецификации привязки"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> перед %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 не поддерживает %<long long%>"
 
 #
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "в спецификаторах декларации заданы и %<_Sat%> и %<char%>"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "дублирование %qE"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "дублирование %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "ожидалось %<new%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "ожидалось %<delete%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "ожидалось %<return%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "ожидалось %<extern%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "ожидалось %<static_assert%>"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "ожидалось %<decltype%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "ожидалось %<operator%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "ожидалось %<class%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "ожидалось %<template%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "ожидалось %<namespace%>"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "ожидалось %<using%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "ожидалось %<asm%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "ожидалось %<try%>"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "ожидалось %<catch%>"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "ожидалось %<throw%>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "ожидалось %<__label__%>"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "ожидалось %<@try%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "ожидалось %<@synchronized%>"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "ожидалось %<@throw%>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "ожидалось %<__transaction_atomic%>"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "ожидалось %<__transaction_relaxed%>"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "ожидалось %<::%>"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "ожидалось %<...%>"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "ожидалось %<*%>"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "ожидалось %<~%>"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "ожидалось %<:%> или %<::%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "ожидалось %<class%>, %<typename%> или %<template%>"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag использован в именовании %q#T"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T был ранее декларирован здесь"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD редекларирован с другим доступом"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, fuzzy, gcc-internal-format
 #| msgid "%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "слово %<template%> (для снятия неоднозначности) допускается только внутри шаблонов"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "конец файла в аргументе по умолчанию"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "неверное положение %<@%D%> конструкции Objective-C++"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c++ message argument(s) are expected"
 msgid "objective-c++ message receiver expected"
 msgstr "ожидались objective-c++ аргумент(ы) сообщения"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "ожидались objective-c++ аргумент(ы) сообщения"
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "в конструкции %<@encode%> в качестве аргумента должен быть задан тип"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "некорректное Objective-C++ имя селектора"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "ожидалась objective-c++ декларация метода"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "атрибуты метода должны задаваться в конце"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "случайное %qs между Objective-C++ методами"
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "некорректный тип для instance переменной"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "ожидался идентификатор после %<@protocol%>"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "атрибуты нельзя задавать до %<@%D%> Objective-C++ ключевого слова"
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "префиксные атрибуты игнорируются до %<@%D%>"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "некорректный тип для property"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "неверный инициализатор"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "скобочная инициализация не допускается в OpenMP %<for%> цикле"
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "скобочная инициализация не допускается в OpenMP %<for%> цикле"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "итерационная переменная %qD не должна быть reduction"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "недостаточно DO циклов для сжатого !$OMP DO в %L"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "атрибуты не допускаются при определении функции"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "неверный инициализатор"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 #| msgid "expected id-expression"
 msgid "expected id-expression (arguments)"
 msgstr "ожидалось id-выражение"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "в описании возвращаемого типа нельзя определять новые типы"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause before %<decltype%>"
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "ожидалась конструкция %<#pragma omp%> перед %<decltype%>"
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -49469,73 +49541,73 @@
 msgstr "%qD не является шаблонным элементом-функцией"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> без включения поддержки транзакционной памяти"
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "мусор в конце директивы %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "некорректные ограничения для операнда"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize не допускается внутри функций"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "межмодульные оптимизации не реализованы для C++"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "Ожидалось имя переменной в %C"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%> before %qE"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "ожидалась %<,%> или %<)%> перед %qE"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
@@ -49631,7 +49703,7 @@
 msgid "candidate is: %#D"
 msgstr "претендент: %+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
@@ -50247,126 +50319,144 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет внешней привязки"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет привязки"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+#| msgid "  variable-sized array type %qT is not a valid template argument"
+msgid "the address of %qD is not a valid template argument"
+msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+#| msgid "  variable-sized array type %qT is not a valid template argument"
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "  тип массива переменного размера %qT не есть корректный аргумент шаблона"
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+#| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%qE не есть корректный аргумент шаблона типа %qT поскольку %qD не имеет внешней привязки"
+
+#: cp/pt.c:6672
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT из-за конфликтов в cv-qualification"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он не есть lvalue"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D не есть корректный аргумент шаблона для типа %qT поскольку ссылочная переменная не имеет постоянного адреса"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он не является объектом с внешней привязкой"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку объект %qD не имеет внешней привязки"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он является указателем"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "попробуйте задать %qE"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE не есть корректный аргумент шаблона для типа %qT поскольку он имеет тип %qT"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "стандартные преобразования в данном контексте недопустимы"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes on template argument %qT"
 msgid "ignoring attributes in template argument %qE"
 msgstr "игнорирование атрибутов аргумента шаблона %qT"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD использовано как шаблон аргумента шаблона"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "некорректное использование деструктора %qE в качестве типа"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "для того чтобы сослаться на тип параметра шаблона, используйте конструкцию %<typename %E%>"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  ожидалась константа типа %qT, а обнаружено %qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  ожидался шаблон класса, а обнаружено %qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  ожидался тип, обнаружено %qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  ожидался тип, обнаружено %qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  ожидался шаблон класса, обнаружено %qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ожидался шаблон типа %qD, обнаружено %qT"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "несоответствия типа/значения в аргументе %d в списке параметров шаблона для %qD"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
@@ -50374,110 +50464,110 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "несоответствие типов в нетиповом parameter pack"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "ошибка при преобразовании аргумента шаблона %qE в %qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "некорректный аргумент шаблона %d"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "неправильное число аргументов шаблона (%d, а должно быть %d)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "задано для %q+D"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 #| msgid "default argument for template parameter for class enclosing %qD"
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "подразумеваемый аргумент для параметра шаблона для класса включающего %qD"
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "подразумеваемый аргумент задан для параметра %d %q#D"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "задано для %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D не является шаблоном функции"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "не-шаблонный тип %qT использован как шаблон"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "для декларации шаблона %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "обнаружена несогласованность внутреннего представления gcc"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "use of invalid variable template %qE"
 msgstr "%qD не переменная"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum) substituting %qS"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d (задайте -ftemplate-depth= чтобы увеличить максимум) при подстановке %qS"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "несоответствие длин argument pack при расширении %<%T%>"
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "несоответствие длин argument pack при расширении %<%E%>"
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -50496,280 +50586,280 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "переменная %qD имеет тип функции"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "некорректный тип параметра %qT"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "в декларации %q+D"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "функция возвращает массив"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "функция возвращает функцию"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "создание указателя на элемент-функцию не классового типа %qT"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "создание ссылки на void"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "формирование указателя на ссылочный тип %qT"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "формирование ссылки на ссылочный тип %qT"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare pointer to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "невозможно декларировать указатель на квалифицированный тип функции %qT"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "невозможно декларировать ссылку на квалифицированный тип функции %qT"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "создание указателя на элемент не классового типа %qT"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "создание указателя на элемент ссылочного типа %qT"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "создание указателя на элемент типа void"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "создание массива элементов типа %qT"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT не является типом class, struct или union"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT разрешается в %qT, который не является перечислимым типом"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT разрешается в %qT, который не является классовым типом"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow initializers in lambda expression capture lists"
 msgid "empty initializer in lambda init-capture"
 msgstr "ISO C++ не допускает инициализаторы в списках lambda expression capture"
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "использование %qs в шаблоне"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "зависимое имя %qE разбирается как не тип, но конкретизация дает тип"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "задайте %<typename %E%>, если подразумевается тип"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "использование некорректного поля %qD"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "некорректное использование pack expansion expression"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "используйте %<...%> для расширения argument pack"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD не декларирован в этом контексте, и не было найдено деклараций при зависимом от аргументов поиске в точке конкретизации"
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "декларации в зависимой базе %qT не найдены при неквалифицированном поиске"
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "используйте %<this->%D%>"
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "используйте %<%T::%D%>"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here, later in the translation unit"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D декларировано здесь, позднее в единице компиляции"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT не является классом или пространством имён"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD не является классом или пространством имён"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT есть/использует анонимный тип"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "аргумент шаблона для %qD использует локальный тип %qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT есть переменно модифицированный тип"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "целочисленное выражение %qE не является константой"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  при конкретизации %qD"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "неоднозначная конкретизация шаблона класса для %q#T"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "неоднозначная конкретизация шаблона класса для %q#T"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "явная конкретизация нешаблона %q#D"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD не является статическим элементом данных шаблона класса"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "нет подходящего шаблона для %qD"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "тип %qT для явной конкретизации %qD не соответствует декларированному типу %qT"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "явная конкретизация %q#D"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "повторная явная конкретизация %q#D"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 запрещает использование %<extern%> в явной конкретизации"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "класс хранения %qD в конкретизации шаблона"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "явная конкретизация неклассового шаблона %qD"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "явная конкретизация типа %qT, не являющегося шаблоном"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "явная конкретизация %q#T до определения шаблона"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ запрещает использование %qE в явных конкретизациях"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "повторная явная конкретизация %q#T"
@@ -50781,98 +50871,98 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "явная конкретизация %qD без определения"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "глубина конкретизации шаблона превышает максимум %d при конкретизации %q+D, возможно при генерации виртуальной таблицы (задайте -ftemplate-depth= чтобы увеличить максимум)"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "некорректный нетиповый параметр шаблона"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T не является корректным типом для нетипового параметра шаблона"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "вывод из взятого в скобки списка инизиализатора требует #include <initializer_list>"
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "не шаблон %qD использован как шаблон"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 #| msgid "  template argument deduction/substitution failed:"
 msgid "class template argument deduction failed:"
 msgstr "  вывод/подстановка аргумента шаблона неудачна:"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "функция не подлежит inline-подстановке"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "невозможно вывести %qT из %qE"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "невозможно вывести %qT из %qE"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "RTL-инструкция не удовлетворяет своим ограничениям:"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -51035,504 +51125,504 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  поскольку %q+#D объявлена в базовом классе"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "используйте явные фигурные скобки вокруг пустого тела цикла %<do%>"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "невозможно определить тип операнда %qE для оператора asm"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "__label__ декларации допускаются только в контекстах функций"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "некорректное использование элемента %q+D в статическом элементе-функции"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "аргументы к деструктору не допускаются"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "имя %<this%> недоступно для статических элементов-функций"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "некорректное использование %<this%> в функции, не являющейся элементом"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "некорректное использование %<this%> на внешнем уровне"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "некорректный квалифицированный контекст в имени псевдодеструктора"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "квалифицированный тип %qT не соответствует имени деструктора ~%qT"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE не имеет тип %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "составной литерал необъектного типа %qT"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "параметры шаблона, являющиеся типами, должны задаваться при помощи ключевых слов %<class%> или %<typename%>"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "некорректное использование типа %qT как подразумеваемого значения для шаблона параметра шаблона"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "некорректный подразумеваемый аргумент для шаблона параметра шаблона"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "определение %q#T внутри списка параметров шаблона"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "некорректное определение квалифицированного типа %qT"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "некорректная спецификация базового класса"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "protected-элемент %q+#D в анонимном объединении"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD не захватывается"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "использование %<auto%> переменной из внутренней функции"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "использование параметра из внутренней функции"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "use of parameter %qD outside function body"
 msgid "use of parameter outside function body"
 msgstr "использование параметра %qD вне тела функции"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "несовпадающие аргументы"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "параметр шаблона %qD типа %qT не допускается в целочисленном константном выражении поскольку он не целого или перечислимого типа"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "использование пространства имён %qD в качестве выражения"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "использование шаблона класса %qT в качестве выражения"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "запрос элемента %qD неоднозначен в сетке множественного наследования"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD не может появляться в константном выражении"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "тип %qE неизвестен"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT не имеет перечислимый тип"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameter pack __bases допустим только в декларации шаблона"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "невозможно применить %<offsetof%> к деструктору %<~%T%>"
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "невозможно применить %<offsetof%> к элементу-функции %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "ссылка на %qD противоречива"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE имеет неверный тип для %<reduction%>"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<firstprivate%>"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD не есть переменная в клаузуле %<lastprivate%>"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk size выражение должно быть целочисленным"
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "collapse аргумент требует положительного константного целого выражения"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, fuzzy, gcc-internal-format
 #| msgid "slice end must be integer"
 msgid "%<device%> id must be integral"
 msgstr "конец вырезки должен быть целым"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "schedule chunk size выражение должно быть целочисленным"
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD появляется более одного раза в клаузуле данных"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "schedule chunk size выражение должно быть целочисленным"
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD не есть переменная в клаузуле %qs"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "слишком много конструкций %qs"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "num_threads выражение должно быть целочисленным"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "тип, заданный в векторном delete, не является ни массивом, ни указателем"
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "значение %<num_threads%> должно быть положительным"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD не есть переменная файла, пространства имен или контекста блока"
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE директива не в %qT определении"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "разность между %qE и %qD не имеет целый тип"
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "в %<#pragma omp atomic update%> используются две различные переменные для памяти"
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp atomic update%> uses two different variables for memory"
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "в %<#pragma omp atomic update%> используются две различные переменные для памяти"
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "не выполнено статическое утверждение: %E"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "неудача static assertion: %s"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "неконстантное условие для static assertion"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "аргумент decltype должен быть выражением"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype не может разрешить адрес перегруженной функции"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 #| msgid "third operand of conditional expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "третий операнд условного выражения ссылка не имеет эффекта"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "аргумент шаблона %qE включает параметр(ы) шаблона"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -51549,121 +51639,121 @@
 msgid "lambda-expression in a constant expression"
 msgstr "выражение %qE не является константным выражением"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "атрибут %qE для типов игнорируется"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE атрибут может применяться только к определениям классов"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "заданный init_priority не является целой константой"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "%qE атрибут может использоваться только для определений объектов типа class на уровне файла"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "заданный init_priority вне диапазона"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "заданный init_priority зарезервировано для внутреннего использования"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE атрибут не поддерживается на данной платформе"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as member of %qT"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "декларация %qD как элемента %qT"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "%qD атрибут требует единственный NTBS аргумент"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "аргумент %qE атрибута не строковая константа"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "аргумент %qE атрибута не строковая константа"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> не является корректным декларатором"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> не является корректным декларатором"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "атрибут %qE для не классовых типов игнорируется"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "проигнорированы атрибуты, примененные к %qT после определения"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "проигнорированы атрибуты, примененные к %qT после определения"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "проигнорированы атрибуты, примененные к %qT после определения"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "атрибут %qE применим только к функциям, а не к %s"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%s атрибут применен к %s %s в %L"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "ноль как константа пустой указатель"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: ошибка в %s, в %s:%d"
@@ -52363,107 +52453,107 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "некорректное преобразование к типу %qT от типа %qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "ошибка преобразования %qT в %qT для аргумента %qP функции %qD"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "ошибка преобразования %qT в %qT в подразумеваемом аргументе"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "ошибка преобразования %qT в %qT при передаче аргументов"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "ошибка преобразования %qT в %qT"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "ошибка преобразования %qT в %qT в инициализации"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "ошибка преобразования %qT в %qT при возврате"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "ошибка преобразования %qT в %qT в присваивании"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "тип результата %q#T неполный"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "параметр %qP %qD мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "параметр мог быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "цель преобразования могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "цель инициализации могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "левая часть присваивания могла быть кандидатом для атрибута формата"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "при передаче аргумента %P функции %q+D"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "возврат ссылки на временную переменную"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "возвращена ссылка на не-lvalue-выражение"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "возвращена ссылка на локальную переменную %q+D"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "возвращен адрес локальной переменной %q+D"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "возвращен адрес локальной переменной %q+D"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "возвращен результат деструктора"
@@ -52470,57 +52560,57 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "возврат в обработчике try-блока конструктора"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "возврат результата конструктора"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return без значения в функции, возвращающей %qT"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 #| msgid "<brace-enclosed initializer list>"
 msgid "returning initializer list"
 msgstr "<инициализатор в фигурных скобках>"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "противоречивые типы %qT и %qT выведены для возвращаемого типа lambda"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "противоречивый вывод для %qT: %qT и затем %qT"
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "return со значением в функции, возвращающей 'void'"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> не должен возвращать NULL, если только он не декларирован %<throw()%> (или задан ключ -fcheck-new)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "использование временного как lvalue"
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "использование xvalue (rvalue ссылка) как lvalue"
@@ -56859,99 +56949,99 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Цель инициализации указателя на процедуру в %L не может быть указателем на процедуру"
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Указательные функции в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable выражение в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Именованная константа '%s' в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' in variable definition context (%s) at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "'%s' в контексте определения переменных (%s) в %L не есть переменная"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Named constant '%s' in variable definition context (%s) at %L"
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Именованная константа '%s' в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in pointer association context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Формальный аргумент '%s' с INTENT(IN) в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' with INTENT(IN) in variable definition context (%s) at %L"
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Формальный аргумент '%s' с INTENT(IN) в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Переменная '%s' является PROTECTED и не может появляться в контексте ассоциации указателей (%s) в %L"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "Переменная '%s' является PROTECTED и не может появляться в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Переменная '%s' не может появляться в контексте определения переменных (%s) в %L"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "'%s' в %L ассоциированное с векторно индексированной целью не может использоваться в контексте определения переменных (%s)"
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "'%s' в %L ассоциированное с выражением не может использоваться в контексте определения переменных (%s)"
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, fuzzy, gcc-internal-format
 #| msgid "Associate-name '%s' can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Имя ассоциации '%s' не может появляться в контексте определения переменных (%s) в %L поскольку его цель в %L также не может"
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L associated to expression can not be used in a variable definition context (%s)"
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
@@ -57154,12 +57244,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Второй аргумент определенного присваивания в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Первый аргумент интерфейса оператора в %L должен быть INTENT(IN)"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Второй аргумент интерфейса оператора в %L должен быть INTENT(IN)"
@@ -58054,545 +58144,563 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "Fortran 2003: DP спецификатор формата не допускается в %C"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: X descriptor requires leading space count at %L"
 msgid "X descriptor requires leading space count at %L"
 msgstr "Расширение: X дескриптор требует предшествующий счетчик пробелов в %L"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: $ descriptor at %L"
 msgid "$ descriptor at %L"
 msgstr "Расширение: $ дескриптор в %L"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ должен быть последним спецификатором в формате в %L"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %L"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Расширение: Отсутствует положительная ширина после L дескриптора в %L"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %L"
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Расширение: Отсутствует положительная ширина после L дескриптора в %L"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %L"
 msgid "%<G0%> in format at %L"
 msgstr "%s в форматной строке в %L"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr "Положительная ширина требуется в спецификаторе формата %s в %L"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "Точка требуется в спецификаторе формата %s в %L"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "Точка требуется в спецификаторе формата в %L"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr "H спецификатор формата в %L есть удаленная возможность Fortran 95"
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing comma at %L"
 msgid "Missing comma at %L"
 msgstr "Расширение: Отсутствует запятая в %L"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s в форматной строке в %L"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr "Лишние символы в формате в %L"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr "Оператор формата в главном блоке модуля в %C"
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "ENTRY оператор в %C не может появляться внутри INTERFACE"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Отсутствует метка формата в %C"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "Некорректное значение для %s спецификации в %C"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "Повторная %s спецификация в %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "Переменная %s не может быть INTENT(IN) в %C"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "Переменная %s не может быть присвоена в PURE процедуре в %C"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "Повторная спецификация %s метки в %C"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "Константное выражение в FORMAT теге в %L должно быть типа default CHARACTER"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "FORMAT тег в %L должен быть типа default-kind CHARACTER или INTEGER"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: ASSIGNED variable in FORMAT tag at %L"
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "Удаленная возможность: ASSIGNED переменная в FORMAT теге в %L"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L has not been assigned a format label"
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "Переменной '%s' в %L не была присвоена метка формата"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar '%s' in FORMAT tag at %L is not an ASSIGNED variable"
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr "Скаляр '%s' в FORMAT теге в %L не есть ASSIGNED переменная"
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Non-character in FORMAT tag at %L"
 msgid "Non-character in FORMAT tag at %L"
 msgstr "Расширение: Non-character в FORMAT теге в %L"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "Non-character элемент массива предполагаемой формы в FORMAT теге в %L"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "Non-character элемент массива предполагаемого размера в FORMAT теге в %L"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "Non-character элемент указательного массива в FORMAT теге в %L"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "%s тег в %L должен быть типа %s"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "%s тег в %L должен быть строкой символов подразумеваемого вида"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "%s тег в %L должен быть скаляром"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: IOMSG tag at %L"
 msgid "IOMSG tag at %L"
 msgstr "Fortran 2003: IOMSG тег в %L"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Fortran 95 требует подразумеваемый INTEGER в %s теге в %L"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2008: Nondefault LOGICAL in %s tag at %L"
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr "Fortran 2008: Неподразумеваемый LOGICAL в %s теге в %L"
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT not specified at %L"
 msgid "NEWUNIT specifier at %L"
 msgstr "UNIT не специфицировано в %L"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: CONVERT tag at %L"
 msgid "CONVERT tag at %L"
 msgstr "Расширение: CONVERT тег в %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: %s specifier in %s statement at %C has value '%s'"
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Fortran 2003: %s спецификатор в %s операторе в %C имеет значение '%s'"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 #| msgid "%s specifier in %s statement at %C has invalid value '%s'"
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "%s спецификатор в %s операторе в %C имеет некорректное значение '%s'"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: %s specifier in %s statement at %C has value '%s'"
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "Расширение: %s спецификатор в %s операторе в %C имеет значение '%s'"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "%s specifier in %s statement at %C has invalid value '%s'"
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "%s спецификатор в %s операторе в %C имеет некорректное значение '%s'"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "OPEN оператор не допускается в PURE процедуре в %C"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr "UNIT спецификатор не допускается с NEWUNIT в %C"
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr "NEWUNIT спецификатор должен иметь FILE= или STATUS='scratch' в %C"
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "OPEN оператор в %C должен иметь UNIT или NEWUNIT специфицированными"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: ASYNCHRONOUS= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: BLANK= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: DECIMAL= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENCODING= at %C not allowed in Fortran 95"
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: ENCODING= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ROUND= at %C not allowed in Fortran 95"
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: ROUND= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: SIGN= at %C not allowed in Fortran 95"
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: SIGN= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "CLOSE оператор не допускается в PURE процедуре в %C"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "CLOSE оператор в %L требует UNIT номер"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT номер в CLOSE операторе в %L должен быть неотрицательным"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s оператор не допускается в PURE процедуре в %C"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number missing in statement at %L"
 msgstr "UNIT номер в операторе в %L должен быть неотрицательным"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "UNIT номер в операторе в %L должен быть неотрицательным"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003: FLUSH оператор в %C"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing format with default unit at %C"
 msgstr "Отсутствует метка формата в %C"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Повторная UNIT спецификация в %C"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Повторная спецификация формата в %C"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Символ '%s' в списке имен '%s' является INTENT(IN) в %C"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Повторная NML спецификация в %C"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Символ '%s' в %C должен быть именем NAMELIST группы"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "END тег в %C не допускается в операторе вывода"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "UNIT не специфицировано в %L"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "UNIT спецификация в %L должна быть INTEGER выражением или CHARACTER переменной"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Некорректная форма WRITE оператора в %L, UNIT требуется"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Внутренняя единица с векторным индексом в %L"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Внешняя IO UNIT не может быть массивом в %L"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST '%s' in READ statement at %L contains the symbol '%s' which may not appear in a variable definition context"
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "NAMELIST '%s' в READ операторе в %L содержит символ '%s' который не может появляться в контексте определения переменной"
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, fuzzy, gcc-internal-format
+#| msgid "NAMELIST object '%s' in namelist '%s' at %L is polymorphic and requires a defined input/output procedure"
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr "NAMELIST объект '%s' в списке имен '%s' в %L является полиморфным и требует определенную процедуру ввода/вывода"
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, fuzzy, gcc-internal-format
+#| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr "Fortran 2003: NAMELIST объект '%s' в списке имен '%s' в %L с ALLOCATABLE или POINTER компонентами"
+
+#: fortran/io.c:3317
+#, fuzzy, gcc-internal-format
+#| msgid "NAMELIST object '%s' in namelist '%s' at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr "NAMELIST объект '%s' в списке имен '%s' в %L имеет ALLOCATABLE или POINTER компоненты и поэтому требует определенную процедуру ввода/вывода"
+
+#: fortran/io.c:3328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Comma before i/o item list at %L"
 msgid "Comma before i/o item list at %L"
 msgstr "Расширение: Запятая перед i/o списком элементов в %L"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR тег метка %d в %L не определена"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END тег метка %d в %L не определена"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "ERR тег метка %d в %L не определена"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT метка %d в %L не определена"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Синтаксическая ошибка в I/O итераторе в %C"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Ожидалась переменная в READ операторе в %C"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Ожидалось выражение в %s операторе в %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "синтаксическая ошибка в %s операторе в %C"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Internal file at %L with namelist"
 msgid "Internal file at %L with namelist"
 msgstr "Fortran 2003: Внутренний файл в %L со списком имен"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "ASYNCHRONOUS= спецификатор в %L должен быть инициализационным выражением"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: PAD= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DELIM= at %C not allowed in Fortran 95"
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: DELIM= в %C не допускается в Fortran 95"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "PRINT список имен в %C является расширением"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Ожидалась запятая в I/O списке в %C"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT оператор в %C не допускается внутри PURE процедуры"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE оператор не допускается в PURE процедуре в %C"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH тег некорректен в INQUIRE операторе в %C"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "INQUIRE оператор в %L не может содержать оба спецификатора FILE и UNIT"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "INQUIRE оператор в %L требует либо FILE либо UNIT спецификатор"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "UNIT номер в операторе в %L должен быть неотрицательным"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "INQUIRE оператор в %L требует PENDING= спецификатор с ID= спецификатором"
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: WAIT at %C not allowed in Fortran 95"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: WAIT в %C не допускается в Fortran 95"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "WAIT оператор не допускается в PURE процедуре в %C"
@@ -59569,283 +59677,283 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "Отсутствует generic спецификация в USE операторе в %C"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Renaming operators in USE statements at %C"
 msgid "Renaming operators in USE statements at %C"
 msgstr "Fortran 2003: Операторы переименования в USE операторе в %C"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' at %C has already been used as an external module name."
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Имя '%s' в %C уже было использовано как имя внешнего модуля."
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "in declaration %q+D"
 msgid "SUBMODULE declaration at %C"
 msgstr "в декларации %q+D"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "ENTRY оператор в %C не может появляться внутри внутренней подпрограммы"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Синтаксическая ошибка в SAVE операторе в %C"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "Reading module %s at line %d column %d: %s"
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "Чтение модуля %s в строке %d колонке %d: %s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "Writing module %s at line %d column %d: %s"
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "Запись модуля %s в строке %d колонке %d: %s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, fuzzy, gcc-internal-format
 #| msgid "Module %s at line %d column %d: %s"
 msgid "Module %qs at line %d column %d: %s"
 msgstr "Модуль %s в строке %d колонке %d: %s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Ошибка записи в файл модулей: %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Список имен %s не может быть переименован путем USE ассоциации в %s"
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' of module '%s', imported at %C, is also the name of the current program unit"
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "'%s' от модуля '%s', импортированного в %C, есть также имя текущей программной единицы"
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Символ '%s' встречающийся в %L не найден в модуле '%s'"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Пользовательский оператор '%s' встречающийся в %L не найден в модуле '%s'"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Встроенный оператор '%s' встречающийся в %L не найден в модуле '%s'"
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Не удалось открыть файл модуля '%s' для записи в %C: %s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Ошибка записи файла модуля '%s' для записи: %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "Не удалось удалить файл модуля '%s': %s"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Не удалось переименовать файл модуля '%s' в '%s': %s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Не удалось удалить временный файл модуля '%s': %s"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs at %C already declared"
 msgstr "Символ '%s' уже декларирован"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, fuzzy, gcc-internal-format
 #| msgid "The symbol '%s', referenced at %L, is not in the selected standard"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Символ '%s', встречающийся в %L, не содержится в выбранном стандарте"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Символ '%s' встречающийся в %L не найден во встроенном модуле ISO_C_BINDING"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "Символ '%s' уже декларирован"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "Use of intrinsic module '%s' at %C conflicts with non-intrinsic module name used previously"
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Использование встроенного модуля '%s' в %C конфликтует с именем невстроенного модуля использованным ранее"
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Использование NUMERIC_STORAGE_SIZE именованной константы из встроенного модуля ISO_FORTRAN_ENV в %L несовместимо с опцией %s"
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Использование NUMERIC_STORAGE_SIZE именованной константы из встроенного модуля ISO_FORTRAN_ENV в %C несовместимо с опцией %s"
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Символ '%s' встречающийся в %L не найден во встроенном модуле ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "CLOSE statement at %L requires a UNIT number"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "CLOSE оператор в %L требует UNIT номер"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003: ISO_FORTRAN_ENV встроенный модуль в %C"
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_C_BINDING module at %C"
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003: ISO_C_BINDING модуль в %C"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Не удалось найти встроенный модуль с названный '%s' в %C"
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Ошибка открытия файла модуля '%s' на чтение в %C: %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Использование невстроенного модуля '%s' в %C конфликтует с именем встроенного модуля использованным ранее"
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Файл '%s' открытый в %C не есть GFORTRAN файл модуля"
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building!"
@@ -62488,7 +62596,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Не удается разрешить конкретную функцию '%s' в %L"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -64124,507 +64232,495 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003: Generic имя '%s' функции '%s' в %L то же что и имя производного типа в %L"
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %L is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Массив предполагаемого размера '%s' в списке имен '%s' в %L не допускается"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003: NAMELIST массивный объект '%s' с предполагаемой формой в списке имен '%s' в %L"
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST array object '%s' with nonconstant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003: NAMELIST массивный объект  '%s' с неконстантной формой в списке имен '%s' в %L"
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: NAMELIST object '%s' with nonconstant character length in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003: NAMELIST объект '%s' с неконстантной character длиной в списке имен '%s' в %L"
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, fuzzy, gcc-internal-format
-#| msgid "NAMELIST object '%s' in namelist '%s' at %L is polymorphic and requires a defined input/output procedure"
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr "NAMELIST объект '%s' в списке имен '%s' в %L является полиморфным и требует определенную процедуру ввода/вывода"
-
-#: fortran/resolve.c:13924
-#, fuzzy, gcc-internal-format
-#| msgid "Fortran 2003: NAMELIST object '%s' in namelist '%s' at %L with ALLOCATABLE or POINTER components"
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "Fortran 2003: NAMELIST объект '%s' в списке имен '%s' в %L с ALLOCATABLE или POINTER компонентами"
-
-#: fortran/resolve.c:13942
-#, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект '%s' был декларирован PRIVATE и не может быть членом PUBLIC списка имен '%s' в %L"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST объект '%s' имеет use-associated PRIVATE компоненты и не может быть членом списка имен '%s' в %L"
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST объект '%s' имеет PRIVATE компоненты и не может быть членом PUBLIC списка имен '%s' в %L"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE атрибут конфликтует с NAMELIST атрибутом в '%s' в %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter массив '%s' at %L не может быть автоматическим или отложенной формы"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Неявно типизированный PARAMETER '%s' в %L не соотвествует более позднему IMPLICIT типу"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Несовместимый производный тип в PARAMETER в %L"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, fuzzy, gcc-internal-format
 #| msgid "COMMON block '%s' at %L can not have the EXTERNAL attribute"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "COMMON блок '%s' в %L не может иметь EXTERNAL атрибут"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "PROTECTED атрибут конфликтует с EXTERNAL атрибутом в %L"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "PROCEDURE атрибут конфликтует с PROTECTED атрибутом в %L"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "'%s' в %L имеет CONTIGUOUS атрибут но не является указателем на массив или массивом предполагаемой формы"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Массив предполагаемого размера в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Массив предполагаемой формы в %L должен быть формальным аргументом"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Символ в %L не является DUMMY переменной"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' в %L не может иметь VALUE атрибут поскольку он не является формальным аргументом"
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Character формальная переменная '%s' в %L с VALUE атрибутом должна иметь константную длину"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C совместимая character формальная переменная '%s' в %L с VALUE атрибутом должна иметь длину один"
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Производный тип '%s' в %L имеет тип '%s', который не был определен"
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута POINTER и BIND(C)"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "'%s' at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape array"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "'%s' в %L имеет CONTIGUOUS атрибут но не является указателем на массив или массивом предполагаемой формы"
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Массив предполагаемой формы '%s' в %L не разрешен в инициализационном выражении"
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута ALLOCATABLE и BIND(C)"
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Переменная '%s' в %L не может иметь оба атрибута POINTER и BIND(C)"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Loop variable at %C cannot be a coarray"
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Переменная цикла в %C не может быть комассивом"
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Переменная '%s' at %L не может быть BIND(C) поскольку она не COMMON блок и не декларирована на уровне модуля"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIC %s '%s' в %L PRIVATE производного типа '%s'"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Переменная %s в %L типа LOCK_TYPE или с подкомпонентом типа LOCK_TYPE должна быть комассивом"
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "The INTENT(OUT) формальный аргумент '%s' в %L имеет ASSUMED SIZE и поэтому не может иметь подразумеваемый инициализатор"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент '%s' в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Формальный аргумент '%s' в %L типа LOCK_TYPE не должен быть INTENT(OUT)"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "Function result '%s' at %L shall not be a coarray or have a coarray component"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Результат функции '%s' в %L не должен быть комассивом или иметь комассивный компонент"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Переменная '%s' в %L типа TYPE(C_PTR) или TYPE(C_FUNPTR) не должна быть комассивом"
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L with coarray component shall be a nonpointer, nonallocatable scalar"
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Переменная '%s' в %L с комассивным компонентом должна быть неуказательным, неразмещаемым скаляром"
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Переменная '%s' в %L является комассивом и не является ни ALLOCATABLE, ни SAVE, ни формальным аргументом"
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray variable '%s' at %L shall not have codimensions with deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Комассивная переменная '%s' в %L не должна иметь коизмерения с отложенной формой"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable coarray variable '%s' at %L must have deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Размещаемая комассивная переменная '%s' в %L должна иметь отложенную форму"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Переменная '%s' в %L является INTENT(OUT) и может поэтому не быть размещаемым комассивом или иметь комассивные компоненты"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная '%s' в %L не допускается в BIND(C) процедуре '%s'"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная '%s' в %L не допускается в BIND(C) процедуре '%s'"
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, fuzzy, gcc-internal-format
 #| msgid "Coarray dummy variable '%s' at %L not allowed in BIND(C) procedure '%s'"
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Комассивная формальная переменная '%s' в %L не допускается в BIND(C) процедуре '%s'"
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Список имен %s не может быть переименован путем USE ассоциации в %s"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate в %L не является SAVEd"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA элемент '%s' в %L должен быть в COMMON"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA массив '%s' в %L должен быть специфицирован в предшествующей декларации"
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L cannot have a coindex"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA элемент '%s' в %L не может иметь коиндекс"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, fuzzy, gcc-internal-format
 #| msgid "DATA element '%s' at %L is a pointer and so must be a full array"
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA элемент '%s' в %L является указателем и поэтому должен быть полным массивом"
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Неконстантная секция массива в %L в DATA операторе"
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA оператор в %L имеет больше переменных чем значений"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "начало implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "окончание implied-do цикла в %L не может быть упрощено до константного значения"
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "шаг implied-do цикла в %L не может быть упрощен до константного значения"
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA оператор в %L имеет больше значений чем переменных"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Метка %d в %L определена но не используется"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Метка %d в %L определена но не может быть использована"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Переменная производного типа '%s' в %L должна иметь SEQUENCE атрибут чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Переменная производного типа '%s' в %L не может иметь ALLOCATABLE компоненты чтобы быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Переменная производного типа '%s' в %L с подразумеваемой инициализацией не может быть в EQUIVALENCE с переменной в COMMON"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Переменная производного типа '%s' в %L с указательными компонентами не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Синтаксическая ошибка в EQUIVALENCE операторе в %L"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Все или никакие объекты в EQUIVALENCE множестве в %L должны иметь PROTECTED атрибут"
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Член common блока '%s' в %L не может быть EQUIVALENCE объектом в pure процедуре '%s'"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Именованная константа '%s' at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Массив '%s' at %L с неконстантными границами не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Компонент структуры '%s' at %L не может быть EQUIVALENCE объектом"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Подстрока в %L имеет нулевую длину"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC function '%s' at %L of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003: PUBLIC функция '%s' в %L PRIVATE типа '%s'"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY '%s' в %L не имеет IMPLICIT типа"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Процедура пользовательского оператора '%s' в %L должна быть FUNCTION"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Процедура пользовательского оператора '%s' в %L не может быть character предполагаемой длины"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Процедура пользовательского оператора '%s' в %L должна иметь по крайней мере один аргумент"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Первый аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Второй аргумент интерфейса оператора в %L не может быть необязательным"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Интерфейс оператора в %L должен иметь не более двух аргументов"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -65805,12 +65901,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Указательный объект в %C не должен быть коиндексирован"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "Некорректный базовый тип ввода-вывода (%d)"
@@ -68174,11 +68270,6 @@
 #~ msgid "Pointer initialization target at %L must not be ALLOCATABLE "
 #~ msgstr "Цель инициализации указателя в %L не должна быть ALLOCATABLE "
 
-#, fuzzy
-#~| msgid "NAMELIST object '%s' in namelist '%s' at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
-#~ msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
-#~ msgstr "NAMELIST объект '%s' в списке имен '%s' в %L имеет ALLOCATABLE или POINTER компоненты и поэтому требует определенную процедуру ввода/вывода"
-
 #~ msgid "bad method signature"
 #~ msgstr "некорректная сигнатура метода"
 
@@ -69189,9 +69280,6 @@
 #~ msgid "Fix errata in K128RIO unaligned load instructions"
 #~ msgstr "Обходить ошибки невыровненного чтения K128RIO"
 
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "Генерировать плавающие команды умножения с накоплением"
-
 #~ msgid "-mstack-limit-register=REG\tCheck stack overflow using REG as stack limit value"
 #~ msgstr "-mstack-limit-register=REG\tПроверять переполнение стека, считая что граница стека находится в регистре REG"
 
Index: gcc/po/sv.po
===================================================================
--- gcc/po/sv.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/sv.po	(.../branches/gcc-7-branch)
@@ -23,7 +23,7 @@
 msgstr ""
 "Project-Id-Version: gcc 7.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2017-05-15 14:41+0200\n"
 "Last-Translator: Göran Uddeborg <goeran@uddeborg.se>\n"
 "Language-Team: Swedish <tp-sv@listor.tp-sv.se>\n"
@@ -210,13 +210,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "flyttalskonstant felanvänd"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -503,62 +503,62 @@
 "vidare till de barnprocesser som startas av %s. För att skicka med andra\n"
 "flaggor till dessa processer måste flaggan -W<bokstav> användas.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Bearbetar specifikationen (%s), som är ”%s”\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Mål: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Konfigurerad med: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Trådmodell: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc version %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "gcc-drivrutin version %s %skör gcc version %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr "Felet är inte reproducerbart, så det är förmodligen ett problem med hårdvara eller OS.\n"
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr "Preprocessad källkod lagrad i filen %s, bifoga den till din felrapport.\n"
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "installation: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "program: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "bibliotek: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -569,16 +569,16 @@
 "<tp-sv@listor.tp-sv.se>.\n"
 "För felrapporteringsinstruktioner i övrigt, se:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "©"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -589,7 +589,7 @@
 "SPECIELLT ÄNDAMÅL.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -602,7 +602,7 @@
 "================\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -611,7 +611,7 @@
 "Använd ”-Wl,FLAGGA” för att skicka ”FLAGGA” till länkaren.\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -622,7 +622,7 @@
 "================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -634,16 +634,16 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr "  merge [flaggor] <kat1> <kat2>         Slå samman innehåll i täckningsfiler\n"
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "    -o, --output <kat>                  Utdatakatalog\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "    -v, --verbose                       Utförligt läge\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "    -o, --output <kat>                  Utdatakatalog\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -659,16 +659,16 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr "  rewrite [flaggor] <kat>               Skriv om innehåll i täckningsfiler\n"
 
+#: gcov-tool.c:270
+#, c-format
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgstr "    -n, --normalize <int64_t>           Normalisera profilen\n"
+
 #: gcov-tool.c:272
 #, c-format
 msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr "    -s, --scale <flyttal el. bråk>      Skala profilräknarna\n"
 
-#: gcov-tool.c:273
-#, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
-msgstr "    -n, --normalize <int64_t>           Normalisera profilen\n"
-
 #: gcov-tool.c:290
 #, c-format
 msgid "Rewrite subcommand usage:"
@@ -694,27 +694,27 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr "  overlap [flaggor] <kat1> <kat2>       Beräkna överlappningen mellan två profiler\n"
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "    -h, --hotonly                       Skriv endast info om heta objekt/funktioner\n"
-
-#: gcov-tool.c:422
-#, c-format
 msgid "    -f, --function                      Print function level info\n"
 msgstr "    -f, --function                      Skriv funktionsnivåinfo\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:421
 #, c-format
 msgid "    -F, --fullname                      Print full filename\n"
 msgstr "    -F, --fullname                      Skriv fullständiga filnamn\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:422
 #, c-format
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr "    -h, --hotonly                       Skriv endast info om heta objekt/funktioner\n"
+
+#: gcov-tool.c:423
+#, c-format
 msgid "    -o, --object                        Print object level info\n"
 msgstr "    -o, --object                        Skriv objektnivåinfo\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr "    -t <float>, --hot_threshold <float> Ange gränsvärdet för värme\n"
@@ -800,20 +800,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Visa denna hjälp, avsluta sedan\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Visa information för varje grundblock\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Tag med hoppsannolikheter i utdata\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -822,16 +817,21 @@
 "  -c, --branch-counts             Skriv antal hopp tagna istället\n"
 "                                    för procentsatser\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          Visa förloppsinformation\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Skriv sammanfattningar för varje funktion\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Visa denna hjälp, avsluta sedan\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1018,82 +1018,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s:graf är olösbar för ”%s”\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Körda rader:%s av %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Inga körbara rader\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s: ”%s”\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Utförda hopp:%s av %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "Tagna minst en gång:%s av %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Inga grenar\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Gjorda anrop:%s av %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Inga anrop\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s:inga rader för ”%s\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "anrop %2d returnerade %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "anrop %2d aldrig utfört\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "hopp %2d gjort %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "gren %2d aldrig utförd\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "ovillkorligt hopp %2d taget %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "ovillkorligt hopp %2d aldrig utfört\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "Kan inte öppna källkodsfilen %s\n"
@@ -1200,89 +1200,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr "Användning av denna flagga diagnostiseras."
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr "standard %d minimum %d maximum %d"
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr "Samma som %s.  Använd den senare flaggan istället."
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s  Samma som %s."
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[standard]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[aktiverad]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[avslagen]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Det finns inga flaggor med de eftersökta egenskaperna\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Det fanns inga.  Använd --help=%s för att visa *alla* flaggorna som stödjs av framänden %s.\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Alla flaggor med de eftersökta egenskaperna har redan visats\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "Följande flaggor är målberoende"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "Följande flaggor styr kompilatorns varningsmeddelanden"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "Följande flaggor styr optimeringar"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "Följande flaggor är språkoberoende"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "Flaggan --param accepterar följande som parametrar"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "Följande flaggor är specifika för just språket"
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "Följande flaggor stödjs av språket"
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "Följande flaggor är inte dokumenterade"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "Följande flaggor tar separata argument"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "Följande flaggor tar sammanslagna argument"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "Följande flaggor är språkrelaterade"
 
@@ -2812,8 +2812,8 @@
 msgid "<command-line>"
 msgstr "<kommandorad>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Ej stödd operand för kod ”%c”"
@@ -2832,7 +2832,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "inkompatibla flyttals-/vektorregisteroperander för ”%%%c”"
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "operand saknas"
@@ -2852,8 +2852,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "ogiltig operandprefix ”%%%c”"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "”%%&” använt utan någon lokal dynamisk TLS-referens"
@@ -2869,18 +2869,18 @@
 msgstr "ogiltigt %%r-värde"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "ogiltigt %%R-värde"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "ogiltigt %%N-värde"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "ogiltigt %%P-värde"
@@ -2890,7 +2890,7 @@
 msgid "invalid %%h value"
 msgstr "ogiltigt %%h-värde"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "ogiltigt %%L-värde"
@@ -2911,7 +2911,7 @@
 msgstr "ogiltigt %%U-värde"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "ogiltigt %%s-värde"
@@ -2921,7 +2921,7 @@
 msgid "invalid %%C value"
 msgstr "ogiltigt %%C-värde"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "ogiltigt %%E-värde"
@@ -2932,7 +2932,7 @@
 msgstr "okänd avspecifikation av omlokalisering"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ogiltig %%xn-kod"
@@ -2995,7 +2995,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "ogiltig operand i utmatningskod"
@@ -3005,29 +3005,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ogiltig UNSPEC som operand: %d"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "ogiltig skiftoperand"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "förutsade Thumb-instruktion"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "förutsade instruktion i villkorlig sekvens"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3035,101 +3035,101 @@
 msgid "invalid operand for code '%c'"
 msgstr "ogiltig operand för kod ”%c”"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "instruktionen aldrig utförd"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "föråldrad Maverick-formatkod ”%c”"
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "adressoperander kräver begränsning för X-, Y- eller Z-register"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "operander till %T/%t måste vara reg + const_int:"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr "felaktig adress, inte en I/O-adress:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr "felaktig adress, inte en konstant:"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "felaktig adress, inte (reg+avst):"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "felaktig adress, inte post_inc eller pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "internt kompilatorfel.  Felaktig adress:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Ej stödd kod ”%c” för fixdecimal:"
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "internt kompilatorfel.  Okänt läge:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "ogiltig instruktion:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "felaktig instruktion:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "okänd move-instruktion:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "felaktig skiftinstruktion:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "internt kompilatorfel.  Felaktig skift:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 msgid "unsupported fixed-point conversion"
 msgstr "ej stödd fixdecimalskonvertering"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr "variabel"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 msgid "function parameter"
 msgstr "funktionsparameter"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 msgid "structure field"
 msgstr "postfält"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 msgid "return type of function"
 msgstr "returtyp för en funktion"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr "pekare"
 
@@ -3153,7 +3153,7 @@
 msgstr "ogiltig const_double-operand"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3375,87 +3375,87 @@
 msgid "bad output_condmove_single operand"
 msgstr "felaktig operand till output_condmove_single"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ogiltig UNSPEC som operand"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "felaktig användning av asm-flaggutdata"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ogiltig operandstorlek för operandkod ”O”"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ogiltig operandstorlek för operandkod ”z”"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ogiltig operandtyp vid operandkod ”Z”"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ogiltig operandstorlek för operandkod ”Z”"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operanden är inte en villkorskod, ogiltig operandkod ”Y”"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”D”"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operand är inte en villkorskod, ogiltig operandkod ”%c”"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operand är inte en justerbar minnesreferens, ogiltig operandkod ”H”"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operanden är inte ett heltal, ogiltig operandkod ”K”"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operanden är inte ett specifikt heltal, ogiltig operandkod ”r”"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operanden är inte ett heltal, ogiltig operandkod ”R”"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operanden är inte ett specifikt heltal, ogiltig operandkod ”R”"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ogiltig operandkod ”%c”"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ogiltig begränsning för operand"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "okänt instruktionsläge"
 
@@ -3492,7 +3492,7 @@
 msgid "invalid %%P operand"
 msgstr "ogiltig %%P-operand"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "ogiltigt %%p-värde"
@@ -3546,7 +3546,7 @@
 msgstr "efterinkrementeringsadress är inte ett register"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "felaktig adress"
 
@@ -3579,7 +3579,7 @@
 msgstr "instruktionen innehåller en ogiltig adress!"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "ogiltig adress"
 
@@ -3670,277 +3670,277 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Försök köra ”%s” i skalet för att öka dess gräns.\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le är inte tillåtet för mål med rak byteordning"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx kräver hårdvaruflyttal"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx och -mpaired är inkompatibla"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx behöver indexerad adressering"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx och -mno-altivec är inkompatibla"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec avaktiverar vsx"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--mquad-memory kräver 64-bitarsläge"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic förutsätter 64-bitarsläge"
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory är inte tillgängligt i läget med omvänd byteordning"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--mtoc-fusion kräver 64-bitar"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "-mtoc-fusion behöver medium/stor kodmodell"
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr "felaktig förflyttning"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr "Felaktig 128-bitsförflyttning"
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, c-format
 msgid "invalid %%e value"
 msgstr "ogiltigt %%e-värde"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "ogiltigt %%f-värde"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "ogiltigt %%F-värde"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "ogiltigt %%G-värde"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "ogiltig %%j-kod"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "ogiltig %%J-kod"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "ogiltigt %%k-värde"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "ogiltigt %%K-värde"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "ogiltigt %%O-värde"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "ogiltigt %%q-värde"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "ogiltigt %%T-värde"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "ogiltigt %%u-värde"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "ogiltig %%v-kod"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "ogiltigt %%x-värde"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ogiltigt %%y-värde, försök använda ”Z”-begränsningen"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 och __ibm128 kan inte användas i samma uttryck"
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 och long double inte användas i samma uttryck"
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 och long double kan inte användas i samma uttryck"
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argument skickat till funktion utan prototyp"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 msgid "Could not generate addis value for fusion"
 msgstr "Kunde inte generera addis-värde för sammanslagning"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Kan inte generera ladda/lagra-avstånd för sammanslagning"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr "Felaktig GPR-sammanslagning"
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, felaktigt register nr. 1"
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, felaktigt register nr. 2"
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load inte MEM"
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, felaktigt register nr. 1"
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, felaktigt register nr. 2"
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store inte MEM"
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "symboliska minnesreferenser stödjs endast på z10 eller senare"
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "kan inte dekomponera adress."
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ogiltig jämförelseoperator för utmatningsmodifieraren ”E”"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ogiltig referens för utmatningsmodifieraren ”J”"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ogiltig adress för utmatningsmodifieraren ”O”"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ogiltig adress för utmatningsmodifieraren ”R”"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "minnesreferens förväntas för utmatningsmodifieraren ”S”"
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ogiltig adress för ”S”-utmatningsmodifierare"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "register- eller minnesuttryck förväntas för utmatningsmodifieraren ”N”"
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "register- eller minnesuttryck förväntas för utmatningsmodifieraren ”M”"
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ogiltig konstant för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "ogiltig konstant - försök med att använda en utmatningsmodifierare"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ogiltig konstant vektor för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ogiltigt uttryck - försök med att använda en utmatningsmodifierare"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ogiltigt uttryck för utmatningsmodifieraren ”%c”"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 msgid "vector argument passed to unprototyped function"
 msgstr "vektorargument skickat till funktion utan prototyp"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 msgid "types differ in signedness"
 msgstr "typer skiljer i teckenhet"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr "binäroperator stödjer inte två vektorbooleanoperander"
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr "den binära operatorn stödjer inte vektor-bool-operand"
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binär operator stödjer inte blandning av operanderna vektorboolean och flyttalsvektor"
 
@@ -3966,43 +3966,43 @@
 msgid "created and used with different endianness"
 msgstr "skapad och använd med olika byteordning"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ogiltig %%Y-operand"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ogiltig %%A-operand"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ogiltig %%B-operand"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "ogiltig %%C-operand"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "ogiltig %%D-operand"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ogiltig %%f-operand"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ogiltig %%s-operand"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "flyttalskonstant inte en giltig omedelbar operand"
@@ -4166,30 +4166,30 @@
 msgid "bad test"
 msgstr "felaktig test"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "ogiltigt %%D-värde"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "ogiltigt mask"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "ogiltigt %%d-värde"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "ogiltigt %%t/%%b-värde"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "inget register i adress"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "adressavstånd inte en konstant"
 
@@ -4210,8 +4210,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> förväntades"
@@ -4233,14 +4233,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> förväntades"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> förväntades"
@@ -4271,7 +4271,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> förväntades"
@@ -4279,7 +4279,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> förväntades"
@@ -4289,7 +4289,7 @@
 msgstr "%<;%>, %<,%> eller %<)%> förväntades"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> förväntades"
@@ -4296,7 +4296,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> förväntades"
@@ -4306,7 +4306,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> förväntades"
@@ -4319,24 +4319,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "Cilk-vektornotation kan inte användas till ett throw-uttryck"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr "Cilk-vektornotation kan inte användas som villkor i en switch-sats"
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr "Cilk-vektornotation kan inte användas som villkor till en while-sats"
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> förväntades"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr "Cilk-vektornotation kan inte användas som villkor till en do-while-sats"
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr "Cilk-vektornotation kan inte användas i ett villkor till en for-slinga"
 
@@ -4344,18 +4344,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> förväntades"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> förväntades"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> förväntades"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> eller %<)%> förväntades"
@@ -4363,17 +4363,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> förväntades"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> eller %<}%> förväntades"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> förväntades"
@@ -4382,7 +4382,7 @@
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> förväntades"
@@ -4391,11 +4391,11 @@
 msgid "expected label"
 msgstr "etikett förväntades"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
@@ -4614,11 +4614,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%r%s:%d:%R   i expansion av konstantuttryck i från %qs"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "kandidater är:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "kandidat är:"
@@ -4789,80 +4789,80 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "aktuellt argument till INTENT = OUT/INOUT"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "Positiv bredd krävs"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "Ickenegativ bredd krävs"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Oväntat element %qc i formatsträng vid %L"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "Oväntat slut på formatsträng"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr "Nollbredd i formatbeskrivning"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "Inledande vänsterparentes saknas"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 msgid "Left parenthesis required after %<*%>"
 msgstr "Vänsterparentes krävs efter %<*%>"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "Redigeringsbeskrivning P förväntades"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "P-beskrivare kräver inledande skalfaktor"
 
-#: fortran/io.c:726
-#, c-format
-msgid "Right parenthesis expected at %C"
-msgstr "Högerparentes förväntades vid %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr "Komma krävs efter P-beskrivare"
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr "Positiv bredd krävs med T-beskrivare"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "Specificeraren E är inte tillåten vid g0-deskriptor"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "Positiv exponentbredd krävs"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, c-format
+msgid "Right parenthesis expected at %C"
+msgstr "Högerparentes förväntades vid %C"
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr "Period krävs i formatangivelse"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr "%s-tagg"
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr "intern enhet i WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s-tagg med INQUIRE"
@@ -4872,75 +4872,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "Syntaxfel i uttryck vid %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Oväntat filslut"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Heltalsspill"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "För långt namn"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Felaktigt namn"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Förväntade ett namn"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "Vänsterparentes förväntades"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "Högerparentes förväntades"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Heltal förväntades"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Sträng förväntades"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum(): Enum finns inte"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "Attributbitnamn förväntades"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Heltalssträng förväntades"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "Fel vid konvertering av heltal"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Förväntade reell sträng"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "Uttryckstyp förväntades"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "Felaktig operator"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "Felaktig typ i konstant uttryck"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "Oväntat modulslut"
 
@@ -5185,12 +5185,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Aktuell stränglängd är kortare än den deklarerade för attrappargument ”%s” (%ld/%ld)"
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Målet för återavbildning av ordning är för litet (%ld < %ld)"
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr "Tilldelning av skalär till en oallokerad vektor"
 
@@ -5535,7 +5535,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "går inte att använda både -m32 och -m64"
 
@@ -8414,7 +8414,7 @@
 msgstr "Ange bitstorlek på omedelbara TLS-avstånd."
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr "Schemalägg kod för en given CPU."
@@ -8635,7 +8635,7 @@
 msgid "target the software simulator."
 msgstr "ha programvarusimulatorn som mål."
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr "Använd LRA istället för omladdning."
 
@@ -8853,12 +8853,12 @@
 msgid "Use 80-bit long double."
 msgstr "Använd 80-bitars long double."
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 msgid "Use 64-bit long double."
 msgstr "Använd 64-bitars long double."
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr "Använd 128-bitars long double."
@@ -9872,87 +9872,87 @@
 msgid "64 bit ABI."
 msgstr "64-bitars ABI."
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr "Håll med bakåtkedjepekare."
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr "Ytterligare felsökningsutskrifter."
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr "ESA/390-arkitektur."
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 msgid "Enable decimal floating point hardware support."
 msgstr "Använd hårdvarustöd för decimala flyttal."
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 msgid "Enable hardware floating point."
 msgstr "Använd hårdvaruflyttal."
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr "Tar två icke-negativa heltal separerade av ett kommatecken.  Inled funktionsetiketten med det antal tvåbytes Nop-instruktioner som indikeras av det första.  Avsluta med Nop-instruktioner som täcker det antal halvord som indikeras av den andra efter etiketten.  Nop-instruktioner av största möjliga storlek används (sex, fyra eller två byte), med början med den största möjliga storleken.  Att använda 0 för båda värdena avaktiverar hotpatchning."
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 msgid "Use hardware transactional execution instructions."
 msgstr "Använd transaktionskörningsinstruktioner i hårdvara."
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "Använd instruktioner för vektorfunktioner i hårdvara och aktivera vektor-ABI:et."
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr "Använd packad stacklayout."
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr "Använd bras för körbara program < 64k."
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 msgid "Disable hardware floating point."
 msgstr "Använd inte hårdvaruflyttal."
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "Ange det maximala antalet byte som måste finnas kvar till stackstorleken före en fällinstruktion utlöses."
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr "Slår av flaggan -mstack-guard=."
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "Mata ut extra kod i funktionsprologen för att fånga om stackstorleken överskrider den givna gränsen."
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr "Slår av flaggan -mstack-size=."
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 msgid "Use the mvcle instruction for block moves."
 msgstr "Använd mvcle-instruktioner för blockförflyttningar."
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr "Aktivera språkutökningen z-vektor som ger det kontextkänsliga vektormakrot och aktivera de inbyggda i Altivec-stil i vecintrin.h."
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "Varna om en funktion använder alloca eller skapar en vektor med dynamisk storlek."
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "Varna om en enskild funktions ramstorlek överskrider den angivna ramstorleken."
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr "z/Arkitektur."
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr "Ställ in grenkostnaden för villkorliga greninstruktioner.  Rimliga värden är små, ickenegativa heltal.  Standardkostnaden för grenar är 1."
 
@@ -10004,11 +10004,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr "Kända ARM CPU:er (att användas med flaggorna -mcpu= och -mtune=):"
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr "Kända ARM-arkitekturer (att användas med flaggan -march=):"
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr "Kända ARM FPU:er (att användas med flaggan -mfpu=):"
 
@@ -10234,78 +10234,102 @@
 msgstr "Använd UltraSPARC:s utökningar Visual Instruction Set version 4.0."
 
 #: config/sparc/sparc.opt:86
+#, fuzzy
+#| msgid "Use vector and scalar instructions added in ISA 2.07."
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr "Använd vektor och skalära instruktioner som lades till i ISA 2.07."
+
+#: config/sparc/sparc.opt:90
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "Använd UltraSPARC:s utökningar Compare-and-Branch."
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "Använd UltraSPARC:s utökningar Fused Multiply-Add."
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+#, fuzzy
+#| msgid "Use hardware floating-point divide and square root instructions."
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Använd instruktioner i hårdvara för division och kvadratrot av flyttal."
+
+#: config/sparc/sparc.opt:102
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "Använd UltraSparc:s instruktion Population-Count."
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "Använd UltraSparc:s instruktion Subtract-Extended-with-Carry."
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 msgid "Pointers are 64-bit."
 msgstr "Pekare är 64-bitars."
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 msgid "Pointers are 32-bit."
 msgstr "Pekare är 32-bitars."
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 msgid "Use 64-bit ABI."
 msgstr "Använd 64-bitars ABI."
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 msgid "Use 32-bit ABI."
 msgstr "Använd 32-bitars ABI."
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr "Använd stackförskjutning."
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Använd starkare justering för poster för dubbelordkopieringar."
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Optimera svansanropsinstruktioner i assembler och länkare."
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr "Generera inte kod som endast kan köra i övervakarläge (standard)."
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr "Använd funktioner i och schemalägg kod för angiven CPU."
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr "Använd angiven SPARC-V9-kodmodell."
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 msgid "Enable debug output."
 msgstr "Aktivera felsökningsutdata."
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "Aktivera strikt 32-bits psABI-kontroller av postreturer."
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr "Aktivera en lösning för ensamt errata för processorn AT697F (motsvarar errata nr. 13 för processorn AT697E.)"
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr "Aktivera en lösning för errata för processorn UT699."
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+#, fuzzy
+#| msgid "Enable workarounds for the errata of the UT699 processor."
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr "Aktivera en lösning för errata för processorn UT699."
+
+#: config/sparc/sparc.opt:250
+#, fuzzy
+#| msgid "Enable workarounds for the errata of the UT699 processor."
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr "Aktivera en lösning för errata för processorn UT699."
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr "Ange minnesmodellen som skall gälla för programmet."
 
@@ -14657,7 +14681,9 @@
 msgstr "Detektera vägar som utlöser felaktigt eller odefinierat beteende på grund av dereferering av nollpekare.  Isolera dessa vägar från huvudsakliga styrflödet och gör om satsen med det felaktiga eller odefinierade beteendet till en fälla."
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+#, fuzzy
+#| msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Detektera vägar som utlöser felaktigt eller odefinierat beteende på grund av att ett nollvärde används på ett sätt som förbjuds av ett returns_nonnull- eller nonnull-attribut.  Isolera dessa vägar från huvudsakliga styrflödet och gör om satsen med det felaktiga eller odefinierade beteendet till en fälla."
 
 #: common.opt:2502
@@ -15059,7 +15085,7 @@
 msgstr "boolesk typ förväntades"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "heltal förväntades"
@@ -15337,125 +15363,125 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr "en intervallklausul måste ha vektor-, skiv-, sträng-, avbildnings- eller kanaltyp"
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 msgid "invalid comparison of non-ordered type"
 msgstr "ogiltig jämförelse av oordnad typ"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr "en skiva kan endast jämföras med nil"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr "en avbildning kan endast att jämföras med nil"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr "en funktion kan endast jämföras med nil"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, c-format
 msgid "invalid operation (%s)"
 msgstr "ogiltig operation (%s)"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 msgid "invalid comparison of non-comparable type"
 msgstr "ogiltig jämförelse av ojämförbar typ"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 msgid "invalid comparison of generated struct"
 msgstr "ogiltig jämförelse av genererad post"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr "ogiltig jämförelse av ojämförbar post"
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 msgid "invalid comparison of generated array"
 msgstr "ogiltig jämförelse av genererad vektor"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr "ogiltig jämförelse av ojämförbar vektor"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr "flervärt funktionsanrop i sammanhang för enstaka värde"
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr "explicit konvertering behövs"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr "det går inte att använda typ %s som typ %s"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr "olika mottagartyper"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr "olika antal parametrar"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr "olika parametertyper"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr "olika varargs"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr "olika antal resultat"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr "olika resultattyper"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "en explicit konvertering behövs, metoden %s%s%s saknas"
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "inkompatibel typ för metoden %s%s%s"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "inkompatibel typ för metoden %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr "pekare till gränssnittstyp har inga metoder"
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr "typen har inga metoder"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "tvetydig metod %s%s%s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "metoden saknas %s%s%s"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "metoden %s%s%s kräver en pekarmottagare"
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "metoden %s%s%s är märkt go:nointerface"
@@ -15630,7 +15656,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr "den angivna gränsen %wu är lika med storleken på destinationen"
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "För många argument till funktionen %<va_start%>"
@@ -15692,27 +15718,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "ogiltig minnesmodell för %<__atomic_load%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ogiltigt minnesmodell för %<__atomic_store%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "argument 1 till __atomic_always_lock_free är inte konstant"
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "argument 1 till __atomic_is_lock_free är inte heltal"
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_thread_pointer stödjs inte på denna målarkitektur"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_set_thread_pointer stödjs inte på denna målarkitektur"
@@ -15719,7 +15745,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kogiltigt användning av %<__builtin_va_arg_pack ()%>"
@@ -15726,12 +15752,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kogiltigt användning av %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "andra argumentet till %<__builtin_longjmp%> måste vara 1"
@@ -15738,62 +15764,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Din målplattform stödjer inte -fcheck-pointer-bounds"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "målformatet stödjer inte oändligheten"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> används i en funktion med fixt antal parametrar"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "fel antal argument till funktionen %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> anropad utan argument"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "fel antal argument till funktionen %<__builtin_next_arg%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "andra parametern till %<va_start%> är inte det sista namngivna argumentet"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "odefinierat beteende när andra parametern till %<va_start%> är deklarerad med lagringsklass %<register%>"
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%Kförsta argumentet till %D måste vara en pekare, det andra en heltalskonstant"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%Ksista argumentet till %D är inte en heltalskonstant mellan 0 och 3"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kförsök att frigöra ett icke-heap-objekt %qD"
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kförsök att frigöra ett icke-heap-objekt"
@@ -16701,12 +16727,12 @@
 msgstr "attributet %<weakref%> ignorerat för att variabeln är initierad"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F är använd men inte definierad"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F är deklarerad %<static%> men definieras aldrig"
@@ -16801,12 +16827,12 @@
 msgid "cannot find '%s'"
 msgstr "kan inte hitta ”%s”"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init misslyckades: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -16816,7 +16842,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER måste vara satt"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17027,7 +17053,7 @@
 msgid "error writing %qs"
 msgstr "fel när %qs skrevs"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "kan inte öppna %s"
@@ -17107,17 +17133,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr "ignorerar flaggan %<-fopt-info-%s%> som möjligen står i konflikt"
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "multipla EH-personligheter stödjs endast med assemblerare som stödjer direktivet .cfi.personality."
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "odelegitimerad UNSPEC %s (%d) funnen på variabelplats"
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr "-feliminate-dwarf2-dups är trasig för C++, ignorerar"
@@ -17227,12 +17253,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "skrivning av %wu-bitsdata utanför gränsen för destinationsobjektet, data avhuggen till %wu bitar"
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kanrop av %qs deklarerad med attributet error: %s"
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K anrop av %qs deklarerad med attributet warning: %s"
@@ -17247,12 +17273,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "ramstorleken på %wd byte är större än %wd byte"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "det gick inte att öppna slutgiltig instruktionsdumpfil %qs: %m"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "det gick inte att stänga slutgiltig instruktionsdumpfil %qs: %m"
@@ -17267,7 +17293,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "jämförelsen är alltid %d på grund av bredd på bitfält"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "antar att teckenspill inte förekommer vid förenkling av intervalltest"
@@ -17297,7 +17323,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "antar att teckenspill inte förekommer vid kombination av konstanter runt en jämförelse"
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "vikningskontroll: originalträdet ändrat av vikning"
@@ -17307,7 +17333,7 @@
 msgid "total size of local objects too large"
 msgstr "total storlek på lokala objekt är för stor"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "omöjlig begränsning i %<asm%>"
@@ -17407,62 +17433,68 @@
 msgid "input file %qs is the same as output file"
 msgstr "indatafilen %qs är samma som utdatafilen"
 
-#: gcc.c:4498
+#: gcc.c:4476
+#, fuzzy, gcc-internal-format
+#| msgid "output file not specified"
+msgid "output filename may not be empty"
+msgstr "utdatafilen inte angiven"
+
+#: gcc.c:4501
 #, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "-pipe ignorerad eftersom -save-temps angivits"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "%<-x %s%> efter sista indatafilen har ingen effekt"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr "kan inte lokalisera standardlänkskriptet %qs i bilblioteksökvägarna"
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "flaggan %qs börjar inte med %<-%>"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr "spec-genererad flagga är bara %<-%>"
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "det gick inte att öppna temporär svarsfil %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "det gick inte att skriva till temporär svarsfil %s"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "det gick inte att stänga temporär svarsfil %s"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "specifikationen %qs är ogiltig"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "specifikation %qs har ogiltig %<%%0%c%>"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "specifikation %qs har ogiltig %<%%W%c%>"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "specifikation %qs har ogiltig %<%%x%c%>"
@@ -17470,228 +17502,228 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "specifikationsfel: %<%%*%> har inte initierats av en mönstermatchning"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "specifikationsfel: okänd specifikationsflagga %qc"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "okänd specifikationsfunktion %qs"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "fel i argument till specifikationsfunktionen %qs"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "felaktigt specifikationsfunktionsnamn"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "inga argument till spec-funktion"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "felaktiga specifikationsfunktionsargument"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "klammerspecifikation %qs är ogiltig vid %qc"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "klammerspecifikationskropp %qs är ogiltig"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s: det gick inte att avgöra längden på compare-debug-filen %s"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr "%s: -fcompare-debug misslyckades (längd)"
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s: det gick inte att öppna compare-debug-filen %s"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "%s: -fcompare-debug misslyckades"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "spec-fel: mer än ett argument till SYSROOT_SUFFIX_SPEC"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "spec-fel: mer än ett argument till SYSROOT_HEADERS_SUFFIX_SPEC"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "okänd kommandoradsflagga %<-%s%>, menade du %<-%s%>?"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "okänd kommandoradsflagga %<-%s%>"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "ej konfigurerad med suffix för sysroot-huvuden"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "inga indatafiler"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "det går inte att ange -o med -c, -S eller -E med flera filer"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: kompilatorn %s är inte installerad på detta system"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "kompilerar om med -fcompare-debug"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr "under omkompilering med -fcompare-debug"
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr "jämför slutliga instruktionsdumpar"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "-fuse-linker-plugin, men %s inte funnen"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: infil till länkaren oanvänd eftersom ingen länkning gjordes"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr "det går inte att använda %<-%> som indatafilnamn för förkompilerade huvuden"
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "språk %s känns inte igen"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "multilib-specifikation %qs är ogiltig"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "multilib-undantag %qs är ogiltiga"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib-val %qs %qs är ogiltigt"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "multilib-val %qs är ogiltigt"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "multilib-undantag %qs är ogiltigt"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "omgivningsvariabeln %qs är inte definierad"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "ogiltigt versionsnummer %qs"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "för få argument till %%:version-compare"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "för många argument till %%:version-compare"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "okänd operator %qs i %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "för många argument till %%:comparedebug-dump-opt"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "för många argument till %%:compare-debug-self-opt"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "för få argument till %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "för många argument till %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr "argumentet till %%:compare-debug-auxbase-opt slutar inte i .gk"
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "för få argument till %%:replace-extension"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "fel antal argument till %%:debug-level-gt"
@@ -17836,9 +17868,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "deklarerad här"
@@ -18253,227 +18285,227 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr "attributet %<fallthrough%> föregår inte en case-etikett eller standardetikett"
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "använder resultat från funktion som returnerar %<void%>"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "ogiltigt l-värde i asm-utdata %d"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "icke-minnesindata %d måste stanna i minnet"
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "minnesindata %d är inte direkt adresserbar"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "trådprivat variabel %qE använd i målregion"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "omgivande målregion"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "trådprivat variabel %qE använd i obunden uppgift"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "omgivande uppgift"
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE inte angiven i omgivande %qs"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "omgivande %qs"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE inte angiven i omgivande OpenACC %qs-konstruktion"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "omgivande OpenACC %qs-konstruktion"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE med %<link%>-klausul använd i %<routine%>-funktion"
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE behöver ett %<declare%>-direktiv att användas i en %<routine%>-funktion"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variabeln %qE deklarerad i omgivande %<host_data%>-region"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "%qD refererad i målregion som inte har en avbildbar typ"
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "iterationsvariabel %qE är förutbestämt linjär"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "instansvariabel %qE skall vara privat"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "iterationsvariabel %qE får inte vara firstprivate"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "iterationsvariabel %qE får inte vara reduction"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "instansvariabel %qE får inte vara linjär"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "iterationsvariabel %qE får inte vara lastprivate"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "instansvariabel %qE får inte vara privat"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%>-klausul för en annan variabel än en slingiterator angiven vid konstruktion kombinerad med %<distribute%>"
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "avbildningsfältet %qE med variabel längds post"
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE förekommer mer än en gång i avbildningsklausuler"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "copyprivate-variabel %qE är inte privat threadprivate eller private i yttre sammanhang"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s-variabel %qE är privat i yttre sammanhang"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%qs %<if%>-klausulmodifierare förväntades snarare än %qs"
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD i implicit %<map%>-klausul"
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD i implicit %<firstprivate%>-klausul vid %<target%>-konstruktion"
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD i %<firstprivate%>-klausul vid %<target%>-konstruktion"
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "samma variabel använd i %<firstprivate%>- och %<lastprivate%>-klausuler vid %<distribute%>-konstruktion"
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr "inkompatibel dataklausul med reduktion på %qE; befordrar till present_or_copy"
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "ogiltig privat reduktion av %qE"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%>-konstruktion med %<depend%>-klausul måste vara nära innesluten inuti en slinga med %<ordered%>-klausul med en parameter"
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "variabeln %qE är inte en iterator av den yttersta slingan %d, %qE förväntades"
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "antalet variabler i %<depend(sink)%>-klausulen stämmer inte med antalet iterationsvariabler"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr "mer än en %<depend(source)%>-klausul på en %<ordered%>-konstruktion"
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr "%<depend(source)%>-klausul angiven tillsammans med %<depend(sink:)%>-klausuler på samma konstruktion"
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<_Cilk_spawn%> förväntades före %<_Cilk_sync%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification misslyckades"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT konverteras till %qT när det skickas via %<...%>"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(alltså skall du skicka %qT och inte %qT till %<va_arg%>)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "om denna kod nås, kommer programmet att avbryta"
@@ -18705,8 +18737,9 @@
 msgstr "typer har olika parameterantal"
 
 #: ipa-devirt.c:1229
-#, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+#, fuzzy, gcc-internal-format
+#| msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "typen %qT själv bryter mot C++ endefinitionsregel"
 
 #: ipa-devirt.c:1235
@@ -18805,8 +18838,9 @@
 msgstr "ett fält med samma namn men annan typ är definierat i en annan översättningsenhet"
 
 #: ipa-devirt.c:1576
-#, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+#, fuzzy, gcc-internal-format
+#| msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr "fält har en annan layout i en annan översättningsenhet"
 
 #: ipa-devirt.c:1599
@@ -19187,198 +19221,198 @@
 msgid "multiple loop axes specified for routine"
 msgstr "multipla slingaxlar angivna för rutinen"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr "%<seq%> åsidosätter andra OpenACC-slingspecificerare"
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr "%<auto%> står i konflikt med andra OpenACC-slingspecificerare"
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr "den inre slingan använder samma OpenACC-parallellism som den omgivande slingan"
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr "argument är inte tillåtna på %qs-klausulen i OpenACC %<parallel%>"
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr "icke-OpenACC-konstruktion inuti OpenACC-rutin"
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr "icke-OpenACC-konstruktion inuti OpenACC-region"
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr "%<ordered simd threads%> måste vara nära inneslutet inuti en %<for simd%>-region"
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr "OpenMP-konstruktioner andra än %<#pragma omp ordered simd%> får inte inneslutna i en %<simd%>-region"
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr "endast %<distribute%>- eller %<parallel%>-regioner tillåts vara strikt inneslutna inuti en %<teams%>-region"
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr "en %<distribute%>-region måste vara strikt inneslutna inuti en %<teams%>-konstruktion"
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr "OpenACC-slingdirektiv måste vara associerade med en OpenACC-beräkningsregion"
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr "föräldralös %qs-konstruktion"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr "%<#pragma omp cancel for%> inuti %<nowait%> for-konstruktion"
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr "%<#pragma omp cancel for%> inuti %<ordered%> for-konstruktion"
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<#pragma omp cancel sections%> inuti %<nowait%>-sektionskonstruktion"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr "en %<%s taskgroup%>-konstruktion som inte är nära innesluten inuti en %<taskgroup%>-region"
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, gcc-internal-format
 msgid "invalid arguments"
 msgstr "ogiltiga argument"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr "%<%s %s%>-konstruktion inte nära innesluten inuti %qs"
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "barriärregion får inte vara nära innesluten inuti en arbetsdelande, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> eller %<taskloop%> region"
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "arbetsdelande region får inte vara nära innesluten inuti arbetsdelande, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> eller %<taskloop%> region"
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr "en %<master%>-region får inte vara nära innesluten inuti arbetsdelande, explicit %<task%> eller %<taskloop%> region"
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr "%<depend(%s)%> är bara tillåtet i %<omp ordered%>"
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr "en %<ordered%> konstruktion med %<depend%>-klausul måste vara nära innesluten inuti en %<ordered%>-slinga"
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr "ogiltig beroendesort i omp %<ordered%> %<depend%>"
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr "%<ordered%> %<simd%> måste vara nära innesluten inuti en %<simd%>-region"
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr "en %<ordered%> region får inte vara nära innesluten inuti en %<critical%>, %<ordered%>, explicit %<task%> eller %<taskloop%> region"
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr "en %<ordered%> region måste vara nära innesluten inuti en slingaregion med en %<ordered%>-klausul"
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr "en %<critical%> region får inte vara innesluten inuti en %<critical%> region med samma namn"
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr "%<teams%>-konstruktion inte vara nära innesluten inuti en %<target%>-konstruktion"
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr "OpenACC-region inuti OpenACC-rutin, nästad parallellism stödjs inte ännu"
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr "OpenACC-konstruktion inuti en icke-OpenACC-region"
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr "%s %qs-konstruktion inuti en %s %qs-region"
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr "%qs-konstruktion inuti en %qs-region"
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr "setjmp/longjmp inuti simd-konstruktion"
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr "ignorerar sink-klausul med ett avstånd som inte är en multipel av slingsteget"
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr "första avståndet måste vara i motsatt riktning mot slingiterationer"
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "ogiltig utgång från strukturerat %s-block"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "ogiltig ingång till strukturerat %s-block"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "ogiltig gren till/från strukturerat %s-block"
@@ -19463,7 +19497,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "kommandoradsflaggan %qs stödjs inte av denna konfiguration"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "argument saknas till %qs"
@@ -19619,127 +19653,139 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr "-fsanitize-address-use-after-scope förutsätter flaggan -fstack-reuse=none"
 
-#: opts.c:1410
+#: opts.c:1012
+#, fuzzy, gcc-internal-format
+#| msgid "transactional memory is not supported with non-call exceptions"
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "transaktionsminne stödjs inte i denna konfiguration"
+
+#: opts.c:1015
+#, fuzzy, gcc-internal-format
+#| msgid "transactional memory is not supported with non-call exceptions"
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "transaktionsminne stödjs inte i denna konfiguration"
+
+#: opts.c:1417
 #, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr "okända include_flags 0x%x skickade till print_specific_help"
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr "flaggan -fsanitize=all är inte giltig"
 
-#: opts.c:1642
+#: opts.c:1649
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "okänt argument till flaggan -f%ssanitize%s=: %q.*s; menade du %qs?"
 
-#: opts.c:1649
+#: opts.c:1656
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "okänt argument till flaggan -f%ssanitize%s=: %q.*s"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "argumentet %q.*s till --help är tvetydigt, var mer precis"
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "okänt argument till --help=-flagga: %q.*s"
 
-#: opts.c:2078
+#: opts.c:2085
 #, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr "HSA har inte aktiverats under konfigurationen"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr "flaggan -foffload-abi kan anges endast för en avlastande kompilator"
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "postjustering måste vara två upphöjt till ett litet tal, inte %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "okänd stackkontrollparameter %qs"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr "%<-gdwarf%s%> är tvetydigt; använd %<-gdwarf-%s%> för DWARF-version eller %<-gdwarf -g%s%> för felsökningsnivå"
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "dwarf-version %d stödjs inte"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: argument till --param skall ha formen NAMN=VÄRDE"
 
-#: opts.c:2371
+#: opts.c:2378
 #, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "ogiltigt --param-namn %qs; menade du %qs?"
 
-#: opts.c:2374
+#: opts.c:2381
 #, gcc-internal-format
 msgid "invalid --param name %qs"
 msgstr "ogiltigt --param-namn %qs"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "ogiltigt --param-värde %qs"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "målsystemet stödjer inte felsökningsutdata"
 
-#: opts.c:2513
+#: opts.c:2520
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "felsökningsformatet %qs står i konflikt med tidigare val"
 
-#: opts.c:2531
+#: opts.c:2538
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "okänd felsökningsnivå %qs"
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "felsökningsnivå %qs är för hög"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "när gräns för maximal storlek på core-fil hämtades: %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "när gräns för maximal storlek på core-fil sattes: %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "ej igenkänd felsökningsflagga för gcc: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: ingen flagga -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr "-Werror=%s: -%s är inte en flagga som styr varningar"
@@ -20085,7 +20131,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "register för %qD använt till flera globala registervariabler"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "står i konflikt med %qD"
@@ -20685,12 +20731,12 @@
 msgid "error closing %s: %m"
 msgstr "fel när %s stängdes: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr "självtester är inkompatibla med -E"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "självtester är inte aktiverade i detta bygge"
@@ -21603,47 +21649,47 @@
 msgid "in expansion of macro %qs"
 msgstr "i expansionen av makrot %qs"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i har flera EH-bågar"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr "BB %i kan inte kasta men har en EH-båge"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "BB %i:s sista sats har felaktigt satt lp"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "BB %i sakar en EH-båge"
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "Felaktig EH-båge %i->%i"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "BB %i saknar en båge"
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "BB %i har för många fall-igenom-bågar"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "BB %i har felaktig båge"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "BB %i har felaktig fall-igenom-båge"
@@ -21744,32 +21790,32 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr "målet stödjer inte atomär profiluppdatering, enkelläge valt"
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr "argument %u är noll där icke-noll förväntades"
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "i ett anrop till den inbyggda funktionen %qD"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "i ett anrop till funktionen %qD deklarerad här"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "saknad slingoptimering, slingräknaren kan spilla över"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr "iteration %s orsakar odefinierat beteende"
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr "i denna slinga"
@@ -22123,11 +22169,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -23094,7 +23140,7 @@
 msgid "type was previously declared %qE"
 msgstr "typen var tidigare deklarerad %qE"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> kan endast anges för en virtuell funktion"
@@ -23369,7 +23415,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "kompilatorn kan anta att adressen till %qD kommer alltid beräknas till %<true%>"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "föreslår parenteser runt tilldelning som används som sanningsvärde"
@@ -23988,62 +24034,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "extra typkvalificerare i formatargument (argument %d)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> förväntar sig argument av typen %<%s%s%>, men argument %d har typen %qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> förväntar sig ett matchande %<%s%s%>-argument"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> förväntar sig argument av typen %<%T%s%>, men argument %d har typen %qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> förväntar sig ett matchande %<%T%s%>-argument"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> är inte definierad som en typ"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> är inte definierad som %<long%> eller %<long long%>"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> är inte definierad som en typ"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> är inte definierad som en typ"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> är inte definierad som en typ"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> är inte definierad som en pekartyp"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "argumenten som skall formateras är inte %<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime-format kan inte formatera argument"
@@ -24144,7 +24190,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "upprepat %<@%> före Objective-C++-sträng"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "ej stödd konkatenering av strängliteraler som inte följer standard"
@@ -24174,7 +24220,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika variabler till minne"
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ogiltig typ för iterationsvariabeln %qE"
@@ -24189,22 +24235,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE är inte initierad"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "styrpredikat saknas"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "ogiltigt styrpredikat"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "utelämnat ökningsuttryck"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ogiltigt ökningsuttryck"
@@ -24749,8 +24795,8 @@
 msgid "wrong type argument to %s"
 msgstr "fel typ på argument till %s"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "spill i konstant uttryck"
@@ -25418,7 +25464,7 @@
 msgid "this condition has identical branches"
 msgstr "detta villkor har identiska grenar"
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "%<_Cilk_spawn%> kan endast anges inuti en funktion"
@@ -25578,7 +25624,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr "-march=%s: ISA-understräng som ej stödjs %qs"
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "okänd flagga -mdebug-%s"
@@ -25901,7 +25947,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%Kargument %d måste vara en konstant omedelbar"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%Kbanindex måste vara en konstant omedelbar"
@@ -25981,7 +26027,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "okänt värde %qs till -mtune"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "flaggan -mcpu=%s står i konflikt med flaggan -march=%s"
@@ -26066,9 +26112,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "målet %s %s=%s är ogiltigt"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "argument till attribut %<target%> är inte en sträng"
@@ -26154,7 +26200,7 @@
 msgstr "felaktigt värde %qs till flaggan -mmemory-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26328,234 +26374,234 @@
 msgid "insn addresses not freed"
 msgstr "instruktionsadressen inte frigjord"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "denna inbyggda stödjs inte på denna målarkitektur"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr "Du måste aktivera NEON-instruktioner (t.ex. -mfloat-abi=softfp -mfpu=neon) för att använda dessa inbyggda."
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Du måste aktivera VFP-instruktioner för att använda dessa inbyggda."
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr "Du måste aktivera kryptoinstruktioner (t.ex. inkludera -mfloat-abi=softfp -mfpu=crypto-neon …) för att använda dessa inbyggda."
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "en väljare måste vara en omedelbar"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "intervallet för väljaren skall vara inom 0 till 7"
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "intervallet för väljaren skall vara inom 0 till 3"
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "intervallet för väljaren skall vara inom 0 till 1"
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask måste vara en omedelbar"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "intervallet för masken skall vara i 0 till 255"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_rori_pi16 i koden."
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_rori_pi32 i koden."
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_ror_pi16 i koden."
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "intervallet för antal skall vara inom 0 till 32.  kontrollera den inbyggda _mm_ror_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "intervallet för antal skall vara inom 0 till 64.  kontrollera den inbyggda _mm_rori_si64 i koden."
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "intervallet för antal skall vara inom 0 till 64.  kontrollera den inbyggda _mm_ror_si64 i koden."
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srli_si64 i koden."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_slli_si64 i koden."
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srai_si64 i koden."
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_srl_si64 i koden."
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sll_si64 i koden."
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_pi16 i koden."
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_pi32 i koden."
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "antalet skall inte vara mindre än 0.  kontrollera den inbyggda _mm_sra_si64 i koden."
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt och NEON är inkompatibla"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "målprocessorn stödjer inte ARM-läge"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "aktivering av stöd för bakåtspårning är endast meningsfullt vid kompilering för Thumb"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "aktivering av stöd för anroparnätverkande är endast meningsfullt vid kompilering för Thumb"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g med -mno-apcs-frame ger kanske inte vettig felsökning"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr "iWMMXt stödjs inte i Thumb-läge"
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "det går inte att använda -mtp=cp15 med 16-bitars Thumb"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC är inkompatibel med Thumb"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr "-mslow-flash-data stödjer endast icke-pic-kod på armv7-m-mål"
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr "-mpure-code stödjer endast icke-pic-kod på armv7-m-mål"
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "målprocessorn stödjer inte THUMB-instruktioner"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "målprocessorn stödjer inte ojusterade åtkomster"
@@ -26562,141 +26608,141 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mfpu=auto stödjs för närvarande inte utan en explicit CPU."
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "målprocessorn stödjer inte interworking"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check är inkompatibel med -mno-apcs-frame"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic och -mapcs-reent är inkompatibla"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS-återanropsbar kod stödjs inte.  Ignoreras"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "valda fp16-alternativ är inkompatibla"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt kräver ett AAPCS-kompatibelt ABI för att fungera riktigt"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt-abi kräver en CPU som klarar iwmmxt"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS stödjer inte -mcaller-super-interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS stödjer inte -mcallee-super-interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 och ingen ldrh"
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard: den valda processorn saknar en FPU"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard och VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "storleksgräns för poster kan bara sättas till 8, 32 eller 64"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "storleksgräns för poster kan bara sättas till 8 eller 32"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "RTP PIC är inkompatibelt med -msingle-pic-base"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= är oanvändbar utan -fpic"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "kan inte använda ”%s” som PIC-register"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition stödjs inte på denna arkitektur"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "målprocessorn stödjer inte ARMv8-M:s säkerhetstillägg"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "icke-AAPCS-härledd PCS-variant"
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "variadiska funktioner måste använda bas-AAPCS-varianten"
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS-variant"
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 hårda flyttals VFP ABI"
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "parameterskickandet för argument av typen %qT ändrades i GCC 7.1"
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -26704,72 +26750,77 @@
 msgid "%qE attribute only applies to functions"
 msgstr "attributet %qE är bara tillämpligt på funktioner"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "attributet %qE är inte tillgängligt för funktioner med argument som skickas på stacken"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "attributet %qE är inte tillgängligt för funktioner med ett variabelt antal argument"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "attributet %qE är inte tillgängligt för funktioner som returnerar ett värde på stacken"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "attributet %qE ignorerat utan flaggan -mcmse."
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "attributet %qE har ingen effekt på funktioner med statisk länkklass"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "attributet %qE är bara tillämpligt på bastypen av en funktionspekare"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K%s %wd utanför intervall %wd - %wd"
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "%s %wd utanför intervall %wd - %wd"
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "kan inte beräkna verklig plats för stackparameter"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Oväntat långt thumb1-hopp"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "inga låga register tillgängliga för att poppa höga register"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "avbrottshanteringsrutiner kan inte kodas i Thumb-läge"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr "-fstack-check=specific för Thumb-1"
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr "ogiltig fpu för attribute(target(\"%s\"))"
@@ -26777,13 +26828,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatiskt fpu-val är för närvarande inte tillåtet här"
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) är okänt"
@@ -26877,163 +26928,176 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr "funktionsattributen %qs och %qs har ingen effekt på funktionen %qs"
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "funktionen %qs kan inte ha argument"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktionen %qs kan inte returnera ett värde"
 
-#: config/avr/avr.c:1084
-#, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+#: config/avr/avr.c:1085
+#, fuzzy, gcc-internal-format
+#| msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs verkar vara en felstavad %s-hanterare, prefixet __vector saknas"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> innehåller bara 2 byte adress"
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "pekarförskjutning från symbol kan vara oriktig"
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "åtkomst av dataminne med programminnesadress"
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "åtkomst av programminne med dataminnesadress"
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "fast register %s använt för att skicka en parameter till en funktion"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "skrivning till adressrymden %qs stödjs inte"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "attributet %qE är bara tillämpligt på variabler med statisk lagringsklass"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "attributet %qE stödjs bara för reducerade Tiny-kärnor"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "attributet %qE är bara tillämpligt på variabler"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "attributet %qE tillåter endast en heltalskonstant som argument"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr "adressen till attributet %qE är utanför giltigt intervall"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "både attributet %s och %qE anger en adress"
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "attributet %qE på en icke-volatile variabel"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "adressrymder stödjs inte för reducerade Tiny-enheter"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "adressrymden %qs stödjs inte för enheter med flash-storlek upp till %d KiB"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "pekare med mål i adressrymden %qs måste vara konstanta i %qT"
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "pekare med mål i adressrymden %qs måste vara konstanta i %s %q+D"
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "variabeln %q+D måste vara const för att kunna läggas i en endast läsbar sektion med hjälp av %qs"
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr "statisk IO-deklaration för %q+D behöver en adress"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr "IO-definition för %q+D behöver en adress"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "bara oinitierade variabler kan placeras i sektionen .noinit"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
+#, fuzzy, gcc-internal-format
+#| msgid "uninitialized variable %q+D put into program memory area"
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "den oinitierade variabeln %q+D placerad i programminnesområdet"
+
+#: config/avr/avr.c:10160
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "den oinitierade variabeln %q+D placerad i programminnesområdet"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D har inkompatibla attribut %qs och %qs"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "arkitekturen %qs stödjs endast i assembler"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "konvertering från adressrymd %qs till adressrymd %qs"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s förväntar sig ett heltal konstant vid kompileringstillfället"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s förväntar sig ett långt heltal konstant vid kompileringstillfället som första argument"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "avrundning till %d bitar har ingen effekt för flyttalsvärde med %d decimalbitar"
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "avrundningsresultatet kommer alltid bli 0"
@@ -27316,12 +27380,12 @@
 msgid "invalid IACC argument"
 msgstr "ogiltigt IACC-argument"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs förväntar sig ett konstant argument"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "konstant argument utanför intervallet för %qs"
@@ -27499,7 +27563,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "kodmodellen %qs stödjs inte i x32-läge"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "kodmodellen %s stödjer inte PIC-läge"
@@ -27633,287 +27697,287 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> ignoreras i 64-bitsläge"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary stödjs inte för denna målarkitektur"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d är inte mellan %d och %d"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d är inte mellan %d och 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount är inte kompatibelt med denna målarkitektur"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount är inte implementerat för -fPIC"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> använd utan SSE aktiverat"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> använt utan SSE aktiverat"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "instruktionsuppsättningen SSE avaktiverad, använder 387-aritmetik"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "instruktionsuppsättningen 387 avaktiverad, använder SSE-aritmetik"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stackavkänning kräver %<-maccumulate-outgoing-args%> för att bli korrekt"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stackavkänning kräver %<target(\"accumulate-outgoing-args\")%> för att bli korrekt"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "fasta ebp-register kräver %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "fasta ebp-register kräver %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry stödjs inte för 32 bitar i kombination med -fpic"
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry är inte kompatibelt med SEH"
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "okänt alternativ till -mrecip=%s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(”%s”) var redan angivet"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Endast felsökningsformatet DWARF stödjs för avbrottshanteringsrutiner."
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "%s-instruktioner är inte tillåtna i en %s-hanteringsrutin"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "%s-instruktioner är inte tillåtna i en funktion utan något attribut no_caller_saved_registers"
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attributen fastcall och regparm är inte kompatibla"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attributen regparam och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "attributet %qE kräver en heltalskonstant som argument"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "argument till attributet %qE är större än %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attributen fastcall och cdecl är inte kompatibla"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attributen fastcall och stdcall är inte kompatibla"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attributen fastcall och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attributen stdcall och cdecl är inte kompatibla"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attributen stdcall och fastcall är inte kompatibla"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attributen stdcall och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attributen cdecl och thiscall är inte kompatibla"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "attributet %qE används för annat än klassmetod"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qD med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "anrop av %qT med attributet sseregparm utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 stödjer inte attributet ms_abi"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue är inte kompatibelt med nästade funktioner"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorargument utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F-vektorretur utan AVX512F aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-vektorargument utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-vektorretur utan AVX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-vektorargument utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-vektorretur utan SSE aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-vektorargument utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-vektorretur utan MMX aktiverat ändrar ABI:et"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med en flexibel vektormedlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI:et för att skicka unioner med long double har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI:et för att skicka en post med complex float medlem har ändrats i GCC 4.4"
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-registerretur med SSE avaktiverat"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-registerargument med SSE avaktiverat"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-registerretur med x87 avaktiverat"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "anrop av %qD med SSE-anropskonvention utan SSE/SSE2 aktiverat"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "detta är ett fel i GCC som kan gås runt genom att lägga till attributet used till den anropade funktionen"
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI:et för att skicka parametrar med %d-bytejustering har ändrats i GCC 4.6"
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "attributet ms_hook_prologue är inte kompatibelt med -mfentry i 32-bitsläge"
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "Dynamic Realign Argument Pointer (DRAP) stödjs inte i avbrottshanteringsrutiner.  Detta kan gås runt genom att undvika funktioner med sammansatta returvärden."
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack stödjer inte fastcall med nästade funktioner"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack stödjer inte 2 registerparametrar för en nästad funktion"
@@ -27920,298 +27984,298 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack stödjer inte 3 registerparametrar"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "ej stödd storlek för heltalsregister"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "utökade register har inga höga halvor"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ej stödd operandstorlek för utökat register"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "operand som inte är heltal använt med operandkod ”z”"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "avbrottshanteringsrutiner kan inte anropas direkt"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Ingen avsändare funnen för versionsattributen"
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Ingen avsändare funnen för %s"
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Ingen avsändare funnen för versionsattributen: %s"
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Funktionsversioner kan inte markeras som gnu_inline, kropparna måste vara genererade"
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionering av virtuell funktion stödjs inte"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr "saknat attribut %<target%> för flerversioners %D"
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "tidigare deklaration av %D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "multiversionering behöver ifunc som inte stödjs på detta mål"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Parameter till inbyggd måste vara en strängkonstant eller -literal"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Parameter till inbyggd är inte giltig: %s"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "det sista argumentet måste vara en 2-bitars omedelbar"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "det femte argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "det tredje argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "det sista argumentet måste vara en 3-bitars omedelbar"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "det sista argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "det sista argumentet måste vara en 1-bits omedelbar"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "det sista argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "det näst sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "det sista argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "det tredje argumentet måste vara en jämförelsekonstant"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "felaktigt jämförelsesätt"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "felaktig avrundningsoperand"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 4-bitars omedelbar"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 5-bitars omedelbar"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "det omedelbara argumentet måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "det sista argumentet måste vara en 32-bitars omedelbar"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "väljaren måste vara en heltalskonstant i intervallet 0..%wi"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE behöver en okänd isa-flagga"
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE behöver isa-flaggan %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "sista argumentet måste vara en omedelbar"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "det sista argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "det fjärde argumentet ha skala 1, 2, 4, 8"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "felaktig tipsoperand"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "argumentet till xabort måste vara en 8-bitars omedelbar"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "attributet %qE är bara tillgängligt för 32 bitar"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumentet till attributet %qE är varken noll eller ett"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "attributen ms_abi och sysv_abi är inte kompatibla"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibelt attribut ignorerat"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "avbrottshanteringsrutiner skall ha en pekare som första argument"
 
 # "unsigned %sint" är tänkt att expanderas till C-syntax
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "avbrottshanteringsrutiner skall ha unsigned %sint som andra argument"
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "avbrottshanteringrutiner kan endast ha ett pekarargument och ett valfritt heltalsargument"
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "avbrottshanteringsrutiner kan inte ha ett annat returvärde än void"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "alternativ är inte tillåtna i asm-flaggutdata"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "okänd asm-flaggutdata %qs"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "ogiltigt typ för asm-flaggutdata"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "Okänd arkitekturspecifik minnesmodell"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE används inte med ACQUIRE eller starkare minnesmodell"
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE används inte med RELEASE eller starkare minnesmodell"
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "ej stödd simdlen: %d"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr "returtyp %qT stödjs ej för simd\n"
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "argumenttyp %qT som inte stödjs till simd\n"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Pekarkontrolleraren kräver stöd för MPX på detta mål.  Använd flaggan -mmpx för att aktivera MPX."
@@ -28331,7 +28395,7 @@
 msgid "argument %qd is not a constant"
 msgstr "argumentet %qd är inte en konstant"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, null-pekare"
@@ -28341,7 +28405,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: Okänd interpunktion '%c'"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND null-pekare"
@@ -28442,7 +28506,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread är tillgängligt endast för fido"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "stackgränsuttryck stödjs inte"
@@ -28949,8 +29013,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr "MSP430 inbyggda funktioner fungerar endast inuti avbrottshanterare"
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr "felaktig inbyggd kod"
@@ -29201,27 +29265,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr "PTX stödjer inte svaga deklarationer (endast svaga definitioner)"
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "attributet %qE kräver returtypen void"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "attributet %qE är inte tillåtet med lagringsklassen auto"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr "använder vector_length (%d), ignorerar %d"
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr "använder vector_length (%d), ignorerar körtidsinställningen"
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "använder num_workers (%d), ignorerar %d"
@@ -29246,7 +29310,7 @@
 msgid "-g option disabled"
 msgstr "flaggan -g är avslagen"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "justering (%u) för %s överskrider maximal justering för globala common-data.  Använder %u"
@@ -29381,157 +29445,157 @@
 msgid "junk at end of #pragma longcall"
 msgstr "skräp vid slutet av #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr bör undvikas för omvänd byteordning; använd tilldelning för ojusterade laddningar och lagringar"
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_mul tar endast 2 argument"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_cmpne tar endast 2 argument"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_adde tar endast 3 argument"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_addec tar endast 3 argument"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s tar endast %d argument"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s tar endast ett argument"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s tar bara 2 argument"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract tar endast 2 argument"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert tar endast 3 argument"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "att skicka argument %d till %qE kastar kvalificerare från pekarmåltyp"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "Den inbyggda funktionen %s stödjs inte i denna kompilatorkonfiguration"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "ogiltigt parameterkombination för inbyggd %s i AltiVec"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr "-mrecip kräver -ffinite-math eller -ffast-math"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr "-mrecip kräver -fno-trapping-math eller -ffast-math"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr "-mrecip kräver -freciprocal-math eller -ffast-math"
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 kräver PowerPC64-arkitektur, aktiverar"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power stödjs inte för 64-bitars Darwin, det är inkompatibelt med de installerade C- och C++-biblioteken"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr "kommer inte generera power9-instruktioner för att assemblern saknar stöd för power9"
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr "kommer inte generera power8-instruktioner för att assemblern saknar stöd för power8"
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr "kommer inte generera power7-instruktioner för att assemblern saknar stöd för power7"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr "kommer inte generera power6-instruktioner för att assemblern saknar stöd för power6"
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr "kommer inte generera power5-instruktioner för att assemblern saknar stöd för power5"
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr "inte konfigurerad för SPE-ABI"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr "inte konfigurerad för instruktionsuppsättningen SPE"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "målattribut eller pragma ändrar SPE ABI"
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec stödjs inte på denna målarkitektur"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "SPE stödjs inte på denna målarkitektur"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple stödjs inte på system med omvänd byteordning"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring stödjs inte på system med omvänd byteordning"
@@ -29538,67 +29602,67 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "-mpower9-minmax är inkompatibel med uttryckligen avaktiverade flaggor"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr "Målflaggan för power9 är inkompatibel med -mcpu=<xxx> för <xxx> som är mindre än power9"
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr "-mcrypto behöver -maltivec"
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr "-mdirect-move behöver -mvsx"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr "-mpower8-vector behöver -maltivec"
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr "-mpower8-vector behöver -mvsx"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr "-mvsx-timode behöver -mvsx"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "-mhard-dfp behöver -mhard-float"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "-mupper-regs-df behöver -mvsx"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "-mupper-regs-di behöver -mvsx"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr "-mupper-regs-sf behöver -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr "-mpower8-fusion-sign behöver -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr "-mtoc-fusion behöver -mpower8-fusion"
@@ -29607,514 +29671,519 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "-mpower9-fusion behöver -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr "-mpower9-vector behöver -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr "-mpower9-dform behöver -mpower9-vector"
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar kräver -mdirect-move"
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr "-mpower9-dform behöver -mupper-regs-df"
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr "-mpower9-dform behöver -mupper-regs-sf"
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr "-mvsx-timode kan behöva -mlra"
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr "-mallow-movmisalign behöver -mvsx"
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr "-mefficient-unaligned-vsx behöver -mvsx"
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr "-mefficient-unaligned-vsx behöver -mallow-movmisalign"
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr "-mvsx-small-integer kräver -mpower8-vector, -mupper-regs-di och -mdirect-move"
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "målattribut eller pragma ändrar storlek på long double"
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr "-mfloat128 behöver VSX-stöd"
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr "-mfloat128-type behöver VSX-stöd"
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr "-mfloat128 behöver -mfloat128-type"
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr "-mfloat128-hardware behöver -mfloat128-type"
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr "-mfloat128-hardware behöver fullt ISA 3.0-stöd"
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr "-mfloat128-hardware behöver -m64"
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr "okänd ABI-typ (%s) till vektoriseringsbibliotek för flaggan -mveclibabi="
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "målattribut eller pragma ändrar AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "målattribut eller pragma ändrar darwin64 ABI"
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "målattribut eller pragma ändrar enkel precisions flyttal"
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "målattribut eller pragma ändrar dubbel precisions flyttal"
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs är inte ett giltigt tal i -mstack-protector-guard-offset="
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs är inte ett giltigt avstånd i -mstack-protector-guard-offset="
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs är inte ett giltigt basregister i -mstack-protector-guard-reg="
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr "-mstack-protector-guard=tls behöver ett giltigt basregister"
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "layouten av aggregat som innehåller vektorer med %d-bytejustering har ändrats i GCC 5"
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor returnerad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "det går inte att returnera värde i vektorregister för att altivec-instruktioner är avaktiverade, använd -maltivec för att aktivera dem"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI:et för att skicka aggregat med %d-bytejustering har ändrats i GCC 5"
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "det går inte att skicka argument i vektorregister för att altivec-instruktioner är avaktiverade, använd -maltivec för att aktivera dem"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI:et för att skicka homogena flyttalsaggregat har ändrats i GCC 5"
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-vektor skickad som referens: icke-standard ABI-utökning utan kompatibilitetsgaranti"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "internt fel: den inbyggda funktionen %s redan bearbetad"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argument 1 måste vara ett 8-bitars fältvärde"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argument 1 måste vara en 5-bitars literal med tecken"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argument 2 måste vara en 5-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argument 1 måste vara en 6-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "argument 2 måste vara en 7-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "argumentet 1 till __builtin_altivec_predicate måste vara en konstant"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "argument 1 till __builtin_altivec_predicate är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "inbyggd %s är endast giltigt i 64-bitsläge"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "argument %d måste vara en literal utan tecken"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argument %d är en literal utan tecken som är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr "den inbyggda %s tar endast ett strängargument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr "cpu %s är ett ogiltigt argument till den inbyggda %s"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "hwcap %s är ett ogiltigt argument till den inbyggda %s"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argument 3 måste vara en 4-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argument 3 måste vara en 2-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argument 3 måste vara en 1-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "argument 1 måste vara 0 eller 2"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argument 1 måste vara en 1-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argument 2 måste vara en 6-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "argument 2 måste vara 0 eller 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "argument 3 måste vara i intervallet 0..15"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argument till %qs måste vara en 2-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ej upplöst överlagring för inbyggd Altivec %qF"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "argument till dss måste vara en 2-bitars literal utan tecken"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr "andra argumentet till vec_vextract4b måste vara 0..12"
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, gcc-internal-format
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "tredje argumentet till vec_vinsert4b måste vara 0..12"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "argument 1 till __builtin_paired_predicate måste vara en konstant"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "argument 1 till __builtin_paired_predicate är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "argument 1 till __builtin_spe_predicate måste vara en konstant"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "argument 1 till __builtin_spe_predicate är utanför sitt intervall"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "Den inbyggda funktionen %s är endast giltig för cell-processorn"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mvsx"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mhtm"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -maltivec"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mpaired"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mspe"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "Den inbyggda funktionen %s behöver flaggorna -mhard-dfp och -mpower8-vector"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mhard-dfp"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mpower8-vector"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "Den inbyggda funktionen %s behöver flaggorna -mcpu=power9 och -m64"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mcpu=power9"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "Den inbyggda funktionen %s behöver flaggorna -mhard-float och -mlong-double-128"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mhard-float"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "Den inbyggda funktionen %s behöver flaggan -mfloat128"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "Den inbyggda funktionen %s stödjs inte med de aktuella flaggorna"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "internt fel: inbyggd funktion %s hade en oväntad returtyp %s"
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "internt fel: inbyggd funktion %s, argument %d har en oväntad argumenttyp %s"
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "för stor stackram"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack använder register r29"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "Stackramar större än 2 G stödjs inte med -fsplit-stack"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "ingen profilering av 64-bitskod för detta ABI"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Du kan inte ta adressen till en nästad funktion om du använder flaggan -mno-pointers-to-nested-functions"
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "användning av %<long double%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "användning av booleaner i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "användning av %<complex%> i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "användning av decimala flyttalstyper i AltiVec-typer är ogiltigt"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "användning av %<long%> i AltiVec-typer är ogiltigt för 64-bitskod utan -mvsx"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "användning av %<long%> i AltiVec-typer bör undvikas, använd %<int%>"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "användning av %<long long%> i AltiVec-typer är ogiltigt utan -mvsx"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "användning av %<double%> i AltiVec-typer är ogiltigt utan -mvsx"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "matar ut mikrokodsinstruktion %s\t[%s] nr %d"
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "matar ut villkorlig mikrokodsinstruktion %s\t[%s] nr %d"
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "felaktig cpu ”%s” för %s”%s”%s"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s”%s”%s är inte tillåtet"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s”%s”%s är ogiltigt"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr "-mno-%s slår av -m%s"
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr "-mno-power9-vector slår av -mpower9-dform"
@@ -30301,6 +30370,7 @@
 msgstr "-mcall-aixdesc är inkompatibel med -mabi=elfv2"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 kräver en PowerPC64-CPU"
@@ -30392,7 +30462,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr "inbyggd vec_step kan endast användas på vektortyper."
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "konstant värde behövs till den inbyggda %qF argument %d"
@@ -30418,8 +30488,9 @@
 msgstr "%qF behöver -mvx"
 
 #: config/s390/s390-c.c:889
-#, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+#, fuzzy, gcc-internal-format
+#| msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr "%qF behöver -march=arch12 eller högre"
 
 #: config/s390/s390-c.c:903
@@ -30438,8 +30509,9 @@
 msgstr "tvetydig överlagring för den inbyggda %qs"
 
 #: config/s390/s390-c.c:966
-#, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+#, fuzzy, gcc-internal-format
+#| msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr "%qs-matchning kräver -march=arch12 eller högre"
 
 #: config/s390/s390-c.c:972
@@ -30452,160 +30524,161 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "det konstanta argumentet %d till den inbyggda %qF är utanför intervallet för måltypen"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "det konstanta argumentet %d till den inbyggda %qF ligger utanför intervallet (0.."
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "det konstanta argumentet %d till den inbyggda %qF ligger utanför intervallet ("
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr "inbyggd %qF stödjs inte utan -mhtm (standard med -march=zEC12 och högre)."
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr "inbyggd %qF behöver -mvx (standard med -march=z13 och högre)."
 
-#: config/s390/s390.c:850
-#, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+#: config/s390/s390.c:853
+#, fuzzy, gcc-internal-format
+#| msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr "Inbyggd %qF kräver arch12 eller högre."
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "ej upplöst överlagrad inbyggd"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "felaktig inbyggd icode"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "ogiltigt argument %d till den inbyggda %qF"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "begärt attribut %qE är inte ett kommaseparerat par av ickenegativa heltalskonstanter eller för stort (max. %d)"
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "totala storleken på lokala variabler överskrider arkitekturens gräns"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket överskrider användarens valda stackgräns på %d byte.  En ovillkorlig fälla läggs till."
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "ramstorleken för funktionen %qs är %wd byte vilket är mer än hälften av stackstorleken.  Den dynamiska kontrollen skulle inte vara pålitlig.  Ingen kontroll läggs ut för denna funktion."
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "ramstorlek på %qs är %wd byte"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs använder dynamisk stackallokering"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr "CPU:er äldre än z900 stödjs inte med -fsplit-stack"
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr "%sarch=%s%s bör undvikas och kommer tas bort i framtida utgåvor; använd åtminstone %sarch=z900%s"
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr "%stune=%s%s bör undvikas och kommer tas bort i framtida utgåvor; använd åtminstone %stune=z900%s"
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture-läge stödjs inte på %s"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bits ABI stödjs inte i ESA/390-läge"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "vektorstöd i hårdvara är inte tillgängliga på %s"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr "stöd för hårdvaruvektorer är inte tillgängligt med -msoft-float"
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "hårdvaruinstruktioner för decimala flyttal är inte tillgängliga på %s"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "hårdvaruinstruktioner för decimalflyttal är inte tillgängliga i läget ESA/390"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp kan inte användas tillsammans med -msoft-float"
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float stödjs inte i kombination"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "stackstorlek måste vara större än stackvaktsvärdet"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "stackstorlek får inte vara större än 64 k"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard implicerar användning av -mstack-size"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumenten till %qs skall vara ickenegativa heltal"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "argumentet till %qs är för stort (max. %d)"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "värdet %qs stödjs inte av attributet %<target%>"
@@ -30662,27 +30735,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax stödjs endast för RTP PIC"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s stödjs inte i denna konfiguration"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 är inte tillåten med -m64"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "felaktigt värde (%s) till flaggan -mcmodel="
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= stödjs inte på 32-bitars system"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "-fcall-saved-REG stödjs inte för utregister"
@@ -30970,22 +31044,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "ogiltig konstant i %<#pragma %s%>"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "booleska register krävs för flyttalsalternativet"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "-f%s stödjs inte med CONST16-instruktioner"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "PIC krävs men stödjs inte med CONST16-instruktioner"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "endast oinitierade variabler kan placeras i en .bss-sektion"
@@ -31072,7 +31146,7 @@
 msgid "could not read the BRIG file"
 msgstr "det gick inte att läsa BRIG-filen"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -31475,9 +31549,9 @@
 msgstr "etikett %qD är definierad här"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD är deklarerad här"
@@ -31610,7 +31684,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> är inte tillåtet annat än inom en funktionsprototyp"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D i deklarationsmålsdirektiv har inte en avbildbar typ"
@@ -32655,7 +32729,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "två eller fler datatyper i deklaration av specificerare"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> är för långt för GCC"
@@ -32795,17 +32869,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C stödjer inte bara %<complex%> i meningen %<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C stödjer inte komplexa heltalstyper"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-kombinerare refererar variabeln %qD som inte är varken %<omp_out%> eller %<omp_in%>"
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-initierare refererar till variabeln %qD som inte är varken %<omp_priv%> eller %<omp_orig%>"
@@ -32855,7 +32929,7 @@
 msgid "version control conflict marker in file"
 msgstr "markör för versionshanteringskonflikt i filen"
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "oväntat radslut"
@@ -32896,7 +32970,7 @@
 msgstr "okänt typnamn %qE"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "deklarationsspecificerare förväntades"
@@ -32911,7 +32985,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, identifierare eller %<(%> förväntades"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "prefixattribut ignoreras för metoder"
@@ -32926,8 +33000,8 @@
 msgid "unexpected attribute"
 msgstr "oväntat attribut"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "attributet %<fallthrough%> följs inte av %<;%>"
@@ -32965,7 +33039,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kan endast användas med en ensam deklarerare"
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> eller %<;%> förväntades"
@@ -32993,7 +33067,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 stödjer inte %<_Static_assert%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "strängkonstant förväntades"
@@ -33057,14 +33131,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "identifierare förväntades"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "komma i slutet av uppräkningslista"
@@ -33199,7 +33273,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> förväntades före %<else%>"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> utan ett föregående %<if%>"
@@ -33224,12 +33298,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr "en etikett kan endast vara en del av en sats och en deklaration är inte en sats"
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr "-fcilkplus måste vara aktiverat för att använda %<_Cilk_for%>"
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr "-fcilkplus måste vara aktiverat för att använda %<_Cilk_sync%>"
@@ -33243,17 +33317,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "sats förväntades"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<if%>-sats"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "föreslår klamrar runt tom kropp i en %<else%>-sats"
@@ -33263,7 +33337,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr "if-satser kan inte innehålla %<Cilk_spawn%>"
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "föreslår uttryckliga klamrar för att undvika tvetydighet i %<else%>"
@@ -33283,7 +33357,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ogiltigt iterationsvariabel i snabb uppräkning"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "slingvillkor saknas i slinga med %<GCC ivdep%>-pragma"
@@ -33459,17 +33533,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "operander till %<__builtin_complex%> av olika typer"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "fel antal argument till %<__builtin_shuffle%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr "-fcilkplus måste vara aktiverat för att använda %<_Cilk_spawn%>"
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr "konsekutiva %<_Cilk_spawn%>-nyckelord är inte tillåtet"
@@ -33524,61 +33598,61 @@
 msgid "no type or storage class may be specified here,"
 msgstr "ingen typ eller lagringsklass kan anges här,"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "okänt egenskapsattribut"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<getter%>)"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<=%> saknas (efter attributet %<setter%>)"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "attributet %<setter%> kan bara anges en gång"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter-namn måste avslutas med %<:%>"
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "attributet %<getter%> kan bara anges en gång"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> får bara användas i sammansatta satser"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> måste ha filräckvidd"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> får bara användas i %<#pragma omp sections%>-konstruktion"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- eller do-sats förväntades"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> måste komma först"
@@ -33593,12 +33667,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "%<#pragma grainsize%> måste vara inuti en funktion"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "för många %qs-klausuler"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "heltalsuttryck förväntades före ”)”"
@@ -33613,53 +33687,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD är inte en variabel"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD är inte en pekarvariabel"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "collapse-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, gcc-internal-format
 msgid "expected %<none%>"
 msgstr "%<none%> förväntades"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> eller %<shared%> förväntades"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> eller %<exit%> förväntades"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> förväntades"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "för många %<if%>-klausuler med %qs-modifierare"
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "för många %<if%>-klausuler"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "för många %<if%>-klausuler utan modifierare"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "om någon %<if%>-klausul har en modifierare måste alla %<if%>-klausuler använda modifierare"
@@ -33687,22 +33761,22 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_tasks%>-värdet måste vara positivt"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<grainsize%>-värdet måste vara positivt"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<priority%>-värdet måste vara positivt"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "%<tofrom%> förväntades"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "%<scalar%> förväntades"
@@ -33712,57 +33786,57 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "%<num_workers%>-värdet måste vara positivt"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "för många %<static%>-argument"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "oväntat argument"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%qs-värdet måste vara positivt"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumentet till %<tile%> behöver en positiv heltalskonstant"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "ordered-argument behöver ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> eller identifierare förväntades"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "både %<monotonic%>- och %<nonmonotonic%>-modifierare angivna"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "%<runtime%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "%<auto%>-schemaläggning tar ingen %<chunk_size%>-parameter"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "värdet på styckesstorleken måste vara positivt"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ogiltig schedule-sort"
@@ -33777,17 +33851,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_teams%>-värdet måste vara positivt"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<thread_limit%>-värdet måste vara positivt"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%<aligned%>-klausulens justeringsuttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr "att använda parametrar för %<linear%>-steg stödjs inte än"
@@ -33807,17 +33881,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%<simdlen%>-klausulens uttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ogiltig depend-sort"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ogiltig map-sort"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ogiltig dist_schedule-sort"
@@ -33827,67 +33901,67 @@
 msgid "invalid proc_bind kind"
 msgstr "ogiltig proc_bind-sort"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma acc%>-klausul förväntades"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs är inte giltigt för %qs"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs måste vara den första klausulen i %qs"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%>-klausul förväntades"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "inga giltiga klausuler angivna i %<#pragma acc declare%>"
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "vektorsektionen i %<#pragma acc declare%>"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "%qD måste vara en global variabel i %<#pragma acc declare link%>"
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ogiltig OpenACC-klausul vid filräckvidd"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<extern%>-variabel %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ogiltig användning av %<global%>-variabeln %qD i %<#pragma acc declare%>"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "variabeln %qD använd mer än en gång med %<#pragma acc declare%>"
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<data%> förväntades efter %<#pragma acc %s%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> har ingen dataflyttningsklausul"
@@ -33902,7 +33976,7 @@
 msgid "expected function name"
 msgstr "ett funktionsnamn förväntades"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD refererar inte till en funktion"
@@ -33912,42 +33986,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> följs inte omedelbart av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> redan använd på %qD"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före användning"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> måste vara tillämpad före definitionen"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> måste innehålla åtminstone en %<device%>- eller %<host%>- eller %<self%>-klausul"
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ogiltig form på %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ogiltig operator för %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> använder två olika uttryck till minne"
@@ -33957,27 +34031,27 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> eller filslut förväntades"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-klausulparameter är mindre än %<collapse%>"
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "en %<linear%>-klausul får inte anges tillsammans med en %<ordered%>-klausul med en parameter"
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for-sats förväntades"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "_Cilk_for-sats förväntades"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "iterationsdeklaration eller initiering förväntades"
@@ -33987,72 +34061,72 @@
 msgid "not enough perfectly nested loops"
 msgstr "inte tillräckligt med perfekt nästade slingor"
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "kollapsade slingor inte perfekt nästade"
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterationsvariabel %qD får inte vara firstprivate"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "en %<ordered%>-klausul med parameter får inte anges på en %qs-konstruktion"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> med %<depend%>-klausul får bara användas i sammansatta satser"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> förväntades efter %qs"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> förväntades"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> måste innehålla åtminstone en %<from%>- eller %<to%>-klausul"
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> med en annan map-typ än %<to%> eller %<alloc%> på %<map%>-klausul"
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> med en annan map-typ än %<from%>-, %<release%>- eller %<delete%> på %<map%>-klausul"
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> måste innehålla åtminstone en %<map%>-klausul"
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> med en annan map-typ än %<to%>, %<from%>, %<tofrom%> eller %<alloc%> på %<map%>-klausul"
@@ -34067,7 +34141,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> måste följas av en funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr "%<#pragma omp declare simd%> eller %<simd%>-attribut kan inte användas i samma funktion som är markerad som en Cilk Plus SIMD-aktiverad funktion"
@@ -34077,32 +34151,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en funktionsdefinition eller -deklaration"
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en ensam funktionsdeklaration eller -definition"
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> med klausuler mellan %<#pragma omp declare target%> utan klausuler och %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD angivet både i deklarationsmålets %<link%>- och %<to%>-klausuler"
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> förväntades"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> förväntades"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma omp end declare target%> utan en motsvarande %<#pragma omp declare target%>"
@@ -34157,22 +34231,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "en av initierarens anropsargument skall vara %<&omp_priv%>"
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> eller %<reduction%> eller %<target%> förväntades"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE är deklarerad %<threadprivate%> efter första användningen"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatisk variabel %qE kan inte vara %<threadprivate%>"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE har ofullständig typ"
@@ -34187,52 +34261,52 @@
 msgid "pragma simd must be inside a function"
 msgstr "pragma simd måste vara inuti en funktion"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "vektorlängd måste vara en heltalskonstant"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "vektorlängd måste vara en potens av 2"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "stegstorleken måste vara ett konstant heltalsuttryck eller en heltalsvariabel"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "%<#pragma simd%>-klausul förväntades"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma cilk grainsize%> följs inte av %<_Cilk_for%>"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> utan att stöd för transaktionsminne är aktiverat"
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> inom en %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "yttre %<__transaction_cancel%> som inte är inom en yttre %<__transaction_atomic%>"
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  eller en %<transaction_may_cancel_outer%>-funktion"
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> inte inom %<__transaction_atomic%>"
@@ -34242,7 +34316,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "basen av vektorsektionen måste vara en pekar- eller vektortyp"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "%<:%> eller tal förväntades"
@@ -34957,7 +35031,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "vänsterhandssida av initiering kan vara en kandidat för ett formatattribut"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "returtypen kan vara en kandidat för ett formatattribut"
@@ -35285,7 +35359,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C förbjuder %<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "funktion deklarerad %<noreturn%> har en %<return%>-sats"
@@ -35295,7 +35369,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "vektornotationsuttryck kan inte användas som ett returvärde"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr "användning av %<_Cilk_spawn%> i en retursats är inte tillåtet"
@@ -35320,7 +35394,7 @@
 msgid "function returns address of label"
 msgstr "funktionen returnerar adress till en etikett"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-argument är inte ett heltal"
@@ -35335,7 +35409,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case-etikett är inte ett konstant heltalsuttryck"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-etikett är inte i en switch-sats"
@@ -35355,17 +35429,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr "ordningen stämmer inte mellan if-satsens villkor och else-blocket"
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-sats som inte är i en loop eller switch"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-sats som inte är i en loop"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-sats använd med OpenMP-for-slinga"
@@ -35375,7 +35449,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-sats i en %<#pragma simd%>-slingas kropp"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-sats i en %<#pragma simd%>-slingas kropp"
@@ -35481,12 +35555,12 @@
 msgid "used vector type where scalar is required"
 msgstr "vektortyp använd där skalär krävs"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> måste ange en av klausulerna %<parallel%>, %<for%>, %<sections%> eller %<taskgroup%>"
@@ -35496,25 +35570,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%> %qE i %qs-klausul"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "bitfältet %qE i %qs-klausul"
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE är en medlem i en union"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD är inte en variabel i en %qs-klausul"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE är inte en variabel i en %qs-klausul"
@@ -35525,70 +35599,70 @@
 msgstr "%<_Atomic%> %qD i %qs-klausul"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD är en trådprivat variabel i en %qs-klausul"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "undre gränsen %qE i vektorsektion har inte heltalstyp"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "längden %qE i vektorsektion har inte heltalstyp"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "nollängds vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "för en vektor med okänd gräns måste ett längduttryck anges"
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negativ nedre gräns i vektorsektion i %qs-klausul"
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "negativ längd i vektorsektion i en %qs-klausul"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "nedre gränsen %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "längden %qE över storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "övre gräns %qE ovanför storleken på vektorsektionen i en %qs-klausul"
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "för pekartyper måste ett längduttryck anges"
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "vektorsektionen är inte sammanhängande i %qs-klausulen"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE har inte pekar- eller vektortyp"
@@ -35608,7 +35682,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE har ogiltig typ för %<reduction(%s)%>"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "ingen användardefinierad reduktion funnen för %qE"
@@ -35618,17 +35692,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "elementtyp med variabel längd i vektor-%<reduction%>-klausul"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "en %<nowait%>-klausul får inte användas tillsammans med %<copyprivate%>"
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE måste vara %<threadprivate%> för %<copyin%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "modifierare skall inte anges i %<linear%>-klausul på %<simd%>- eller %<for%>-konstruktioner"
@@ -35648,18 +35722,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD i %<linear%>-klausul"
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "%<linear%>-klausulens steg %qE är varken en konstant eller en parameter"
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE är inte en variabel i klausul %qs"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD förekommer mer än en gång i reduktionsklausuler"
@@ -35671,32 +35745,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD förekommer mer än en gång i dataklausuler"
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD förekommer både i data- och map-klausuler"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE är inte en variabel i klausul %<firstprivate%>"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE är inte en variabel i klausul %<lastprivate%>"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE är inte en variabel i %<aligned%>-klausul"
@@ -35716,55 +35790,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE är inte en variabel i en %<depend%>-klausul"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "vektorsektionen har inte en avbildbar typ i %qs-klausulen"
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD förekommer mer än en gång i rörelseklausuler"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD förekommer mer än en gång i avbildningsklausuler"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD har inte en avbildbar typ i %qs-klausul"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE är varken en variabel eller ett funktionsnamn i klausulen %qs"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE förekommer mer än en gång i samma %<declare target%>-direktiv"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD är inte en ett argument i en %<uniform%>-klausul"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE är inte ett argument i en %<uniform%>-klausul"
@@ -35774,32 +35848,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "%qs-variabeln är varken en pekare eller en vektor"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr "%<nonmonotonic%>-modifierare angiven för schemaläggningssort %qs"
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "en %<inbranch%>-klausul är inkompatibel med %<notinbranch%>"
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE är förutbestämd som %qs för %qs"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-klausulvärde är större än %<safelen%>-klausulvärde"
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-schemaläggningsmodiferare angiven tillsammans med %<ordered%>-klausul"
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-klausulsteg är en parameter %qD inte angiven i %<uniform%>-klausul"
@@ -36342,152 +36416,152 @@
 msgid "use of multiversioned function without a default"
 msgstr "användning av multiversionsfunktion utan ett standardfall"
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "att skicka %qT som %<this%>-argument kastar kvalificerare"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  i anrop till %qD"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT är inte en åtkomlig bas till %qT"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "härleder %qT som %qT"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (du kan avaktivera detta med -fno-deduce-init-list)"
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "skickar argument till ellips av den ärvda konstrueraren %qD"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "konstruerare delegerar till sig själv"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "anrop av icke-funktion %qD"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "kan inte anropa konstrueraren %<%T::%D%> direkt"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "för en typkonvertering i funktionsstil, ta bort det överflödiga %<::%D%>"
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "ingen matchande funktion för anrop av %<%T::%E(%A)%#V%>"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "ingen funktion som stämmer för anrop av %<%s(%A)%>"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "anrop av överlagrad %<%s(%A)%> är tvetydigt"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtual %q#D anropad från initierare av ickestatisk datamedlem"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtual %q#D anropad från en konstruerare"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtual %q#D anropad från en destruerare"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "det går inte att anropa medlemsfunktion %qD utan ett objekt"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "att skicka %qT väljer %qT framför %qT"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "väljer %qD framför %qD"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  för konvertering från %qT till %qT"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  för att konverteringssekvensen för argumentet är bättre"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "standardargument stämmer inte överens i upplösning av överlagring"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ säger att dessa är tvetydiga, trots att den sämsta konverteringen för den första är bättre än den sämsta konverteringen för den andra:"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "kunde inte konvertera %qE från %qT till %qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "en temporär bunden till %qD består endast tills konstrueraren avslutar"
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "ogiltig initiering av icke konstant referens av typ %qT från ett r-värde av typ %qT"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "ogiltig initiering av referens av typ %qT från uttryck av typ %qT"
@@ -36588,272 +36662,272 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "kan inte härleda från %<final%> bas %qT i härledd typ %qT"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "alla medlemsfunktioner i klass %qT är privata"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T definierar bara en privat destruerare och har inga vänner"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T definierar bara privata konstruerare och har inga vänner"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "ingen unik slutlig ersättare för %qD i %qT"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD kan markeras override"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D är markerad %<final%>, men är inte virtuell"
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D är markerad %<override%>, men den åsidosätter inte"
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD var dold"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  av %qD"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q#D ogiltig, en anonym union kan bara ha ickestatiska datamedlemmar"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q#D ogiltig, en anonym post kan bara ha ickestatiska datamedlemmar"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "privat medlem %q#D i anonym union"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr "privat medlem %q#D i anonym post"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "skyddad medlem %q#D i anonym union"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr "skyddad medlem %q#D i anonym post"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "ellipsen i %qD ärvs inte"
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bitfält %q+#D har en icke-heltalstyp"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bredd för bitfältet %q+D inte en heltalskonstant"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "negativ bredd i bitfält %q+D"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "noll i bredd i bitfält %q+D"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "bredden på %qD är större än dess typ"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD är för liten för att få plats med alla värden hos %q#T"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "medlem %q+#D med konstruerare inte tillåten i union"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "medlem %q+#D med destruerare inte tillåten i union"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "medlem %q+#D med kopieringstilldelningsoperator inte tillåten i union"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "obegränsade unioner är endast tillgängliga med -std=c++11 eller -std=gnu++11"
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "i C++98 får %q+D inte vara statisk eftersom den är medlem av en union"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "icke-statisk datamedlem %q+D i en union får inte ha referenstyp %qT"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "fält %q+D ogiltigt deklarerad funktionstyp"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "fält %q+D ogiltigt deklarerad metodtyp"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "ignorerar attributet packed på grund av opackat icke-POD-fält %q#D"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "medlemmen %q+D kan inte både deklareras %<const%> och %<mutable%>"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "medlem %q+D kan inte deklareras som en %<mutable%> referens"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "flera fält i unionen %qT initierade"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "fält %q#D med samma namn som en klass"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T har pekardatamedlemmar"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  men ersätter inte %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eller %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  men ersätter inte %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr "justeringen av %qD ökade i -fabi-version=9 (GCC 5.2)"
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "justering av %qD kommer öka med -fabi-version=9"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "initierare angiven för icke-virtuell metod %q+D"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "metoden åsidosätter både metoderna %<transaction_pure%> och %qE"
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "metod deklarerad %qE åsidosätter %qE-metod"
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "omslutande klass till constexpr icke-statisk medlemsfunktion %q+#D är inte en literal typ"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T är inte literal för att:"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T har en icke-trivial destruerare"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr "  %q+T är inte ett aggregat, har inte en trivial standardkonstruerare och har ingen constexpr-konstruerare som inte är en kopierings- eller flyttningskonstruerare"
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  basklassen %qT till %q+T är inte literal"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  den icke-statiska datamedlemmen %qD har icke-literal typ"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  den icke-statiska datamedlemmen %qD har volatile typ"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "basklassen %q#T har en åtkomlig icke-virtuell destruerare"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "icke-statisk referens %q#D i klass utan en konstruerare"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "icke-statisk const-medlem %q#D i klass utan en konstruerare"
@@ -36860,152 +36934,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D deklarerad att ta const-referens, men implicit deklaration skulle ta icke-const"
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkt bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuell bas %qT är oåtkomlig i %qT på grund av tvetydighet"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "förskjutningen av %qD följer inte ABI:et och kan ändras i en framtida version av GCC"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "storleken på typen %qT är för stor (%qE byte)"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ogiltig användning av %qT med en vektor av storlek noll i %q#D"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ogiltig användning av %q#T med flexibel vektormedlem i %q#T"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "vektormedlem %q#D är deklarerad här"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "vektormedlem %qD med storlek noll är inte vid slutet av %q#T"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "vektormedlem %qD med storlek noll i en i övrigt tom %q#T"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "i definitionen av %q#T"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexibel vektormedlem %qD inte vid slutet av %q#T"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexibel vektor medlem %qD i en i övrigt tom %q#T"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "nästa medlem %q#D är deklarerad här"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "omdefinition av %q#T"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T har virtuella funktioner och åtkomlig ickevirtuell destruerare"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typgenomskinliga %q#T har inga fält"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "den typgenomskinliga klassen %qT har basklasser"
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "den typgenomskinliga klassen %qT har virtuella funktioner"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparenta %q#T kan inte göras transparent eftersom typen på första fältet har ett annat ABI än klassen som helhet"
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "definitionen av std::initializer_list matchar inte #include <initializer_list>"
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "försökte avsluta post, men hoppade ut på grund av tidigare parsningsfel"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "språksträng %<”%E”%> känns inte igen"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "det går inte att lösa upp överlagrad funktion %qD baserat på konvertering till typ %qT"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "ingen match som konverterar funktionen %qD till typen %q#T"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "konvertering av överlagrad funktion %qD till typ %q#T är tvetydig"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "antar pekare till medlem %qD"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(en pekare på medlem kan bara skapas med %<&%E%>)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "inte tillräcklig typinformation"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "kan inte konvertera %qE från typ %qT till typ %qT"
@@ -37015,12 +37089,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "deklaration av %q#D"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr "byter betydelse av %qD från %q#D"
@@ -37050,333 +37124,333 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "ogiltig returtyp %qT för constexpr-funktionen %q+D"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T har virtuella basklasser"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr "constexpr-konstruerare har inte tom kropp"
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr "kroppen av %<constexpr%>-konstruerare kan inte vara ett function-try-block"
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%>-konstrueraren för unionen %qT måste initiera precis en icke statisk datamedlem"
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "medlemmen %qD måste initieras av en mem-initierare i %<constexpr%>-konstruerare"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "kroppen i constexpr-funktionen %qD är inte en retursats"
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%qD är inte användbar som en constexpr-funktion eftersom:"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E är inte ett konstant uttryck"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "anrop av intern funktion %qE"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "uttrycket %qE anger inte en constexpr-funktion"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "anrop av icke-constexpr-funktion %qD"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD anropad i ett konstant uttryck före dess definition är komplett"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD anropad i ett konstant uttryck"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD användes före sin definition"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "anrop har cirkulärt beroende"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "beräkning av constexpr överskrider maxvärdet på %d (använd -fconstexpr-depth= för att öka maxvärdet)"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr "constexpr-anrop flödar förbi slutet på funktionen"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "höger operand av skiftuttrycket %q+E är negativ"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr "högra operanden av skiftuttrycket %q+E är ≥ precisionen på den vänstra operanden"
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "vänster operand av skiftuttrycket %q+E är negativ"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "skiftuttrycket %q+E spiller över"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "aritmetik som innefattar en nollpekare i %qE"
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "vektorindexvärdet %qE är utanför gränserna för vektorn %qD av typen %qT"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "vektorindexvärdet %qE är utanför gränserna för vektortypen %qT"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "använder oinitierat vektorelement"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "derefererar en nollpekare i %qE"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "muterbar %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "använder medlem %qD istället för initierad medlem %qD i ett konstant uttryck"
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "använder oinitierad medlem %qD"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "derefererar en nollpekare"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "använder värdet av %qE genom ett %qT-glvalue i ett konstant uttryck"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "värdet på %qD är inte användbart i ett konstant uttryck"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD använd i sin egen initierare"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D är inte const"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q+#D är volatile"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD initierades inte med ett konstant uttryck"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD deklarerades inte %<constexpr%>"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD har inte heltals- eller uppräkningstyp"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "ändring av %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "constexpr-slingiterationsantal överskrider gränsen på %d (använd -fconstexpr-loop-limit= för att öka gränsen)"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "värdet %qE av typen %qT är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "temporär av den ej literala typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "en reinterpret_cast är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "konvertering av %qT-nullpekare till %qT som inte är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "uttrycket %qE är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "satsen är inte ett konstant uttryck"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "oväntat uttryck %qE av sorten %s"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE är inte ett konstant uttryck eftersom det har referenser till muterbara delobjekt av %qT"
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE är inte ett konstant uttryck eftersom det refererar till en ofullständigt initierad variabel"
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "konvertering från pekartypen %qT till den aritmetiska typen %qT i ett konstant uttryck"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "uttrycket %qE har sidoeffekter"
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast från heltal till pekare"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "adress-av på ett objekt %qE med trådlokal eller automatisk lagring är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%<this%> används i ett konstant uttryck"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-uttryck är inte ett konstant uttryck eftersom %qE har polymorf typ"
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "typkonvertering till %qT som inte är en heltalstyp i ett konstant uttryck"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%qDF är deklarerad %<static%> i en %<constexpr%>-funktion"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qD är deklarerad %<thread_local%> i en %<constexpr%>-funktion"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "oinitierad variabel %qD i %<constexpr%>-funktion"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "division med noll är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> är inte ett konstant uttryck"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ickekonstant vektorinitierare"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> är inte ett konstant uttryck"
 
 # ast = abstract syntax tree
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "oväntat AST av sorten %s"
@@ -38172,7 +38246,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  hoppar över initiering av %q#D"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ogiltig utgång från OpenMP-strukturerat block"
@@ -38187,7 +38261,7 @@
 msgid "%qD is not a type"
 msgstr "%qD är inte en typ"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD använd utan mallparametrar"
@@ -39823,7 +39897,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "parametern deklarerad %<auto%>"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ogiltig användning av mallnamnet %qE utan en argumentlista"
@@ -40274,13 +40348,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD har samma namn som klassen den är deklarerad i"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT är inte en mall"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "tidigare deklaration här"
@@ -40290,8 +40364,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "kanske du vill explicit lägga till %<%T::%>"
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referens till %qD är tvetydig"
@@ -40341,7 +40415,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "uppräkningstyp med/utan räckviddsbegränsning stämmer inte överens för enum %q#T"
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "tidigare definition här"
@@ -40405,7 +40479,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "returtypen %q#T är ofullständig"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> skall returnera en referens till %<*this%>"
@@ -40420,7 +40494,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "inga retursatser i funktion som returnerar %qT"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "endast enkel returtyp %<auto%> kan härledas till %<void%>"
@@ -40578,27 +40652,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bredden på bitfältet %qD har icke-heltalstyp %qT"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "den statiska datamedlemmen %q+D är inuti deklarationsmålsdirektiv"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonym post som inte är inuti en namngiven typ"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonyma aggregat med namnrymdsräckvidd måste vara statiska"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonym union utan medlemmar"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> måste returnera typ %qT"
@@ -40607,67 +40681,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "andra parametern till %<operator new%> kan inte ha standardargument"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> tar typen %<size_t%> (%qT) som första parameter"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> måste returnera typ %qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> tar typen %qT som första parameter"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT har ett fält %qD vars typ inte har någon länkklass"
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT har ett fält %qD vars typ beror på typen %qT som inte har någon länkklass"
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT har ett fält %qD vars typ använder den anonyma namnrymden"
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT är deklarerad med större synlighet än typen för dess fält %qD"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT har en bas %qT vars typ inte har någon länkklass"
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT har en bas %qT vars typ beror på typen %qT som inte har någon länkklass"
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT har en bas %qT vars typ använder den anonyma namnrymden"
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT är deklarerad med större synlighet än sin bas %qT"
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q#D, deklarerad med en namnlös typ, används men är aldrig definierad"
@@ -40676,47 +40750,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "namnlös typ utan länkklass används för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "namnlös typ utan länkklass används för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D refererar inte till den okvalificerade typen, så den används int för länkklass"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D, deklarerad med en lokal typ %qT, används men är aldrig definierad"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "typen %qT utan länkklass använd för att deklarera variabeln %q#D med länkklass"
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "typen %qT utan någon länkklass använd för att deklarera funktionen %q#D med länkklass"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "programmet borde även definiera %qD"
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "inline-funktion %qD använd men aldrig definierad"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "standardargumentet saknas för parameter %P till %q+#D"
@@ -40723,12 +40797,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "konverterar lambda som använder %<...%> till funktionspekare"
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "användning av borttagen funktion %qD"
@@ -41037,18 +41111,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "ogiltigt initierare för vektormedlem %q#D"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "oinitierad const-medlem i %q#T"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D borde initieras"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "oinitierad referensmedlem i %q#T"
@@ -41148,7 +41222,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "vektorer måste initieras med en initierare inom klamrar"
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT är inte en klasstyp"
@@ -41168,7 +41242,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "ogiltig användning av icke-statisk medlemsfunktion %qD"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ogiltig användning av icke-statisk datamedlem %qD"
@@ -41363,22 +41437,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr "eftersom vektorelementtypen %qT har variabel storlek"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "det går inte att fånga %qE via referens"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "fångst av kopia av ofullständig typ %qT"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "redan infångad %qD i lambdauttryck"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> fångades inte för denna lambdafunktion"
@@ -41433,186 +41507,186 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(om du använder %<-fpermissive%>, kommer G++ acceptera din kod, men man bör undvika att tillåta användning av ett odeklarerat namn)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "manglar typeof, använd decltype istället"
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "manglar __underlying_type"
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "manglar okänd fixdecimaltyp"
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "användning av inbyggd egenskap %qE i funktionssignatur; använd biblioteksegenskaper istället"
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "manglar %C"
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "utelämnad mittenoperand till %<?:%> kan inte manglas"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "strängliteral i funktionsmallsignatur"
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "det manglade namnet för %qD kommer ändras i C++17 eftersom undantagsspecifikationen är en del av funktionstypen"
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "en senare -fabi-version= (eller =0) undviker detta fel med en ändring av manglingen"
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "det manglade namnet på %qD ändrades mellan -fabi-version=%d (%D) och -fabi-version=%d (%D)"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "det manglade namnet på %qD ändras mellan -fabi-version=%d (%D) och -fabi-version=%d (%D)"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det manglade namnet på en snutt för %qD ändras mellan -fabi-version=%d och -fabi-version=%d"
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det manglade namnet på %qD ändras mellan -fabi-version=%d och -fabi-version=%d"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "det manglade namnet på initieringsvaktsvariabeln för %qD ändras mellan -fabi-version=%d och -fabi-version=%d"
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "ickestatisk const-medlem %q#D, kan inte använda standardtilldelningsoperatorn"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "ickestatisk referensmedlem %q#D, kan inte använda standardtilldelningsoperatorn"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr "syntetiserad metod %qD krävs första gången här "
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "union-medlem %q+D med icketrivial %qD"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "standarddefinierad konstruerare anropar %qD som inte är constexpr"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "initieraren för %q#D är ogiltig"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "den standarddefinierade standardkonstrueraren initierar inte %q#D"
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "kopierar icke-statisk datamedlem %q#D med rvärdereferenstyp"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "den standarddefinierade standardkonstrueraren initierar inte några ej statiska datamedlemmar"
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr "standarddefinierad flyttningstilldelning av %qT anropar en icketrivial flyttningstilldelningsoperator för den virtuella basen %qT"
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "en lambdahöljestyp har en raderad standardkonstruerare"
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "en lambdahöljetyp har en raderad koperingstilldelningsoperator"
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q#D är implicit deklarerad som raderad för att %qT deklarerar en flyttkonstruerare eller flyttilldelningsoperator"
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr "%q#D ärver från flera bassubobjekt"
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q#D är underförstått raderad eftersom standarddefinitionen skulle vara felformulerad:"
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F raderas implicit för att dess undantagsspecifikation stämmer inte med den implicita undantagsspecifikationen %qX"
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "standarddefinierad deklaration %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr "stämmer inte med förväntad signatur %qD"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr "funktionen %q+D standarddefinierades i sin omdeklaration med en undantagsspecifikation som skiljer från den implicita undantagsspecifikationen %qX"
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr "den explicit standarddefinierade funktionen %q+D kan inte deklareras som constexpr för att den implicita deklarationen är inte constexpr:"
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "en mall kan inte standarddefinieras"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD kan inte standarddefinieras"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "standarddefinierad funktion %q+D med standardargument"
@@ -41804,97 +41878,97 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> namnger konstruerare i %qT"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "kan inte ärva konstruerare från den indirekta basen %qT"
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "inga medlemmar matchar %<%T::%D%> i %q#T"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklaration av %qD inte i namnrymd som omger %qD"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explicit-kvalifikation i deklaration av %qD"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr "%qD har inte deklarerats inom %D"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, gcc-internal-format
 msgid "only here as a friend"
 msgstr "endast här som en vän"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD borde ha deklarerats inuti %qD"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "attributet %qD kräver ett ensamt NTBS-argument"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "attributet %qD är meningslöst eftersom medlemmar av den anonyma namnrymden får lokala symboler"
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "ignorerar attributet %qD på en namnrymd som inte är inline"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "ignorerar attributet %qD på en anonym namnrymd"
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "attributdirektivet %qD ignorerat"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namnrymdsalias %qD inte tillåtet här, antar %qD"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "användning av strong bör undvikas; använd inline-namnrymder istället"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "strong using är endast meningsfullt vid namnrymdsräckvidd"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "nuvarande namnrymd %qD innesluter inte den starkt använda namnrymden %qD"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "maxgräns på %d namnrymder sökta %qE"
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "föreslaget alternativ: %qs"
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -41901,27 +41975,27 @@
 msgstr[0] "föreslaget alternativ:"
 msgstr[1] "föreslagna alternativ:"
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr "argumentberoende uppslagning hittar %q+D"
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr "definitionen av std::initializer_list matchar inte #include <initializer_list>, är inte en mall"
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX går in i pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX lämnar pop_everything ()\n"
@@ -41941,7 +42015,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P är inte satt till true"
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> som inte omedelbart följs av en funktionsdeklaration eller -definition"
@@ -41966,7 +42040,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "begäran av medlem %qE i typ %qT som inte är en klasstyp"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> har inte deklarerats"
@@ -42026,725 +42100,731 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(kanske ett semikolon saknas efter definitionen av %qT)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "%qE är inte en klassmall"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE är inte en mall"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "ogiltigt mall-id"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ förbjuder användning av en flyttalsliteral i ett konstantuttryck"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "en typomvandling till en annan typ än en heltals- eller uppräkningstyp kan inte förekomma i ett konstantuttryck"
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "%<typeid%>-operator får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "ej konstanta sammansatta literaler får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "ett funktionsanrop får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "en ökning får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "en minskning får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "en vektorreferens får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "adressen till en etikett får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "anrop till överlagrade operatorer får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "en tilldelning får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "en kommaoperator får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "ett anrop till en konstruerare får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "ett transaktionsuttryck får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%qs får inte finnas i ett konstantuttryck"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "härledning av klassmallargument är endast tillgängligt med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "ogiltig användning av destruerare %qD som en typ"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "ogiltig kombination av flera typkvalificerare"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE är inte namnet på en typ; menade du %qs?"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE är inte namnet på en typ"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<constexpr%> är endast tillgängligt med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<noexcept%> är endast tillgängligt med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<thread_local%> är endast tillgängligt med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr "%<concept%> är endast tillgängligt med -fconcepts"
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(kanske %<typename %T::%E%> avsågs)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE i namnrymden %qE är inte namnet på en malltyp"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE i namnrymden %qE är inte namnet på en typ"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%E%> namnger konstrueraren, inte typen"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "typ %qT har inga mallkonstruerare"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr "%<typename%> behövs före %<%T::%E%> för att %qT är en beroende räckvidd"
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE i %q#T är inte namnet på en malltyp"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE i %q#T är inte namnet på en typ"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr "strängliteral förväntades"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr "inkonsistenta användardefinierade literalsuffix %qD och %qD i strängliteral"
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr "en bred sträng är inte tillåten i denna kontext"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr "kan inte hitta en teckenliteraloperator %qD med argumentet %qT"
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr "heltalskonstant överskrider intervallet för typen %qT"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr "flyttalskonstant överskrider intervallet för typen %qT"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr "flyttalskonstant avkortas till noll"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr "kan inte hitta en numerisk literaloperator %qD"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr "använd -std=gnu++11 eller -fext-numeric-literals för att aktivera fler inbyggda suffix"
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "kan inte hitta en strängliteraloperator %qD med argumenten %qT, %qT"
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "en deklaration förväntades"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, gcc-internal-format
 msgid "expected binary operator"
 msgstr "binär operator förväntades"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, gcc-internal-format
 msgid "expected ..."
 msgstr "... förväntades"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr "binärt uttryck i operanden till ett vikningsuttryck"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "villkorligt uttryck i operanden till ett vikningsuttryck"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr "operator som inte stämmer i vikningsuttryck"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "fixdecimaltyper stödjs inte i C++"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ förbjuder klammergrupper inuti uttryck"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "satsuttryck är inte tillåtna utanför funktioner eller i mallargumentlistor"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "vikningsuttryck är endast tillgängliga med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "primäruttryck förväntades"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "%<this%> kan inte användas i detta sammanhang"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "en malldeklaration får inte förekomma på blocknivå"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "lokal variabel %qD får inte förekomma i detta sammanhang"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "id-uttryck förväntades"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "räckvidd %qT före %<~%> är inte ett klassnamn"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "deklaration av %<~%T%> som medlem av %qT"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-namnet %qD använt som destruerardeklarerare"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "literala operatorsuffix som inte föregås av %<_%> är reserverade för framtida standardisering"
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "okvalificerat id förväntades"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "%<:%> hittades i kapslad namnspecifikation, %<::%> förväntades"
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype beräknas till %qT, som inte är en klass eller uppräkningstyp"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "funktionsmalls-id %qD i nästad namnspecificerare"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "variabelmall-id %qD  i nästad namnspecificerare"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD är inte en mall"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "nästat namn-specificerare förväntades"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "typer får inte definieras i typkonverteringar"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "typer får inte definieras i ett %<typeid%>-uttryck"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr "%<_Cilk_spawn%> måste följas av ett uttryck"
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "fel antal argument till %<__builtin_addressof%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "fel antal argument till %<__builtin_launder%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ förbjuder sammansatta literaler"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "två på varandra följande %<[%> får bara introducera ett attribut"
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr "klammerlistindex är inte tillåtet med vektornotation"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ogiltigt användning av %qD"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> är inte en klassmedlem"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "icke skalär typ"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tillåter inte %<alignof%> med annat än en typ"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "typer får inte definieras i %<noexcept%>-uttryck"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "typer får inte definieras i en new-uttryck"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "vektorgräns är förbjuden efter typ-id i parenteser"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "försök ta bort parenteserna runt typ-id:t"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "initiering av new-uttryck för typen %<auto%> tar precis ett element"
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "uttryckslista eller typ-id förväntades"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "typer får inte definieras i en new-type-id"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "uttryck i new-deklarerare måste ha heltals- eller uppräkningstyp"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "användning av gammaldags typkonvertering"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "operatorn %<>>%> hanteras som två högervinkelparenteser i C++11"
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "föreslår parenteser runt %<>>%>-uttryck"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ tillåter inte ?: med mellersta operanden utelämnad"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "lambdauttryck i oevaluerat sammanhang"
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "lambdauttryck i mallargument"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "slut på fångstlista förväntades"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "explicit fångst via kopiering av %<this%> överflödigt med standardfall av fångst via kopiering"
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "fångst av %<*this%> är endast tillgängligt med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "lambdafångstinitierare är endast tillgängliga med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "tom initierare för lambdas init-fångst"
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "fångst av en icke-variabel %qD"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D är deklarerad här"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "fångst av variabeln %qD med ej automatisk lagringsvaraktighet"
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "explicit fångst via kopiering av %qD överflödigt vid standardfångst via kopiering"
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "explicit fångst via referens av %qD överflödigt med standardfångst via referens"
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "lambdamallar är endast tillgängliga med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, gcc-internal-format
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C++ stödjer inte lambdamallar"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "standardargumentet angivet för lambdaparameter"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "dubblerad %<mutable%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "%<constexpr%> lambda är endast tillgängligt med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "attribut vid början av satser ignoreras"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "etikettsats förväntades"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-etikett %qE är inte i en switch-sats"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> behövs före %qE för att %qT är en beroende räckvidd"
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> namnger konstrueraren, inte typen"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr "sammansatt sats i en constexpr-funktion"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "%<if constexpr%> är endast tillgängligt med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "init-satsen i valsatser är endast tillgängliga med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "selektionssats förväntades"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "typer får inte definieras i villkor"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "intervallbaserat %<for%>-uttryck av typen %qT har ofullständig typ"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr "intervallbaserat %<for%>-uttryck av typen %qT har en %<end%>-medlem men inte någon %<begin%>"
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr "intervallbaserat %<for%>-uttryck av typen %qT har en %<begin%>-medlem men inte någon %<end%>"
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "inkonsistenta start-/sluttyper i intervallbaserat %<for%>-sats: %qT och %qT"
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "iterationssats förväntades"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "intervallbaserad %<for%>-slinga är endast tillgänglig med -std=c++11 eller -std=gnu++11"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr "break-sats använd med Cilk Plus-for-slinga"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> i %<constexpr%>-funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ förbjuder beräknade goto"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "hoppsats förväntades"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "extra %<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> som inte inleder ett block"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "icke-variabel %qD i deklaration med mer än en deklarerare med platshållartyp"
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "inkonsistent härledning för %qT: %qT och sedan %qT"
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "att blanda deklarationer och funktionsdefinitioner är förbjudet"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "typer får inte definieras i en for-range-deklaration"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "initierare i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "flera deklarationer i intervallbaserad %<for%>-slinga"
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "dekomponeringsdeklarationer är endast tillgängliga med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, gcc-internal-format
 msgid "empty decomposition declaration"
 msgstr "tom dekomponeringsdeklaration"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+#| msgid "invalid initializer for member function %qD"
+msgid "invalid initializer for structured binding declaration"
+msgstr "ogiltigt initierare för medlemsfunktion %qD"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> använd utanför en klass"
@@ -42751,476 +42831,476 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> ändrar betydelse i C++11; var god ta bort det"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-specificerare är ogiltig i villkor"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD är ogiltigt i lambda"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "klassdefinition kan inte deklareras som en vän"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallar får inte vara %<virtual%>"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ogiltig länkklasspecifikation"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "static_assert utan ett meddelande är endast tillgänglig med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "typer får inte definieras i %<decltype%>-uttryck"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "typer får inte definieras i en conversion-type-id"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ogiltig användning av %<auto%> i konverteringsoperator"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "användning av %<auto%> i medlemsmallskonverteringsoperator kan aldrig vara härledd"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "endast konstruerare tar medlemsinitierare"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "det går inte att expandera initierare för medlem %<%D%>"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "minnesinitierare för %qD följer en konstruerardelegering"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "konstruerardelegering följer mem-initierare för %qD"
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anakronistisk gammaldags basklassinitierare"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (en kvalificerad medlemsinitierare är implicit en typ)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "oväntat nyckelord; ta bort mellanrum mellan citationstecken och suffixidentifierare"
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "suffixidentifierare förväntades"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "en tom sträng förväntades efter nyckelordet %<operator%>"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ogiltigt kodningsprefix i literal operator"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "operator förväntades"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "nyckelordet %<export%> är inte implementerat och kommer ignoreras"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ogiltig begränsad typparameter"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-kvalificerad typparameter"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "variadisk begränsning introducerad utan %<...%>"
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "felaktig användning av %<auto%> i standardmallargument"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "mallparameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "mallparameterpaket kan inte ha standardargument"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "mall-id förväntades"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kan inte inleda en argumentlista till en mall"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> är en alternativ stavning av %<[%>.  Lägg in mellanrum mellan %<<%> och %<::%>"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(om du använder %<-fpermissive%> eller %<-std=c++11%> eller %<-std=gnu++11%> kommer G++ acceptera din kod)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "parsningsfel i mallargumentlista"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "mallnamn förväntades"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "icke-mall %qD använd som mall"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "använd %<%T::template %D%> för att indikera att det är en mall"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "parameterpaket förväntades före %<...%>"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "mallargument förväntades"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ogiltigt mallargument som inte är en typ"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "en explicit instansiering skall inte använda %<inline%>-specificerare"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "en explicit instansiering skall inte använda %<constexpr%>-specificerare"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "mallspecialisering med C-länkning"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "användning av %<auto%> i lambdaparameterdeklarationer är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "användning av %<auto%> i parameterdeklarationer är endast tillgängligt med -std=c++14 eller -std=gnu++14"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C++ förbjuder användning av %<auto%> i en parameterdeklaration"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "mall-id för typ förväntades"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "typnamn förväntades"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "beräknad typspecifikation för en enum med räckvidd får inte använda nyckelordet %<%D%>"
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklaration %qD deklarerar inte något"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "attributet ignorerat på oinstansierad typ"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "attribut ignoreras vid mallinstansiering"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "attribut ignoreras för bearbetade typspecificerare som inte är en framåtdeklaration"
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD är en uppräkningsmall"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD är inte namnet på en uppräkningstyp i %qT"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "namnlös enum med räckvidd är inte tillåtet"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> eller %<{%> förväntades"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "det går inte att lägga till en uppräkningslista till en mallinstansiering"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "nästad namnspecificerare %qT för enum-deklaration som inte namnger en klass eller namnrymd"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "deklaration av %qD i namnrymd %qD som inte innesluter %qD"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "deklaration av %qD i %qD som inte innesluter %qD"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "extra kvalifikation inte tillåten"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "fler definitioner av %q#T"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ förbjuder tomma namnlösa enum"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "ogenomskinlig enum-specifikation utan namn"
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "en ogenomskinlig enum-specifikation måste använda en enkel identifierare"
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD är inte ett namnrymdsnamn"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "namnrymdsnamn förväntades"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "en nästad namnrymdsdefinition kan inte ha attribut"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "nästade namnrymdsdefinitioner är endast tillgängliga med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "en nästad namnrymdsdefinition kan inte inline:as"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, gcc-internal-format
 msgid "nested identifier required"
 msgstr "nästad identifierare behövs"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "gick in i namnrymden %qD"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-definition är inte tillåten här"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "paketexpansion i using-deklaration är endast tillgängligt med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "ett mall-id får inte förekomma i en using-deklaration"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "en kommaseparerad lista i using-deklaration är endast tillgängligt med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "åtkomstdeklarationer bör undvikas till förmån för using-deklarationer; förslag: lägg till nyckelordet %<using%>"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "typer får inte definieras i aliasmalldeklarationer"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> i %<constexpr%>-funktion"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "en funktionsdefinition är inte tillåten här"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "en asm-specifikation är inte tillåten på en funktionsdefinition"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "attribut är inte tillåtna vid en funktionsdefinition"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "konstruerare, destruerare eller typkonvertering förväntades"
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "initierare förväntades"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "initierare angiven för funktion"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "attribut efter initierare inom parentes ignoreras"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "icke-funktionen %qD deklarerad som implicit mall"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "vektorgräns är inte en heltalskonstant"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "det går inte att definiera medlem av beroende typedef %qT"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> är inte en typ"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ogiltig användning av konstruerare som en mall"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "använd %<%T::%D%> istället för %<%T::%D%> för att namnge konstrueraren i ett kvalificerat namn"
@@ -43229,7 +43309,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ogiltig deklarator"
@@ -43236,337 +43316,339 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "kvalificerad id i deklaration"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "deklarator förväntades"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD är en namnrymd"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "kan inte skapa en pekare till medlem av %q#T som inte är en klass"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "oväntad pekaroperator"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "upprepade cv-kvalificerare"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "upprepade ref-kvalificerare"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr "%E kräver %<-fgnu-tm%>"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "upprepade virt-specificerare"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "mallargument saknas efter %qT"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ogiltigt användning av %qT"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "typer får inte definieras i mallargument"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "felaktig användning av %<auto%> i mallargument"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "typspecificerare förväntades"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> eller %<...%> förväntades"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "typer får inte definieras i parametertyper"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "standardargument är endast tillåtna för funktionsparametrar"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "parameterpaket %qD kan inte ha ett standardargument"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "mallparameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "parameterpaket kan inte ha ett standardargument"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ tillåter inte designerade initierare"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tillåter inte C99:s designerade initierare"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "klassnamn förväntades"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> förväntades efter klassdefinition"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> förväntades efter postdefinition"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> förväntades efter uniondefinition"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> eller %<:%> förväntades"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "det går inte att ange %<override%> för en klass"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globala kvalificering av klassnamn är ogiltigt"
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "kvalificerat namn namnger inte en klass"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ogiltigt klassnamn i deklaration av %qD"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "en explicit specialisering måste föregås av %<template <>%>"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktionsmall %qD omdeklarerad som en klassmall"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "det gick inte att lösa upp typnamnstyp"
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "föregående definition av %q#T"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "klassnyckel förväntades"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr "ISO C++ förbjuder nyckelordet typename i mall-mall-parameter; använd -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> eller %<typename%> förväntades"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "i C++03 måste en klassnyckel användas när en vän deklareras"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "vändeklaration som inte namnger en klass eller funktion"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "en lagringklass på ett anonymt aggregat i klassräckvidd tillåts inte"
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-specificerare på funktionsdefinition"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "överblivet %<,%> vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> förväntades vid slutet av medlemsdeklaration"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ogiltig pure-specificerare (endast %<= 0%> är tillåtet)"
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "en klammeromsluten initierare är inte tillåten här"
 
-#: cp/parser.c:23680
-#, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+#: cp/parser.c:23703
+#, fuzzy, gcc-internal-format
+#| msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> anges mer än en gång i basspecificerade"
 
-#: cp/parser.c:23700
-#, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+#: cp/parser.c:23723
+#, fuzzy, gcc-internal-format
+#| msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr "mer än en åtkomstspecifikation i basspecificerade"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "nyckelordet %<typename%> är inte tillåtet utanför mallar"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "nyckelordet %<typename%> är inte tillåtet i detta sammanhang (basklassen är implicit en typ)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "typer får inte definieras i en undantagsspecifikation"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "ISO C++1z tillåter inte dynamiska undantagsspecifikationer"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamiska undantagsspecifikationer undanbedes i C++11"
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ogiltig användning av %<auto%> i undantagsspecifikation"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> i %<constexpr%>-funktion"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "typer får inte definieras i undantagsdeklarationer"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "attribut som använder prefix använt tillsammans med attributsymboler med räckvidd"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "en identifierare förväntades som attributnamn"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "attributet %<noreturn%> får förekomma högst en gång i en attributlista"
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "attributet %<deprecated%> kan förekomma högst en gång i en attributlista"
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "attribut förväntades före %<...%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribut som använder prefix är endast tillgängligt med -std=c++1z eller -std=gnu++1z"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> är endast tillgängligt med -fconcepts"
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "ett transaktionsuttryck får inte finnas utanför en mall"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "specialisering av medlem %<%T::%E%> kräver %<template<>%>-syntax"
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ogiltig omdeklaration av %<%T::%E%>"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "för få mallparameterlistor"
@@ -43575,489 +43657,489 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "för många mallparameterlistor"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "namngivna returvärden stödjs inte längre"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "den literala operatormallen %qD har ogiltig parameterlista.  Ett mallargument som inte är en typ pack <char...> eller <typename CharT, CharT...> förväntades"
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "den literala operatormallen %qD har ogiltig parameterlista.  Ett mallargument som inte är en typ pack <char...> förväntades"
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "tom introduktionslista"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "det finns inget matchande koncept för mallintroduktionen"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ogiltig deklaration av medlemsmall i lokal klass"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "mall med C-länkning"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ogiltig explicit specifikation"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malldeklaration av %<typedef%>"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "en klassmallsdeklaration får inte deklarera något annat"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explicit mallspecialisering kan inte ha en lagringsklass"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> skulle vara %<> >%> inuti en nästad mallargumentlista"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "vilsekommet %<>>%>, använd %<>%> för att avsluta en mallargumentlista"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "argument till %<sizeof...%> måste omges av parenteser"
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ogiltig användning av %qD i länkklasspecifikation"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> före %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 stödjer inte %<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "både %<__thread%> och %<thread_local%> angivna"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "dubblerad %qD"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "dubblerad %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> förväntades"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> förväntades"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> förväntades"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> förväntades"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> förväntades"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> förväntades"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> förväntades"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> förväntades"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> förväntades"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> förväntades"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> förväntades"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> förväntades"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> förväntades"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> förväntades"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> förväntades"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> förväntades"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> förväntades"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> förväntades"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> förväntades"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> förväntades"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> förväntades"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> förväntades"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> förväntades"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> förväntades"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> förväntades"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> eller %<::%> förväntades"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> eller %<template%> förväntades"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs-tagg använd vid namngivning av %q#T"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T deklarerades tidigare här"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD omdeklarerad med annan åtkomst"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "i C++98 är %<template%> (för att lösa upp tvetydighet) är endast tillåtet inuti mallar"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "filen slutar i standardargument"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "felplacerad Objective-C++-konstruktion %<@%D%>"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++-meddelandemottagare förväntades"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++-meddelandeargument förväntades"
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> måste ange en typ som ett argument"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "ogiltigt Objective-C++-väljarnamn"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "metoddeklaration i objective-c++ förväntades"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "metodattribut måste anges på slutet"
 
 # %qs blir "{" eller "}"
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "vilsekommet %qs mellan Objective-C++ metoder"
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ogiltig typ för iterationsvariabel"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "identifierare förväntades efter %<@protocol%>"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "attribut får inte anges före Objective-C++-nyckelordet %<@%D%>"
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "prefixattribut ignoreras före %<@%D%>"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ogiltigt typ på egenskap"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-uttryck måste vara heltal"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ogiltig reduktionsidentifierare"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "initiering i parenteser är inte tillåtet i en OpenMP-%<for%>-slinga"
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "initiering i parenteser är inte tillåtet i en for-slinga"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr "%<_Cilk_for%> tillåter ett uttryck istället för en deklaration endast i C, inte i C++"
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterationsvariabel %qD skall inte vara reduction"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "inte tillräckligt med for-slingor att kollapsa"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "vektorattribut som inte omedelbart följs av en ensam funktionsdeklaration eller -definition"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ogiltig initierarklausul"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "id-uttryck förväntades (argument)"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "en av initieraranropets argument skall vara %<omp_priv%> eller %<&omp_priv%>"
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "typer får inte definieras i en declare reduction-typlista"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "en fördeklarerad aritmetisk typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "funktions- eller vektortyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "referenstyp %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const-, volatile- eller __restrict-kvalificerad typ %qT i %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> namnger en mängd överlagrade"
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD refererar inte till en funktion med namnrymdsräckvidd"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> utan stöd för transaktionsminne aktiverat"
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "skräp vid slutet av %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "ogiltig kornstorlek för _Cilk_for"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> måste vara inuti en funktion"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "%<#pragma simd%> måste vara inuti en funktion"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "%<#pragma cilk grainsize%> måste vara inuti en funktion"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr "-fcilkplus måste vara aktiverat för att använda %<#pragma cilk grainsize%>"
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "intermoduloptimeringar inte implementerade för C++"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, gcc-internal-format
 msgid "expected variable-name"
 msgstr "variabelnamn förväntades"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "%<,%> eller %<)%> förväntades efter %qE"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "implicita mallar får inte vara %<virtual%>"
@@ -44149,7 +44231,7 @@
 msgid "candidate is: %#D"
 msgstr "kandidat är: %#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %#D"
@@ -44725,122 +44807,140 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE är inte ett giltigt mallargument av typ %qT eftersom %qD inte har extern länkklass"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom %qD inte har någon länkklass"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+#| msgid "  variable-sized array type %qT is not a valid template argument"
+msgid "the address of %qD is not a valid template argument"
+msgstr "  vektortypen %qT med variabel storlek är inte ett giltigt mallargument"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+#| msgid "  variable-sized array type %qT is not a valid template argument"
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "  vektortypen %qT med variabel storlek är inte ett giltigt mallargument"
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+#| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%qE är inte ett giltigt mallargument av typ %qT eftersom %qD inte har extern länkklass"
+
+#: cp/pt.c:6672
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom det står i konflikt med cv-kvalificeringar"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom inte är ett l-värde"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D är inte ett giltigt mallargument till typen %qT eftersom en referensvariabel inte har en konstant adress"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det inte är ett objekt med länkklass"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE är inte ett giltigt mallargument för typ %qT eftersom objekt %qD inte har någon länkklass"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är en pekare"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "försök att använda %qE istället"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE är inte ett giltigt mallargument för typen %qT eftersom det är av typen %qT"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "standardkonverteringar är inte tillåtna i denna kontext"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "ignorerar attribut på mallargumentet %qT"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "ignorerar attribut i mallargumentet %qE"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "inskjutet klassnamn %qD använt som mallmallargument"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ogiltig användning av destrueraren %qE som en typ"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "för att referera till en typmedlem av en mallparameter, använd %<typename %E%>"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "typ/värde stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  förväntade en konstant av typen %qT, fick %qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  förväntade en klassmall, fick %qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  förväntade en typ, fick %qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  förväntade en typ, fick %qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  förväntade en klassmall, fick %qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  förväntade en mall av typen %qD, fick %qT"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "begränsningar stämmer inte vid argument %d i mallparameterlistan till %qD"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD förväntades men fick %qD"
@@ -44847,102 +44947,102 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "typer stämmer inte i icke-typs parameterpaket"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "kunde inte konvertera mallargument %qE från %qT till %qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "mallargument %d är ogiltigt"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "fel antal mallargument (%d, skulle vara %d)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "fel antal mallargument (%d, skulle vara åtminstone %d)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "angivna till %qD"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till aliasmall %qD"
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "pack-expansionsargument för icke-pack-parametern %qD till konceptet %qD"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "så varje instansiering med ett icke-tomt parameterpaket vore felformulerad"
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "angivna till %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D är inte en funktionsmall"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "icke-malltyp %qT använd som en mall"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "för malldeklaration %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "mallbegränsningsfel"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "användning av felaktig variabelmall %qE"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d (använd -ftemplate-depth= för att öka maxvärdet)"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "fold över tom expansion över %O"
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %<%T%>"
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "argumentpaketlängder stämmer inte överens vid expansion av %<%E%>"
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "  vid instansiering av standardargument för anrop av %D"
@@ -44960,271 +45060,271 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabeln %qD har funktionstyp"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ogiltig parametertyp %qT"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "i deklaration %q+D"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "funktion som returnerar en vektor"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion som returnerar en funktion"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "skapar pekare till medlemsfunktion i typ %qT som inte är en klass"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "formar referens till void"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "formar pekare till en referenstyp %qT"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "formar referens till en referenstyp %qT"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "formerar en pekare till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "formerar en referens till en kvalificerad funktionstyp %qT"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "skapar pekare till medlem av typ %qT som inte är en klass"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "skapar pekare till medlemsreferenstyp %qT"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "skapar pekare till medlem av typ void"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "skapar vektor av %qT"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT är inte en klass-, post- eller unionstyp"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT slås upp till %qT som inte är en uppräkningstyp"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT löses upp till %qT, som inte är en klasstyp"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "tom initierare i lambdas init-fångst"
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "användning av %qs i mall"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "kvalificerande typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "namnet %qE i den beroende tolkas som något annat än en typ, men instansiering ger en typ"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "säg %<typename %E%> om en typ avses"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "användning av ogiltigt fält %qD"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "ogiltig användning av paketexpansionsuttryck"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "använd %<...%>  för att expandera argumentpaket"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD deklarerades inte i detta definitionsområde, och inga deklarationer hittades av en argumentberoende uppslagning vid instansieringspunkten"
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "deklarationer i beroende bas %qT hittas inte av en okvalificerad uppslagning"
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "använd %<this->%D%> istället"
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "använd %<%T::%D%> istället"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD är deklarerad här, senare i översättningsenheten"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT är inte en klass eller namnrymd"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD är inte en klass eller namnrymd"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT är/använder en namnlös typ"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "mallargumentet för %qD använder lokal typ %qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT är en variabel typ"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "heltalsuttryck %qE är inte konstant"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  försöker instansiera %qD"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "tvetydig mallinstansiering av %q#T"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "tvetydig mallinstansiering av %q#D"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 msgid "%s %#S"
 msgstr "%s %#S"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explicit instansieringar av icke-mall %q#D"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD är inte en statisk datamedlem i en klassmall"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "det finns ingen matchande mall för %qD"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "typ %qT för explicit instansiering %qD stämmer inte med deklarerad typ %qT"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explicit instansiering av %q#D"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "dubblerad explicit instansiering av %q#D"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 förbjuder användning av %<extern%> vid explicita instansieringar"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "lagringsklass %qD tillämpad på mallinstansiering"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explicit instansieringar av mallen %q#D som inte är en klass"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explicit instansieringar av icke-malltyp %qT"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explicit instansiering av %q#T före definitionen av mallen"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ förbjuder användning av %qE vid explicita instansieringar"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "dubblerad explicit instansiering av %q#T"
@@ -45236,92 +45336,92 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explicit instansiering av %qD men ingen definition tillgänglig"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "mallinstansieringsdjupet överskrider maxvärdet på %d vid instansiering av %q+D, möjligen från generering av virtuell tabell (använd -ftemplate-depth= för att öka maxvärdet)"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ogiltig mallparameter som inte är en typ"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T är inte en giltig typ för en mallparameter som inte är en typ"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "härledning från klammeromgiven initierarlista kräver #include <initializer_list>"
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "icke-klass-mall %qT använd utan mallargument"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "kan inte härleda mallargument för kopieinitiering av %qT, eftersom den inte har några icke-explicita härledningsguider eller användardeklarerade konstruerare"
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "härledning av klassmallargument misslyckades:"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "explicita härledningsguider övervägs inte vid kopieinitiering"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direkt listinitiering av %<auto%> tar precis ett element"
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "för härledning till %<std::initializer_list%>, använd kopielistinitiering (d.v.s. lägg till %<=%> före %<{%>)"
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT som en typ snarare en enkel %<decltype(auto)%>"
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "kan inte härleda lambdareturtyp från %qE"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "kan inte härleda %qT från %qE"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "platshållarbegränsningar är inte uppfyllt"
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "härledd initierare uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "härledd returtyp uppfyller inte sina platshållarbegränsningar"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "härledd uttryckstyp uppfyller inte sina platshållarbegränsningar"
@@ -45478,466 +45578,466 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  eftersom %q+#D är deklarerad i basklassen"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "föreslår uttryckliga klamrar runt tom kropp i %<do%>-sats"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "typen på asm-operand %qE kunde inte avgöras"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "__label__-deklarationer får bara förekomma på funktionsnivå"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "ogiltig användning av %qD i en statisk medlemsfunktion"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "argument till destruerare är inte tillåtet"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> är inte tillgängligt i en statisk medlemsfunktion"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ogiltig användning av %<this%> i icke-medlemsfunktion"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ogiltigt användning av %<this%> på toppnivå"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ogiltigt kvalificerande räckvidd i pseudodestruerarnamn"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "kvalificerad typ %qT matchar inte destruerarnamnet ~%qT"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE har inte typen %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "sammansatt literal för ej objekttyp %qT"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "malltypparametrar måste använda nyckelordet %<class%> eller %<typename%>"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ogiltigt användning av typ %qT som standardvärde för en mallmallparameter"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ogiltigt standardargument för en mallmallparameter"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "definition av %q#T inuti mallparameterlista"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ogiltig definition av kvalificerad typ %qT"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ogiltig basklasspecifikation"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "kan inte fånga medlemmen %qD i anonym union"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD är inte fångad"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "lambdat har ingen standardfångst"
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "lambda i lokal klass %q+T kan inte fånga variabler från det omgivande sammanhanget"
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "användning av lokal variabel med automatisk lagringsklass från en kringliggande funktion"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "användning av parameter från den kringliggande funktionen"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "användning av parameter utanför funktionskroppen"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "mallargument saknas"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "mallparameter %qD av typ %qT är inte tillåten i ett konstant heltalsuttryck eftersom den inte är av heltals- eller uppräkningstyp"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "användning av namnrymden %q+D som uttryck"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "användning av klassmall %qT som uttryck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "begäran av medlem %qD är tvetydig i gitter av multipelt arv"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD får inte finnas i ett konstantuttryck"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "typen på %qE är okänd"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT är inte ett uppräkningstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameterpakets-__bases är endast giltiga i malldeklarationer"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "det går inte att applicera %<offsetof%> på destrueraren %<~%T%>"
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr "andra operanden till %<offsetof%> är varken en ensam identifierare eller en sekvens av medlemsåtkomster och vektorreferenser"
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "det går inte att använda %<offsetof%> på medlemsfunktion %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr "offsetof inom icke-standardlayouttypen %qT är odefinierat"
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> tillåtet i OpenMP endast i %<declare simd%>-klausuler"
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "användardefinierad reduktionsuppslagning är tvetydig"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE i %<reduction%>-klausul är en vektor med storlek noll"
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE har const-typ för %<reduction%>"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "användardefinierad reduktion med konstruerarinitierare för basklassen %qT"
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "linjär klausul med modifieraren %qs tillämpad på en variabel som inte är en referens med typen %qT"
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr "linjär klausul tillämpad på en variabel som inte är heltals-, flyttals- eller pekarvariabel med typen %qT"
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "linjär klausul tillämpad på en variabel som inte är heltal och inte pekare med typen %qT"
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "ett linjärt steguttryck måste vara ett heltal"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD är inte en variabel i klausul %qs"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD är inte en variabel i klausul %<firstprivate%>"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD är inte en variabel i klausul %<lastprivate%>"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "%<gang%>-statiskt uttryck måste vara heltal"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<gang%>-statiskt värde måste vara positivt"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "%<gang%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "%<vector%>-längduttryck måste vara ett heltal"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "%<worker%>-numeriskt uttryck måste vara ett heltal"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-uttrycket måste vara ett heltal"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<gang%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<vector%>-längdvärdet måste vara positivt"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<worker%>-numeriskt värde måste vara positivt"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "uttryck för styckesstorlek för schemaläggning måste vara heltal"
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "%qs-längduttryck måste vara ett heltal"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%qs längduttryck måste vara ett positivt konstant heltalsuttryck"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-uttryck måste vara heltal"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-id måste vara ett heltal"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "%<dist_schedule%> styckesstorleksuttryck måste vara heltal"
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD är inte en variabel i %<aligned%>-klausul"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE i %<aligned%>-klausul är varken en pekare eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD förekommer mer än en gång i %<aligned%>-klausuler"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "%<aligned%>-klausuls justeringsuttryck måste vara heltal"
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD är inte en variabel i %<depend%>-klausul"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "överlagrad funktion med namnet %qE i klausulen %qs"
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "mallen %qE i-klausulen %qs"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "%<grainsize%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "%<priority%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_tasks%>-uttryck måste vara ett heltal"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "%qs-variabeln är varken en pekare, eller en vektor eller en referens till pekare eller vektor"
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tile%>-argumentet behöver en heltalstyp"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD är inte fil-, namnrymds- eller blockräckviddsvariabel"
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE-direktiv inte i %qT-definition"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "skillnaden mellan %qE och %qD har inte heltalstyp"
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> använd med klassiterationsvariabeln %qE"
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> använder två olika uttryck för minne"
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statisk försäkran misslyckades"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statisk försäkran misslyckades: %s"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "icke-konstant villkor i statisk deklaration"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "argument till decltype måste vara ett uttryck"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype kan inte lösa upp adressen till en överlagrad funktion"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operanden till vikningsuttrycket har inget oexpanderat parameterpaket"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "båda argumenten i en binär vikning har oexpanderade parameterpaket"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "inga oexpanderade parameterpack i binär fold"
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "icke-pekar-argument till %<__builtin_launder%>"
@@ -45952,107 +46052,107 @@
 msgid "lambda-expression in a constant expression"
 msgstr "lambdauttryck i ett konstantuttryck"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "attributet %qE tillämpat på %qD med returtypen void"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "attributet %qE kan bara användas på funktioner eller på klass- eller uppräkningstyper"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "begärd init_priority är inte en heltalskonstant"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "det går bara att använda attributet %qE på definitioner av objekt- eller klasstyp med filräckvidd"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "begärd init_priority är utanför sitt intervall"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "begärt init_priority är reserverad för internt bruk"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "attributet %qE stödjs inte på denna plattform"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "omdeklaration av %qD lägger till abi-taggen %E"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "attributet %qE behöver argument"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumenten till attributet %qE måste vara smala strängkonstanter"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumenten till attributet %qE måste innehålla giltiga identifierare"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> är inte ett giltigt första tecken för en identifierare"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> är inte ett giltig bokstav i en identifierare"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "attributet %qE använt på typen %qT som inte är en klass eller uppräkningstyp"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "attributet %qE använt på %qT efter dess definition"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "ignorerar attributet %qE använt på mallinstansieringen %qT"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "ignorerar attributet %qE använt på mallspecialiseringen %qT"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "attributet %qE tillämpat på %qD som inte är en funktion eller variabel"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "attributet %qE tillämpat på extern \"C\"-deklaration %qD"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "noll som en nollpekarkonstant"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_*-kontroll: misslyckades i %s, vid %s:%d"
@@ -46734,102 +46834,102 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ogiltig konvertering till typ %qT från typ %qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "kan inte konvertera %qT till %qT för argument %qP till %qD"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "det går inte att konvertera %qT till %qT i standardargument"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "det går inte att konvertera %qT till %qT när argument skickas"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "det går inte att konvertera %qT till %qT"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "det går inte att konvertera %qT till %qT i initiering"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "det går inte att konvertera %qT till %qT i retur"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "det går inte att konvertera %qT till %qT i tilldelning"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "returtypen %qT är ofullständig"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "parameter %qP till %qD kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "parameter kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "målet för konvertering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "målet för initialisering kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "vänsterhandssida av tilldelning kan vara en kandidat för ett formatattribut"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "när argument %P till %qD skickades"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "returnerar referens till en temporär"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "referens till annat än lvärde returnerad"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "referens till lokal variabel %qD returnerad"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "adressen till etiketten %qD returnerad"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "adress till lokal variabel %qD returnerad"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "returnerar ett värde från en destruerare"
@@ -46836,55 +46936,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "det går inte att returnerar från en hanterare i ett funktions-try-block eller en konstruerare"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "returnerar ett värde från en konstruerare"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-sats utan värde i funktion som returnerar %qT"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "returnerar en initierarlista"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "inkonsistenta typer %qT och %qT härledda för lambda-returtypen"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "inkonsistent härledning för auto-returtyp: %qT och sedan %qT"
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "return-sats med värde i funktion som returnerar ”void”"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> får inte returnera NULL om den inte är deklarerad %<throw()%> (eller -fcheck-new är aktivt)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "använder temporär som lvärde"
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "hjälp xvärde (rvärdesreferens) som lvärde"
@@ -50839,87 +50939,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Procedurpekarinitieringsmål vid %L får inte vara en procedurpekare"
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Pekarfunktioner i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Icke variabelt uttryck i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Namngiven konstant %qs i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs i variabeldefinitionssammanhang (%s) vid %L är inte en variabel"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Icke-POINTER i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Typen är oåtkomlig i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Attrappargument %qs med INTENT(IN) i variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett pekarassociationssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "Variabeln %qs är PROTECTED och kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabeln %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med vektorindexerat mål kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "%qs vid %L som är associerad med uttryck kan inte användas i ett variabeldefinitionssammanhang (%s)"
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Associationsnamn %qs kan inte förekomma i ett variabeldefinitionssammanhang (%s) vid %L eftersom dess mål vid %L inte heller kan"
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Element med samma värde vid %L och %L i vektorindex i ett variabeldefinitionssammanhang (%s)"
@@ -51106,12 +51206,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Andra argumentet av definierad tilldelning vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Första argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Andra argumentet till operatorgränssnitt vid %L måste vara INTENT(IN)"
@@ -51886,508 +51986,524 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "Fortran 2003: DT-formatspecificerare är inte tillåten vid %C"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr "X-beskrivare kräver inledande utrymmesantal vid %L"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr "$-beskrivare vid %L"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ måste vara den sista specificeraren i formatet vid %L"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Utökning: Nollbredd efter L-beskrivare vid %L"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Positiv bredd saknas efter L-beskrivare vid %L"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "%<G0%>” i format vid %L"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr "Positiv bredd krävs i formatspecificerare %s vid %L"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "Period krävs i formatangivelse %s vid %L"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "Period krävs i formatangivelse vid %L"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr "Formatspecificeraren H vid %L är en funktion borttagen i Fortran 95"
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "Saknat komma vid %L"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s i formatsträng vid %L"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr "Överflödiga tecken i format vid %L"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr "Formatsats i modulhuvudblock vid %C"
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "FORMAT-sats vid %C kan inte förekomma inuti ett INTERFACE"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Formatetikett saknas vid %C"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr "IOMSG måste vara en scalar-default-char-variable vid %L"
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr "%s kräver ett scalar-default-char-expr vid %L"
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "Ogiltigt värde för %s-specifikation vid %C"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "Dubblerad %s-specifikation vid %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "Variabeln %s får inte vara INTENT(IN) vid %C"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "Variabel %s kan inte tilldelas i en PURE-procedur vid %C"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "Dubblerad %s-etikettspecifikation vid %C"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr "%s är en DEC-utökning vid %C, kompilera om med -fdec för att aktivera"
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "Konstant uttryck i FORMAT-tagg vid %L måste vara av typ CHARACTER"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "FORMAT-tagg vid %L måste ha typen standardsorts CHARACTER eller INTEGER"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "ASSIGNED-variabel i FORMAT-tagg vid %L"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "Variabeln %qs vid %L har inte tilldelats en formatetikett"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr "Skalär %qs i FORMAT-tagg vid %L är inte en ASSIGNED-variabel"
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr "Icke-tecken i FORMAT-tagg vid %L"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "Icke-teckens vektorelement med antagen form i FORMAT-tagg vid %L"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "Icke-teckens vektorelement med antagen storlek i FORMAT-tagg vid %L"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "Icke-teckens pekarvektorelement i FORMAT-tagg vid %L"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "%s-tagg vid %L måste ha typen %s"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "Taggen %s vid %L måste vara en teckensträng av standardsort"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "%s-tagg vid %L måste vara skalär"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr "IOMSG-tagg vid %L"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Fortran 95 kräver standard-INTEGER i %s-tagg vid %L"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr "Icke-standard LOGICAL sort i %s-tagg vid %L"
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr "NEWUNIT-specificerare vid %L"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr "CONVERT-tagg vid %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Fortran 2003: %s-specificerare i %s-sats vid %C har värdet %qs"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "%s-specificerare i %s-sats vid %C har värdet %qs"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "Utökning: %s-specificerare i %s-sats vid %C har värdet %qs"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "%s-specificerare i %s-sats vid %C har ogiltigt värde %qs"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "OPEN-sats är inte tillåten i en PURE-procedur vid %C"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr "UNIT-specificerare är inte tillåten med NEWUNIT vid %C"
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr "NEWUNIT-specificerare måste ha FILE= eller STATUS='scratch' vid %C"
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "OPEN-sats vid %C måste ha antingen UNIT eller NEWUNIT angivet"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr "Typen ACTION står i konflikt med READONLY-specificeraren vid %C"
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "ASYNCHRONOUS= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "BLANK= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "DECIMAL= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "ENCODING= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "ROUND= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "SIGN= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "CLOSE-sats inte tillåten i PURE-procedur vid %C"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "CLOSE-sats vid %L kräver ett UNIT-tal"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT-tal i CLOSE-sats vid %L måste vara ickenegativt"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s-sats är inte tillåtet i PURE-procedur vid %C"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr "UNIT-tal saknas i satsen vid %L"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "UNIT-tal i sats vid %L måste vara ickenegativt"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "FLUSH-sats vid %C"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr "Format saknas med standardenhet vid %C"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Dubblerad UNIT-specifikation vid %C"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Dubblerad formatspecifikation vid %C"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Symbolen %qs i namnlistan %qs är INTENT(IN) vid %C"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Dubblerad NML-specifikation vid %C"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Symbolen %qs vid %C måste vara ett NAMELIST-gruppnamn"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "END-tagg vid %C är inte tillåten i utmatningssats"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "UNIT inte angivet vid %L"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "UNIT-specifikation vid %L måste vara ett INTEGER-uttryck eller en CHARACTER-variabel"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Ogiltig form av WRITE-sats vid %L, UNIT krävs"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Intern enhet med vektorindex vid %L"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Extern IO UNIT får inte vara en vektor vid %L"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "NAMELIST %qs i READ-sats vid %L innehåller symbolen %qs som inte får stå i ett variabeldefinitionssammanhang"
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr "NAMELIST-objektet %qs i namnlistan %qs vid %L med ALLOCATABLE- eller POINTER-komponenter"
+
+#: fortran/io.c:3317
+#, fuzzy, gcc-internal-format
+#| msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "Komma före i/o-elementlista vid %L"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR-taggetikett %d vid %L inte definierad"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END-taggetikett %d vid %L inte definierad"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR-taggetikett %d vid %L inte definierad"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT-etikett %d vid %L inte definierad"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr "io_kind_name(): felaktig I/O-sort"
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Syntaxfel i I/O-iterator vid %C"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Variabel förväntades i READ-sats vid %C"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Förväntade uttryck i %s-sats vid %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfel i %s-sats vid %C"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "Intern fil vid %L med namnlista"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "ASYNCHRONOUS=-specificerare vid %L måste vara ett initieringsuttryck"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "PAD= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "DELIM= vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "PRINT-namnlista vid %C är en utökning"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Komma förväntades i I/O-lista vid %C"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT-sats vid %C är inte tillåten inuti PURE-procedur"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE-sats är inte tillåten i PURE-procedur vid %C"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH-tagg ogiltig i INQUIRE-sats vid %C"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "INQUIRE-sats vid %L får inte innehålla både FILE- och UNIT-specificerare"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "INQUIRE-sats vid %L kräver antingen FILE- eller UNIT-specificerare"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "UNIT-tal i INQUIRE-sats vid %L får inte vara %d"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "INQUIRE-sats vid %L kräver en PENDING=-specificerare med ID=-specificeraren"
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "WAIT vid %C är inte tillåtet i Fortran 95"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "WAIT-sats är inte tillåtet i PURE-procedur vid %C"
@@ -53284,252 +53400,252 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "Generisk specifikation saknas i USE-sats vid %C"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr "Byter namn på operatorer i USE-sats vid %C"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Namnet %qs vid %C har redan använts som ett externt modulnamn"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "SUBMODULE-deklaration vid %C"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "SUBMODULE-deklarationen vid %C får inte förekomma i en annan räckviddsenhet"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Syntaxfel i SUBMODULE-sats vid %C"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "När modul %qs på rad %d kolumn %d lästes: %s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "När modul %qs på rad %d kolumn %d lästes: %s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr "Modul %qs på rad %d kolumn %d: %s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr "require_atom(): felaktig atomtyp begärd"
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Fel när modulfil skrevs: %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr "write_atom(): Skriver negativt heltal"
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr "write_atom(): Försöker skriva dab-atom"
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr "unquote_string(): fick en felaktig sträng"
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr "mio_array_ref(): Okänd vektorreferens"
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Namnlistan %s får inte namnändras av USE-association till %s"
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Tvetydig !$OMP DECLARE REDUCTION från modulen %s vid %L"
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Tidigare !$OMP DECLARE REDUCTION från modulen %s vid %L"
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%qs i modulen %qs, importerad vid %C, är också namnet på den aktuella programenheten"
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Symbolen %qs refererad från %L finns inte i modulen %qs"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Användaroperatorn %qs refererad från %L finns inte i modulen %qs"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Inbyggd operator %qs refererad från %L finns inte i modulen %qs"
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): felaktig modulsymbol %qs"
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbolen inte skriven"
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Kan inte öppna modulfilen %qs för skrivning vid %C: %s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Fel när modulfilen %qs skrevs: %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "Kan inte radera modulfilen %qs: %s"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Kan inte ändra namn på modulfilen %qs till %qs: %s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Kan inte radera temporär modulfil %qs: %s"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Symbolen %qs vid %C är redan deklarerad"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Kan inte skapa en symbol för %s"
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Symbolen %qs, refererad vid %L, finns inte i den valda standarden"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Symbolen %qs refererad från %L hittas inte i den inbyggda modulen ISO_C_BINDING"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbolen %qs är redan deklarerad"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Användning av inbyggd modul %qs vid %C står i konflikt med namn på ej inbyggd modul använd tidigare"
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Användning av namngiven NUMERIC_STORAGE_SIZE-konstant från inbyggd modul ISO_FORTRAN_ENV vid %L är inte kompatibelt med flaggan %qs"
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Användning av namngiven NUMERIC_STORAGE_SIZE-konstant från inbyggd modul ISO_FORTRAN_ENV vid %C är inte kompatibelt med flaggan %s"
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Symbolen %qs refererad vid %L hittas inte i den inbyggda modulen ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "USE-sats vid %C har ingen ONLY-kvalificerare"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "inbyggd modul ISO_FORTRAN_ENV vid %C"
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "ISO_C_BINDING-modul vid %C"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Det finns ingen inbyggd modul med namnet %qs vid %C"
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "IEEE_FEATURES-modul vid %C"
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "IEEE_EXCEPTIONS-modul vid %C"
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "IEEE_ARITHMETIC-modul vid %C"
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Kan inte öppna modulfilen %qs för läsning vid %C: %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Modulfilen %qs har inte genererats, antingen för att modulen inte innehåller en MODULE PROCEDURE eller så finns det ett fel i modulen."
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Användning av ej inbyggd modul %qs vid %C står i konflikt med namn på inbyggd modul använd tidigare"
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Filen %qs öppnad vid %C är inte en GNU Fortran-modulfil"
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Kan inte läsa modulfilen %qs öppnad vid %C, eftersom den skapades av en annan version av GNU Fortran"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr "Det går inte att USE samma %smodul vi bygger!"
@@ -55903,7 +56019,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Kan inte slå upp den specifika funktionen %qs vid %L"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktionen %qs vid %L har ingen IMPLICIT-typ"
@@ -57391,447 +57507,437 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Det generiska namnet %qs på funktionen %qs vid %L är samma namn som den härledda typen vid %L"
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Vektor %qs med antagen storlek i namnlistan %qs vid %L är inte tillåtet"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med antagen form i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant form in namnlistan %qs vid %L"
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-vektorobjektet %qs med icke-konstant längd i namnlistan %qs vid %L"
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr "NAMELIST-objekt %qs i namnlistan %qs vid %L är polymorf och behöver en definierad input/output-procedur"
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "NAMELIST-objektet %qs i namnlistan %qs vid %L med ALLOCATABLE- eller POINTER-komponenter"
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs deklarerades PRIVATE och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har användningsassociativa PRIVATE-komponenter och kan inte vara medlem av namnlistan %qs vid %L"
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-objekt %qs har PRIVATE-komponenter och kan inte vara medlem av PUBLIC-namnlista %qs vid %L"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribut i konflikt med NAMELIST-attribut i %qs vid %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parametervektor %qs vid %L kan inte ha automatisk eller fördröjd form"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implicit typad PARAMETER %qs vid %L matchar inte en senare IMPLICIT-typ"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Inkompatibel härledd typ i PARAMETER vid %L"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "CLASS-variabeln %qs vid %L får inte ha attributet PARAMETER"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Ledsen, allocatable/pointer-komponenter i co-vektor av polymorf (CLASS)-typ vid %L stödjs inte"
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attributet PROTECTED står i konflikt med attributet EXTERNAL vid %L"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attributet PROCEDURE står i konflikt med attributet PROTECTED vid %L"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs vid %L har attributet CONTIGUOUS, men är inte en vektorpekare eller en vektor med antagen form eller antagen ordning"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Vektor med antagen storlek vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Vektor med antagen form vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Vektor med antagen ordning vid %L måste vara ett attrappargument"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Vektor med antagen ordning vid %L kan inte ha attributet VALUE eller CODIMENSION"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol vid %L är inte en DUMMY-variabel"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs vid %L kan inte ha attributet VALUE eftersom det inte är ett attrappargument"
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Teckenvärd attrappvariabel %qs vid %L med attributet VALUE måste ha konstant längd"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-interoperativ teckenattrappvariabel %qs vid %L med attributet VALUE måste ha längd ett"
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Den härledda typen %qs vid %L har typen %qs, som inte har definierats"
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall vara ett attrappargument"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall ha typen TYPE(*) eller en numerisk inbyggd typ"
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variabeln %s vid %L med attributet NO_ARG_CHECK skall antingen vara en skalär eller en vektor med förmodad storlek"
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Den antagna typen på variabeln %s vid %L är bara tillåten för attrappvariabler"
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet ALLOCATABLE, CODIMENSION, POINTER eller VALUE"
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabeln ”%s” med antagen typ vid %L får inte ha attributet INTENT(OUT)"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variabeln %s med antagen typ vid %L får inte vara en vektor med explicit form"
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel %qs vid %L kan inte vara BIND(C) eftersom den varken är ett COMMON-block eller deklarerad med räckvidd modulnivå"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs vid %L har PRIVATE härledd typ %qs"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen LOCK_TYPE eller med en delkomponent av typen LOCK_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variabeln %s vid %L av typen EVENT_TYPE eller med en delkomponent av typen LOCK_TYPE måste vara en co-vektor"
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT)-attrappargumentet %qs vid %L har ASSUMED SIZE och kan därför inte ha en standardinitierare"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av LOCK_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Attrappargumentet %qs vid %L av EVENT_TYPE får inte vara INTENT(OUT)"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsresultat %qs vid %L skall inte vara en co-vektor eller ha en co-vektorkomponent"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variabeln %qs vid %L av TYPE(C_PTR) eller TYPE(C_FUNPTR) får inte vara en co-vektor"
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variabeln %qs vid %L med co-vektorkomponent skall vara en skalär som inte är en pekare eller allokerbar och inte en co-vektor"
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variabeln %qs vid %L är en co-vektor och är inte ALLOCATABLE, SAVE eller ett attrappargument"
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Co-vektorvariabeln %qs vid %L skall inte ha co-dimensioner med fördröjd form"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allokerbar co-vektorvariabel %qs vid %L måste ha en fördröjd form"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variabeln %qs vid %L är INTENT(OUT) och kan alltså inte vara en allokerbara co-vektor eller har co-vektorkomponenter"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Co-attrappvariabeln %qs vid %L är inte tillåten i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-attrappargumentet %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-resultatvariabeln %qs vid %L med icke-C_Bool-sort i BIND(C)-proceduren %qs"
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Namnlistan %qs får inte vara ett argument till en subrutin eller funktion vid %L"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Trådprivat vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "!$OMP DECLARE TARGET-variabeln %qs vid %L är inte SAVE:ad"
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Felaktigt uttryck"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA-element %qs vid %L måste vara i COMMON"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-vektor %qs vid %L måste anges i en tidigare deklaration"
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-elementet %qs vid %L kan inte ha ett co-index"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-element %qs vid %L är en pekare och måste då vara en fullständig vektor"
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Ickekonstant vektorsektion vid %L i DATA-sats."
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-sats vid %L har fler variabler än värden"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "början av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "slutet av implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "steget i implicerad do-slinga vid %L kan inte förenklas till ett konstant värde"
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-sats vid %L har fler värden än variabler"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Etiketten %d vid %L är definierad men inte använd"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Etiketten %d vid %L är definierad men kan inte användas"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L måste ha attributet SEQUENCE för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L kan inte ha ALLOCATABLE-komponenter för att vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Härledd typvariabel %qs vid %L med standardinitiering kan inte vara i EQUIVALENCE med en variabel i COMMON"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Härledd typvariabel %qs vid %L med pekarkomponent(er) kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfel i EQUIVALENCE-sats vid %L"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Antingen alla eller inget av objekten i EQUIVALENCE-mängden vid %L kan ha attributet PROTECTED"
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Common-blockmedlem %qs vid %L kan inte vara ett EQUIVALENCE-objekt i den rena proceduren %qs"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Namngiven konstant %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Vektor %qs vid %L med icke-konstanta gränser kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Postkomponent %qs vid %L kan inte vara ett EQUIVALENCE-objekt"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Delsträng vid %L har längden noll"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-funktionen %qs vid %L har PRIVATE typ %qs"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs vid %L har ingen IMPLICIT-typ"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Användaroperatorprocedur %qs vid %L måste vara en FUNCTION"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Användaroperatorprocedur %qs vid %L får inte ha antagen teckenlängd"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Användaroperatorprocedur %qs vid %L måste ha åtminstone ett argument"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Första argumentet till operatorgränssnitt vid %L får inte vara frivilligt"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Andra argumentet till operatorgränssnitt vid %L får inte vara valfritt"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorgränssnitt vid %L måste ha, högst, två argument"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Innesluten procedur %qs vid %L i en PURE-procedur måste också vara PURE"
@@ -58915,12 +59021,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Händelsevariabeln vid %L får inte vara co-indexerad"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr "build_dt: format med namnlista"
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "Felaktig IO-bastyp (%d)"
Index: gcc/po/de.po
===================================================================
--- gcc/po/de.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/de.po	(.../branches/gcc-7-branch)
@@ -8,10 +8,10 @@
 # Roland Illig <roland.illig@gmx.de>, 2015, 2017.
 msgid ""
 msgstr ""
-"Project-Id-Version: gcc 7.1.0\n"
+"Project-Id-Version: gcc 7.2.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
-"PO-Revision-Date: 2017-05-03 22:55+0200\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
+"PO-Revision-Date: 2017-08-20 23:01+0200\n"
 "Last-Translator: Roland Illig <roland.illig@gmx.de>\n"
 "Language-Team: German <translation-team-de@lists.sourceforge.net>\n"
 "Language: de\n"
@@ -20,7 +20,7 @@
 "Content-Transfer-Encoding: 8bit\n"
 "X-Bugs: Report translation errors to the Language-Team address.\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
-"X-Generator: Poedit 2.0.1\n"
+"X-Generator: Poedit 2.0.3\n"
 
 #: cfgrtl.c:2661
 msgid "flow control insn inside a basic block"
@@ -198,13 +198,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "Gleitkommakonstante falsch verwendet"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -498,62 +498,62 @@
 " Um weitere Optionen an diese Prozesse zu übergeben, müssen die Optionen\n"
 " -W<Buchstabe> verwendet werden.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Spezifikation (%s, ist »%s«) wird verarbeitet\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Ziel: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Konfiguriert mit: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Thread-Modell: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc-Version %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "gcc-Treiberversion %s %s führt GCC-Version %s aus\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr "Der Fehler ist nicht reproduzierbar, daher handelt es sich wahrscheinlich um ein Problem mit der Hardware oder dem Betriebssystem.\n"
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr "Vorverarbeiteter Quellcode wurde in Datei %s gespeichert, bitte hängen Sie die an Ihren Fehlerbericht an.\n"
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "installiere: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "Programme: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "Bibliotheken: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -564,16 +564,16 @@
 "folgenden Hinweise; Fehler in der deutschen Übersetzung sind an\n"
 "translation-team-de@lists.sourceforge.net zu melden:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "(C)"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -583,7 +583,7 @@
 "gibt KEINE Garantie; auch nicht für MARKTGÄNGIGKEIT oder FÜR SPEZIELLE ZWECKE.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -596,7 +596,7 @@
 "==============\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -605,7 +605,7 @@
 "»-Wl,OPTION« verwenden, um »OPTION« an den Linker zu übergeben.\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -616,7 +616,7 @@
 "=================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -630,16 +630,16 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr "  merge [Optionen] <Ordner1> <Ordner2>  Abdeckungsdateien zusammenführen\n"
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "    -o, --output <Verzeichnis>          Ausgabeverzeichnis\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "    -v, --verbose                       Ausführlicher Modus\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "    -o, --output <Verzeichnis>          Ausgabeverzeichnis\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -655,16 +655,16 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr "  rewrite [Optionen] <Verzeichnis>      Inhalt der Abdeckungsdatei umschreiben\n"
 
+#: gcov-tool.c:270
+#, c-format
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgstr "    -n, --normalize <int64_t>           Profil normalisieren\n"
+
 #: gcov-tool.c:272
 #, c-format
 msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr "    -s, --scale <Gleitkomma oder einfacher Bruch>  Profilzähler skalieren\n"
 
-#: gcov-tool.c:273
-#, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
-msgstr "    -n, --normalize <int64_t>           Profil normalisieren\n"
-
 #: gcov-tool.c:290
 #, c-format
 msgid "Rewrite subcommand usage:"
@@ -690,27 +690,27 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr "  overlap [Optionen] <Verz1> <Verz2>    Überlappung zwischen zwei Profilen berechnen\n"
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "    -h, --hotonly                       Daten nur für heiße Objekte/Funktionen ausgeben\n"
-
-#: gcov-tool.c:422
-#, c-format
 msgid "    -f, --function                      Print function level info\n"
 msgstr "    -f, --function                      Daten über Funktionsebene ausgeben\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:421
 #, c-format
 msgid "    -F, --fullname                      Print full filename\n"
 msgstr "    -F, --fullname                      Vollständigen Dateinamen ausgeben\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:422
 #, c-format
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr "    -h, --hotonly                       Daten nur für heiße Objekte/Funktionen ausgeben\n"
+
+#: gcov-tool.c:423
+#, c-format
 msgid "    -o, --object                        Print object level info\n"
 msgstr "    -o, --object                        Daten über Objektebene ausgeben\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr "    -t <Gleitkomma>, --hot_threshold <Gleitkomma>  Schwellwert für Heißheit festlegen\n"
@@ -797,20 +797,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Diese Hilfe anzeigen\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Informationen für jeden Basisblock zeigen\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Zweigwahrscheinlichkeiten in Ausgabe aufnehmen\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -819,16 +814,21 @@
 "  -c, --branch-counts             Anzahl der Zweigdurchläufe statt\n"
 "                                    Prozentzahlen ausgeben\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          Fortschrittsinformationen anzeigen\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Ausgabezusammenfassungen für jede Funktion\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Diese Hilfe anzeigen\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1015,82 +1015,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s: Graph ist für »%s« unlösbar\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "%s von %d Zeilen ausgeführt\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Keine ausführbaren Zeilen\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s: »%s«\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "%s von %d Zweigen ausgeführt\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "%s von %d Zweigen mindestens einmal genommen\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Keine Zweige\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "%s von %d Aufruf(en) ausgeführt\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Keine Aufrufe\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s: keine Zeilen für »%s«\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "Aufruf %2d gab %s zurück\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "Aufruf %2d niemals ausgeführt\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "Zweig %2d wurde genommen: %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "Zweig %2d niemals ausgeführt\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "unbedingtes %2d, genommen: %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "unbedingtes %2d niemals ausgeführt\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "Quelldatei %s kann nicht geöffnet werden\n"
@@ -1197,89 +1197,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr "Die Verwendung dieser Option wird diagnostiziert."
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr "Standard %d Minimum %d Maximum %d"
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr "Identisch mit %s. Verwenden Sie daher bitte diese Option."
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s ist identisch mit %s."
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[Standard]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[eingeschaltet]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[ausgeschaltet]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Keine Optionen mit den gewünschten Eigenschaften gefunden\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Nichts gefunden. Bitte verwenden Sie »--help=%s«, um *alle* vom Frontend %s unterstützten Optionen anzuzeigen\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Alle Optionen mit den gewünschten Eigenschaften wurden bereits angezeigt\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "Die folgenden Optionen sind zielspezifisch"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "Die folgenden Optionen steuern Warnmeldungen des Compilers"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "Die folgenden Optionen steuern Optimierungen"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "Die folgenden Optionen sind sprach-unabhängig"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "Die Option »--param« erkennt die folgenden Parameter"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "Die folgenden Optionen sind nur spezifisch für die Sprache "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "Die folgenden Optionen werden von der Sprache unterstützt "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "Die folgenden Optionen sind nicht dokumentiert"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "Die folgenden Optionen verwenden separate Argumente"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "Die folgenden Optionen verwenden gemeinsame Argumente"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "Die folgenden Optionen sind sprachbezogen"
 
@@ -2806,8 +2806,8 @@
 msgid "<command-line>"
 msgstr "<Kommandozeile>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Operand für Code »%c« nicht unterstützt"
@@ -2826,7 +2826,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr "unverträglicher Gleitkomma- / Vektorregisteroperand für »%%%c«"
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "fehlender Operand"
@@ -2846,8 +2846,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "ungültiger Operandenpräfix »%%%c«"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "»%%&« ohne lokale dynamische TLS-Referenzen verwendet"
@@ -2863,18 +2863,18 @@
 msgstr "ungültiger %%r-Wert"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "ungültiger %%R-Wert"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "ungültiger %%N-Wert"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "ungültiger %%P-Wert"
@@ -2884,7 +2884,7 @@
 msgid "invalid %%h value"
 msgstr "ungültiger %%h-Wert"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "ungültiger %%L-Wert"
@@ -2905,7 +2905,7 @@
 msgstr "ungültiger %%U-Wert"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "ungültiger %%s-Wert"
@@ -2915,7 +2915,7 @@
 msgid "invalid %%C value"
 msgstr "ungültiger %%C-Wert"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "ungültiger %%E-Wert"
@@ -2926,7 +2926,7 @@
 msgstr "Unbekanntes relocation unspec"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "ungültiger %%xn-Code"
@@ -2989,7 +2989,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "ungültiger Operanden-Ausgabecode"
@@ -2999,29 +2999,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "ungültiges UNSPEC als Operand: %d"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "ungültiger Schiebeoperand"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "bedingter Thumb-Befehl"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "bedingter Befehl in bedingter Sequenz"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3029,101 +3029,101 @@
 msgid "invalid operand for code '%c'"
 msgstr "ungültiger Operand für Code »%c«"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "Befehl wird niemals ausgeführt"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "veralteter Maverick-Formatcode »%c«"
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "Adressoperand erfordert Beschränkung für X-, Y- oder Z-Register"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "Operanden für %T/%t müssen reg + const_int sein:"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr "falsche Adresse, keine E/A-Adresse:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 msgid "bad address, not a constant:"
 msgstr "falsche Adresse, keine Konstante:"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "Falsche Adresse, nicht (reg+disp):"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "Falsche Adresse, nicht post_inc oder pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "Interner Compiler-Fehler. Falsche Adresse:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "Code »%c« für Festkomma nicht unterstützt:"
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "Interner Compiler-Fehler. Unbekannter Modus:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "Ungültiger Befehl:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "Falscher Befehl:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "Falscher Kopierbefehl:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "Falscher Schiebe-Befehl:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "Interner Compiler-Fehler. Falsche Verschiebung:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 msgid "unsupported fixed-point conversion"
 msgstr "Festkommaumwandlung nicht unterstützt"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr "Variable"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 msgid "function parameter"
 msgstr "Funktionsparameter"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 msgid "structure field"
 msgstr "Strukturfeld"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 msgid "return type of function"
 msgstr "Rückgabetyp für Funktion"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr "Zeiger"
 
@@ -3147,7 +3147,7 @@
 msgstr "ungültiger const_double-Operand"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3369,87 +3369,87 @@
 msgid "bad output_condmove_single operand"
 msgstr "Falscher Operand für output_condmove_single"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "ungültiges UNSPEC als Operand"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, c-format
 msgid "invalid use of asm flag output"
 msgstr "ungültige Verwendung der asm-Schalter-Ausgabe"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "ungültige Operandengröße für Operandencode »O«"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "ungültige Operandengröße für Operandencode »z«"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "ungültiger Operandentyp mit Operandencode »Z« verwendet"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "ungültige Operandengröße für Operandencode »Z«"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »Y«"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »D«"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Operand ist kein Bedingungscode, ungültiger Operandencode »%c«"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "Operand ist keine ausgleichbare Speicherreferenz, ungültiger Operandencode »H«"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "Operand ist keine Ganzzahl, ungültiger Operandencode »K«"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "Operand ist keine bestimmte Ganzzahl, ungültiger Operandencode »r«"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "Operand ist keine Ganzzahl, ungültiger Operandencode »R«"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "Operand ist keine bestimmte Ganzzahl, ungültiger Operandencode »R«"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "ungültiger Operandencode »%c«"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "ungültige Bedingungen für Operand"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "unbekannter Befehlsmodus"
 
@@ -3486,7 +3486,7 @@
 msgid "invalid %%P operand"
 msgstr "ungültiger %%P-Operand"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "ungültiger %%p-Wert"
@@ -3540,7 +3540,7 @@
 msgstr "Post-Increment-Adresse ist kein Register"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "Falsche Adresse"
 
@@ -3573,7 +3573,7 @@
 msgstr "Befehl enthält eine ungültige Adresse!"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "ungültige Adresse"
 
@@ -3664,277 +3664,277 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "»%s« in der Shell könnte diese Beschränkung erhöhen.\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr "-maltivec=le ist nicht für Big-Endian-Zielsysteme erlaubt"
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx benötigt Hardware-Gleitkommabefehle"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "»-mvsx« und »-mpaired« sind unverträglich"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx benötigt indizierte Adressierung"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "»-mvsx« und »-mno-altivec« sind unverträglich"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec schaltet vsx aus"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory benötigt 64-Bit-Modus"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr "-mquad-memory-atomic benötigt 64-Bit-Modus"
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "-mquad-memory ist im Little-Endian-Modus nicht verfügbar"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mtoc-fusion benötigt 64-bit-Zielarchitektur"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr "»-mtoc-fusion« benötigt medium/large-Codemodell"
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr "ungültige Bewegung"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr "Falsche 128-Bit-Verschiebung"
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, c-format
 msgid "invalid %%e value"
 msgstr "ungültiger %%e-Wert"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "ungültiger %%f-Wert"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "ungültiger %%F-Wert"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "ungültiger %%G-Wert"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "ungültiger %%j-Code"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "ungültiger %%J-Code"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "ungültiger %%k-Wert"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "ungültiger %%K-Wert"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "ungültiger %%O-Wert"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "ungültiger %%q-Wert"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "ungültiger %%T-Wert"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "ungültiger %%u-Wert"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "ungültiger %%v-Wert"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "ungültiger %%x-Wert"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "ungültiger %%y-Wert, bitte »Z«-Bedingung probieren"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr "__float128 und __ibm128 können nicht im selben Ausdruck verwendet werden"
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "__ibm128 und long double können nicht im gleichen Ausdruck verwendet werden"
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr "__float128 und long double können nicht im selben Ausdruck verwendet werden"
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 msgid "Could not generate addis value for fusion"
 msgstr "addis-Wert für Fusion kann nicht erzeugt werden"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Lade-/Speicheroffset für Fusion kann nicht generiert werden"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr "Falsche GPR-Fusion"
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr "emit_fusion_p9_load, falsches Register #1"
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr "emit_fusion_p9_load, falsches Register #2"
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr "emit_fusion_p9_load kein MEM"
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr "emit_fusion_p9_store, falsches Register #1"
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr "emit_fusion_p9_store, falsches Register #2"
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr "emit_fusion_p9_store kein MEM"
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "symbolische Speicherreferenzen werden nur auf z10 oder neuer unterstützt"
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "Adresse kann nicht zerlegt werden"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "ungültiger Vergleichsoperator für Ausgabemodifizierer »E«"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "ungültige Referenz für Ausgabemodifizierer »J«"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »O«"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »R«"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "Speicherreferenz für Ausgabemodifizierer »S« erwartet"
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "ungültige Adresse für Ausgabemodifizierer »S«"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "Register oder Speicherausdruck für Ausgabemodifizierer »N« erwartet"
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "Register oder Speicherausdruck für Ausgabemodifizierer »M« erwartet"
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "ungültige Konstante für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "Ungültige Konstante – anderen Ausgabemodifizierer probieren"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "ungültiger konstanter Vektor für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "ungültiger Ausdruck – anderen Ausgabemodifizierer probieren"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "ungültiger Ausdruck für Ausgabemodifizierer »%c«"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 msgid "vector argument passed to unprototyped function"
 msgstr "Vektor-Argument an Funktion ohne Prototyp übergeben"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 msgid "types differ in signedness"
 msgstr "Typen unterscheiden sich im Vorzeichenbesitz"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr "binärer Operator unterstützt keine zwei bool-Vektor-Operanden"
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr "Binärer Operator unterstützt Boolean-Vektor-Argument nicht"
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr "binärer Operator unterstützt nicht, dass bool-Vektor mit Gleitkommavektor vermischt wird"
 
@@ -3960,43 +3960,43 @@
 msgid "created and used with different endianness"
 msgstr "erzeugt und mit anderer Bytereihenfolge verwendet"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "ungültiger %%Y-Operand"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "ungültiger %%A-Operand"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "ungültiger %%B-Operand"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "ungültiger %%C-Operand"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "ungültiger %%D-Operand"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "ungültiger %%f-Operand"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "ungültiger %%s-Operand"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr "Gleitkommakonstante ist kein gültiger direkter Operand"
@@ -4158,30 +4158,30 @@
 msgid "bad test"
 msgstr "Falscher Test"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "ungültiger %%D-Wert"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "ungültige Maske"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "ungültiger %%d-Wert"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "ungültiger %%t/%%b-Wert"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "Kein Register in Adresse"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "Adressversatz ist keine Konstante"
 
@@ -4202,8 +4202,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> erwartet"
@@ -4225,14 +4225,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> erwartet"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> erwartet"
@@ -4263,7 +4263,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> erwartet"
@@ -4271,7 +4271,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> erwartet"
@@ -4281,7 +4281,7 @@
 msgstr "%<;%>, %<,%> oder %<)%> erwartet"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> erwartet"
@@ -4288,7 +4288,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> erwartet"
@@ -4298,7 +4298,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> erwartet"
@@ -4311,24 +4311,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "Cilk-Array-Notation kann nicht in throw-Ausdruck verwendet werden"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr "Cilk-Array-Notation kann nicht als Bedingung für switch-Anweisung verwendet werden"
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr "Cilk-Array-Notation kann nicht als Bedingung für while-Schleife verwendet werden"
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> erwartet"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr "Cilk-Array-Notation kann nicht als Bedingung für eine do-while-Schleife verwendet werden"
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr "Cilk-Array-Notation kann nicht als Bedingung für eine for-Schleife verwendet werden"
 
@@ -4336,18 +4336,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> erwartet"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> erwartet"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> erwartet"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> oder %<)%> erwartet"
@@ -4355,17 +4355,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> erwartet"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> oder %<}%> erwartet"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> erwartet"
@@ -4374,7 +4374,7 @@
 msgid "(anonymous)"
 msgstr "(anonym)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<%> erwartet"
@@ -4383,11 +4383,11 @@
 msgid "expected label"
 msgstr "Sprungmarke erwartet"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "Kandidat 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "Kandidat 2:"
 
@@ -4606,11 +4606,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%r%s:%d:%R   in constexpr-Ersetzung von %qs"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "Kandidaten sind:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "Kandidat ist:"
@@ -4781,80 +4781,80 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "effektives Argument für INTENT = OUT/INOUT"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "Positive Breite benötigt"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "Nicht-negative Breite benötigt"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Unerwartetes Element %qc in Formatzeichenkette bei %L"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "Unerwartetes Ende der Formatzeichenkette"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr "Breite null in Formatbeschreibung"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "Führende linke Klammer fehlt"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 msgid "Left parenthesis required after %<*%>"
 msgstr "Linke Klammer benötigt nach %<*%>"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "P-Edit-Deskriptor erwartet"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "P-Deskriptor benötigt führenden Skalierungsfaktor"
 
-#: fortran/io.c:726
-#, c-format
-msgid "Right parenthesis expected at %C"
-msgstr "Schließende Klammer erwartet bei %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr "Nach P-Deskriptor Komma benötigt"
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr "Mit T-Deskriptor positive Breite benötigt"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "E-Symbol nicht erlaubt mit g0-Deskriptor"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "Positive Exponentenbreite erforderlich"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, c-format
+msgid "Right parenthesis expected at %C"
+msgstr "Schließende Klammer erwartet bei %C"
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr "Punkt in Formatspezifikation erforderlich"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr "%s-Symbol"
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr "interne Einheit in WRITE"
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s-Symbol mit INQUIRE"
@@ -4864,75 +4864,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "Syntaxfehler in Ausdruck bei %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Unerwartetes EOF"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Ganzzahlüberlauf"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "Name zu lang"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Schlechter Name"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Name erwartet"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "Linke Klammer erwartet"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "Rechte Klammer erwartet"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Ganzzahl erwartet"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Zeichenkette erwartet"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum(): Enum not found"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "Attributbitname erwartet"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Ganzzahlzeichenkette erwartet"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "Fehler beim Umwandeln einer Ganzzahl"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Echte Zeichenkette erwartet"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "Ausdruckstyp erwartet"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "Falscher Operator"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "Falscher Typ in Konstanten-Ausdruck"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "Unerwartetes Modulende"
 
@@ -5177,12 +5177,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Effektive Zeichenkettenlänge ist kürzer als die deklarierte für Scheinargument »%s« (%ld/%ld)"
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "Ziel für neue Rangabbildung ist zu klein (%ld < %ld)"
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr "Zuweisung von Skalar zu unalloziertem Array"
 
@@ -5527,7 +5527,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "»-m32« und »-m64« können nicht zusammen angegeben werden"
 
@@ -8406,7 +8406,7 @@
 msgstr "Bit-Breite des unmittelbaren TLS-Versatzes angeben."
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr "Code für die gegebene CPU planen."
@@ -8627,7 +8627,7 @@
 msgid "target the software simulator."
 msgstr "Auf den Software-Simulator abzielen."
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr "LRA statt »reload« verwenden."
 
@@ -8844,12 +8844,12 @@
 msgid "Use 80-bit long double."
 msgstr "80-bit long double verwenden."
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 msgid "Use 64-bit long double."
 msgstr "64-bit long double verwenden."
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr "128-bit long double verwenden."
@@ -9861,87 +9861,87 @@
 msgid "64 bit ABI."
 msgstr "64-Bit-ABI."
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr "Rückwärtskettenzeiger pflegen."
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr "Zusätzliche Fehlerprotokollausdrucke."
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr "ESA/390-Architektur."
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 msgid "Enable decimal floating point hardware support."
 msgstr "Hardwareunterstützung für dezimales Gleitkomma einschalten."
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 msgid "Enable hardware floating point."
 msgstr "Hardware-Gleitkommabefehle einschalten."
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr "Akzeptiert zwei durch Komma getrennte nichtnegative ganze Zahlen. Die erste Zahl gibt an, wie viele Zwei-Byte-NOP-Befehle vor der Funktionssprungmarke eingefügt werden. Die zweite Zahl gibt an, wie viele Halbwörter nach der Funktionssprungmarke mit NOP-Befehlen aufgefüllt werden. Es werden immer die größtmöglichen NOP-Befehle (6, 4 oder 2 Bytes) verwendet. Die Angabe von »0,0« schaltet das Hotpatching aus."
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 msgid "Use hardware transactional execution instructions."
 msgstr "Hardware-Transaktionsausführungs-Befehle verwenden."
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "Hardware-Vektorbefehle verwenden und die Vektor-ABI einschalten."
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr "Gepacktes Stapellayout verwenden."
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr "bras für ausführbare Datei < 64k verwenden."
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 msgid "Disable hardware floating point."
 msgstr "Hardware-Gleitkommabefehle ausschalten."
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "Höchstanzahl der Bytes angeben, die noch im Stapel übrig sind, bevor ein Trap-Befehl ausgelöst wird."
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr "Die Option »-mstack-guard« ausschalten."
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "Zusätzlichen Code im Funktionsprolog ausgeben, um ein Überschreiten des angegebenen Limits für die Stapelgröße abzufangen (trap)."
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr "Die Option »-mstack-size« ausschalten."
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 msgid "Use the mvcle instruction for block moves."
 msgstr "mvcle-Befehl für Blockkopieroperationen verwenden."
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr "Die z-Vektor-Spracherweiterung einschalten, die das kontextabhängige Vektormakro einschaltet und eingebaute Funktionen im Altivec-Stil aus vecintrin.h einschaltet."
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "Warnen, wenn eine Funktion alloca verwendet oder ein Array dynamischer Größe erzeugt."
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "Warnen, wenn Rahmengröße einer einzelnen Funktion die angegebene Rahmengröße überschreitet."
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr "z/Architektur."
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr "Sprungkosten für bedingte Sprungbefehle setzen. Angemessene Werte sind kleine, nicht-negative Ganzzahlen. Standard ist 1."
 
@@ -9993,11 +9993,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr "Bekannte ARM-CPUs (für Verwendung mit Optionen -mcpu= und -mtune=):"
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr "Bekannte ARM-Architekturen (für Verwendung mit Option -march=):"
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr "Bekannte ARM-FPUs (für Verwendung mit Option -mfpu=):"
 
@@ -10223,78 +10223,94 @@
 msgstr "Visuelle Befehlssatzerweiterungen Version 4.0 für UltraSPARC verwenden."
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr "Zusätzliche VIS-Befehle verwenden, die in OSA2017 hinzugefügt wurden."
+
+#: config/sparc/sparc.opt:90
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "Vergleich-und-Sprung-Erweiterungen für UltraSPARC verwenden."
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "Multiplizier-Addier-Erweiterungen für UltraSPARC verwenden."
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Hardware-Gleitkommabefehle für Multiplikation von einfacher auf doppelte Genauigkeit (FsMULd) verwenden."
+
+#: config/sparc/sparc.opt:102
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "Bitzähl-Befehl für UltraSPARC verwenden."
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "Befehl für erweitertes Subtrahieren mit Übertrag für UltraSPARC verwenden."
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 msgid "Pointers are 64-bit."
 msgstr "Zeiger sind 64 Bit."
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 msgid "Pointers are 32-bit."
 msgstr "Zeiger sind 32 Bit."
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 msgid "Use 64-bit ABI."
 msgstr "64-Bit-ABI verwenden."
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 msgid "Use 32-bit ABI."
 msgstr "32-Bit-ABI verwenden."
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr "Stapelversatz verwenden."
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Structs an stärkeren Grenzen ausrichten, um Daten doppelwortweise zu kopieren."
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Ende-Aufruf-Befehle in Assembler und Binder optimieren."
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr "Keinen Code generieren, der nur im Supervisor-Modus läuft (Standard)."
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr "Eigenschaften der gegebenen CPU verwenden und entsprechend Code planen."
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr "Gegebenes SPARC-V9-Codemodell verwenden."
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 msgid "Enable debug output."
 msgstr "Ausgaben zur Fehlersuche einschalten."
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "Strenge Prüfung für 32-bit psABI Strukturrückgabe einschalten"
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr "Workaround für einzelnes Erratum des AT697F-Prozessors einschalten (entspricht Erratum #13 des Prozessors AT697E)."
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr "Workaround für Errata des UT699-Prozessors einschalten."
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr "Workarounds für Errata des UT699E/UT700-Prozessors einschalten."
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr "Workarounds für Errata des GR712RC-Prozessors einschalten."
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr "Für Programm zu verwendendes Speichermodell angeben"
 
@@ -14638,7 +14654,7 @@
 msgstr "Ausführungspfade erkennen, die durch Dereferenzieren eines Nullzeigers fehlerhaftes oder undefiniertes Verhalten auslösen. Solche Pfade werden aus dem Hauptablauf herausgenommen und durch eine Trap ersetzt."
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr "Ausführungspfade erkennen, die ausgelöst werden, indem ein Nullwert auf eine Weise verwendet wird, die durch ein »returns_nonnull«- oder »nonnull«-Attribut verboten ist. Solche Pfade werden aus dem Hauptablauf herausgenommen und durch eine Trap ersetzt."
 
 #: common.opt:2502
@@ -15040,7 +15056,7 @@
 msgstr "boolescher Typ erwartet"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, gcc-internal-format
 msgid "expected integer"
 msgstr "Ganzzahl erwartet"
@@ -15318,125 +15334,125 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr "Bereichsklausel muss vom Typ Array, Scheibe, Zeichenkette, Map oder Kanal sein"
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 msgid "invalid comparison of non-ordered type"
 msgstr "ungültiger Vergleich ungeordneter Typen"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr "Ausschnitt kann nur mit nil verglichen werden"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr "Abbildung kann nur mit nil verglichen werden"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr "Funktion kann nur mit nil verglichen werden"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, c-format
 msgid "invalid operation (%s)"
 msgstr "ungültige Operation (%s)"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 msgid "invalid comparison of non-comparable type"
 msgstr "ungültiger Vergleich eines nicht-vergleichbaren Typs"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 msgid "invalid comparison of generated struct"
 msgstr "ungültiger Vergleich mit einer generierten Struktur"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr "ungültiger Vergleich einer nicht-vergleichbaren Struktur"
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 msgid "invalid comparison of generated array"
 msgstr "ungültiger Vergleich eines generierten Arrays"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr "ungültiger Vergleich eines nicht-vergleichbaren Arrays"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr "Funktionsaufruf mit mehreren Werten in Kontext mit einem Wert"
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr "ausdrückliche Umwandlungen erforderlich"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr "Typ %s kann nicht als Typ %s verwendet werden"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr "unterschiedliche Empfängertypen"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr "unterschiedliche Parameteranzahl"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr "unterschiedliche Parametertypen"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr "unterschiedliche variable Argumente"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr "unterschiedliche Ergebnisanzahl"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr "unterschiedliche Ergebnistypen"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "explizite Umwandlung nötig; Methode %s%s%s fehlt"
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "Inkompatibler Typ für Methode %s%s%s"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "Inkompatibler Typ für Methode %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr "Zeiger auf Schnittstellentyp hat keine Methoden"
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr "Typ hat keine Methoden"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "mehrdeutige Methode %s%s%s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "fehlende Methode %s%s%s"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "Methode %s%s%s erfordert einen Zeigerempfänger"
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "Methode %s%s%s ist als go:nointerface gekennzeichnet"
@@ -15611,7 +15627,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr "angegebene Grenze %wu ist genau die Größe des Ziels"
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "Zu wenige Argumente für %<va_start%>"
@@ -15673,27 +15689,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "ungültiges Speichermodell für %<__atomic_load%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "ungültiges Speichermodell für %<__atomic_store%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "nicht-konstantes Argument 1 für __atomic_always_lock_free"
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "nicht-ganzzahliges Argument 1 für __atomic_is_lock_free"
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_thread_pointer wird für dieses Ziel nicht unterstützt"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_set_thread_pointer wird für dieses Ziel nicht unterstützt"
@@ -15700,7 +15716,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kungültige Verwendung von %<__builtin_va_arg_pack ()%>"
@@ -15707,12 +15723,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kungültige Verwendung von %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "Zweites Argument für %<__builtin_longjmp%> muss 1 sein"
@@ -15719,62 +15735,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "Zielformat unterstützt »-fcheck-pointer-bounds« nicht"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "Zielformat unterstützt nicht »unendlich«"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> in Funktion mit fester Parameterzahl verwendet"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "falsche Anzahl der Argumente für Funktion %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> ohne Argument gerufen"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "falsche Anzahl der Argumente für Funktion %<__builtin_next_arg%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "Zweiter Parameter von %<va_start%> ist nicht letztgenanntes Argument"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "undefiniertes Verhalten, wenn zweiter Parameter von %<va_start%> mit %<register%>-Speicherklasse deklariert wird"
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%Kerstes Argument von %D muss ein Zeiger, das zweite eine Ganzzahlkonstante sein"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%Kletztes Argument von %D ist keine Ganzzahlkonstante zwischen 0 und 3"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%KVersuch, Nicht-Heap-Objekt %qD freizugeben"
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%KVersuch, Nicht-Heap-Objekt freizugeben"
@@ -16683,12 +16699,12 @@
 msgstr "Attribut %<weakref%> ignoriert, da Variable bereits initialisiert ist"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F verwendet, aber nirgendwo definiert"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F als %<static%> deklariert, aber nirgendwo definiert"
@@ -16783,12 +16799,12 @@
 msgid "cannot find '%s'"
 msgstr "»%s« kann nicht gefunden werden"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init gescheitert: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -16798,7 +16814,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER muss gesetzt sein"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17009,7 +17025,7 @@
 msgid "error writing %qs"
 msgstr "Fehler beim Schreiben von %qs"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "»%s« kann nicht geöffnet werden"
@@ -17089,17 +17105,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr "möglicherweise in Konflikt stehende Option %<-fopt-info-%s%> wird ignoriert"
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "Mehrere EH-Persönlichkeiten werden nur mit Assemblern unterstützt, die die Direktive .cfi_personality unterstützen"
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "Nicht-Delegitimiertes UNSPEC %s (%d) am Variablenort gefunden"
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr "-feliminate-dwarf2-dups ist in C++ kaputt, wird ignoriert"
@@ -17210,12 +17226,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr "Schreiben von %wu Bit Daten außerhalb der Grenzen des Zielobjekts, Daten wurden auf %wu Bit abgeschnitten"
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%KAufruf von %qs mit Attributfehler deklariert: %s"
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%KAufruf von %qs mit Attributwarnung deklariert: %s"
@@ -17230,12 +17246,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "die Rahmengröße von %wd Bytes überschreitet %wd Bytes"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "endgültige Abzugsdatei %qs der Befehle konnte nicht geöffnet werden: %m"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "endgültige Abzugsdatei %qs der Befehle konnte nicht geschlossen werden: %m"
@@ -17250,7 +17266,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "Vergleich ist immer %d wegen Breite des Bitfeldes"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Bereichsprüfung vereinfacht wird"
@@ -17280,7 +17296,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "Annahme, dass vorzeichenbehafteter Überlauf nicht auftritt, wenn Konstanten um einen Vergleich kombiniert werden"
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "Faltungstest: ursprünglicher Baum durch Faltung geändert"
@@ -17290,7 +17306,7 @@
 msgid "total size of local objects too large"
 msgstr "Gesamtgröße der lokalen Objekte zu hoch"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "unmögliche Bedingung in »asm«"
@@ -17390,62 +17406,67 @@
 msgid "input file %qs is the same as output file"
 msgstr "Eingabedatei %qs ist dieselbe wie die Ausgabedatei"
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, gcc-internal-format
+msgid "output filename may not be empty"
+msgstr "Name der Ausgabedatei darf nicht leer sein"
+
+#: gcc.c:4501
+#, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "-pipe ignoriert, da -save-temps angegeben"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "%<-x %s%> hinter letzter Eingabedatei hat keine Auswirkung"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr "Standard-Linkerscript %qs kann nicht in den Bibliotheks-Suchpfaden gefunden werden"
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "Schalter %qs beginnt nicht mit %<-%>"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr "aus Spezifikation erzeugtes switch ist nur %<-%>"
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "temporäre Antwortdatei %s konnte nicht geöffnet werden"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "in temporäre Antwortdatei %s konnte nicht geschrieben werden"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "temporäre Antwortdatei %s konnte nicht geschlossen werden"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "Spezifikation %qs ist ungültig"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "Spezifikation %qs hat ungültiges %<%%0%c%>"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "Spezifikation %qs hat ungültiges %<%%W%c%>"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "Spezifikation %qs hat ungültiges %<%%x%c%>"
@@ -17453,228 +17474,228 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "Spezifikationsfehler: %<%%*%> wurde nicht durch Mustererkennung initialisiert"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "Spezifikationsfehler: nicht erkannte Spezifikationsoption »%c«"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "unbekannte Spezifikationsfunktion %qs"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "Fehler in Argumenten für Spezifikationsfunktion %qs"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "schlechter Name für Spezifikationsfunktion"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "keine Argumente für Spezifikationsfunktion"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "schlechte Argumente für Spezifikationsfunktion"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "geschweift geklammerte Spezifikation %qs ist bei %qc ungültig"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "geschweift geklammerter Spezifikationskörper %qs ist ungültig"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s: Größe der Vergleichs-Prüfdatei %s konnte nicht ermittelt werden"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr "%s: -fcompare-debug ist fehlgeschlagen (Länge)"
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s: Vergleichs-Prüfdatei %s konnte nicht geöffnet werden"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "%s: -fcompare-debug ist fehlgeschlagen"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "Spezifikationsfehler: mehr als ein Argument für SYSROOT_SUFFIX_SPEC"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "Spezifikationsfehler: mehr als ein Argument für SYSROOT_HEADERS_SUFFIX_SPEC"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "unbekannte Kommandozeilenoption %<-%s%>; meinten Sie %<-%s%>?"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "unbekannte Kommandozeilenoption %<-%s%>"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "nicht mit sysroot-Header-Suffix konfiguriert"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "keine Eingabedateien"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "-o kann nicht mit -c, -S oder -E mit mehreren Dateien angegeben werden"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: %s-Compiler ist auf diesem System nicht installiert"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "Neuübersetzung mit -fcompare-debug"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr "während Neuübersetzung mit -fcompare-debug"
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr "Vergleich der endgültigen Befehlslisten"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "-fuse-linker-plugin, aber %s nicht gefunden"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: Eingabedatei des Linkers unbenutzt, da das Linken nicht durchgeführt wird"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr "der Eingabedateiname für einen vorkompilierten Header darf nicht %<-%> sein"
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "Sprache %s nicht erkannt"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "Multilib-Spezifikation %qs ist ungültig"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "Multilib-Ausschlüsse %qs sind ungültig"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "Multilib-select %qs %qs ist ungültig"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "Multilib-select %qs ist ungültig"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "Multilib-Ausschluss %qs ist ungültig"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "Umgebungsvariable %qs nicht definiert"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "ungültige Versionsnummer %qs"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "zu wenige Argumente für %%:version-compare"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "zu viele Argumente für %%:version-compare"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "unbekannter Operator %qs in %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "zu viele Argumente für %%:version-compare"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "zu viele Argumente für %%:compare-debug-self-opt"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "zu wenige Argumente für %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "zu viele Argumente für %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr "Argument für %%:compare-debug-auxbase-opt endet nicht mit .pk"
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "zu wenige Argumente für %%:replace-extension"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "falsche Anzahl der Argumente für %%:debug-level-gt"
@@ -17819,9 +17840,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "hier deklariert"
@@ -18236,228 +18257,228 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr "%<fallthrough%>-Attribut ist nicht direkt vor einer case-Marke oder einer default-Marke"
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "Ergebnis einer %<void%> zurückgebenden Funktion verwendet"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "ungültiger L-Wert in asm-Ausgabe %d"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "Eingabe von Nicht-Speicher %d muss im Speicher bleiben"
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "Speichereingabe %d ist nicht direkt adressierbar"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "threadprivate Variable %qE in Zielregion verwendet"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr "umgebende Zielregion"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "threadprivate Variable %qE in unverknüpfter Task verwendet"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr "umgebende Task"
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE in umgebendem %qs nicht angegeben"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "umgebendes %qs"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE in umgebendem OpenACC-%qs-Konstrukt nicht angegeben"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "umgebendes OpenACC-%qs-Konstrukt"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr "%qE mit %<link%>-Klausel wird in %<routine%>-Funktion verwendet"
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE erfordert eine %<declare%>-Direktive, um in einer %<routine%>-Funktion verwendet zu werden"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "Variable %qE in umgebender %<host_data%>-Region deklariert"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr "Zielregion verweist auf %qD, aber der Ausdruck hat keinen zuordenbaren Typ"
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "Iterationsvariable %qE ist vorbestimmt linear"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "Schleifenvariable %qE sollte »private« sein"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "Schleifenvariable %qE sollte nicht »firstprivate« sein"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "Schleifenvariable %qE sollte nicht Reduktion sein"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "Iterationsvariable %qE sollte nicht »linear« sein"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "Iterationsvariable %qE sollte nicht »lastprivate« sein"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "Iterationsvariable %qE sollte nicht »private« sein"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr "%<linear%>-Klausel für Variable, die keine Schleifeniterationsvariable ist, wurde für ein mit %<distribute%> kombiniertes Konstrukt angegeben"
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr "Feld %qE der Struktur variabler Länger wird zugeordnet"
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE tritt in Mapklauseln mehrfach auf"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "»copyprivate«-Variable %qE ist im äußeren Kontext weder »threadprivate« noch »private«"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "»%s«-Variable %qE ist im äußeren Kontext »private«"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "%qs %<if%>-Klausel-Modifizierer anstelle %qs erwartet"
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr "%<_Atomic%> %qD in implizier %<map%>-Klausel"
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD in impliziter %<firstprivate%>-Klausel am %<target%>-Konstrukt"
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr "%<_Atomic%> %qD in %<firstprivate%>-Klausel am %<target%>-Konstrukt"
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr "selbe Variable wird in %<firstprivate%>- und %<lastprivate%>-Klauseln am %<distribute%>-Konstrukt"
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr "inkompatible Datenklausel mit Reduktion an %qE; wird zu »present_or_copy« befördert"
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "ungültige »private«-Reduktion auf %qE"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "%<ordered%>-Konstrukt mit %<depend%>-Klausel muss innerhalb einer Schleife mit %<ordered%>-Klausel und Parameter eng geschachtelt sein"
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr "Variable %qE ist keine Iteration der äußersten Schleife %d, jedoch %qE erwartet"
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "Anzahl der Variablen in %<depend(sink)%>-Klausel passt nicht zur Anzahl der Iterationsvariablen"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr "mehr als eine %<depend(source)%>-Klausel an einem %<ordered%>-Konstrukt"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79999
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr "%<depend(source)%>-Klausel zusammen mit %<depend(sink:)%>-Klausel an demselben Konstrukt"
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<_Cilk_spawn%> vor %<_Cilk_sync%> erwartet"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "Gimplifikation gescheitert"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT auf %qT erweitert beim Durchlaufen von %<...%>"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(Es sollte also %qT statt %qT an %<va_arg%> übergeben werden)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "Wenn dieser Code erreicht wird, wird das Programm abgebrochen"
@@ -18690,7 +18711,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "Typ %qT verletzt für sich genommen die One-Definition-Rule von C++"
 
 #: ipa-devirt.c:1235
@@ -18790,7 +18811,7 @@
 
 #: ipa-devirt.c:1576
 #, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr "Felder haben unterschiedliches Layout in einer anderen Übersetzungseinheit"
 
 #: ipa-devirt.c:1599
@@ -19171,198 +19192,198 @@
 msgid "multiple loop axes specified for routine"
 msgstr "Mehrere Schleifenachsen für Routine angegeben"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr "%<seq%> übersteuert andere OpenACC-Schleifenspezifizierer"
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr "%<auto%> steht in Konflikt mit anderen OpenACC-Schleifenspezifizierern"
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr "innere Schleife verwendet denselben OpenACC-Parallelismus wie enthaltende Schleife"
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr "Argument an %qs-Klausel in OpenACC-%<parallel%> nicht erlaubt"
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr "Nicht-OpenACC-Konstrukt innerhalb einer OpenACC-Routine"
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr "Nicht-OpenACC-Konstrukt innerhalb einer OpenACC-Region"
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr "%<ordered simd threads%> muss innerhalb der %<for simd%>-Region eng geschachtelt sein"
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr "OpenMP-Konstrukte außer %<#pragma omp ordered simd%> dürfen nicht innerhalb von %<simd%>-Regionen geschachtelt sein"
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr "nur %<distribute%>- und %<parallel%>-Regionen dürfen innerhalb einer %<teams%>-Region streng geschachtelt sein"
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr "%<distribute%>-Region muss innerhalb eines %<teams%>-Konstrukts streng geschachtelt sein"
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr "OpenACC-Schleifendirektive muss mit einer OpenACC-Berechnungsregion verknüpft sein"
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr "verwaistes %qs-Konstrukt"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr "%<#pragma omp cancel for%> innerhalb von %<nowait%>-for-Konstrukt"
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr "%<#pragma omp cancel for%> innerhalb von %<ordered%>-for-Konstrukt"
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<#pragma omp cancel sections%> innerhalb %<nowait%>-Abschnittskonstrukt"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr "%<%s taskgroup%>-Konstrukt nicht eng geschachtelt innerhalb von %<taskgroup%>-Region"
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, gcc-internal-format
 msgid "invalid arguments"
 msgstr "ungültige Argumente"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr "%<%s %s%>-Konstrukt innerhalb von %qs nicht eng geschachtelt"
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "Sperrregion darf nicht innerhalb einer Region eng geschachtelt sein, die arbeitsteilend, %<critical%>, %<ordered%>, %<master%>, explizit %<task%> oder %<taskloop%> ist"
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "arbeitsteilende Region darf nicht innerhalb einer Region eng geschachtelt sein, die arbeitsteilend, %<critical%>, %<ordered%>, %<master%>, explizit %<task%> oder %<taskloop%> ist"
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr "%<master%>-Region darf nicht innerhalb einer Region eng geschachtelt sein, die arbeitsteilend, explizit %<task%> oder %<taskloop%> ist"
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr "%<depend(%s)%> ist nur in %<omp ordered%> erlaubt"
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr "%<ordered%>-Konstrukt mit %<depend%>-Klausel muss innerhalb einer %<ordered%>-Schleife eng geschachtelt sein"
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr "ungültige Abhängigkeitsart in omp %<ordered%> %<depend%>"
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr "%<ordered%> %<simd%> muss innerhalb einer %<simd%>-Region eng geschachtelt sein"
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr "%<ordered%>-Region darf innerhalb einer Region, die %<critical%>, %<ordered%>, expliziten %<task%> oder %<taskloop%> ist, nicht eng geschachtelt sein"
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr "%<ordered%>-Region muss eng geschachtelt sein, wenn sie innerhalb einer Schleifenregion mit %<ordered%>-Klausel auftritt"
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr "%<critical%>-Region darf innerhalb einer gleichnamigen %<critical%>-Region nicht eng geschachtelt sein"
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr "%<teams%>-Konstrukt noch eng geschachtelt innerhalb von %<target%>-Konstrukt"
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr "OpenACC-Region innerhalb einer OpenACC-Routine, geschachtelter Parallelismus wird noch nicht unterstützt"
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr "OpenACC-Konstrukt innerhalb einer Nicht-OpenACC-Region"
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr "%s-%qs-Konstrukt innerhalb einer %s-%qs-Region"
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr "%qs-Konstrukt innerhalb einer %qs-Region"
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr "setjmp/longjmp innerhalb eines SIMD-Konstrukts"
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr "»sink«-Klausel wird ignoriert, da der Offset kein Vielfaches der Schrittweite ist"
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr "erster Offset muss in umgedrehter Richtung der Schleifeniterationen sein"
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "ungültiger Austritt aus strukturiertem %s-Block"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "ungültiger Eintritt in strukturierten %s-Block"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "ungültiger Zweig zu/von strukturiertem %s-Block"
@@ -19447,7 +19468,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "Kommandozeilenoption %qs wird von dieser Konfiguration nicht unterstützt"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "fehlendes Argument für %qs"
@@ -19603,127 +19624,137 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr "»-fsanitize-address-use-after-scope« erfordert »-fstack-reuse=none«"
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "transaktionsbasierter Speicher wird von %<-fsanitize=address%> nicht unterstützt"
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "transaktionsbasierter Speicher wird von %<-fsanitize=kernel-address%> nicht unterstützt"
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr "nicht erkanntes include_flags 0x%x an print_specific_help weitergegeben"
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr "Option »-fsanitize=all« ist ungültig"
 
-#: opts.c:1642
+#: opts.c:1649
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "unbekanntes Argument für »-f%ssanitize%s=«: %q.*s; meinten Sie %qs?"
 
-#: opts.c:1649
+#: opts.c:1656
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "unbekanntes Argument für »-f%ssanitize%s=«: %q.*s"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "Argument %q.*s für --help ist mehrdeutig, bitte präzisieren"
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "Argument %q.*s für Option --help= nicht erkannt"
 
-#: opts.c:2078
+#: opts.c:2085
 #, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr "HSA wurde in dieser Konfiguration nicht eingeschaltet"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr "Option »-foffload-abi« kann nur für Offload-Compiler angegeben werden"
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "Strukturausrichtung muss eine kleine Zweierpotenz sein, nicht %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "unbekannter Stapel-Überprüfungsparameter %qs"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr "%<-gdwarf%s%> ist mehrdeutig; verwenden Sie %<-gdwarf-%s%> für DWARF-Version und %<-gdwarf -g%s%> für Debugstufe"
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "Dwarf-Version %d wird nicht unterstützt"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: »--param«-Argumente sollten von der Form NAME=VALUE sein"
 
-#: opts.c:2371
+#: opts.c:2378
 #, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "ungültiger Name %qs für --param; meinten Sie %qs?"
 
-#: opts.c:2374
+#: opts.c:2381
 #, gcc-internal-format
 msgid "invalid --param name %qs"
 msgstr "ungültiger Name %qs für --param"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "ungültiger Wert für --param: %qs"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "Zielsystem unterstützt keine Testausgaben"
 
-#: opts.c:2513
+#: opts.c:2520
 #, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "Debugformat %qs steht in Konflikt mit vorheriger Auswahl"
 
-#: opts.c:2531
+#: opts.c:2538
 #, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "Unbekannte Debugausgabestufe %qs"
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "Debugausgabestufe %qs ist zu groß"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "Kern-Dateigrößenlimit kann nicht geholt werden: %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "Kern-Dateigrößenlimit kann nicht gesetzt werden: %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "GCC-Debuggingoption nicht erkannt: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: Keine Option -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr "-Werror=%s: -%s ist keine Option, die Warnungen steuert"
@@ -20071,7 +20102,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "Register von %qD für mehrere globale Registervariablen verwendet"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "Konflikt mit %qD"
@@ -20698,12 +20729,12 @@
 msgid "error closing %s: %m"
 msgstr "Fehler beim Schließen von %s: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr "Selbsttests sind unverträglich mit »-E«"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr "Selbsttests sind in diesem Build nicht eingeschaltet"
@@ -21638,47 +21669,47 @@
 msgid "in expansion of macro %qs"
 msgstr "bei Substitution des Makros %qs"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i hat mehrere EH-Kanten"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr "BB %i kann nicht werfen, hat aber eine EH-Kante"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "BB %i: letzte Anweisung hat falsch gesetztes LP"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "dem BB %i fehlt eine EH-Kante"
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "falsche EH-Kante %i->%i"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "dem BB %i fehlt eine Kante"
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "BB %i hat zu viele »fallthru«-Kanten"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "BB %i hat falsche Kante"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "BB %i hat falsche »fallthru«-Kante"
@@ -21779,32 +21810,32 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr "Ziel unterstützt kein Aktualisieren des atomaren Profils, einfacher Modus wird ausgewählt"
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr "Argument %u ist null, aber nichtnull wird erwartet"
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "in einem Aufruf der eingebauten Funktion %qD"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "in einem Aufruf der hier deklarierten Funktion %qD"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "Schleifenoptimierung übersprungen, die Schleifen-Zählvariable könnte überlaufen"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr "Durchlauf %s führt zu undefiniertem Verhalten"
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr "innerhalb dieser Schleife"
@@ -22172,11 +22203,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -23144,7 +23175,7 @@
 msgid "type was previously declared %qE"
 msgstr "Typ war vorher als %qE deklariert"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "%<transaction_safe_dynamic%> kann nur für virtuelle Funktionen angegeben werden"
@@ -23419,7 +23450,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "der Compiler kann davon ausgehen, dass die Adresse von %qD immer zu %<true%> evaluiert"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "Um Zuweisung, die als Wahrheitswert verwendet wird, werden Klammern empfohlen"
@@ -24038,62 +24069,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "zusätzliche Typqualifizierer in Format-Argument (Argument %d)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> erwartet Argumenttyp %<%s%s%>, aber Argument %d hat Typ %qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> erwartet ein passendes Argument %<%s%s%>"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> erwartet Argumenttyp %<%T%s%>, aber Argument %d hat Typ %qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> erwartet ein passendes Argument %<%T%s%>"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> ist nicht als Typ definiert"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> ist nicht als %<long%> oder %<long long%> definiert"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> ist nicht als ein Typ definiert"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> ist nicht als ein Typ definiert"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> ist nicht als ein Typ definiert"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> ist nicht als ein Zeigertyp definiert"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "zu formatierendes Argument ist nicht %<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime-Formate können keine Argumente formatieren"
@@ -24195,7 +24226,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "wiederholtes %<@%> vor Objective-C-Zeichenkette"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "nicht unterstützte Nicht-Standard-Verkettung von Zeichenkettenliteralen"
@@ -24225,7 +24256,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Variablen für Speicher"
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "ungültiger Typ für Schleifenvariable %qE"
@@ -24240,22 +24271,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE ist nicht initialisiert"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Steuerprädikat fehlt"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Steuerprädikat ungültig"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "Erhöhungsausdruck fehlt"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Erhöhungsausdruck ungültig"
@@ -24800,8 +24831,8 @@
 msgid "wrong type argument to %s"
 msgstr "Argument falschen Typs für %s"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "Überlauf in Konstanten-Ausdruck"
@@ -25469,7 +25500,7 @@
 msgid "this condition has identical branches"
 msgstr "diese Bedingung hat identische Zweige"
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "%<_Cilk_spawn%> kann nur innerhalb einer Funktion verwendet werden"
@@ -25629,7 +25660,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr "-march=%s: nicht unterstützte ISA-Teilzeichenkette %qs"
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "unbekannter Schalter -mdebug-%s"
@@ -25953,7 +25984,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%KArgument %d muss eine direkt angegebene Konstante sein"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "%KSpurindex muss eine direkt angegebene Konstante sein"
@@ -26035,7 +26066,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "unbekannter Wert %qs für -mtune"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "Schalter -mcpu=%s steht mit dem Schalter -march=%s in Konflikt"
@@ -26133,9 +26164,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "Ziel»%s« %s=%s ist ungültig"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "Argument für Attribut %<target%> ist keine Zeichenkette"
@@ -26224,7 +26255,7 @@
 msgstr "Falscher Wert %qs für -mmemory-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -26400,234 +26431,234 @@
 msgid "insn addresses not freed"
 msgstr "Befehlsadressen nicht freigegeben"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "diese eingebaute Funktion wird auf diesem Ziel nicht unterstützt"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie NEON-Befehle einschalten (zum Beispiel mit »-mfloat-abi=softfp -mfpu=neon«)."
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie VFP-Befehle einschalten."
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr "Um diese intrinsischen Funktionen zu verwenden, müssen Sie Krypto-Befehle einschalten (zum Beispiel mit »-mfloat-abi=softfp -mfpu=crypto-neon«)"
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "Wähler muss »immediate« sein"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "der Wertebereich des Selektors sollte 0 bis 7 sein"
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "der Wertebereich des Selektors sollte 0 bis 3 sein"
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "der Wertebereich des Selektors sollte 0 bis 1 sein"
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "Maske muss »immediate« sein"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "der Wertebereich der Maske ist 0 bis 255"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_rori_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_rori_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_ror_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 32. Bitte intrinsisches _mm_ror_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 64. Bitte intrinsisches _mm_rori_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr "der Wertebereich des Zählers ist 0 bis 64. Bitte intrinsisches _mm_ror_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srli_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_slli_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srai_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_srl_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sll_si64 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_pi16 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_pi32 im Code prüfen."
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr "der Zähler darf nicht kleiner als 0 sein. Bitte das intrinsische _mm_sra_si64 im Code prüfen."
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt und NEON sind unverträglich"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "Ziel-CPU unterstützt nicht ARM-Modus"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "Das Einschalten der Ablaufverfolgung ist nur bei der Übersetzung für THUMB sinnvoll"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "Das Einschalten der Unterstützung der Aufgerufenen-Zusammenarbeit ist nur bei der Übersetzung für THUMB sinnvoll"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g mit -mno-apcs-frame könnte vernünftige Fehlersuche verhindern"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr "iWMMXt wird im Thumb-Modus nicht unterstützt"
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "-mtp=cp15 kann nicht mit 16-Bit-Thumb verwendet werden"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC ist mit Thumb unverträglich"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr "-mslow-flash-data unterstützt auf ARMv7M-Zielen nur positionsabhängigen Code"
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr "-mpure-code unterstützt auf ARMv7M-Zielen nur positionsabhängigen Code"
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "Ziel-CPU unterstützt keine THUMB-Befehle"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "Ziel-CPU unterstützt keine unausgerichteten Zugriffe"
@@ -26634,141 +26665,141 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mftp=auto wird derzeit nur unterstützt, wenn die CPU explizit angegeben ist."
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "Ziel-CPU unterstützt keine Zusammenarbeit"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check inkompatibel mit -mno-apcs-frame"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic und -mapcs-reent sind inkompatibel"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "wiedereinsprungsfähiger APCS-Code nicht unterstützt. Ignoriert."
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "die ausgewählten fp16-Optionen sind inkompatibel"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt erfordert ein AAPCS-kompatibles ABI für den richtigen Einsatz"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt ABI erfordert eine iwmmxt-fähige CPU"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS unterstützt nicht -mcaller-super-interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS unterstützt nicht -mcallee-super-interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 ohne ldrh"
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard: ausgewählter Prozessor hat keine FPU"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard und VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "Grenze für Strukturgröße kann nur auf 8, 32 oder 64 gesetzt werden"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "Grenze für Strukturgröße kann nur auf 8 oder 32 gesetzt werden"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "RTP PIC ist mit -msingle-pic-base unverträglich"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= ist ohne -fpic nutzlos"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "»%s« kann nicht für PIC-Register verwendet werden"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition wird auf dieser Architektur nicht unterstützt"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "Ziel-CPU unterstützt keine ARMv8-M-Security-Erweiterungen"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "von nicht-AAPCS abgeleitete PCS-Variante"
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "variadische Funktionen müssen die AAPCS-Basisvariante verwenden"
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS-Variante"
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 Hardware-Gleitkomma VFP ABI"
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr "die Parameterübergabe für das Argument vom Typ %qT hat sich in GCC 7.1 geändert"
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -26776,74 +26807,79 @@
 msgid "%qE attribute only applies to functions"
 msgstr "Attribut %qE bezieht sich nur auf Funktionen"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar, die Argumente auf dem Stack übergeben"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar, die variable Anzahl von Argumenten haben"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "Attribut %qE ist nicht auf Funktionen anwendbar, die Argumente auf dem Stack zurückgeben"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "Attribut %qE ignoriert, da die Option »-mcmse« nicht angegeben ist."
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "Attribut %qE wirkt sich nicht auf Funktionen mit »static«-Bindung aus"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "Attribut %qE kann nur auf Basistypen von Funktionszeiger angewandt werden"
 
+#: config/arm/arm.c:8656
+#, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr "Zugriff auf threadlokalen Speicher wird derzeit mit %<-mpure-code%> oder %<-mslow-flash-data%> nicht unterstützt"
+
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79871
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:12232
 #, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "%K»%s« %wd ist außerhalb des gültigen Bereichs von %wd bis %wd"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79871
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "»%s« %wd ist außerhalb des gültigen Bereichs von %wd bis %wd"
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "Wirkliche Stelle des gestapelten Parameters kann nicht berechnet werden"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "Unexpected thumb1 far jump"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "keine unteren Register für das Hervorholen der hohen Register verfügbar"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "Interrupt-Dienst-Routinen können nicht im »Thumb«-Modus codiert werden"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr "-fstack-check=specific für Thumb-1"
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr "ungültige FPU für »attribute(target(\"%s\"))«"
@@ -26851,13 +26887,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr "automatische FPU-Auswahl ist hier momentan nicht erlaubt"
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) ist unbekannt"
@@ -26951,164 +26987,175 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr "Funktionsattribute %qs und %qs haben keine Auswirkung auf Funktion %qs"
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Funktion %qs kann keine Argumente haben"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "Funktion %qs kann keinen Wert zurückgeben"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79883
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
-msgstr "%qs scheint ein falsch geschriebener %qs-Handler zu sein, __vector-Präfix fehlt"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
+msgstr "%qs scheint ein falsch geschriebener %qs-Handler zu sein, das Präfix %<__vector%> fehlt"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr "%qs ist in der AVR-LibC ein reservierter Bezeichner. Erwägen Sie %<#include <avr/interrupt.h>%> vor der Benutzung des Makros %qs"
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "%<builtin_return_address%> enthält nur 2 Adressbytes"
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "Zeigeroffset von Symbol könnte falsch sein"
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "Zugriff auf Datenspeicher mit Programmspeicheradresse"
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "Zugriff auf Programmspeicher mit Datenspeicheradresse"
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "festes Register %s zur Parameterübergabe an Funktion verwendet"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "Schreibzugriff auf Adressraum %qs wird nicht unterstützt"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "Attribut %qE kann nur für »static«-Variablen verwendet werden"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "Attribut %qE wird nur für reduzierte Tiny-Kerne unterstützt"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "Attribut %qE bezieht sich nur auf Variablen"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "Attribut %qE erlaubt nur eine Ganzzahlkonstante als Argument"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr "Adresse von Attribut %qE außerhalb des gültigen Bereichs"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr "sowohl »%s« als auch das %qE-Attribut geben die Adresse an"
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "Attribut %qE an nicht-»volatile«-Variable"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "Adressräume werden auf reduzierten Tiny-Kernen nicht unterstützt"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "Adressraum %qs wird auf Geräten mit Flashspeicher bis zu %d KiB nicht unterstützt"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "Zeiger auf Adressraum %qs muss in %qT konstant sein"
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "Zeiger auf Adressraum %qs muss in %s %q+D konstant sein"
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "Variable %q+D muss konstant sein, um mit %qs in Nur-Lese-Abschnitt gelegt zu werden"
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr "»static IO«-Deklaration von %q+D erfordert eine Adresse"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr "IO-Definition für %q+D erfordert eine Adresse"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "Nur uninitialisierte Variablen können im .noinit-Bereich platziert werden"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "dynamisch initialisierte Variable %q+D in Programmspeicherbereich platziert"
+
+#: config/avr/avr.c:10160
+#, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "nicht initialisierte Variable %q+D in Programmspeicherbereich platziert"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%q+D hat unverträgliche Attribute %qs und %qs"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "Architektur %qs wird nur für Assemblierung unterstützt"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "Umwandlung von Adressraum %qs in Adressraum %qs"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s erwartet eine Ganzzahlkonstante zur Kompilierzeit"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s erwartet eine Long-Ganzzahlkonstante als erstes Argument zur Kompilierzeit"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr "Rundung auf %d Bits hat keinen Effekt für Festkommawert mit %d Bit Nachkommaanteil"
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "Rundungsergebnis wird immer 0 sein"
@@ -27391,12 +27438,12 @@
 msgid "invalid IACC argument"
 msgstr "ungültiges IACC-Argument"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs erwartet ein konstantes Argument"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "Konstantes Argument außerhalb des Wertebereiches für %qs"
@@ -27574,7 +27621,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "Codemodell %qs wird im x32-Modus nicht unterstützt"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "Codemodell %s unterstützt keinen PIC-Modus"
@@ -27704,287 +27751,287 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%<target(\"rtd\")%> wird im 64-Bit-Modus ignoriert"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary wird für dieses Ziel nicht unterstützt"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d ist nicht zwischen %d und %d"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d ist nicht zwischen %d und 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount ist nicht mit diesem Ziel kompatibel"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "-mnop-mcount ist für -fPIC nicht implementiert"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%<-msseregparm%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%<target(\"sseregparm\")%> verwendet, ohne dass SSE eingeschaltet ist"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE-Befehlssatz ausgeschaltet, es wird 387-Arithmetik verwendet"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387-Befehlssatz ausgeschaltet, es wird SSE-Arithmetik verwendet"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<-maccumulate-outgoing-args%> für Korrektheit"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "Stapel-Überprüfung erfordert %<target(\"accumulate-outgoing-args\")%> für Korrektheit"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "feststehendes ebp-Register erfordert %<-maccumulate-outgoing-args%>"
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "feststehendes ebp-Register erfordert %<target(\"accumulate-outgoing-args\")%>"
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry wird für 32 Bit in Kombination mit -fpic nicht unterstützt"
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry ist nicht mit SEH verträglich"
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "unbekannte Option für -mrecip=%s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") wurde bereits spezifiziert"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr "Nur das DWARF-Debugformat ist für Interrupt-Service-Routinen unterstützt."
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "%s-Befehle sind in »%s«-Serviceroutine nicht erlaubt"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "%s-Befehle sind in Funktionen mit »no_caller_saved_registers«-Attribut nicht erlaubt"
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "Attribute fastcall und regparm sind nicht verträglich"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "Attribute regparam und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "Attribut %qE benötigt eine Ganzzahlkonstante als Argument"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "Argument für Attribut %qE ist größer als %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "Attribute fastcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "Attribute fastcall und stdcall sind nicht verträglich"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "Attribute fastcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "Attribute stdcall und cdecl sind nicht verträglich"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "Attribute stdcall und fastcall sind nicht verträglich"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "Attribute stdcall und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "Attribute cdecl und thiscall sind nicht verträglich"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "Attribut %qE wird für Nicht-Klassen-Methode verwendet"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qD mit Attribut sseregparam, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Aufruf von %qT mit Attribut sseregparam, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 unterstützt »ms_abi«-Attribut nicht"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue ist mit geschachtelter Funktion nicht verträglich"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX512F-Vektorargument ohne eingeschaltetes AVX512F ändert das ABI"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX512F-Vektorrückgabe ohne eingeschaltetes AVX512F ändert das ABI"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX-Vektorargument ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX-Vektorrückgabe ohne eingeschaltetes AVX ändert das ABI"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE-Vektorargument ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE-Vektorrückgabe ohne eingeschaltetes SSE ändert das ABI"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX-Vektorargument ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX-Vektorrückgabe ohne eingeschaltetes MMX ändert das ABI"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "Das ABI der Struct-Übergabe mit einem flexiblen Arrayelement hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "Das ABI der Union-Übergabe mit »long double« hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "Das ABI der Strukturübergabe mit komplexem Gleitkommaelement hat sich in GCC 4.4 geändert"
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE-Registerrückgabe mit SSE ausgeschaltet"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE-Registerargument mit SSE ausgeschaltet"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87-Registerrückgabe mit ausgeschaltetem x87"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Aufruf von %qD mit SSE-Aufrufkonvention, ohne dass SSE/SSE2 eingeschaltet ist"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr "dies ist ein GCC-Bug; ein Workaround ist, die aufgerufene Funktion mit dem »used«-Attribut zu markieren"
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "Das ABI der Parameterübergabe mit %d-Byte-Ausrichtung hat sich in GCC 4.6 geändert"
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "Attribut ms_hook_prologue ist mit -mfentry für 32 Bit nicht verträglich"
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr "Dynamic Realign Argument Pointer (DRAP) wird in Interrupt-Service-Routinen nicht unterstützt. Ein Workaround ist, Funktionen mit Aggregat-Rückgabetypen zu vermeiden."
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack unterstützt nicht fastcall mit geschachtelter Funktion"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack unterstützt nicht 2 Registerparameter für eine geschachtelte Funktion"
@@ -27991,297 +28038,297 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack unterstützt nicht 3 Registerparameter"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "nicht unterstützte Größe für Ganzzahlregister"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "erweiterte Register haben keine oberen Hälften"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "nicht unterstützte Operandengröße für erweitertes Register"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "Nicht-Ganzzahl-Operand mit Operandencode »z« verwendet"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "Interrupt-Dienst-Routinen können nicht direkt aufgerufen werden"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr "Kein Dispatcher für versionierte Attribute gefunden"
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Kein Dispatcher für %s gefunden"
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr "Kein Dispatcher für versionierte Attribute gefunden: %s"
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr "Funktionsversionen können nicht als gnu_inline markiert werden, Körper müssen generiert werden"
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Multiversionierung virtueller Funktionen wird nicht unterstützt"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr "Attribut %<target%> fehlt für multiversioniertes %D"
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "vorherige Deklaration von %D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "Multiversionierung erfordert »ifunc«, was in dieser Konfiguration nicht unterstützt wird"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Parameter für eingebaute Funktion muss Zeichenkettenkonstante oder Literal sein"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "Parameter für eingebaute Funktion ist ungültig: %s"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Das letzte Argument muss ein 2-Bit-Immediate sein"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fünftes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "drittes Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "das letzte Argument muss ein 3-Bit-Immediate sein"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Das letzte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Das letzte Argument muss ein 1-Bit-Immediate sein"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Das letzte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Das vorletzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Das letzte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "das dritte Argument muss eine Vergleichskonstante sein"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "Falscher Vergleichsmodus"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "Falscher Rundungsoperand"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Der direkte Argument muss ein 4-Bit-Immediate sein"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Das direkte Argument muss ein 5-Bit-Immediate sein"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Das direkte Argument muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Das letzte Argument muss ein 32-Bit-Immediate sein"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "Selektor eine Ganzzahlkonstante im Bereich 0..%wi sein"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE erfordert unbekannte ISA-Option"
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE erfordert ISA-Option %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "das letzte Argument muss ein Immediate sein"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "Das letzte muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "Das vierte Argument muss Skalierung 1, 2, 4, 8 sein"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "Falscher Hinweis-Operand"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "Das Argument für xabort muss ein 8-Bit-Immediate sein"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "Attribut %qE nur für 32 Bit verfügbar"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Argument des Attributes %qE ist weder Null noch Eins"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "Attribute ms_abi und sysv_abi sind nicht verträglich"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-inkompatibles Attribut wird ignoriert"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "in Interrupt-Service-Routinen sollte das erste Argument ein Zeiger sein"
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr "in Interrupt-Service-Routinen sollte das zweite Argument vom Typ »unsigned %sint« sein"
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr "Interrupt-Service-Routine darf nur ein Zeiger- und ein optionales Ganzzahl-Argument haben"
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "Interrupt-Service-Routine muss den Rückgabetyp »void« haben"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "Alternativen sind in asm-Flag-Ausgabe nicht erlaubt"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "unbekannte Ausgabe %qs des asm-Schalters"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "ungültiger Typ für asm-Flag-Ausgabe"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "Unbekanntes architekturspezifisches Speichermodell«"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr "HLE_ACQUIRE nicht mit ACQUIRE oder stärkerem Speichermodell verwendet"
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr "HLE_RELEASE nicht mit RELEASE oder stärkerem Speichermodell verwendet"
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "nicht unterstützte simdlen %d"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr "nicht unterstützter Rückgabetyp %qT für SIMD\n"
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "nicht unterstützter Argumenttyp %qT für SIMD\n"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr "Zeigerprüfer benötigt MPX-Unterstützung auf diesem Ziel. Verwenden Sie »-mmpx«, um MPX einzuschalten."
@@ -28401,7 +28448,7 @@
 msgid "argument %qd is not a constant"
 msgstr "Argument %qd ist keine Konstante"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, Null-Zeiger"
@@ -28411,7 +28458,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: Unbekanntes Zeichen '%c'"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND Null-Zeiger"
@@ -28512,7 +28559,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread ist nur auf Fido verfügbar"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "Ausdruck der Stapelgrenze wird nicht unterstützt"
@@ -29019,8 +29066,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr "eingebaute MSP430-Funktionen sind nur innerhalb von Interrupt-Handlern einsetzbar"
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr "Falscher eingebauter Code"
@@ -29271,27 +29318,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr "PTX unterstützt keine schwachen Deklarationen (nur schwache Definitionen)"
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "Attribut %qE erfordert den Rückgabetyp »void«"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "Attribut %qE nicht mit Speicherklasse »auto« erlaubt"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr "vector_length (%d) wird verwendet, %d wird ignoriert"
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr "vector_length (%d) wird verwendet, Laufzeiteinstellung wird ignoriert"
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr "num_workers (%d) wird verwendet, %d wird ignoriert"
@@ -29316,7 +29363,7 @@
 msgid "-g option disabled"
 msgstr "Option -g ausgeschaltet"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "Ausrichtung (%u) für »%s« überschreitet maximale Ausrichtung für globale gemeinsame Daten. Es wird %u verwendet"
@@ -29451,157 +29498,157 @@
 msgid "junk at end of #pragma longcall"
 msgstr "Ausschuss am Ende von #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsl ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr "vec_lvsr ist für Little-Endian veraltet; verwenden Sie Zuweisungen für unausgerichtete Speicherzugriffe"
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_mul akzeptiert nur 2 Argumente"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_cmpne akzeptiert nur 2 Argumente"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_adde akzeptiert nur 3 Argumente"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_addec akzeptiert nur 3 Argumente"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s akzeptiert nur %d Argumente"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s akzeptiert nur 1 Argument"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s akzeptiert nur 2 Argumente"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract akzeptiert nur 2 Argumente"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert akzeptiert nur 3 Argumente"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "Übergabe des Arguments %d von %qE entfernt Kennzeichner von Zeiger-Ziel-Typ"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "Eingebaute Funktion %s wird in dieser Konfiguration nicht unterstützt"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "ungültige Parameterkombination für AltiVec-spezifisches intrinsisches %s"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr "-mrecip erfordert -ffinite-math oder -ffast-math"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr "-mrecip erfordert -fno-trapping-math oder -ffast-math"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr "-mrecip erfordert -freciprocal-math oder -ffast-math"
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 erfordert PowerPC64-Architektur voraus, eingeschaltet"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power wird für 64-Bit-Darwin nicht unterstützt; es ist mit den installierten C- und C++-Bibliotheken unverträglich"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr "power9-Befehle werden nicht erzeugt, da der Assembler power9 nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr "power8-Befehle werden nicht erzeugt, da der Assembler power8 nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr "power7-Befehle werden nicht erzeugt, da der Assembler power7 nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr "power6-Befehle werden nicht erzeugt, da der Assembler power6 nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr "power5-Befehle werden nicht erzeugt, da der Assembler power5 nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr "nicht für SPE-ABI konfiguriert"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr "Nicht für SPE-Befehlssatz konfiguriert"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "Ziel-Attribut oder Pragma ändert SPE ABI"
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec wird für dieses Ziel nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "SPE wird für dieses Ziel nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple wird auf »little endian«-Systemen nicht unterstützt"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring wird auf »little endian«-Systemen nicht unterstützt"
@@ -29608,67 +29655,67 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "-mpower9-minmax unverträglich mit explicit ausgeschalteten Optionen"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr "Power9-Zieloption ist mit -mcpu=<xxx> für <xxx> kleiner als power9 unverträglich"
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr "-mcrypto erfordert -maltivec"
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr "-mdirect-move benötigt -mvsx"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr "-mpower8-vector erfordert -maltivec"
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr "-mpower8-vector benötigt -mvsx"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr "-mvsx-timode benötigt -mvsx"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "-mhard-dfp benötigt -mhard-float"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "-mupper-regs-df benötigt -mvsx"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "-mupper-regs-di benötigt -mvsx"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr "-mupper-regs-sf erfordert -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr "-mpower8-fusion-sign benötigt -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr "-mtoc-fusion benötigt -mpower8-fusion"
@@ -29677,514 +29724,519 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "-mpower9-fusion benötigt -mpower8-fusion"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr "-mpower9-vector benötigt -mpower8-vector"
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr "-mpower9-dform benötigt -mpower9-vector"
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar erfordern -mdirect-move"
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr "-mpower9-dform benötigt -mupper-regs-df"
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr "-mpower9-dform benötigt -mupper-regs-sf"
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr "-mvsx-timode erfordert möglicherweise -mlra"
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr "-mallow-movmisalign benötigt -mvsx"
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr "-mefficient-unaligned-vsx benötigt -mvsx"
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr "-mefficient-unaligned-vsx erfordert -mallow-movmisalign"
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr "-mvsx-small-integer erfordert -mpower8-vector, -mupper-regs-di, und -mdirect-move"
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "Ziel-Attribut oder Pragma ändert Größe von long double"
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr "-mfloat128 erfordert VSX-Unterstützung"
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr "-mfloat128-type erfordert VSX-Unterstützung"
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr "-mfloat128 erfordert -mfloat128-type"
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr "-mfloat128-hardware benötigt -mfloat128-type"
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr "-mfloat128-hardware erfordert vollständige Unterstützung von ISA 3.0"
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr "-mfloat128-hardware erfordert -m64"
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr "unbekannte ABI-Typ (%s) für Vektorisierungsbibliothek bei Schalter -mveclibabi="
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "Ziel-Attribut oder Pragma ändert AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "Ziel-Attribut oder Pragma ändert darwin64 ABI"
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "Ziel-Attribut oder Pragma ändert Gleitkomma mit einfacher Genauigkeit"
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "Ziel-Attribut oder Pragma ändert Gleitkomma mit doppelter Genauigkeit"
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr "%qs ist keine gültige Zahl in -mstack-protector-guard-offset="
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs ist kein gültiger Offset in »-mstack-protector-guard-offset=«"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr "%qs ist kein gültiges Basisregister in -mstack-protector-guard-reg="
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr "-mstack-protector-guard=tls erfordert ein gültiges Basisregister"
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "das Layout von Aggregaten, die Vektoren mit %d-Byte-Ausrichtung enthalten, hat sich in GCC 5 geändert"
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz zurückgegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Wert kann nicht in Vektorregister zurückgegeben werden, da AltiVec-Befehle ausgeschaltet sind; -maltivec schaltet sie ein"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "das ABI der Parameterübergabe für Aggregate mit %d-Byte-Ausrichtung hat sich in GCC 5 geändert"
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "Argument kann nicht in Vektorregister übergegeben werden, da AltiVec-Befehle ausgeschaltet sind; -maltivec schaltet sie ein"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "das ABI für die Übergabe von homogenen float-Aggregaten hat sich in GCC 5 geändert"
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC-Vektor per Referenz übergegeben: Nicht-Standard-ABI-Erweiterung ohne Kompatibilitätsgarantie"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "internal error: builtin function %s already processed"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Argument 1 muss ein 8-Bit-Feldwert sein"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Argument 1 muss ein vorzeichenbehaftetes 5-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 5-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "Argument 1 muss ein vorzeichenloses 6-Bit-Literal sein"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 7-Bit-Literal sein"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "Argument 1 von __builtin_altivec_predicate muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "Argument 1 von __builtin_altivec_predicate ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "Eingebaute Funktion %s kann nur im 64-Bit-Modus verwendet werden"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "Argument %d muss ein vorzeichenloses Literal sein"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Argument %d ist ein vorzeichenloses Literal, aber außerhalb des gültigen Bereichs"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr "Eingebaute Funktion %s akzeptiert nur ein Zeichenkettenargument"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr "CPU %s ist ein ungültiges Argument für eingebaute Funktion %s"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "hwcap %s ist ein ungültiges Argument für eingebaute Funktion %s"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr "%s erfordert GLIBC (2.23 oder neuer), die Hardware-Fähigkeits-Bits exportiert"
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 4-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Argument 3 muss ein vorzeichenloses 1-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "Argument 1 muss 0 oder 2 sein"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Argument 1 muss ein vorzeichenloses 1-Bit-Literal sein"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Argument 2 muss ein vorzeichenloses 6-Bit-Literal sein"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "Argument 2 muss 0 oder 1 sein"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "Argument 3 muss im Bereich 0..15 liegen"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Argument für %qs muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "ungelöste Überladung des eingebauten Altivec %qF"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "Argument für dss muss ein vorzeichenloses 2-Bit-Symbol sein"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr "zweites Argument für vec_vextract4b muss zwischen 0 und 12 liegen"
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, gcc-internal-format
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "Drittes Argument für »vec_vinsert4b« muss im Bereich 0..12 sein"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "Argument 1 von __builtin_paired_predicate muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "Argument 1 von __builtin_paired_predicate ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "Argument 1 von __builtin_spe_predicate muss eine Konstante sein"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "Argument 1 von __builtin_spe_predicate ist außerhalb des Wertebereiches"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "Eingebaute Funktion %s ist nur für den Cell-Prozessor gültig"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mvsx"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mhtm"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "Eingebaute Funktion %s erfordert die Option -maltivec"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mpaired"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mspe"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "Eingebaute Funktion %s erfordert die Optionen -mhard-dfp und -mpower8-vector"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mhard-dfp"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mpower8-vector"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "Eingebaute Funktion %s erfordert die Optionen -mcpu=power9 und -m64"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mcpu=power9"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "Eingebaute Funktion %s erfordert die Option -mhard-float und -mlong-double-128"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mhard-float"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "Eingebaute Funktion %s erfordert die Option -mfloat128"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "Eingebaute Funktion %s wird mit den aktuellen Optionen nicht unterstützt"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "internal error: builtin function %s had an unexpected return type %s"
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "internal error: builtin function %s, argument %d had unexpected argument type %s"
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "Stapelrahmen zu groß"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack verwendet Register r29"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "Stapelrahmen größer als 2G wird für -fsplit-stack nicht unterstützt"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "kein Profiling von 64-bit-Code für dieses ABI"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "Bei Verwendung der Option -mno-pointers-to-nested-functions kann nicht die Adresse einer geschachtelten Funktion verwendet werden."
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "Verwendung von %<long double%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "Verwendung boolescher Typen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "Verwendung von %<complex%> in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "Verwendung dezimaler Gleitkommatypen in AltiVec-Typen ist ungültig"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist für 64-Bit-Code ohne -mvsx ungültig"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "Verwendung von %<long%> in AltiVec-Typen ist veraltet; %<int%> verwenden"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "Verwendung von %<long long%> in AltiVec-Typen ist ohne -mvsx ungültig"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "Verwendung von %<double%> in AltiVec-Typen ist ohne -mvsx ungültig"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "Ausgabe des Mikrocode-Befehls %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "Ausgabe des bedingten Mikrocode-Befehls %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "ungültige CPU »%s« für %s\"%s\"%s"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s ist nicht erlaubt"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s ist ungültig"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr "-mno-%s schaltet -m%s aus"
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr "-mno-power9-vector schaltet -mpower9-dform aus"
@@ -30371,6 +30423,7 @@
 msgstr "-mcall-aixdesc ist unverträglich mit -mabi=elfv2"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 benötigt eine PowerPC64-CPU"
@@ -30462,7 +30515,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr "das eingebaute vec_step kann nur mit Vektortypen verwendet werden"
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "Konstanter Wert erwartet für Argument %2$d der eingebauten Funktion %1$qF"
@@ -30489,8 +30542,8 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
-msgstr "%qF erfordert -march=arch12 oder höher"
+msgid "%qF requires z14 or higher"
+msgstr "%qF erfordert z14 oder höher"
 
 #: config/s390/s390-c.c:903
 #, gcc-internal-format
@@ -30509,8 +30562,8 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
-msgstr "passende %qs-Variante erfordert -march=arch12 oder höher"
+msgid "%qs matching variant requires z14 or higher"
+msgstr "passende %qs-Variante erfordert z14 oder höher"
 
 #: config/s390/s390-c.c:972
 #, gcc-internal-format
@@ -30523,161 +30576,161 @@
 msgstr "Konstantes Argument %d für eingebautes %qF außerhalb des Wertebereiches für Zieltyp"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79846
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "bla %d %qF"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79846
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "bla %d %qF"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr "eingebautes %qF wird nur mit -mhtm unterstützt (standardmäßig für -march=zEC12 und höher eingeschaltet)"
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr "eingebautes %qF wird nur mit -mvx unterstützt (standardmäßig für -march=z13 und höher eingeschaltet)"
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
-msgstr "Eingebaute %qF erfordert arch12 oder höher."
+msgid "Builtin %qF requires z14 or higher."
+msgstr "Eingebaute %qF erfordert z14 oder höher."
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "unaufgelöste überladene eingebaute Funktion"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "Falscher eingebauter ICode"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "Ungültiges Argument %d für eingebaute Funktion %qF"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "das angeforderte %qE-Attribut ist kein kommaseparierter Paar von nichtnegativen ganzzahligen Konstanten, oder es ist zu groß (maximal %d)"
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "Gesamtgröße der lokalen Variablen übersteigt Grenze der Architektur"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, größer als benutzerdefinierte Stapelgrenze von %d Bytes. Eine unbedingte Falle wird gesetzt."
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "Rahmengröße der Funktion %qs ist %wd Bytes, mehr als die Hälfte der Stapelgröße. Dynamische Prüfung wäre nicht zuverlässig. Für diese Funktion wird keine Prüfung ausgegeben."
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Rahmengröße von %qs ist %wd Bytes"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs verwendet dynamische Stapelanforderung"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr "CPUs älter als z900 werden für -fsplit-stack nicht unterstützt"
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr "%sarch=%s%s ist veraltet und wird in einer zukünftigen Version entfernt; verwenden Sie mindestens %sarch=z900%s"
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr "%stune=%s%s ist veraltet und wird in einer zukünftigen Version entfernt; verwenden Sie mindestens %stune=z900%s"
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architektur-Modus nicht unterstützt auf %s"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-Bit-ABI nicht unterstützt im ESA/390-Modus"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "Hardware-Vektorunterstützung ist auf %s nicht verfügbar"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr "Hardware-Vektorunterstützung ist mit -msoft-float nicht verfügbar"
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Dezimale Hardware-Gleitkommabefehle sind auf %s nicht verfügbar"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Dezimale Hardware-Gleitkommabefehle sind im ESA/390-Modus nicht verfügbar"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp kann nicht in Verbindung mit -msoft-float verwendet werden"
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float werden in dieser Kombination nicht unterstützt"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "Stapelgröße muss größer als der Stapel-Überwachungswert sein"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "Stapelgröße darf nicht größer als 64k sein"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard bringt -mstack-size mit sich"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "Argumente von %qs sollten nicht-negative Ganzzahlen sein"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "Argument für %qs ist zu groß (max. %d)"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "Wert %qs wird von Attribut %<target%> nicht unterstützt"
@@ -30734,27 +30787,27 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax wird nur für RTP PIC unterstützt"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s wird von dieser Konfiguration nicht unterstützt"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 ist mit -m64 nicht erlaubt"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "Falscher Wert (%s) für Schalter -mcmodel="
 
-#: config/sparc/sparc.c:1425
+#: config/sparc/sparc.c:1541
 #, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= wird auf 32-Bit-Systemen nicht unterstützt"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "-fcall-saved-REG wird für Ausgaberegister nicht unterstützt"
@@ -31039,22 +31092,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "ungültige Konstante in %<#pragma %s%>"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "Boolesche Register für die Gleitkommaoption benötigt"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "-f%s wird mit CONST16-Befehlen nicht unterstützt"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "PIC wird benötigt, wird aber nicht mit CONST16-Befehlen unterstützt"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "Nur uninitialisierte Variablen können in einem .bss-Abschnitt platziert werden"
@@ -31140,7 +31193,7 @@
 msgid "could not read the BRIG file"
 msgstr "BRIG-Datei konnte nicht gelesen werden"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -31542,9 +31595,9 @@
 msgstr "Marke %qD hier definiert"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD hier deklariert"
@@ -31677,7 +31730,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> außerhalb des Bereichs des Funktionsprototypen nicht erlaubt"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr "%q+D in »declare target«-Direktive hat keinen zuordenbaren Typ"
@@ -32722,7 +32775,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "zwei oder mehr Datentypen in Deklaration"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> ist für GCC zu lang"
@@ -32862,17 +32915,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO-C unterstützt nicht %<double complex%> bedeutendes einfaches %<complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO-C unterstützt keine komplexen Ganzzahltypen"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr "%<#pragma omp declare reduction%>-Kombinierer verweist auf Variable %qD, die weder %<omp_out%> noch %<omp_in%> ist"
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr "%<#pragma omp declare reduction%>-Initialisierung verweist auf Variable %qD, die weder %<omp_priv%> noch %<omp_orig%> ist"
@@ -32922,7 +32975,7 @@
 msgid "version control conflict marker in file"
 msgstr "Konfliktmarker für Versionskontrolle in Datei"
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "Zeilenende erwartet"
@@ -32963,7 +33016,7 @@
 msgstr "unbekannter Typname: %qE"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "Deklarationsspezifizierer erwartet"
@@ -32978,7 +33031,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>, Bezeichner oder %<(%> erwartet"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "Präfixattribute werden für Methoden ignoriert"
@@ -32993,8 +33046,8 @@
 msgid "unexpected attribute"
 msgstr "unerwartetes Attribut"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "%<fallthrough%>-Attribut ohne darauffolgendes %<;%>"
@@ -33032,7 +33085,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<__auto_type%> kann nur mit einem einzelnen Deklarator verwendet werden"
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> oder %<;%> erwartet"
@@ -33060,7 +33113,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO-C90 unterstützt nicht %<_Static_assert%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "Zeichenkettenliteral erwartet"
@@ -33124,14 +33177,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "Bezeichner erwartet"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "Komma am Ende der Aufzählungsliste"
@@ -33266,7 +33319,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> vor %<else%> erwartet"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> ohne vorheriges %<if%>"
@@ -33291,12 +33344,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr "eine Marke kann nur Teil einer Anweisung sein, und eine Deklaration ist keine Anweisung"
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr "-fcilkplus muss eingeschaltet sein, um %<_Cilk_for%> zu verwenden"
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr "-fcilkplus muss eingeschaltet sein, um %<_Cilk_sync%> zu verwenden"
@@ -33310,17 +33363,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "Anweisung erwartet"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<if%>-Anweisung empfohlen"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "geschweifte Klammern um leeren Körper in einer %<else%>-Anweisung empfohlen"
@@ -33330,7 +33383,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr "if-Anweisung darf kein %<Cilk_spawn%> enthalten"
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "es wird empfohlen, explizite geschweifte Klammern zu setzen, um mehrdeutiges %<else%> zu vermeiden"
@@ -33350,7 +33403,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "ungültiges Schleifenvariable in schneller Aufzählung"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr "fehlende Schleifenbedingung in Schleife mit %<GCC ivdep%>-Pragma"
@@ -33526,17 +33579,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "Operanden von %<__builtin_complex%> unterschiedlichen Typs"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "falsche Anzahl der Argumente für %<__builtin_shuffle%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr "-fcilkplus muss eingeschaltet sein, um %<_Cilk_spawn%> zu verwenden"
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr "aufeinanderfolgende %<_Cilk_spawn%>-Schlüsselwörter sind nicht erlaubt"
@@ -33591,61 +33644,61 @@
 msgid "no type or storage class may be specified here,"
 msgstr "hier darf kein Typ oder Speicherklasse angegeben werden,"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "unbekanntes Eigenschaftsattribut"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<getter%>)"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "fehlendes %<=%> (hinter Attribut %<setter%>)"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "das %<setter%>-Attribut darf nur einmal angegeben werden"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "Setter-Name muss mit %<:%> beendet werden"
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "das %<getter%>-Attribut darf nur einmal angegeben werden"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma %s%> darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma acc routine%> darf nur im Datei-Gültigkeitsbereich auftreten"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> darf nur in %<#pragma omp sections%>-Konstrukt verwendet werden"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "for-, while- oder do-Anweisung erwartet"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> muss zuerst kommen"
@@ -33660,12 +33713,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "%<#pragma grainsize%> muss innerhalb einer Funktion sein"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "zu viele %qs-Klauseln"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "Ganzzahlausdruck vor »)« erwartet"
@@ -33680,53 +33733,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD ist keine Variable"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD ist keine Zeigervariable"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "Collapse-Argument erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, gcc-internal-format
 msgid "expected %<none%>"
 msgstr "%<none%> erwartet"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> oder %<shared%> erwartet"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<data%>, %<update%>, %<enter%> oder %<exit%> erwartet"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%<data%> erwartet"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr "zu viele %<if%>-Klauseln mit %qs-Modifizierer"
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "zu viele %<if%>-Klauseln"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "zu viele %<if%>-Klauseln ohne Modifizierer"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr "wenn eine der %<if%>-Klauseln einen Modifizierer verwendet, müssen alle %<if%>-Klauseln Modifizierer verwenden"
@@ -33754,22 +33807,22 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "Wert von %<num_tasks%> muss positiv sein"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "Wert von %<grainsize%> muss positiv sein"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "Wert von %<priority%> muss positiv sein"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "%<tofrom%> erwartet"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "%<scalar%> erwartet"
@@ -33779,57 +33832,57 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "Wert von %<num_workers%> muss positiv sein"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "zu viele %<static%>-Argumente"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "unerwartetes Argument"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "Wert %qs muss positiv sein"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%<tile%>-Argument muss eine positive, ganzzahlige Konstante sein"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "%<ordered%>-Argument muss ein positiver, ganzzahliger Ausdruck sein"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> oder Bezeichner erwartet"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "widersprüchliche Modifizierer %<monotonic%> und %<nonmonotonic%> angegeben"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<runtime%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "Ablauf %<auto%> akzeptiert keinen Parameter %<chunk_size%>"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "Wert der Chunkgröße muss positiv sein"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "ungültige Ablaufart"
@@ -33844,17 +33897,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "Wert von %<num_teams%> muss positiv sein"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "Wert von %<thread_limit%> muss positiv sein"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "Ausdruck für %<aligned%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr "das Verwenden von Parametern für den %<linear%>-Schritt wird noch nicht unterstützt"
@@ -33874,17 +33927,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "Ausdruck der %<simdlen%>-Klausel erfordert positiven konstanten Ganzzahlausdruck"
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "ungültige Abhängigkeitsart"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, gcc-internal-format
 msgid "invalid map kind"
 msgstr "ungültige Zuordnungsart"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "ungültige »dist_schedule«-Art"
@@ -33894,67 +33947,67 @@
 msgid "invalid proc_bind kind"
 msgstr "ungültige »proc_bind«-Art"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "Klausel %<#pragma acc%> erwartet"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs ist für %qs ungültig"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs muss die erste Klausel von %qs sein"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "Klausel %<#pragma omp%> erwartet"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr "keine gültigen Klauseln in %<#pragma acc declare%> angegeben"
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "Arrayabschnitt in %<#pragma acc declare%>"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "In %<#pragma acc declare link%> muss %qD eine globale Variable sein"
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "ungültige OpenACC-Klausel im Datei-Gültigkeitsbereich"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<extern%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "ungültige Verwendung der %<global%>-Variable %qD in %<#pragma acc declare%>"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr "Variable %qD wird in %<#pragma acc declare%> mehr als einmal verwendet"
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "hinter %<#pragma acc %s%> wird %<data%> erwartet"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma acc %s data%> hat keine Datenverschiebeklausel"
@@ -33969,7 +34022,7 @@
 msgid "expected function name"
 msgstr "Funktionsname erwartet"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "%qD bezeichnet keine Funktion"
@@ -33979,42 +34032,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Funktionsdeklaration oder -definition auftreten"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma acc routine%> muss direkt vor einer Deklaration oder Definition einer einzelnen Funktion auftreten"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "%<#pragma acc routine%> wird bereits auf %qD angewendet"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "%<#pragma acc routine%> muss vor Verwendung angewendet werden"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma acc routine%> muss vor Definition angewendet werden"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma acc update%> muss mindestens eine %<device%>- oder %<host%>- or %<self%>-Klausel enthalten"
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "ungültige Form von %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "ungültiger Operator für %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic capture%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
@@ -34024,27 +34077,27 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> oder Zeilenende erwartet"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr "%<ordered%>-Klauselparameter ist weniger als %<collapse%>"
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr "%<linear%>-Klausel darf nicht zusammen mit %<ordered%>-Klausel mit einem Parameter angegeben werden"
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "für Anweisung erwartet"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "_Cilk_for-Anweisung erwartet"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "Schleifendeklaration oder Initialisierung erwartet"
@@ -34054,72 +34107,72 @@
 msgid "not enough perfectly nested loops"
 msgstr "nicht genügend perfekt geschachtelte Schleifen"
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "zusammengelegte Schleifen sind nicht perfekt geschachtelt"
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "Schleifenvariable %qD sollte nicht »firstprivate« sein"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<ordered%>-Klausel mit Parameter darf nicht beim %qs-Konstruk angegeben werden"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp ordered%> mit %<depend%>-Klausel darf nur in Verbundanweisungen verwendet werden"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "%<for%> hinter %qs erwartet"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "%<point%> erwartet"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target data%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp target update%> muss mindestens eine %<from%>- oder %<to%>-Klausel enthalten"
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target enter data%> mit Zuordnungstyp außer %<to%> oder %<alloc%> an %<map%>-Klausel"
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target enter data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp target exit data%> mit Zuordnungstyp außer %<from%>, %<release%> oder %<delete%> an %<map%>-Klausel"
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp target exit data%> muss mindestens eine %<map%>-Klausel enthalten"
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp target%> mit Zuordnungstyp außer %<to%>, %<from%>, %<tofrom%> oder %<alloc%> an %<map%>-Klausel"
@@ -34134,7 +34187,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma omp declare simpl%> muss vor der Deklaration oder Definition einer Funktion auftreten"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr "%<#pragma omp declare simd%> oder %<simd%>-Attribut darf nicht in derselben Funktion verwendet werden, die auch als Cilk-Plus-SIMD-aktivierte Funktion markiert ist"
@@ -34144,32 +34197,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr "hinter %<#pragma omp declare simd%> muss direkt eine Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr "hinter %<#pragma omp declare simd%> muss direkt eine einzelne Funktionsdeklaration oder -definition stehen"
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma omp declare target%> mit Klauseln zwischen %<#pragma omp declare target%> ohne Klauseln und %<#pragma omp end declare target%>"
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr "%qD ist sowohl in %<link%>- als auch %<to%>-Klauseln des Deklarationsziels angegeben"
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%<target%> erwartet"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%<declare%> erwartet"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma opt end declare target%> ohne zugehöriges %<#pragma omp declare target%>"
@@ -34224,22 +34277,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr "eins der Argumente für den Initialisierungsaufruf sollte %<&omp_priv%> sein"
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<simd%> oder %<reduction%> oder %<target%> erwartet"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE nach erster Verwendung als %<threadprivate%> deklariert"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automatische Variable %qE kann nicht %<threadprivate%> sein"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE hat unvollständigen Typen"
@@ -34254,52 +34307,52 @@
 msgid "pragma simd must be inside a function"
 msgstr "»pragma simd« muss innerhalb einer Funktion sein"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "»vectorlength« muss eine Ganzzahlkonstante sein"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "»vectorlength« muss eine Zweierpotenz sein"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "Schrittweite muss eine ganzzahliger Konstantenausdruck oder eine Ganzzahlvariable sein"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "%<#pragma simd%>-Klausel erwartet"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma cilk gransize%> ist nicht gefolgt von %<_Cilk_for%>"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%> ohne eingeschaltete Unterstützung für transaktionsbasierten Speicher"
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%> innerhalb eines %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "äußeres %<__transaction_cancel%> nicht innerhalb des äußeren %<__transaction_atomic%>"
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  oder einer %<transaction_may_cancel_outer%>-Funktion"
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%> nicht innerhalb von %<__transaction_atomic%>"
@@ -34309,7 +34362,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "Basis des Arrayabschnitts muss Zeiger- oder Arraytyp sein"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "%<:%> oder Zahl erwartet"
@@ -35025,7 +35078,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "Linke-Initialisierung könnte Kandidat für Formatattribut sein"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "Rückgabetyp könnte Kandidat für Formatattribut sein"
@@ -35353,7 +35406,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO-C verbietet %<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "als %<noreturn%> deklarierte Funktion hat %<return%>-Anweisung"
@@ -35363,7 +35416,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "Arraynotations-Ausdruck kann nicht als Rückgabewert verwendet werden"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr "%<_Cilk_spawn%> darf nicht in einer return-Anweisung verwendet werden"
@@ -35388,7 +35441,7 @@
 msgid "function returns address of label"
 msgstr "Funktion liefert Adresse einer Sprungmarke zurück"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch-Größe ist keine Ganzzahl"
@@ -35403,7 +35456,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "»case«-Marke ist kein konstanter Ganzzahlausdruck"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case-Marke nicht innerhalb einer switch-Anweisung"
@@ -35423,17 +35476,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr "Rangkonflikt zwischen der Bedingung der if-Anweisung und dem else-Block"
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-Anweisung nicht innerhalb einer Schleife oder »switch«"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-Anweisung nicht innerhalb einer Schleife"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-Anweisung mit OpenMP für Schleife verwendet"
@@ -35443,7 +35496,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-Anweisung innerhalb einer %<#pragma simd%>-Schleife"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue-Anweisung innerhalb einer %<#pragma simd%>-Schleife"
@@ -35549,12 +35602,12 @@
 msgid "used vector type where scalar is required"
 msgstr "Vektortyp verwendet, wo Skalars benötigt wird"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancel%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp cancellation point%> muss eine der Klauseln %<parallel%>, %<for%>, %<sections%> oder %<taskgroup%> angeben"
@@ -35564,25 +35617,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%<_Atomic%>-Ausdruck %qE in %qs-Klausel"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "Bitfeld %qE in %qs-Klausel"
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "%qE ist ein Element eines Union-Typs"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD in %qs-Klausel muss eine Variable sein"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE in %qs-Klausel muss eine Variable sein"
@@ -35593,70 +35646,70 @@
 msgstr "%<_Atomic%>-Deklaration %qD in %qs-Klausel"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD in %qs-Klausel ist eine threadprivate Variable"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "Untere Grenze %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Länge %qE des Arrayabschnitts muss Ganzzahltyp haben"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "Arrayabschnitt der Länge 0 in %qs-Klausel"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr "für Arraytyp mit unbekannten Grenzen muss ein Längenausdruck angegeben werden"
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr "negative untere Grenze in Arrayabschnitt in %qs-Klausel"
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "Arrayabschnitt mit negativer Länge in %qs-Klausel"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr "untere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr "Länge %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr "obere Grenze %qE geht über Abschnittsgröße in %qs-Klausel hinaus"
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "für Zeigertyp muss der Längenausdruck angegeben werden"
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "Arrayabschnitt ist in %qs-Klausel nicht zusammenhängend"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE hat weder Zeiger- noch Arraytyp"
@@ -35676,7 +35729,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE hat ungültigen Typ für %<reduction(%s)%>"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "benutzerdefinierte Reduktion für %qE nicht gefunden"
@@ -35686,17 +35739,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "Elementtyp variabler Länge in %<reduction%>-Klausel eines Arrays"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr "%<nowait%>-Klausel darf nicht zusammen mit %<copyprivate%> verwendet werden"
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE muss für %<copyin%> %<threadprivate%> sein"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr "Modifizierer sollte an %<simd%>- oder %<for%>-Konstrukten nicht in %<linear%>-Klausel angegeben werden"
@@ -35716,18 +35769,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr "%<_Atomic%> %qD in %<linear%>-Klausel"
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "Schrittweite %qE der %<linear%>-Klausel muss konstant oder ein Parameter sein"
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE ist in Klausel %qs keine Variable"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD tritt in Reduktionsklauseln mehrfach auf"
@@ -35739,32 +35792,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD tritt in Datenklausel mehrfach auf"
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD tritt in Daten- und Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE ist in Klausel %<firstprivate%> keine Variable"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE ist in Klausel %<lastprivate%> keine Variable"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE ist %<aligned%>-Klausel keine Variable"
@@ -35784,55 +35837,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE ist in %<depends%>-Klausel keine Variable"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "Arrayabschnitt in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD tritt in Bewegungsklausel mehrfach auf"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD tritt in Zuordnungsklauseln mehrfach auf"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD in %qs-Klausel hat keinen zuordenbaren Typ"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE in %qs-Klausel ist weder Variablen- noch Funktionsname"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE tritt in derselben %<declare target%>-Direktive mehrfach auf"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD in %<uniform%>-Klausel ist kein Argument"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE in %<uniform%>-Klausel ist kein Argument"
@@ -35842,32 +35895,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "Variable %qs ist weder Zeiger noch Array"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr "%<nonmonotonic%>-Modifizierer für Planungsart %qs angegeben"
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr "%<inbranch%>-Klausel ist inkompatibel mit %<notinbranch%>"
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE ist vorbestimmt %qs für %qs"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr "%<simdlen%>-Klauselwert ist größer als %<safelen%>-Klauselwert"
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr "%<nonmonotonic%>-Planungsmodifizierer zusammen mit %<ordered%>-Klausel angegeben"
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr "%<linear%>-Klauselschritt ist ein Parameter %qD, der nicht in der %<uniform%>-Klausel angegeben ist"
@@ -36410,152 +36463,152 @@
 msgid "use of multiversioned function without a default"
 msgstr "Verwendung einer multiversionierten Funktion ohne Standardargument"
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "Die Übergabe von %qT als %<this%>-Argument streicht Qualifizierer"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  in Aufruf von %qD"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT ist keine erreichbare Basis von %qT"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%qT ermittelt als %qT"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (dies kann mit -fno-deduce-init-list abgeschaltet werden)"
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Argumente werden an Auslassungspunkte des geerbten Konstruktors %qD übergeben"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "Konstruktor verweist auf sich selbst"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "Aufruf der Nicht-Funktion %qD"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "Konstruktor %<%T::%D%> kann nicht direkt aufgerufen werden"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "um eine funktionsartige Umwandlung zu erreichen, entfernen Sie das redundante %<::%D%>"
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::operator %T(%A)%#V%>"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "keine passende Funktion für Aufruf von %<%T::%E(%A)%#V%>"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "keine passende Funktion für Aufruf von %<%s(%A)%>"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "Aufruf des überladenen %<%s(%A)%> ist mehrdeutig"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "pure virtuelle %q#D aus nichtstatischem Datenelement-Initialisierer heraus aufgerufen"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "pure virtuelle %q#D aus Konstruktor heraus aufgerufen"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "pure virtuelle %q#D aus Destruktor heraus aufgerufen"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "Elementfunktion %qD kann nicht ohne Objekt aufgerufen werden"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "Übergabe von %qT wählt %qT statt %qT"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "Wahl von %qD statt %qD"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  für Umwandlung von %qT in %qT"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  denn die Umwandlungsfolge für das Argument ist besser"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "Zuordnungsfehler der Standardargumente in Überladungsauflösung"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " Kandidat 1: %q#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " Kandidat 2: %q#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ besagt, dass diese mehrdeutig sind, auch wenn die schlechteste Umwandlung für das erste besser ist als die schlechteste Umwandlung für das zweite:"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "%qE konnte nicht von %qT nach %qT umgewandelt werden"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "eine vorübergehende Bindung an %qD besteht nur, bis der Konstruktor beendet ist"
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "ungültige Initialisierung einer nicht-konstanten Referenz des Typs %qT von R-Wert des Typs %qT"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "ungültige Initialisierung einer Referenz des Typs %qT von Ausdruck des Typs %qT"
@@ -36656,272 +36709,272 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "Es kann nicht von %<final%>-Basis %qT in abgeleiteten Typ %qT abgeleitet werden"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "alle Elementfunktionen in Klasse %qT sind privat"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T definiert nur einen privaten Destruktor und hat keine »friends«"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T definiert nur private Konstruktoren und hat keine »friends«"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD wurde nicht eindeutig und endgültig in %qT überschrieben"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "%qD kann als »override« markiert werden"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D als %<final%> markiert, ist aber nicht »virtual«"
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D als %<override%> markiert, überschreibt aber nicht"
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr "%qD war versteckt"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, gcc-internal-format
 msgid "  by %qD"
 msgstr "  von %qD"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q#D ungültig; eine anonyme Union kann nur nicht-statische Datenelemente haben"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q#D ungültig; eine anonyme Struktur kann nur nicht-statische Datenelemente haben"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr "privates Element %q#D in anonymer Union"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr "privates Element %q#D in anonymer struct"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr "geschütztes Element %q#D in anonymer Union"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr "geschütztes Element %q#D in anonymer struct"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "die Auslassung in %qD wurde nicht vererbt"
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "Bit-Feld %q+#D mit Nicht-Ganzzahl-Typ"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "Breite des Bitfeldes %q+D ist keine Ganzzahlkonstante"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "negative Breite in Bitfeld %q+D"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "Breite Null für Bitfeld %q+D"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr "Breite von %qD übersteigt seinen Typen"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%qD ist zu klein, um alle Werte von %q#T aufzunehmen"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "Element %q+#D mit Konstruktor nicht erlaubt in Union"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "Element %q+#D mit Destruktor nicht erlaubt in Union"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "Element %q+#D mit Copy-Zuweisungsoperator ist nicht erlaubt in Union"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "uneingeschränkte »Unions« nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D kann in C++98 nicht static sein, da es ein Union-Element ist"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "nicht-statisches Datenelement %q+D in einer Union darf keinen Referenztypen %qT haben"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "Feld %q+D deklarierte ungültigerweise einen Funktionstypen"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "Feld %q+D deklarierte ungültigerweise einen Methodentypen"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "»packed«-Attribut für ungepacktes nicht-POD-Feld %q#D wird ignoriert"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "Element %q+D darf nicht gleichzeitig als %<const%> und %<mutable%> deklariert sein"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "Element %q+D darf nicht als %<mutable%>-Referenz deklariert sein"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "in Union %qT werden mehrere Felder initialisiert"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "Feld %q#D mit gleichem Namen wie Klasse"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T hat Zeigertypen als Elemente"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  aber überschreibt nicht %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  oder %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  aber überschreibt nicht %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr "Ausrichtung von %qD wurde in -fabi-version=9 (GCC 5.2) erhöht"
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "Ausrichtung von %qD wird in »-fabi-version=9« ansteigen"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Initialisierung für nicht-virtuelle Methode %q+D angegeben"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "Methode überschreibt Methoden %<transaction_pure%> und %qE"
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "als %qE deklarierte Methode überschreibt Methode %qE"
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "umschließende Klasse der nicht-statischen Elementfunktion %q+#D als konstanter Ausdruck ist kein Literaltyp"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T ist kein Literal, denn: "
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T hat einen nicht-trivialen Destruktor"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr " %q+T ist kein Aggregat, hat keinen trivialen Standardkonstruktor und hat keinen Konstruktor mit konstantem Ausdruck, der kein Kopier- oder Bewegungskonstruktor ist"
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  Basisklasse %qT von %q+T ist kein Literal"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  nicht-statisches Datenelement %qD hat nicht-literalen Typ"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  nicht-statisches Datenelement %qD hat nicht-literalen Typ"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Basisklasse %q#T hat einen zugänglichen nicht-virtuellen Destruktor"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "nicht-statische Referenz %q#D in Klasse ohne Konstruktor"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr "nicht-statisches const-Element %q#D in Klasse ohne einen Konstruktor"
@@ -36928,152 +36981,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D mit Eingabe einer konstanten Referenz deklariert, aber implizite Deklaration würde nicht-Konstante annehmen"
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direkte Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtuelle Basis %qT ist in %qT durch Mehrdeutigkeit unzugänglich"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "Offset von %qD ist ABI-unverträglich und kann sich in zukünftigen GCC-Versionen ändern"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "Größe des Typs %qT ist zu groß (%qE Bytes)"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "ungültige Verwendung von %q#T mit Array der Größe 0 in %q#D"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "ungültige Verwendung von %q#T mit flexiblem Arrayelement in %q#T"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "Arrayelement %q#D hier deklariert"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "Arrayelement %qD mit Länge 0 befindet sich nicht am Ende von %q#T"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "Arrayelement %qD mit Länge 0 in ansonsten leerem %q#T"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "in der Definition von %q#T"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexibles Arrayelement %qD nicht am Ende von %q#T"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexibles Arrayelement %qD in ansonsten leerem %q#T"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "nächstes Feld %q#D hier deklariert"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "Redefinition von %q#T"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T hat virtuelle Funktionen und erreichbaren nicht-virtuellen Destruktor"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "typtransparentes %q#T hat keine Felder"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "typtransparente Klasse %qT hat Basisklassen"
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "typtransparente Klasse %qT hat virtuelle Funktionen"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr "typtransparentes %q#T kann nicht transparent gemacht werden, weil der Typ des ersten Feldes anderes ABI als gesamte Klasse hat"
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "Definition von std::initializer_list entspricht nicht #include <initializer_list>"
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "Lesen der struct konnte wegen Syntaxfehlern nicht beendet werden"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "Sprachen-Zeichenkette %<\"%E\"%> nicht erkannt"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "überladene Funktion %qD konnte nicht durch Umwandlung in Typ %qT aufgelöst werden"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "bei der Umwandlung der Funktion %qD in den Typ %q#T gab es keine Übereinstimmungen"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "Umwandung der überladenen Funktion %qD in den Typ %q#T ist mehrdeutig"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "Zeiger auf Element %qD wird angenommen"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(ein Zeiger auf ein Element kann nur mit %<»&%E%> erzeugt werden)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "zu wenig Typinformationen"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE kann nicht vom Typ %qT in den Typ %qT umgewandelt werden"
@@ -37083,12 +37136,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "Deklaration von %q#D"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr "verändert die Bedeutung von %qD von %q#D"
@@ -37118,332 +37171,332 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "ungültiger Rückgabetyp %qT der Funktion %q+D als konstantem Ausdruck"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T hat virtuelle Basisklassen"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr "Konstruktor mit konstantem Ausdruck hat keinen leeren Körper"
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr "Körper des %<constexpr%>-Konstruktor kann kein Funktions-»try«-Block sein"
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%>-Konstruktor für Union %qT muss genau ein nicht-statisches Datenelement initialisieren"
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "Element %qD in %<constexpr%> muss von »mem-initializer« initialisiert werden"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "Körper der Funktion %qD mit konstantem Ausdruck ist keine Rückgabeanweisung"
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%qD ist nicht als »constexpr«-Funktion verwendbar, denn:"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "Aufruf für interne Funktion %qE"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "Ausdruck %qE bezeichnet keine Funktion mit konstantem Ausdruck"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "Aufruf der Funktion %qD, die kein konstanter Ausdruck ist"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD in konstantem Ausdruck aufgerufen, bevor die Definition vollständig war"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD in konstantem Ausdruck aufgerufen"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD vor seiner Definition verwendet"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "Aufruf hat ringförmige Abhängigkeit"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "Auswertungstiefe des konstanten Ausdrucks überschreitet Höchstwert %d (-fconstexpr-depth= verwenden, um dies zu erhöhen)"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr "Kontrollfluss für constexpr-Aufruf fällt hinten aus der Funktion"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "rechter Operand des Schiebeausdrucks %q+E ist negativ"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr "rechter Operand des Schiebeausdrucks %q+E ist mindestens so groß wie die Genauigkeit des linken Operanden"
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "linker Operand des Schiebeausdrucks %q+E ist negativ"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "Schiebeausdruck %q+E läuft über"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr "Arithmetik mit Nullzeiger in %qE"
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "Arrayindexwert %qE ist außerhalb der Grenzen des Arrays %qD vom Typ %qT"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "Arrayindexwert %qE ist außerhalb der Grenzen des Arraytyps %qT"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "Zugriff auf uninitialisiertes Arrayelement"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Dereferenzierung eines Nullzeigers in %qE"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "veränderliches %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "Zugriff auf Element %qD statt auf initialisiertes Element %qD in Konstantenausdruck"
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "Zugriff auf uninitialisiertes Element %qD"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "Dereferenzierung eines Null-Zeigers"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "auf Wert von %qE wird über ein %qT GL-Wert in Konstantenausdruck zugegriffen"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "der Wert von %qD ist in konstantem Ausdruck nicht verwendbar"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD in seiner eigenen Initialisierung verwendet"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D ist nicht konstant"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D ist volatile"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD wurde nicht mit konstantem Ausdruck initialisiert"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD wurde nicht als %<constexpr%> definiert"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD hat keinen Ganzzahl- oder Aufzählungstyp"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "Modifikation von %qE ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "Anzahl der Schleifendurchläufe in »constexpr« überschreitet Höchstwert %d (»-fconstexpr-depth=« verwenden, um diesen zu erhöhen)"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Wert %qE vom Typ %qT ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "Zwischenergebnis des nicht-literalen Typs %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "Ein »reinterpret_cast« ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "Umwandlung eines Nullpointers vom Typ %qT in %qT ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%<reinterpret_cast<%T>(%E)%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "Ausdruck %qE ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "Anweisung ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "unexpected expression %qE of kind %s"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qE ist kein Konstantenausdruck, da er auf veränderliche Teilobjekte von %qT verweist"
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qE ist kein Konstantenausdruck, da er auf eine unvollständig initialisierte Variable verweist"
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "Umwandlung von Zeigertyp %qT in arithmetischen Typ %qT in Konstantenausdruck"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "Ausdruck %qE hat Seiteneffekte"
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast von Integer nach Zeiger"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "Adresse eines Objektes %qE mit thread-lokalem oder automatischem Speicher ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "Verwendung von %<this%> in Konstantenausdruck"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "Typeid-Ausdruck ist kein konstanter Ausdruck, da %qE polymorphen Typ hat"
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Umwandlung in Nicht-Ganzzahltyp %qT in konstantem Ausdruck"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%qD in %<constexpr%>-Funktion als %<static%> deklariert"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qD in %<constexpr%>-Funktion als %<thread_local%> deklariert"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialisierte Variable %qD in %<constexpr%>-Funktion"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Division durch Null ist kein konstanter Ausdruck"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%<delete[]%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "nicht konstante Arrayinitialisierung"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%<goto%> ist kein Konstantenausdruck"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "unerwarteter AST der Art %s"
@@ -38239,7 +38292,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  überspringt Initialisierung von %q#D"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "ungültiger Ausgang von strukturiertem OpenMP-Block"
@@ -38254,7 +38307,7 @@
 msgid "%qD is not a type"
 msgstr "%qD ist kein Typ"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD ohne Template-Parameter verwendet"
@@ -39890,7 +39943,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "Parameter als %<auto%> deklariert"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "ungültige Verwendung des Template-Namens %qE ohne eine Argumentliste"
@@ -40341,13 +40394,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD hat den gleichen Namen wie die Klasse, in der es deklariert wurde"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ist kein Template"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, gcc-internal-format
 msgid "previous declaration here"
 msgstr "vorherige Deklaration hier"
@@ -40357,8 +40410,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr "Sie könnten ein explizites %<%T::%> hinzufügen"
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "Referenz auf %qD ist mehrdeutig"
@@ -40408,7 +40461,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "falsche Zuordnung zwischen innerhalb und außerhalb eines Gültigkeitsbereiches in enum %q#T"
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "vorherige Definition hier"
@@ -40472,7 +40525,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "Rückgabetyp %q#T ist unvollständig"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> sollte eine Referenz auf %<*this%> zurückgeben"
@@ -40487,7 +40540,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "keine return-Anweisungen in %qT zurückgebender Funktion"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "nur einfacher Rückgabetyp %<auto%> kann zu %<void%> hergeleitet werden"
@@ -40645,27 +40698,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "Breite des Bit-Feldes %qD hat Nicht-Ganzzahl-Typ %qT"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "statisches Datenelement %q+D innerhalb von »declare target«-Direktive"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonymes struct nicht innerhalb eines benannten Typs"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonymes Aggregat im Gültigkeitsbereich eines Namespace muss statisch sein"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonyme Union ohne Element"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> muss Typ %qT zurückgeben"
@@ -40674,67 +40727,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "der erste Parameter von %<operator_new%> kann nicht das Standardargument haben"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> nimmt Typ %<size_t%> (%qT) als ersten Parameter"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> muss Typ %qT zurückgeben"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> nimmt Typ %qT als ersten Parameter"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT hat ein Feld %qD, dessen Typ keine Bindung hat"
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT hat ein Feld %qD, dessen Typ vom Typ %qT abhängt, der wiederum keine Bindung hat"
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT hat ein Feld %qD, dessen Typ den anonymen Namensbereich verwendet"
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als der Typ seines Feldes %qD deklariert"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT hat Basis %qT, dessen Typ keine Bindung hat"
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT hat Basis %qT, dessen Typ von Typ %qT abhängt, der wiederum keine Bindung hat"
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT hat Basis %qT, dessen Typ den anonymen Namensbereich verwendet"
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT mit bedeutenderer Sichtbarkeit als seine Basis %qT deklariert"
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q#D (durch einen unbenannten Typen deklariert) wird verwendet, aber nirgends definiert"
@@ -40743,47 +40796,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "unbenannter Typ ohne Bindung wird verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "unbenannter Typ ohne Bindung wird verwendet, um Funktion %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q#D verweist nicht auf den unqualifizierten Typen und wird daher nicht zum Binden verwendet"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q#D (durch lokalen Typen %qT deklariert) wird verwendet, aber nirgends definiert"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "Typ %qT ohne Bindung verwendet, um Variable %q#D mit Bindung zu deklarieren"
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "Typ %qT ohne Bindung für Funktionsdeklaration %q#D mit Bindung deklariert"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr "das Programm sollte auch %qD definieren"
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "inline-Funktion %qD verwendet, aber nirgendwo definiert"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "Standardargument fehlt für Parameter %P von %q+#D"
@@ -40790,12 +40843,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "%<...%> verwendendes Lambda wird in Funktionszeiger umgewandelt"
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "gelöschte Funktion %qD wird verwendet"
@@ -41104,18 +41157,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "ungültige Initialisierung für Arrayelement %q#D"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "nicht initialisiertes konstantes Element in %q#T"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q#D sollte initialisiert werden"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "nicht initialisiertes Referenzelement in %q#T"
@@ -41215,7 +41268,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "Array muss mit Initialisierung mit umgebenden geschweiften Klammern initialisiert werden"
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ist kein Klassentyp"
@@ -41235,7 +41288,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "ungültige Verwendung der nicht-statischen Elementfunktion %qD"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "ungültige Verwendung des nicht-statischen Datenelementes %qD"
@@ -41430,22 +41483,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr "da der Arrayelementtyp %qT variable Größe hat"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "%qE kann nicht per Referenz aufgefangen werden"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "Einfangen per Kopie von unvollständigem Typ %qT"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "%qD bereits in Lambda-Ausdruck erfasst"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> wurde für diese Lambda-Funktion nicht aufgefangen"
@@ -41500,186 +41553,186 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(mit %<-fpermissive%> wird G++ den Code akzeptieren, aber die Verwendung eines nicht deklarierten Namens ist veraltet)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "defektes typeof, stattdessen decltype verwenden"
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "__underlying_type wird vernichtet"
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "unbekannter Festkommatyp wird vernichtet"
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr "Verwendung der eingebauten Eigenschaft %qE in Funktionssignatur; stattdessen sollten Bibliothekseigenschaften verwendet werden"
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "%C wird gemangelt"
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "ausgelassener mittlerer Operand für Operator %<?:%> kann nicht verarbeitet werden"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "Zeichenkettenliteral in Signatur des Funktionstemplate"
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr "gemangelter Name für %qD wird sich ich C++17 ändern, da die Exceptionangabe Teil des Funktionstyps ist"
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "Eine spätere Option -fabi-version= (oder =0) verhindert diesen Fehler mit einer Änderung im Mangeln"
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "der gemangelte Name von %qD hat sich zwischen »-fabi-version=%d« (%D) und »-fabi-version=%d« (%D) geändert"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "der gemangelte Name von %qD ändert sich zwischen »-fabi-version=%d« (%D) und »-fabi-version=%d« (%D)"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "der gemangelte Name eines Thunks für %qD ändert sich zwischen »-fabi-version=%d« und »-fabi-version=%d«"
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "der gemangelte Name von %qD ändert sich zwischen »-fabi-version=%d« und »-fabi-version=%d«"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "der gemangelte Name der Initialisierungswächter-Variable für %qD ändert sich zwischen »-fabi-version=%d« und »-fabi-version=%d«"
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "nicht-statisches konstantes Element %q#D, Standard-Zuweisungsoperator kann nicht verwendet werden"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "nicht-statisches Referenzelement %q#D, Standard-Zuweisungsoperator kann nicht verwendet werden"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr "erzeugte Methode %qD zuerst hier erfordert "
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "Union-Element %q+D mit nichttrivialem %qD"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "standardisierter Konstruktor ruft nicht-konstanten Ausdruck %qD auf"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "Initialisierung für %q#D ist ungültig"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "Standardisierter Standardkonstruktor initialisiert %q#D nicht"
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "Kopieren von nicht-statischem Datenelement %q#D von rvalue-Referenztyp"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "Standardisierter Standardkonstruktor initialisiert kein nicht-statisches Datenelement"
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr "Standard-Kopierzuweisung für %qT ruft nichttrivialen Operator zur Kopierzuweisung für virtuelle Basis %qT auf"
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "Lambda-Abschlusstyp hat gelöschten Standardkonstruktor"
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "Lambda-Abschlusstyp hat gelöschten Kopier-Zuweisungsoperator"
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q#D ist implizit als gelöscht deklariert, da %qT einen Bewegungskonstruktor oder Bewegungs-Zuweisungsoperator deklariert"
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr "%q#D erbt von mehreren Basis-Teilobjekten"
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q#D wird implizit gelöscht, da die Standarddefinition ungültig wäre:"
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr "%q#F wird implizit gelöscht, da ihre Ausnahme-Spezifikation nicht zur impliziten Ausnahme-Spezifikation %qX passt"
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "Vorgabe-Deklaration %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr "passt nicht zur erwarteten Signatur %qD"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr "Funktion %q+D bekam durch »default« eine Exception-Spezifikation, die sich von er impliziten Exception-Spezifikation %qX unterscheidet"
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr "Explizit standardisierte Funktion %q+D kann nicht als konstanter Ausdruck deklariert werden, da die implizite Deklaration kein konstanter Ausdruck ist:"
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "ein Template kann nicht vorbelegt werden"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD kann nicht vorgegeben werden"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "vorgegebene Funktion %q+D mit Standardargument"
@@ -41871,97 +41924,97 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> benennt Konstruktor in %qT"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr "Konstruktoren können nicht von indirekter Basis %qT geerbt werden"
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "kein Element passt zu %<%T::%D%> in %q#T"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "Deklaration von %qD nicht in einem Namensbereich um %qD"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "explizite Qualifizierung in Deklaration von %qD"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr "%qD wurde nicht innerhalb von %D deklariert"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, gcc-internal-format
 msgid "only here as a friend"
 msgstr "sondern nur hier als »friend«"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD sollte innerhalb von %qD deklariert werden"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "Attribut %qD erfordert ein einzelnes NTBS-Argument"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "Attribut %qD ist bedeutungslos, da die Elemente des anonymen Namensraums lokale Symbole erhalten"
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "Attribut %qD an nicht-»inline«-Namensraum wird ignoriert"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "Attribut %qD an unbenanntem Namensraum wird ignoriert"
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "Attribut-Anweisung %qD wird ignoriert"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "Namensbereich-Alias %qD ist hier nicht erlaubt, %qD angenommen"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "»using« mit Attribut »strong« ist veraltet; verwenden Sie stattdessen inline-Namensräume"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "starkes »using« ist nur im Gültigkeitsbereich des Namensbereiches sinnvoll"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "aktueller Namensbereich %qD schließt nicht stark verwendeten Namensbereich %qD ein"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "obere Grenze von %d Namensräumen für %qE durchsucht"
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "empfohlene Alternative: %qs"
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -41968,27 +42021,27 @@
 msgstr[0] "empfohlene Alternative:"
 msgstr[1] "empfohlene Alternativen:"
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr "Argumentabhängiges Nachschlagen findet %q+D"
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr "Deklaration von std::initializer_list entspricht nicht #include <initializer_list>, ist kein Template"
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX Eintritt in pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX pop_everything () wird verlassen\n"
@@ -42008,7 +42061,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr "LEXER_DEBUGGING_ENABLED_P is not set to true"
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma omp declare simd%> ist nicht direkt gefolgt von Funktionsdeklaration oder -definition"
@@ -42033,7 +42086,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "Abfrage des Elementes %qE in Nicht-Klassentyp %qT"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> wurde nicht deklariert"
@@ -42093,1201 +42146,1206 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(vielleicht fehlt ein Semikolon hinter der Definition von %qT)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "%qE ist kein Klassentemplate"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE ist kein Template"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "ungültige Template-ID"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO-C++ verbietet Gleitkommaliterale in Konstanten-Ausdrücken"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "Eine Typumwandlung, die weder zu ganzzahligen noch Aufzählungstypen führt, kann nicht in einem Konstantenausdruck auftreten"
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "%<typeid%>-Operator kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "nicht-konstantes zusammengesetztes Literal kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "ein Funktionsaufruf kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "eine Erhöhung kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "eine Verringerung kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "eine Arrayreferenz kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "die Adresse einer Marke kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "Aufrufe überladener Operatoren können nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "eine Zuweisung kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "ein Komma-Operator kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "ein Konstruktoraufruf kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "ein Transaktionsausdruck kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%qs kann nicht in einem Konstanten-Ausdruck auftreten"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "Argumentherleitung von Klassentemplates ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "ungültige Verwendung des Destruktors %qD als Typ"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "ungültige Kombination mehrerer Typ-Spezifizierer"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE bezeichnet keinen Typ; meinten Sie %qs?"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE bezeichnet keinen Typ"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "%<constexpr%> von C++11 nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "%<noexcept%> von C++11 ist nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "%<thread_local%> von C++11 ist nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr "%<concept%> ist nur mit »-fconcepts« verfügbar"
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(vielleicht war %<typename %T::%E%> beabsichtigt)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE in Namensraum %qE bezeichnet keinen Templatetyp"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE in Namensbereich %qE bezeichnet keinen Typ"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%E%> benennt den Konstruktor, nicht den Typ"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "und %qT hat keinen Template-Konstruktor"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr "vor %<%T::%E%> ist %<typename%> erforderlich, da %qT ein abhängiger Gültigkeitsbereich ist"
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE in %q#T benennt keinen Templatetypen"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE in %q#T benennt keinen Typen"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr "Zeichenkettenliteral erwartet"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr "widersprüchliche benutzerdefinierte literale Suffixe %qD und %qD in Zeichenkettenliteral"
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr "eine Wide-Zeichenkette ist in diesem Kontext ungültig"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr "Operator %qD für Zeichenliterale mit Argument %qT kann nicht gefunden werden"
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr "Ganzzahlliteral überschreitet Wertebereich des Typs %qT"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr "Gleitkommaliteral überschreitet Wertebereich des Typs %qT"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr "Gleitkommaliteral auf Null abgeschnitten"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr "numerischer literaler Operator %qD konnte nicht gefunden werden"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr "verwenden Sie -std=gnu++11 oder -fext-numeric-literals, um weitere eingebaute Suffixe einzuschalten"
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "literaler Operator für Zeichenketten %qD mit Argumenten %qT, %qT konnte nicht gefunden werden"
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "Deklaration erwartet"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, gcc-internal-format
 msgid "expected binary operator"
 msgstr "binärer Operator erwartet"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, gcc-internal-format
 msgid "expected ..."
 msgstr "%<...%> erwartet"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr "binärer Ausdruck in Operand von Faltungsausdruck"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "bedingter Ausdruck in Operand von Faltungsausdruck"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr "unpassender Operator in Faltungsausdruck"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "Festkommatypen werden in C++ nicht unterstützt"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO-C++ verbietet Gruppen in geschweiften Klammern innerhalb von Ausdrücken"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "Anweisungs-Ausdrücke sind weder außerhalb von Funktionen noch in Template-Argumenten erlaubt"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "Faltungsausdrücke sind nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "übergeordneter Ausdruck erwartet"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "%<this%> darf in diesem Kontext nicht verwendet werden"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "eine Template-Deklaration kann nicht im Block-Gültigkeitsbereich auftreten"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "lokale Variable %qD darf in diesem Kontext nicht auftauchen"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr "ID-Ausdruck erwartet"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "Bereich %qT vor %<~%> ist kein Klassenname"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%<~auto%> ist nur mit -std=c++14 oder -std=gnu++14 verfügbar"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "Deklaration von %<~%T%> als Element von %qT"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef-Name %qD als Destruktor-Deklarator verwendet"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "Literale Operator-Suffixe ohne vorangehendes %<_%> sind für zukünftige Standardisierungen reserviert"
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "unqualifizierte ID erwartet"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "%<:%> in Spezifikation mit geschachteltem Namen gefunden, %<::%> erwartet"
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype wird zu %qT ausgewertet, was keine Klasse oder Aufzählungstyp ist"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "Bezeichner %qD für Funktionstemplate ist geschachteltem Namens-Spezifizierer"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "Bezeichner %qD für Variablentemplate ist geschachteltem Namens-Spezifizierer"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ist kein Template"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "Spezifikation mit geschachteltem Namen erwartet"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Typen dürfen nicht in Typumwandlungen definiert werden"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "Typen dürfen nicht in einem %<typeid%>-Ausdruck definiert werden"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr "%<_Cilk_spawn%> muss von einem Ausdruck gefolgt sein"
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_addressof%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "falsche Anzahl von Argumenten für %<__builtin_launder%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO-C++ verbietet zusammengesetzte Literale"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr "zwei aufeinander folgende %<[%> dürfen nur ein Attribut einführen"
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr "mit Arraynotation darf der Arrayindex keine {Initialisierungsliste} sein"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "ungültige Verwendung von %qD"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> ist kein Klassenelement"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "nicht-skalarer Typ"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO-C++ erlaubt kein %<alignof%> mit einem Nicht-Typ"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "Typen dürfen nicht in %<noexcept%>-Ausdrücken definiert werden"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "Typen dürfen nicht in einem »new«-Ausdruck definiert werden"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "Arraygrenze hinter geklammerter type-id ist verboten"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "Klammern um die Type-ID sollten entfernt werden"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr "Initialisierung des new-Ausdrucks für Typ %<auto%> erfordert genau ein Element"
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "»expression-list« oder »type-id« erwartet"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "Typen dürfen nicht in einem »new-type-id« definiert werden"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "Ausdruck in new-Deklarator muss Ganzzahl- oder Aufzählungstyp haben"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "Verwendung einer Typumwandlung im alten Stil"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "Operator %<>>%> wird in C++11 wie zwei spitze schließende Klammern behandelt"
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "Klammern um %<>>%>-Ausdruck empfohlen"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO-C++ erlaubt nicht ?: mit ausgelassenem mittleren Operanden"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "Lambda-Ausdruck in ungeprüftem Kontext"
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "Lambda-Ausdruck in Templateargument"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "unerwartetes Ende der Auffangliste"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "Explizite Erfassung (als Kopie) von %<this%> ist mit Standarderfassung (als Kopie) gedoppelt"
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "%<*this%>-Capture ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "Initialisierungen für Lambda-Captures sind nur mit -std=c++14 oder -std=gnu++14 verfügbar"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr "nicht-leere Initialisierung »init-capture« eines Lambdas"
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "Erfassung von Nicht-Variable %qD"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q#D hier deklariert"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "Erfassung der Variable %qD ohne automatische Speicherdauer"
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "Explizite Erfassung (als Kopie) von %qD ist mit Standarderfassung (als Kopie) gedoppelt"
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "Explizite Erfassung (als Referenz) von %qD ist mit Standarderfassung (als Referenz) gedoppelt"
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "Lambda-Templates sind nur mit -std=c++14 oder -std=gnu++14 verfügbar"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, gcc-internal-format
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO-C++ unterstützt keine Lambda-Templates"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "Standardargument für Lambda-Parameter angegeben"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "doppeltes %<mutable%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "%<constexpr%>-Lambda ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "Attribute am Anfang der Anweisung werden ignoriert"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "benannte Anweisung erwartet"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case-Marke %qE nicht innerhalb einer switch-Anweisung"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%<typename%> vor %qE erforderlich, da %qT ein abhängiger Gültigkeitsbereich ist"
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> benennt Konstruktor, nicht den Typ"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr "zusammengesetzte Anweisung in Funktion als konstantem Ausdruck"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "%<if constexpr%> ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "»init-statement in Auswahlanweisungen« ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "Auswahl-Anweisung erwartet"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "Typen dürfen nicht in Bedingungen definiert werden"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat unvollständigen Typ"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat %<end%>-Element, aber kein %<begin%>"
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr "bereichsbasierter %<for%>-Ausdruck mit Typ %qT hat %<begin%>-Element, aber kein %<end%>"
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "unvereinbare Anfang-/Ende-Typen in bereichsbasierter %<for%>-Anweisung: %qT und %qT"
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "Iterationsanweisung erwartet"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "Bereichsbasierte %<for%>-Schleifen sind nur mit -std=c++11 oder -std=gnu++11 verfügbar"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr "break-Anweisung mit Cilk Plus für Schleife verwendet"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "%<goto%> in %<constexpr%>-Funktion"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO-C++ verbietet berechnete Gotos"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "Sprunganweisung erwartet"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "zusätzliches %<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> nicht am Anfang eines Blocks"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr "Nicht-Variable %qD in Deklaration mit mehr als einem Deklarator mit Platzhaltertyp"
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für %qT: %qT und dann %qT"
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "Vermischung von Deklarationen und Funktionsdefinitionen ist verboten"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "in einer for-Bereichs-Deklaration dürfen keine Typen definiert werden"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "Initialisierung in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "mehrere Deklarationen in bereichsbasierter %<for%>-Schleife"
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "Dekompositionsdeklaration ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, gcc-internal-format
 msgid "empty decomposition declaration"
 msgstr "Leere Dekompositions-Deklaration"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
 #, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr "ungültige Initialisierung für strukturierte Bindungsdeklaration"
+
+#: cp/parser.c:13220
+#, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> außerhalb einer Klasse verwendet"
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "Bedeutung von %<auto%> ändert in C++11 die Bedeutung; Bitte entfernen"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-Spezifizierung in Bedingung ungültig"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "%qD ungültig in Lambda"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "Klassendefinition darf nicht als »friend« deklariert sein"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "Templates dürfen nicht %<virtual%> sein"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "ungültige Bindungsspezifikation"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "static_assert ohne Text ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "Typen dürfen nicht in %<decltype%>-Ausdrücken definiert werden"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "Typen dürfen nicht in einem »conversion-type-id« definiert werden"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "ungültige Verwendung von %<auto%> in Umwandlungsoperator"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "Verwendung von %<auto%> in Umwandlungsoperator von Elementtemplate kann niemals hergeleitet werden"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "nur Konstruktoren nehmen Elementinitialisierungen"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "Initialisierung für Element %<%D%> kann nicht aufgelöst werden"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "Speicherinitialisierung für %qD folgt Konstruktordelegation"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "Konstruktordelegation folgt Speicherinitialisierung für %qD"
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "veraltete Basisklasseninitialisierung"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> in diesem Kontext nicht erlaubt (eine qualifizierte Elementinitialisierung ist implizit ein Typ)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "unerwartetes Schlüsselwort; entfernen Sie Leerzeichen zwischen Anführungszeichen und Suffixbezeichner"
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "Suffixbezeichner erwartet"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "hinter Schlüsselwort %<operator%> wird leere Zeichenkette erwartet"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "ungültiges Encoding-Präfix in Literal-Operator"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "Operator erwartet"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Schlüsselwort %<export%> nicht implementiert, und wird ignoriert"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "ungültiger beschränkter Typparameter"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "cv-qualifizierter Typparameter"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "variadische Einschränkung ohne %<...%> eingeführt"
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "ungültige Verwendung von %<auto%> in Default-Templateargument"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Templateparameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "Template-Parameterpacks können keine Standardargumente haben"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "Template-ID erwartet"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> kann keine Templateargumentliste einleiten"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> ist eine andere Schreibweise für %<[%>. Leerraum zwischen %<<%> und %<::%> einfügen"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(bei Verwendung von %<-fpermissive%>, %<-std=c++11%> oder %<-std=gnu++11%> wird G++ den Code akzeptieren)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "Syntaxfehler in Templateargumentliste"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "Templatename erwartet"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "Nicht-Template %qD als Template verwendet"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "%<%T::template %D%> verwenden, um dies als Template zu kennzeichnen"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "Parameterbündel vor %<...%> erwartet"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "Templateargument erwartet"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "ungültiges Templateargument ohne Typ"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "explizite Instanziierung darf kein %<inline%> verwenden"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "explizite Instanziierung darf kein %<constexpr%> verwenden"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "Templatespezialisierung mit C-Bindung angegeben"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Typspezifizierer erwartet"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "Verwendung von %<auto%> in Lambda-Parameterdeklaration benötigt -std=c++14 oder -std=gnu++14"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "Verwendung von %<auto%> in Parameterdeklaration benötigt -std=c++14 oder -std=gnu++14"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO-C++ verbietet Verwendung von %<auto%> in Parameterdeklaration"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "Template-ID für Typ erwartet"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "Typ-Name erwartet"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "ausführliche Typ-Spezifikation für einen enum mit Gültigkeitsbereich darf nicht das Schlüsselwort %<%D%> verwenden"
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "Deklaration %qD deklariert nichts"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "Attribute an instanziiertem Typen ignoriert"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "Attribute an Templateinstanziierung ignoriert"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "Attribute an Spezifizierer ausführlichen Typs ignoriert, der keine Vorwärtsdeklaration ist"
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ist ein Aufzählungstemplate"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD benennt keinen Aufzählungstyp in %qT"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "unbenanntes »enum« mit Gültigkeitsbereich ist nicht erlaubt"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> oder %<{%> erwartet"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aufzählungsliste kann nicht zu Template-Instanziierung hinzugefügt werden"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "geschachtelter Namensgeber %qT für enum-Deklaration benennt weder Klasse noch Namensraum"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in Namensraum %qD, der nicht %qD einschließt"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "Deklaration von %qD in %qD, das nicht %qD einschließt"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "zusätzliche Qualifizierung nicht erlaubt"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "mehrfache Definition von %q#T"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO-C++ verbietet leere unbenannte Aufzählung"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "intransparente Enum-Spezifikation ohne Namen"
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "intransparente Enum-Spezifikation muss einfachen Bezeichner verwenden"
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ist kein Namensbereichs-Name"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "Namensraumname erwartet"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr "eine verschachtelte Namensraum-Definition darf keine Attribute haben"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "verschachtelte Namensraumdefinitionen sind nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr "eine verschachtelte Namensraumdefinition darf nicht inline sein"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, gcc-internal-format
 msgid "nested identifier required"
 msgstr "verschachtelter Bezeichner benötigt"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "Namensbereich %qD betreten"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-Definition ist hier nicht erlaubt"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "Pack-Expansion in using-Deklaration ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "eine Template-ID darf nicht in »using«-Deklaration auftreten"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "kommagetrennte Liste in using-Deklaration ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "Zugriffsdeklarationen sind zugunsten von %<using%>-Deklarationen veraltet; Vorschlag: %<using%> hinzufügen"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "Typen dürfen nicht in Alias-Templatedeklarationen definiert werden"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "%<asm%> in %<constexpr%>-Funktion"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "eine Funktionsdefinition ist hier nicht erlaubt"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "asm-Spezifikation ist bei Funktionsdefinition nicht erlaubt"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "bei einer Funktionsdefinition sind keine Attribute erlaubt"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "Konstruktor, Destruktor oder Typumwandlung erwartet"
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "Initialisierung erwartet"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Initialisierung für Funktion bereitgestellt"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "Attribute hinter geklammerter Initialisierung werden ignoriert"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Nicht-Funktion %qD als implizites Template deklariert"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "Arraygrenze ist keine Ganzzahlkonstante"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "Element des abhängigen Typedef %qT kann nicht definiert werden"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ist kein Typ"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "ungültige Verwendung des Konstruktors als Template"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "%<%T::%D%> statt %<%T::%D%> verwenden, um den Konstruktor mit qualifiziertem Namen zu benennen"
@@ -43296,7 +43354,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "ungültiger Deklarator"
@@ -43303,337 +43361,337 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "qualified-id in Deklaration"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "Deklarator erwartet"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD ist ein Namensbereich"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "Zeiger auf Element der Nicht-Klasse %q#T kann nicht erzeugt werden"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Ptr-Operator erwartet"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "doppelter CV-Qualifizierer"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "mehrere ref-qualifier"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr "%E benötigt %<-fgnu-tm%>"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "doppelter Virt-Spezifizierer"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "fehlende Templateargumente nach %qT"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "ungültige Verwendung von %qT"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "in Template-Argumenten dürfen keine Typen definiert werden"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "ungültige Verwendung von %<auto%> in Templateargument"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Typspezifikation erwartet"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> oder %<...%> erwartet"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "Typen dürfen nicht in Parametertypen definiert werden"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "Standardargumente sind nur für Funktionsparameter zugelassen"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Parameterpack %qD kann kein Standardargument haben"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "Templateparameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Parameterpack kann kein Standardargument haben"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO-C++ erlaubt keine benannten Initialisierungen von C99"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "Klassenname erwartet"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%<;%> hinter Klassendefinition erwartet"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%<;%> hinter Strukturdefinition erwartet"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%<;%> hinter Uniondefinition erwartet"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> oder %<:%> erwartet"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "für eine Klasse kann kein %<override%> angegeben werden"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "globale Qualifizierung von Klassenname ist ungültig"
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "qualifizierter Name benennt keine Klasse"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "ungültiger Klassenname in Deklaration von %qD"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "einer expliziten Spezialisierung muss %<template <>%> vorausgehen"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Funktions-Template %qD als Klassentemplate redeklariert"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "Typnamen-Typ kann nicht aufgelöst werden"
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "vorherige Definition von %q#T"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr "Klassenschlüssel erwartet"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr "ISO-C++ verbietet Typname-Schlüssel in Template-Template-Parameter; verwenden Sie -std=c++1z oder -std=gnu++1z"
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%> oder %<typename%> erwartet"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "in C++03 muss bei Deklaration eines »friend« ein Klassenschlüssel verwendet werden"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "»friend«-Deklaration benennt keine Klasse oder Funktion"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr "Speicherklasse an anonymem Aggregat im Klassenbereich ist nicht erlaubt"
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "reiner Spezifizierer bei Funktionsdefinition"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "überflüssiges %<,%> am Ende der Elementdeklaration"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "%<;%> am Ende von Elementdeklaration erwartet"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "ungültige reine Spezifikation (nur %<= 0%> ist erlaubt)"
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "eine geschweift geklammerte Initialisierung ist hier nicht erlaubt"
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> mehr als einmal in Basisspezifikation angegeben"
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr "mehr als ein Zugriff in Basisspezifikation angegeben"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "Schlüsselwort %<typename%> nicht außerhalb von Templates erlaubt"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "Schlüsselwort %<typename%> nicht erlaubt in diesem Kontext (die Basisklasse ist implizit ein Typ)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "Typen dürfen nicht in einer Ausnahmespezifikation definiert werden"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "ISO C++1z erlaubt keine dynamischen Ausnahmespezifikationen"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "dynamische Ausnahmespezifikationen sind in C++11 veraltet"
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "ungültige Verwendung von %<auto%> in Ausnahmespezifikation"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "%<try%> in %<constexpr%>-Funktion"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "Typen dürfen nicht in Ausnahmedeklarationen definiert werden"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "Attribut, das Präfix verwendet, wird zusammen mit Gültigkeitsbereich-Attribut-Token verwendet"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "Bezeichner für den Attributnamen erwartet"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "Attribut %<noreturn%> darf höchstens einmal in einer Attributliste auftreten"
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "Attribut %<deprecated%> darf höchstens einmal in einer Attributliste auftreten"
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Attribut vor %<...%> erwartet"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "Attribut mit Präfix ist nur mit -std=c++1z oder -std=gnu++1z verfügbar"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<requires%> ist nur mit -fconcepts verfügbar"
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "ein requires-Ausdruck darf nicht außerhalb eines Templates auftreten"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "spezialisierendes Element %<%T::%E%> erfordert Syntax %<template<>%>"
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "ungültige Deklaration von %<%T::%E%>"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "zu wenige Templateparameterlisten"
@@ -43642,488 +43700,488 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "zu viele Templateparameterlisten"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "benannte Rückgabewerte werden nicht mehr unterstützt"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "Literales Operatortemplate %qD hat ungültige Parameterliste. Nicht-Typ Templateargumentpack <char…> oder <typename CharT, CharT…> erwartet"
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "Literales Operatortemplate %qD hat ungültige Parameterliste. Template für Nicht-Typ Argumentpack <char...> erwartet"
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "leere introduction-list"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "kein passendes Konzept für template-introduction"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "ungültige Deklaration eines Elementtemplates in lokaler Klasse"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "Template mit C-Bindung"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "ungültige explizite Spezialisierung"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "Templatedeklaration von %<typedef%>"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr "eine Klassen-Templatedeklaration darf nichts anderes deklarieren"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "explizite Template-Spezialisierung kann keine Speicherklasse haben"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%> sollte innerhalb einer geschachtelten Templateargumentliste %<> >%> sein"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "falsches %<>>%>; %<>%> verwenden, um eine Templateargumentliste zu beenden"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr "Argument von %<sizeof...%> muss mit Klammern umschlossen werden"
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "ungültige Verwendung von %qD in Spezifizierung der Bindung"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> vor %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO-C++ 1998 unterstützt nicht %<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sowohl %<__thread%> als auch %<thread_local%> angegeben"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "doppeltes %qD"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "doppeltes %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> erwartet"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> erwartet"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> erwartet"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> erwartet"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> erwartet"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> erwartet"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> erwartet"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> erwartet"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> erwartet"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> erwartet"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> erwartet"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> erwartet"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> erwartet"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> erwartet"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> erwartet"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> erwartet"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> erwartet"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> erwartet"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> erwartet"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<__transaction_atomic%> erwartet"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<__transaction_relaxed%> erwartet"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> erwartet"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> erwartet"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> erwartet"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> erwartet"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> oder %<::%> erwartet"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>, %<typename%> oder %<template%> erwartet"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Markierung %qs bei Benennung von %q#T verwendet"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T wurde vorher hier deklariert"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD mit anderem Zugriff redeklariert"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "in C++98 ist %<template%> (zum eindeutig machen) nur innerhalb von Templates erlaubt"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "Datei endet in Standardargument"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "unpassendes Objective-C++-Konstrukt %<@%D%>"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "Objective-C++-Nachrichtenempfänger erwartet"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "Objective-C++ Nachrichtenargument(e) erwartet"
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> muss als Argument einen Typen angeben"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "Ungültiger Objective-C++-Selektorname"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Objective-C++ Methodendeklaration erwartet"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "Methodenattribute müssen am Ende angegeben werden"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "überflüssiges %qs zwischen Objective-C++ Methoden"
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "ungültiger Typ für Instanzvariable"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Bezeichner nach %<@protocol%> erwartet"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "Attribute dürfen nicht vor dem Objective-C++-Schlüsselwort %<@%D%> angegeben werden"
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "Präfix-Attribute vor %<@%D%> werden ignoriert"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr "ungültiger Typ für Eigenschaft"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "%<wait%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "ungültiger reduction-identifier"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "geklammerte Initialisierung ist in OpenMP-%<for%>-Schleife nicht erlaubt"
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "geklammerte Initialisierung ist in for-Schleife nicht erlaubt"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr "%<_Cilk_for%> erlaubt nur in C einen Ausdruck statt einer Deklaration, nicht jedoch in C++"
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "Schleifenvariable %qD sollte keine Reduktion sein"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "zu wenige for-Schleifen um sie einzuklappen"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "Vektorattribut nicht direkt gefolgt von einer einzelnen Funktionsdeklaration oder -definition"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "ungültige Initialisierungsklausel"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "»id-expression (arguments)« erwartet"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr "eins der Aufrufargumente für die Initialisierung sollte %<omp_priv%> oder %<&omp_priv%> sein"
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "neue Typen dürfen nicht in einem Rückgabetyp definiert werden"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr "vordeklarierter arithmetischer Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr "Funktions- oder Arraytyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr "Referenztyp %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr "const-, volatile- oder __restrict-qualifizierter Typ %qT in %<#pragma omp declare reduction%>"
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr "%<#pragma acc routine%> benennt eine Menge von Überladungen"
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "%qD bezeichnet keine Funktion innerhalb eines Namensraum"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "atomic_cancel"
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%> ohne eingeschaltete Unterstützung für transaktionsgebundenen Speicher"
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "Ausschuss am Ende von %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "ungültige Korngröße für _Cilk_for"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "%<#pragma GCC ivdep%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "%<#pragma simd%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "%<#pragma cilk grainsize%> muss innerhalb einer Funktion sein"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr "-fcilkplus muss eingeschaltet sein, um %<#pragma cilk grainsize%> zu verwenden"
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Optimierungen zwischen Modulen noch nicht implementiert für C++"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, gcc-internal-format
 msgid "expected variable-name"
 msgstr "»variable-name« erwartet"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "%<,%> oder %<)%> nach %qE erwartet"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "Implizite Templates dürfen nicht %<virtual%> sein"
@@ -44215,7 +44273,7 @@
 msgid "candidate is: %#D"
 msgstr "Kandidat ist: %#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %#D"
@@ -44791,122 +44849,137 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE ist kein gültiges Templateargument des Typs %qT, weil %qD keine externe Bindung hat"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil %qD keine Bindung hat"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
 #, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr "die Adresse von %qD ist kein gültiges Templateargument"
+
+#: cp/pt.c:6634
+#, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "die Adresse des %qT-Teilobjekts von %qD ist kein gültiges Templateargument"
+
+#: cp/pt.c:6641
+#, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "die Adresse von %qD ist kein gültiges Templateargument, weil sie keine statische Lebensdauer hat"
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, da es in CV-Qualifikation in Konflikt steht"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein L-Wert ist"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D ist kein gültiges Templateargument für Typ %qT, weil eine Referenzvariable keine konstante Adresse hat"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es kein Objekt mit Bindung ist"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil Objekt %qD keine Bindung hat"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es ein Zeiger ist"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "stattdessen %qE verwenden"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ist kein gültiges Templateargument für Typ %qT, weil es vom Typ %qT ist"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "Standardumwandlungen sind in diesem Kontext nicht erlaubt"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "Attribute an Templateargument %qT werden ignoriert"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "Attribute an Templateargument %qE werden ignoriert"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "eingegebener Klassenname %qD als Template-Templateargument verwendet"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "ungültige Verwendung des Destruktors %qE als Typ"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "um auf ein Typelement eines Templateparameters zu verweisen, %<typename %E%> verwenden"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "Typ/Wert des Arguments %d passt nicht in Template-Parameterliste für %qD"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  Konstante des Typs %qT erwartet, %qT erhalten"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  Klassentemplate erwartet, %qE erhalten"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  einen Typ erwartet, %qE erhalten"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  einen Typ erwartet, %qT erhalten"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  Klassentemplate erwartet, %qT erhalten"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  ein Template des Typs %qD erwartet, %qT erhalten"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "unpassende Beschränkungen für Argument %d in Template-Parameterliste für %qD"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "  %qD erwartet, %qD erhalten"
@@ -44913,102 +44986,102 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "Typ passt nicht in Nichttypen-Parameterbündel"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "Templateargument %qE konnte nicht von %qT in %qT umgewandelt werden"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "Templateargument %d ist ungültig"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte %d sein)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "falsche Anzahl der Templateargumente (%d, sollte mindestens %d sein)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr "für %qD bereitgestellt"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Alias-Template %qD"
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "gepacktes Expansionsargument für Parameter %qD ohne »pack« von Konzept %qD"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr "jegliche Instanziierung mit nichtleerer Parameterpackung wäre unzulässig"
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "für %q+D bereitgestellt"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D ist kein Funktionstemplate"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "Nicht-Template-Typ %qT als Template verwendet"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "Für Template-Deklaration %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, gcc-internal-format
 msgid "template constraint failure"
 msgstr "Template-Einschränkung fehlgeschlagen"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Verwendung des ungültigen Variablentemplates %qE"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (-ftemplate-depth= verwenden, um dies zu erhöhen)"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr "Falten einer leeren Expansion über %O"
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "Argumentpacklängen passen nicht bei Auflösung von %<%T%>"
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "Argumentpacklängen passen nicht bei Auflösung von %<%E%>"
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "  bei Instanziierung des Standardarguments für Aufruf von %D"
@@ -45026,271 +45099,271 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "Variable %qD hat Funktionstyp"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "ungültiger Parametertyp %qT"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "in Deklaration %q+D"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "Funktion gibt ein Array zurück"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "Funktion gibt eine Funktion"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "Erzeugung eines Zeigers auf Elementfunktion des Nicht-Klassentyps %qT"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "Referenz auf »void« wird gebildet"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "Zeiger auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "Referenz auf Referenztyp %qT wird geformt"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "Zeiger auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "Referenz auf qualifizierten Funktionstypen %qT wird geformt"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "Zeiger auf Element des Nicht-Klassentypen %qT wird erzeugt"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "Zeiger auf Elementreferenztyp %qT wird erzeugt"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "Zeiger auf Element mit Typ »void« wird erzeugt"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "Array von %qT wird erzeugt"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ist kein Klassen-, Struktur- oder Union-Typ"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT wird in %qT aufgelöst, was kein Aufzählungstyp ist"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT wird in %qT aufgelöst, was kein Klassentyp ist"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "leere Initialisierung in »init-capture« für Lambda"
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "Verwendung von %qs in Template"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "qualifizierender Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "Abhängigenname %qE wird als Nicht-Typ erkannt, aber die Instanziierung liefert einen Typ"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "%<typename %E%> sagen, wenn ein Typ gemeint ist"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "ungültiges Feld %qD wird verwendet"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "falsche Verwendung eines Packauflösungs-Ausdruckes"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "%<...%> verwenden, um Argumentpack aufzulösen"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD wurde in diesem Gültigkeitsbereich nicht deklariert, und bei argumentabhängiger Suche am Ort der Instanziierung wurden keine Deklarationen gefunden"
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "Deklarationen in abhängiger Basis %qT wurden bei unqualifizierter Suche nicht gefunden"
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "stattdessen %<this->%D%> verwenden"
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "stattdessen %<%T::%D%> verwenden"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qD hier deklariert, später in der Übersetzungseinheit"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ist keine Klasse oder Namensbereich"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "%qT ist/verwendet anonymen Typen"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Templateargument für %qD verwendet lokalen Typ %qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT ist ein variabel modifizierter Typ"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "Ganzzahlausdruck %qE ist nicht konstant"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  Versuch, %qD zu instanziieren"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "mehrdeutige Template-Instanziierung für %q#T"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "mehrdeutige Template-Instanziierung für %q#D"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 msgid "%s %#S"
 msgstr "%s %#S"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "explizite Instanziierung des Nicht-Templates %q#D"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD ist kein statisches Datenelement eines Klassentemplates"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "kein passendes Template für %qD gefunden"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "Typ %qT für explizite Instanziierung %qD passt nicht zum deklarierten Typ %qT"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "explizite Instanziierung von %q#D"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "doppelte explizite Instanziierung von %q#D"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO-C++ 1998 verbietet die Verwendung von %<extern%> bei expliziten Instanziierungen"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "Speicherklasse %qD auf Templateinstanziierung angewendet"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "explizite Instanziierung des Nicht-Klassen-Templates %qD"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "explizite Instanziierung des Nicht-Templatetyps %qT"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "explizite Instanziierung von %q#T vor Definition des Templates"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO-C++ verbietet die Verwendung von %qE bei expliziten Instanziierungen"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "doppelte explizite Instanziierung von %q#T"
@@ -45302,92 +45375,92 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "explizite Instanziierung von %qD, aber keine Definition verfügbar"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "Instanziierungstiefe für Templates überschreitet Höchstwert %d (-ftemplate-depth= verwenden, um dies zu erhöhen) bei Instanziierung von %q+D, möglicherweise von Erzeugung der virtuellen Tabelle"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "ungültiger Nicht-Typ-Parameter für Template"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T ist kein gültiger Typ für einen Nicht-Typ-Parameter eines Templates"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "Ermittlung aus geschweift geklammerter Initialisierungsliste erfordert #include <initializer_list>"
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "Nicht-Klassen-Template %qT ohne Template-Argumente verwendet"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr "Templateargumente für die Kopierinitialisierung von %qT können nicht abgeleitet werden, da es keine expliziten Ableitungshinweise oder benutzerdeklarierten Konstruktoren gibt"
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "Argumentherleitung für Klassentemplate gescheitert:"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Explizite Herleitungshinweise werden nicht für »copy-initialization« berücksichtigt"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr "direct-list-initialization von %<auto%> erfordert genau ein Element"
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr "um %<std::initializer_list%> herzuleiten, verwenden Sie einen copy-list-initialization (also mit %<=%> vor dem %<{%>)"
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr "%qT als Typ statt als einfaches %<decltype(auto)%>"
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "Lambda-Rückgabewert von %qE kann nicht hergeleitet werden"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qT kann nicht aus %qE hergeleitet werden"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr "Platzhalter-Beschränkungen nicht erfüllt"
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "hergeleiteter Initialisierer erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Rückgabetyp erfüllt die Platzhalter-Beschränkungen nicht"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr "hergeleiteter Ausdruckstyp erfüllt die Platzhalterbeschränkungen nicht"
@@ -45544,466 +45617,466 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  denn %q+#D ist in Basisklasse deklariert"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "es wird empfohlen, explizite geschweifte Klammern um leeren Körper in %<do%>-Anweisung zu setzen"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "Typ des asm-Operanden %qE konnte nicht ermittelt werden"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "__label__-Deklarationen sind nur im Funktionsgültigkeitsbereich erlaubt"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "ungültige Verwendung des Elementes %qD in statischer Elementfunktion"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "Argumente für Destruktor sind nicht erlaubt"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> ist für statische Elementfunktionen nicht verfügbar"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "ungültige Verwendung von %<this%> in Nicht-Element-Funktion"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "ungültige Verwendung von %<this%> auf höchster Ebene"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "ungültiger angegebener Gültigkeitsbereich in Pseudodestruktor-Name"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "qualifizierter Typ %qT passt nicht zum Destruktornamen ~%qT"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE ist nicht vom Typ %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "zusammengesetztes Literal vom Nicht-Objekt-Typ %qT"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "Templatetypparameter müssen das Schlüsselwort %<class%> oder %<typename%> verwenden"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "ungültige Verwendung des Typs %qT als Standardwert für einen Template-Templateparameter"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "ungültiges Standardargument für einen Template-Templateparameter"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "Definition von %q#T in Templateparameterliste"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "ungültige Definition des qualifizierten Typen %qT"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "ungültige Spezifizierung der Basisklasse"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "Element %qD von unbenannter Union kann nicht eingefangen werden"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD ist nicht eingefangen"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "das Lambda hat keinen »capture-default«"
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr "Lambda in lokaler Klasse %q+T kann Variablen aus dem umschließenden Kontext nicht einfangen"
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "Verwendung lokaler Variable mit automatischer Speicherklasse aus enthaltender Funktion"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "Verwendung eines Parameters aus enthaltender Funktion"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "Verwendung eines Parameters außerhalb des Funktionskörpers"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, gcc-internal-format
 msgid "missing template arguments"
 msgstr "fehlende Templateargumente"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "Templateparameter %qD vom Typ %qT ist in ganzzahligem Konstantenausdruck nicht erlaubt, da er nicht Ganzzahl- oder Aufzählungstyp hat"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "Verwendung des Namensbereiches %qD als Ausdruck"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Verwendung des Klassentemplates %qT als Ausdruck"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "Abfrage des Elementes %qD ist im Gitter der Mehrfachvererbung mehrdeutig"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD kann nicht in Konstanten-Ausdruck auftreten"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "Typ von %qE ist unbekannt"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT ist kein Aufzählungstyp"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "Parameterpack __bases nur in Templatedeklaration gültig"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "%<offsetof%> kann nicht auf Destruktor %<~%T%> angewandt werden"
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr "zweiter Operand von %<offsetof%> ist weder ein einzelner Bezeichner noch eine Folge von Elementzugriffen und Arrayreferenzen"
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "%<offsetof%> kann nicht auf Elementfunktion %qD angewandt werden"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr "offsetof innerhalb von »non-standard-layout«-Typ %qT ist undefiniert"
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr "%<this%> ist in OpenMP nur innerhalb von %<declare simd%>-Klauseln erlaubt"
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "benutzerdefinierte Reduktionsauflösung ist mehrdeutig"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "%qE in %<reduction%>-Klausel ist ein Array der Länge 0"
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE hat konstanten Typ für %<reduction%>"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr "benutzerdefinierte Reduktion mit Konstruktorinitialisierung für Basisklasse %qT"
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr "»linear«-Klausel mit Modifizierer %qs wird auf Nicht-Referenz-Variable mit Typ %qT angewandt"
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr "»linear«-Klausel wird auf Variable vom Typ %qT angewandt, die weder ganzzahlig noch Gleitkomma noch Zeiger ist"
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr "»linear«-Klausel wird auf Variable vom Typ %qT angewandt, die weder ganzzahlig noch Zeiger ist"
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "Ausdruck für »linear«-Schrittweite muss ganzzahlig sein"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD ist in Klausel %qs keine Variable"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD ist in Klausel %<firstprivate%> keine Variable"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD ist in Klausel %<lastprivate%> keine Variable"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "statischer %<gang%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "statischer %<gang%>-Ausdruck muss positiv sein"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "Ausdruck für %<gang%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "Ausdruck für %<vector%>-Länge muss ganzzahlig sein"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "Ausdruck für %<worker%>-Nummer muss ganzzahlig sein"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "%qs-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "Wert von %<gang%> muss positiv sein"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "Wert der %<vector%>-Länge muss positiv sein"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "Wert der %<worker%>-Nummer muss positiv sein"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "Plan-Teilgrößenausdruck muss bestimmt sein"
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig sein"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Ausdruck für %qs-Länge muss ganzzahlig, positiv und konstant sein"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "%<async%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "%<thread_limit%>-Ausdruck muss ganzzahlig sein"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "%<device%>-ID muss ganzzahlig sein"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "Ausdruck für %<dist_schedule%>-Chunkgröße muss ganzzahlig sein"
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD ist in %<aligned%>-Klausel keine Variable"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr "%qE in %<aligned%>-Klausel ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD tritt in %<aligned%>-Klausel mehrfach auf"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "Ausdruck für Ausrichtung der %<aligned%>-Klausel muss ganzzahlig sein"
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD ist in %<depend%>-Klausel keine Variable"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr "überladener Funktionsname %qE in Klausel %qs"
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "Template %qE in Klausel %qs"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "Ausdruck für %<grainsize%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "Ausdruck für %<priority%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "Ausdruck für %<num_tasks%> muss ganzzahlig sein"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "Variable %qs ist weder Zeiger noch Array noch Referenz auf Zeiger oder Array"
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "Argument für %<tile%> erfordert ganzzahligen Typ"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD ist weder Datei-, Namens- noch Blockbereichsvariable"
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> Direktive %qE nicht in Definition von %qT"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "Unterschied zwischen %qE und %qD hat keinen Ganzzahltyp"
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<#pragma omp simd%> zusammen mit Iterationsvariable %qE verwendet"
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<#pragma omp atomic update%> verwendet zwei unterschiedliche Ausdrücke für Speicher"
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr "statische Behauptung gescheitert"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "statische Erklärung gescheitert: %s"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "Nicht-konstante Bedingung für statische Behauptung"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "Argument für decltype muss ein Ausdruck sein"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype kann die Adresse der überladenen Funktion nicht auflösen"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "Operand des Faltungsausdrucks hat keine unexpandierten Parameterpackungen"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "beide Argumente in binärer Faltung haben unexpandierte Parameterpackungen"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr "keine unexpandierten Parameterpackungen in binärer Faltung"
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Argument, das kein Zeiger ist, in %<__builtin_launder%>"
@@ -46018,107 +46091,107 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Lambda-Ausdruck in konstantem Ausdruck"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "Attribut %qE auf %qD mit Rückgabetyp »void« angewendet"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "Attribut %qE kann nur auf Funktionen oder auf Klasse- oder Aufzählungstypen angewendet werden"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "angeforderte »init_priority« muss ganzzahlig und konstant sein"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "nur Attribut %qE kann für Definitionen von Objekten eines Klassentyps im Datei-Gültigkeitsbereich verwendet werden"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "angefordertes init_priority ist außerhalb des Wertebereiches"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "angefordertes init_priority ist für interne Verwendung reserviert"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "Attribut %qE wird auf dieser Plattform nicht unterstützt"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "Redeklaration von %qD fügt ABI-Marke %E hinzu"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "Attribut %qE erfordert Argumente"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Argumente für Attribut %qE müssen enge Zeichenkettenliterale sein"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Argumente für Attribut %qE müssen gültige Bezeichner enthalten"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%c%> ist kein gültiges Anfangszeichen für einen Bezeichner"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%c%> ist kein gültiges Zeichen in einem Bezeichner"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "Attribut %qE auf Nicht-Klassen-, Nicht-Enum-Typ %qT angewendet"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "Attribut %qE auf %qT nach seiner Definition angewendet"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "%qE-Attribut wird für Templateinstanziierung %qT ignoriert"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "%qE-Attribut wird für Templatespezialisierung %qT ignoriert"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE-Attribut wird auf %qD angewendet, das weder Funktion noch Variable ist"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "Attribut %qE wird auf »extern \"C\"«-Deklaration %qD angewendet"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "Null als Nullzeigerkonstante"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check: failed in %s, at %s:%d"
@@ -46801,102 +46874,102 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "ungültige Umwandlung in Typ %qT von Typ %qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "%qT kann nicht nach %qT für Argument %qP nach %qD umgewandelt werden"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "%qT kann nicht nach %qT im Standardargument umgewandelt werden"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "%qT kann nicht nach %qT bei Argumentübergabe umgewandelt werden"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "%qT kann nicht nach %qT umgewandelt werden"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "%qT kann nicht nach %qT in Initialisierung umgewandelt werden"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "%qT kann nicht nach %qT in Rückgabe umgewandelt werden"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "%qT kann nicht nach %qT in Zuweisung umgewandelt werden"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "Klassentyp %qT ist unvollständig"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "Parameter %qP von %qD könnte Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "Parameter könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "Ziel der Umwandlung könnte Kandidat ein für ein Formatattribut sein"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "Ziel der Initialisierung könnte ein Kandidat für Formatattribut sein"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "linke Seite der Zuweisung könnte ein Kandidat für ein Formatattribut sein"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "bei Übergabe des Arguments %P von %qD"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "Referenz auf temporären Wert wird zurückgegeben"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "Referenz auf Nicht-L-Wert zurückgegeben"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "Referenz auf lokale Variable %qD zurückgegeben"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "Adresse der lokalen Variable %qD zurückgegeben"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "Wert von Destruktor zurückgegeben"
@@ -46903,55 +46976,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "vom Behandler eines Funktions-try-Blocks eines Konstruktors kann nicht zurückgekehrt werden"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "Rückgabe eines Wertes von einem Konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "Return-Anweisung ohne Wert, in %qT zurückgebender Funktion"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, gcc-internal-format
 msgid "returning initializer list"
 msgstr "Initialisierungsliste wird zurückgegeben"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "widersprüchliche Typen %qT und %qT für Lambda-Rückgabetypen hergeleitet"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "widersprüchliche Herleitung für automatischen Rückgabetyp: %qT und dann %qT"
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "Return-Anweisung mit Wert in »void« zurückgebender Funktion"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> darf nicht NULL zurückgeben, außer es ist mit %<throw()%> deklariert (oder -fcheck-new ist eingeschaltet)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "temporärer Wert wird als L-Wert verwendet"
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "X-Wert (R-Wert-Referenz) wird als L-Wert verwendet"
@@ -50948,87 +51021,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "Ziel der Zeigerinitialisierung für Prozedur bei %L darf kein Prozedurzeiger sein"
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008: Zeigerfunktionen in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Nicht-variabler Ausdruck in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "Benannte Konstante %qs in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%qs in Variablen-Definitionskontext (%s) bei %L ist keine Variable"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Nicht-POINTER in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "Typ nicht zugreifbar in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_EVENT in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "Scheinargument %qs mit INTENT(IN) in Zeiger-Verbindungskontext (%s) bei %L"
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "Scheinargument %qs mit INTENT(IN) in Variablen-Definitionskontext (%s) bei %L"
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Variable %qs ist PROTECTED und kann nicht in Zeiger-Verbindungskontext (%s) bei %L auftreten"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "Variable %qs ist PROTECTED und kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten"
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variable %qs kann nicht in Variablen-Definitionskontext (%s) bei %L in PURE-Prozedur auftreten"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "%qs ist bei %L mit vektorindiziertem Ziel verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "%qs ist bei %L mit Ausdruck verbunden und kann nicht in Variablen-Definitionskontext (%s) verwendet werden"
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Verbundener Name %qs kann nicht in Variablen-Definitionskontext (%s) bei %L auftreten, da sein Ziel bei %L es auch nicht kann"
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "Elemente mit demselben Wert bei %L und %L in Vektorindex in einem Variablen-Definitionskontext (%s)"
@@ -51215,12 +51288,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Zweites Argument der definierten Zuweisung bei %L muss INTENT(IN)"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L muss INTENT(IN) sein"
@@ -52006,509 +52079,524 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "Fortran 2003: DT-Format-Spezifizierer bei %C nicht erlaubt"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr "X-Deskriptor erfordert führenden Leerzeichenzähler bei %L"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr "$-Deskriptor bei %L"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ sollte das letzte Spezifikationssymbol in Format bei %L sein"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Erweiterung: Nullbreite hinter L-Deskriptor bei %L"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Positive Breite hinter L-Deskriptor bei %L fehlt"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "%<G0%> in Format bei %L"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr "Positive Breite in Formatspezifizierung %s bei %L erforderlich"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "Formatspezifikation %s bei %L erfordert Punkt"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "Formatspezifikation bei %L erfordert Punkt"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr "Das Formatspezifikationssymbol H bei %L ist eine in Fortran 95 entfernte Besonderheit"
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "Fehlendes Komma bei %L"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s in Formatzeichenkette bei %L"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr "Überschüssige Zeichen im Format bei %L"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr "Formatanweisung im Hauptblock des Modules bei %C"
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "FORMAT-Anweisung bei %C kann nicht innerhalb von INTERFACE auftreten"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Fehlende Format-Marke bei %C"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr "IOMSG bei %L muss eine skalare Standardzeichenvariable sein"
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr "%s bei %L erfordert eine scalar-default-char-expr"
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "Ungültiger Wert für Spezifikation %s bei %C"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "Doppelte Spezifikation %s bei %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "Variable %s kann nicht INTENT(IN) bei %C sein"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "Variable %s kann nicht in PURE-Prozedur bei %C zugewiesen werden"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "Doppelte Markenspezifikation %s bei %C"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr "%s bei %C ist eine DEC-Erweiterung; übersetzen Sie erneut mit -fdec, um diese einzuschalten"
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "Konstanter Ausdruck in FORMAT-Markierung bei %L muss vom Standard-CHARACTER-Typ sein"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "FORMAT-Markierung bei %L muss vom Typ Standard-CHARACTER oder INTEGER sein"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "ASSIGNED-Variable in FORMAT-Markierung bei %L"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "Variable %qs bei %L wurde keine Formatmarke zugewiesen"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr "Skalares %qs in FORMAT-Marke bei %L ist keine ASSIGNED-Variable"
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr "Nicht-Zeichen in FORMAT-Markierung bei %L"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "Element eines Feldes mit vermuteter Form aus Nicht-Schriftzeichen in FORMAT-Markierung bei %L"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "Element eines Feldes mit vermuteter Größe aus Nicht-Schriftzeichen in FORMAT-Markierung bei %L"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "Element eines Zeigerfeldes aus Nicht-Schriftzeichen in FORMAT-Markierung bei %L"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "Markierung %s bei %L muss vom Typ %s sein"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "Markierung %s bei %L muss Standard-Zeichenkette sein"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "Markierung %s bei %L muss ein Skalar sein"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr "IOMSG-Markierung bei %L"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Fortran 95 erfordert Standard INTEGER in %s-Marke bei %L"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr "Nicht-Standard-LOGICAL in %s-Marke bei %L"
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr "NEWUNIT-Spezifizierer bei %L"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr "CONVERT-Marke bei %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Fortran 2003: Spezifizierer %s in Anweisung %s bei %C hat Wert %qs"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "Spezifizierer %s in Anweisung %s bei %C hat Wert %qs"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "Erweiterung: Spezifizierer %s in Anweisung %s bei %C hat Wert %qs"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "Spezifizierer %s in Anweisung %s bei %C hat ungültigen Wert %qs"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "OPEN-Anweisung in PURE-Prozedur bei %C nicht erlaubt"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr "UNIT-Spezifizierer mit NEWUNIT bei %C nicht erlaubt"
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr "NEWUNIT-Spezifizierer muss FILE= oder STATUS='scratch' bei %C haben"
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "OPEN-Anweisung bei %C muss UNIT oder NEWUNIT haben"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr "ACTION-Typ bei %C steht in Konflikt mit READONLY-Spezifizierer"
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "ASYNCHRONOUS= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "BLANK= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "DECIMAL= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "ENCODING= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "ROUND= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "SIGN= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "CLOSE-Anweisung in PURE-Prozedur bei %C nicht erlaubt"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "CLOSE-Anweisung bei %L erfordert eine UNIT-Zahl"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT-Zahl in CLOSE-Anweisung bei %L muss nicht-negativ sein"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s-Anweisung in PURE-Prozedur bei %C nicht erlaubt"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr "Fehlende UNIT-Zahl in Anweisung bei %L"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "UNIT-Zahl in Anweisung bei %L muss nicht-negativ sein"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "FLUSH-Anweisung bei %C"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr "Fehlendes Format mit Standard-Einheit bei %C"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Doppelte UNIT-Spezifikation bei %C"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Doppelte Format-Spezifikation bei %C"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Symbol %qs in Namensliste %qs ist INTENT(IN) bei %C"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Doppelte NML-Spezifikation bei %C"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Symbol %qs bei %C muss ein NAMELIST-Gruppenname sein"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "END-Tag bei %C in Ausgabe-Anweisung nicht erlaubt"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "bei %L wurde kein UNIT angegeben"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "UNIT-Spezifikation bei %L muss ein INTEGER-Ausdruck oder eine CHARACTER-Variable sein"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Ungültige Form der WRITE-Anweisung bei %L, UNIT erforderlich"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Interne Einheit mit Vektor-Index bei %L"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Externe IO UNIT kann kein Feld bei %L sein"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "NAMELIST %qs in READ-Anweisung bei %L enthält Symbol %qs, das im Kontext zur Variablendefinition nicht auftreten darf"
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L ist polymorph und erfordert eine definierte Ein-/Ausgabeprozedur"
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L mit ALLOCATABLE- oder POINTER-Komponenten"
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L hat ALLOCATABLE- oder POINTER-Komponenten erfordert daher eine definierte Ein-/Ausgabeprozedur"
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "Komma vor Ein-/Ausgabeelementliste bei %L"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR-Marke %d bei %L nicht definiert"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END-Marke %d bei %L nicht definiert"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR-Marke %d bei %L nicht definiert"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT-Marke %d bei %L nicht definiert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr "io_kind_name(): bad I/O-kind"
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Syntaxfehler in E/A-Iterator bei %C"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Variable in READ-Anweisung bei %C erwartet"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Ausdruck in %s-Anweisung bei %C erwartet"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaxfehler in Anweisung %s bei %C"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "Interne Datei bei %L mit Namensliste"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "Spezifikation ASYNCHRONOUS= bei %L muss ein Initialisierungsausdruck sein"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "PAD= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "DELIM= bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "PRINT-Namensliste bei %C ist eine Erweiterung"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Komma in E/A-Liste bei %C erwartet"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT-Anweisung bei %C innerhalb PURE-Prozedur nicht erlaubt"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE-Anweisung in PURE-Prozedur bei %C nicht erlaubt"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH-Markierung in INQUIRE-Anweisung bei %C ungültig"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "INQUIRE-Anweisung bei %L kann nicht sowohl FILE- als auch UNIT-Spezifikationssymbole enthalten"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "INQUIRE-Anweisung bei %L erfordert entweder FILE- oder UNIT-Spezifikationssymbol"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "UNIT-Zahl in INQUIRE-Anweisung bei %L darf nicht %d sein"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "INQUIRE-Anweisung bei %L erfordert PENDING= mit Spezifizierung ID="
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "WAIT bei %C ist in Fortran 95 nicht erlaubt"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "WAIT-Anweisung ist in PURE-Prozedur bei %C nicht erlaubt"
@@ -53413,261 +53501,261 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "Fehlende allgemeine Spezifikation in USE-Anweisung bei %C"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr "Umbenennungsoperatoren in USE-Anweisungen bei %C"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Der Name %qs bei %C wurde bereits als ein externer Modulname verwendet"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "SUBMODULE-Deklaration bei %C"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "SUBMODULE-Deklaration bei %C kann nicht innerhalb eines anderen Gültigkeitsbereichs auftreten"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Syntaxfehler in SUBMODULE-Anweisung bei %C"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "Modul %qs in Zeile %d, Spalte %d wird gelesen: %s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "Modul %qs in Zeile %d, Spalte %d wird geschrieben: %s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr "Modul %qs in Zeile %d, Spalte %d: %s"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr "require_atom(): bad atom type required"
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Fehler beim Schreiben der Moduldatei: %s"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr "write_atom(): Writing negative integer"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr "write_atom(): Trying to write dab atom"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr "unquote_string(): got bad string"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr "mio_array_ref(): Unknown array ref"
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Namensliste %s kann nicht mit USE-Verbindung in %s umbenannt werden"
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Mehrdeutiges !$OMP DECLARE REDUCTION von Modul %s bei %L"
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr "Vorherige !$OMP DECLARE REDUCTION von Modul %s bei %L"
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "Bei %3$C importiertes %1$qs von Modul %2$qs ist auch der Name der aktuellen Programmeinheit"
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Bei %2$L referenziertes Symbol %1$qs nicht im Modul %3$qs gefunden"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Bei %2$L referenzierter Benutzeroperator %1$qs nicht im Modul %3$qs gefunden"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Bei %2$L referenzierter intrinsischer Operator %1$qs nicht im Modul %3$qs gefunden"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr "write_symbol(): bad module symbol %qs"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr "write_symtree(): Symbol not written"
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Moduldatei %qs kann bei %C nicht zum Schreiben geöffnet werden: %s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Fehler beim Schreiben der Moduldatei %qs: %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "Moduldatei %qs kann nicht gelöscht werden: %s"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Moduldatei %qs kann nicht in %qs umbenannt werden: %s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Temporäre Moduldatei %qs kann nicht gelöscht werden: %s"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "Symbol %qs bei %C bereits deklariert"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr "import_iso_c_binding_module(): Unable to create symbol for %s"
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Das bei %2$L referenzierte Symbol %1$qs ist nicht im gewählten Standard vorhanden"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Bei %2$L referenziertes Symbol %1$qs nicht im Modul ISO_C_BINDING gefunden"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "Symbol %qs bereits deklariert"
 
 # https://german.stackexchange.com/questions/35158/deklination-mehrerer-attributiver-adjektive
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Verwendung des intrinsischen Moduls %qs bei %C steht mit nicht-intrinsischem vorher verwendeten Modulnamen in Konflikt"
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Verwendung der Konstante NUMERIC_STORAGE_SIZE aus intrinsischem Modul ISO_FORTRAN_ENV bei %L ist mit Option %qs unverträglich"
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Verwendung der Konstante NUMERIC_STORAGE_SIZE aus intrinsischem Modul ISO_FORTRAN_ENV bei %C ist mit Option %s unverträglich"
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Bei %2$L referenziertes Symbol %1$qs nicht im intrinsischen Modul ISO_FORTRAN_ENV gefunden"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "USE-Anweisung bei %C hat keinen ONLY-Qualifizierer"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Intrinsisches Modul ISO_FORTRAN_ENV bei %C"
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Modul ISO_C_BINDING bei %C"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Intrinsisches Modul %qs bei %C nicht gefunden"
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "IEEE_FEATURES-Modul bei %C"
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "IEEE_EXCEPTIONS-Modul bei %C"
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "IEEE_ARITHMETIC-Modul bei %C"
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Moduldatei %qs kann bei %C nicht zum Lesen geöffnet werden: %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr "Moduldatei %qs wurde nicht generiert, entweder weil das Modul keine MODULE PROCEDURE enthält oder weil es einen Fehler in dem Modul gibt."
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Verwendung des nicht-intrinsischen Moduls %qs bei %C steht mit vorher verwendetem intrinsischen Modulnamen in Konflikt"
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Bei %2$C geöffnete Datei %1$qs ist keine GNU-Fortran-Moduldatei"
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr "Bei %2$C geöffnete Moduldatei %1$qs kann nicht gelesen werden, da sie von einer anderen Version von GNU Fortran erstellt wurde"
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr "Das %sModul, das gerade gebaut wird, kann nicht gleichzeitig mit USE verwendet werden"
@@ -56054,7 +56142,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Spezifische Funktion %qs bei %L kann nicht aufgelöst werden"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "Funktion %qs bei %L hat keinen IMPLICIT-Typ"
@@ -57557,449 +57645,439 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Allgemeiner Name %qs der Funktion %qs bei %L ist der gleiche wie der des abgeleiteten Typs bei %L"
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Feld %qs mit vermuteter Größe in Namensliste %qs bei %L ist nicht erlaubt"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs mit vermuteter Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST-Feldobjekt %qs ohne konstante Form in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs ohne konstante Zeichenlänge in Namensliste %qs bei %L"
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L ist polymorph und erfordert eine definierte Ein-/Ausgabeprozedur"
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "NAMELIST-Objekt %qs in Namensliste %qs bei %L mit ALLOCATABLE- oder POINTER-Komponenten"
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs wurde als PRIVATE deklariert und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat Verwendungs-verbundene PRIVATE-Komponenten und kann kein Element der Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST-Objekt %qs hat PRIVATE-Komponenten und kann kein Element der PUBLIC-Namensliste %qs bei %L sein"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut NAMELIST in %qs bei %L in Konflikt"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameterfeld %qs bei %L kann nicht automatische oder vermutete Form haben"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Implizit angegebener PARAMETER %qs bei %L passt nicht zu früherem IMPLICIT-Typ"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Unverträglicher abgeleiteter Typ in PARAMETER bei %L"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "COMMON-Block %qs bei %L kann nicht das EXTERNAL-Attribut haben"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr "Sorry, allozierbare/Zeiger-Komponenten in polymorphen (CLASS-)getypten Koarrays bei %L werden nicht unterstützt"
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "Attribut PROTECTED steht mit Attribut EXTERNAL bei %L in Konflikt"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "Attribut PROCEDURE steht mit Attribut PROTECTED bei %L in Konflikt"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%qs bei %L hat Attribut CONTIGUOUS, aber ist kein Feldzeiger oder Feld vermuteter Größe oder Rang"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Größe bei %L muss ein Schein-Argument sein"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Feld mit vermuteter Form bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Feld mit vermutetem Rang bei %L muss ein Scheinargument sein"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr "Feld mit vermutetem Rang bei %L darf kein Attribut VALUE oder CODIMENSION haben"
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Symbol bei %L ist keine Scheinvariable"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%qs bei %L kann nicht das VALUE-Attribut haben, da es kein Scheinargument ist"
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss konstante Länge haben"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C-kompatible zeichenwertige Scheinvariable %qs bei %L mit VALUE-Attribut muss Länge eins haben"
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Der abgeleitete Typ %qs bei %L hat Typ %qs, der nicht definiert wurde"
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss ein Scheinargument sein"
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss vom Typ TYPE(*) oder von einem numerischen intrinsischen Typ sein"
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr "Variable %s bei %L mit NO_ARG_CHECK-Attribut muss entweder skalar sein oder ein Feld vermuteter Größe"
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Vermuteter Typ der Variable %s bei %L ist nur für Scheinvariablen erlaubt"
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht die Attribute ALLOCATABLE, CODIMENSION, POINTER oder VALUE haben"
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variable %s vermuteten Typs bei %L darf nicht das Attribut INTENT(OUT) haben"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "Variable %s vermuteten Typs bei %L darf kein Feld mit ausdrücklicher Form sein"
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variable %qs bei %L kann nicht BIND(C) sein, weil es weder ein COMMON-Block noch mit Sichtbarkeit auf Modulebene deklariert ist"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "PUBLIC %s %qs bei %L mit abgeleitetem PRIVATE-Typen %qs"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variable %s bei %L mit LOCK_TYPE oder mit Subkomponente mit LOCK_TYPE muss ein Koarray sein"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79866
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "Variable %s bei %L mit EVENT_TYPE oder mit Subkomponente mit LOCK_TYPE muss ein Koarray sein"
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "Das INTENT(OUT)-Scheinargument %qs bei %L hat ASSUMED SIZE und kann damit keine Standardinitialisierung haben"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit LOCK_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Scheinargument %qs bei %L mit EVENT_TYPE darf nicht INTENT(OUT) sein"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Funktionsergebnis %qs bei %L darf weder Koarray sein noch eine Koarray-Komponente haben"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "Variable %qs bei %L mit TYPE(C_PTR) oder TYPE(C_FUNPTR) darf kein Koarray sein"
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "Variable %qs bei %L mit Koarraykomponente muss ein Nichtzeiger, nichtallozierbares Skalar und damit kein Koarray sein"
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "Variable %qs bei %L ist ein Koarray und ist weder ALLOCATABLE, SAVE, noch ein Scheinargument"
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Koarray-Variable %qs bei %L darf keine Kodimensionen mit aufgeschobener Form haben"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Zuordnungsfähige Koarray-Variable %qs bei %L muss aufgeschobene Form haben"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "Variable %qs bei %L ist INTENT(OUT) und kann daher kein reservierbares Coarray sein oder Coarray-Komponenten haben"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray-Scheinvariable %qs bei %L in BIND(C)-Prozedur %qs nicht erlaubt"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Scheinargument %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "LOGICAL-Rückgabevariable %qs bei %L mit Nicht-C_Bool-Art in BIND(C)-Prozedur %qs"
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Namensliste %qs kann bei %L nicht als Argument für Unterprogramm oder Funktion verwendet werden"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate bei %L ist nicht SAVEd"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr "»!$OMP DECLARE TARGET«-Variable %qs bei %L ist nicht gespeichert (SAVE)"
 
 # https://gcc.gnu.org/bugzilla/show_bug.cgi?id=79596
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr "check_data_variable(): Bad expression"
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "BLOCK DATA Element %qs bei %L muss in COMMON sein"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA-Feld %qs bei %L muss in vorheriger Deklaration angegeben werden"
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "DATA-Element %qs bei %L kann keinen Coindex haben"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "DATA-Element %qs bei %L ist ein Zeiger und muss daher ein vollständiges Feld sein"
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Abschnitt eines nicht konstanten Feldes bei %L in DATA-Anweisung"
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "DATA-Anweisung bei %L hat mehr Variablen als Werte"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Anfang der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Ende der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "Schritt der Implied-do-Schleife bei %L konnte nicht zu einem konstanten Wert vereinfacht werden"
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "DATA-Anweisung bei %L hat mehr Werte als Variablen"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Marke %d bei %L definiert, aber nicht verwendet"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Marke %d bei %L definiert, kann aber nicht verwendet werden"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L muss SEQUENCE-Attribut haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L kann keine ALLOCATABLE-Komponenten haben, um EQUIVALENCE-Objekt zu sein"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Standardinitialisierung kann nicht in EQUIVALENCE mit einer Variablen in COMMON sein"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Variable %qs abgeleiteten Typs bei %L mit Zeigerkomponenten kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaxfehler in EQUIVALENCE-Anweisung bei %L"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Entweder alle oder keines der Objekte in bei %L gesetztem EQUIVALENCE muss das Attribut PROTECTED haben"
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Allgemeines Blockelement %qs bei %L kann kein EQUIVALENCE-Objekt in PURE-Prozedur %qs sein"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Benannte Konstante %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Feld %qs bei %L mit nicht-konstanten Grenzen kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Strukturkomponente %qs bei %L kann kein EQUIVALENCE-Objekt sein"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Teilzeichenkette bei %L hat Länge Null"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "PUBLIC-Funktion %qs bei %L mit PRIVATE-Typ %qs"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY %qs bei %L hat keinen IMPLICIT-Typ"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss eine FUNCTION sein"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prozedur für Benutzeroperator %qs bei %L kann nicht vermutete Zeichenlänge haben"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prozedur für Benutzeroperator %qs bei %L muss mindestens ein Argument haben"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Erstes Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Zweites Argument der Operatorschnittstelle bei %L kann nicht optional sein"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Operatorschnittstelle bei %L darf höchstens zwei Argumente haben"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "Enthaltene Prozedur %qs bei %L einer PURE-Prozedur muss auch PURE sein"
@@ -59113,12 +59191,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "Event-Variable bei %L darf nicht koindiziert sein"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr "build_dt: Format mit Namensliste"
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "Falscher IO-Basistyp (%d)"
Index: gcc/po/ja.po
===================================================================
--- gcc/po/ja.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/ja.po	(.../branches/gcc-7-branch)
@@ -19,7 +19,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.6.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2011-10-30 18:48+0900\n"
 "Last-Translator: Yasuaki Taniguchi <yasuakit@gmail.com>\n"
 "Language-Team: Japanese <translation-team-ja@lists.sourceforge.net>\n"
@@ -212,13 +212,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "浮動小数定数を使い損ねました"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -587,63 +587,63 @@
 "子プロセスに自動的に渡されます。こういったプロセスにその他のオプションを渡す\n"
 "には -W<letter> オプションを使わなければなりません。\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, fuzzy, c-format
 #| msgid "Processing spec %c%s%c, which is '%s'\n"
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "spec %c%s%c を処理中, これは '%s' です\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "ターゲット: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "configure 設定: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "スレッドモデル: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc バージョン %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "gcc ドライババージョン %s %s 実行 gcc バージョン %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "インストール: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "プログラム: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "ライブラリ: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -652,16 +652,16 @@
 "\n"
 "バグレポートの手順は、以下を参照してください\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "(C)"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -671,7 +671,7 @@
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -684,7 +684,7 @@
 "==============\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -693,7 +693,7 @@
 "\"OPTION\" をリンカに渡すには \"-Wl,OPTION\" を使用してください\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -704,7 +704,7 @@
 "=================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -718,18 +718,18 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+#| msgid "  -n, --no-output                 Do not create an output file\n"
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -n, --no-output                 出力ファイルを作成しない\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 #| msgid "  -v, --version                   Print version number, then exit\n"
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -v, --version                   バージョン番号を表示して終了する\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -n, --no-output                 出力ファイルを作成しない\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -745,14 +745,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -780,31 +780,31 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -f, --function                      Print function level info\n"
 msgstr "  -h, --help                      このヘルプを表示して終了する\n"
 
-#: gcov-tool.c:422
+#: gcov-tool.c:421
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr "  -h, --help                      このヘルプを表示して終了する\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:422
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr "  -h, --help                      このヘルプを表示して終了する\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:423
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -o, --object                        Print object level info\n"
 msgstr "  -h, --help                      このヘルプを表示して終了する\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -891,20 +891,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      このヘルプを表示して終了する\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                各基本ブロックに関する情報を表示する\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      出力に分岐可能性情報を含める\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, fuzzy, c-format
 #| msgid ""
 #| "  -c, --branch-counts             Given counts of branches taken\n"
@@ -916,16 +911,21 @@
 "  -c, --branch-counts             分岐に関する百分率では無く行われた\n"
 "                                    回数を取得する\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          進捗情報を表示する\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        各関数に関する要約を出力する\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      このヘルプを表示して終了する\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1120,82 +1120,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s: '%s' 用のグラフが解決できません\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "実行された行:%s of %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "実行可能な行がありません\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s '%s'\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "実行された分岐:%s of %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "分岐がありません\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "実行された呼び出し:%s of %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "呼び出しがありません\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s: '%s' に対する行がありません\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr ""
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr ""
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr ""
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, fuzzy, c-format
 #| msgid "%s:cannot open source file\n"
 msgid "Cannot open source file %s\n"
@@ -1308,89 +1308,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[デフォルト]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[有効]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[無効]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "このオプションはターゲット固有のものです"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "次のオプションはコンパイラの警告メッセージを制御します"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "次のオプションは最適化を制御します"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "次のオプションは言語に依存しないものです"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "--param オプションは以降をパラメータとして認識します"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "次のオプションはこの言語固有のものです"
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "次のオプションはこの言語でサポートされているものです"
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "次のオプションは文書化されていません"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "次のオプションは分離した引数を取ります"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "次のオプションは結合した引数を取ります"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "次のオプションは言語に関係したものです"
 
@@ -2984,8 +2984,8 @@
 msgid "<command-line>"
 msgstr "<コマンドライン>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
@@ -3006,7 +3006,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "被演算子がありません"
@@ -3029,8 +3029,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "局所動的 TLS 参照無しで '%%&' が使用されました"
@@ -3046,18 +3046,18 @@
 msgstr "無効な %%r 値"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "無効な %%R 値"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "無効な %%N 値"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "無効な %%P 値"
@@ -3067,7 +3067,7 @@
 msgid "invalid %%h value"
 msgstr "無効な %%h 値"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "無効な %%L 値"
@@ -3088,7 +3088,7 @@
 msgstr "無効な %%U 値"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "無効な %%s 値"
@@ -3098,7 +3098,7 @@
 msgid "invalid %%C value"
 msgstr "無効な %%C 値"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "無効な %%E 値"
@@ -3109,7 +3109,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無効な %%xn コード"
@@ -3177,7 +3177,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "無効な被演算子出力コード"
@@ -3188,29 +3188,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "被演算子として無効な UNSPEC です"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "無効なシフト被演算子"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "述語付き Thumb 命令"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "条件シーケンスにある述語付き命令"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3218,116 +3218,116 @@
 msgid "invalid operand for code '%c'"
 msgstr "コード '%c' に対する無効な被演算子です"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "命令は決して実行されません"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "アドレス被演算子は X、Y または Z レジスタに対する制約を要求します"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 #, fuzzy
 #| msgid "output operand %d must use %<&%> constraint"
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "出力被演算子 %d は %<&%> 制約を使用しなければいけません"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 #, fuzzy
 #| msgid "bad address, not (reg+disp):"
 msgid "bad address, not an I/O address:"
 msgstr "誤ったアドレスです。(reg+disp) ではありません:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 #, fuzzy
 #| msgid "bad address, not a constant):"
 msgid "bad address, not a constant:"
 msgstr "誤ったアドレスです。定数ではありません):"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "誤ったアドレスです。(reg+disp) ではありません:"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "誤ったアドレスです。post_inc または pre_dec ではありません:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "コンパイラ内部エラー。誤ったアドレス:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "コンパイラ内部エラー。不明なモード:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "無効な命令:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "正しくない命令:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "不明な move 命令:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "誤ったシフト命令:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "コンパイラ内部エラー。正しくないシフト:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 #| msgid "invalid types in fixed-point conversion"
 msgid "unsupported fixed-point conversion"
 msgstr "固定小数変換内で無効な型です"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 #, fuzzy
 #| msgid "STAT variable"
 msgid "variable"
 msgstr "STAT 変数"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "仮引数 %q+D が再宣言されました"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 #| msgid "struct defined here"
 msgid "structure field"
 msgstr "構造体がここで定義されています"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 msgid "return type of function"
 msgstr "`%s' の宣言は関数の配列"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 #, fuzzy
 #| msgid "null pointer"
 msgid "pointer"
@@ -3352,7 +3352,7 @@
 msgstr "無効な const_double 被演算子"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3574,98 +3574,98 @@
 msgid "bad output_condmove_single operand"
 msgstr "誤った output_condmove_single 被演算子"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "被演算子として無効な UNSPEC です"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 #| msgid "invalid use of type"
 msgid "invalid use of asm flag output"
 msgstr "無効な型の使用法です"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 #| msgid "invalid operand size for operand code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "演算子コード '%c' に対する無効な被演算子サイズです"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'Y' です"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "被演算子は条件コードではありません。無効な被演算子コード 'D' です"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無効な被演算子コード '%c' です"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "演算子に対する無効な制約です"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "不明な命令モード"
 
@@ -3703,7 +3703,7 @@
 msgid "invalid %%P operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "無効な %%p 値です"
@@ -3757,7 +3757,7 @@
 msgstr "後置増分アドレスがレジスタではありません"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "誤ったアドレスです"
 
@@ -3790,7 +3790,7 @@
 msgstr "命令に無効なアドレスが含まれています!"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "無効なアドレスです"
 
@@ -3883,289 +3883,289 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "'%s' をシェル内で実行して制限値を上げてください\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx はハードウェア浮動小数を要求します"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx と -mpaired は併用できません"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx と -mno-altivec は併用できません"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec は vsx を無効にします"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "リトルエンディアンモードでコードを生成する"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 msgid "-mtoc-fusion requires 64-bit"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr "誤った move です"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無効な %%H 値"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "無効な %%f 値です"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "無効な %%F 値です"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "無効な %%G 値です"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "無効な %%j コードです"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "無効な %%J コードです"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "無効な %%k 値です"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "無効な %%K 値です"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "無効な %%O 値です"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "無効な %%q 値です"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "無効な %%T 値です"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "無効な %%u 値です"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "無効な %%v 値です"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "無効な %%x 値です"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無効な %%y 値です。'Z' 制約を使用してみてください"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "各関数で単一の終了点を生成しない"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 #| msgid "Enable unaligned load/store instruction"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "整列されていない load/store 命令を有効にする"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "シンボルによるメモリ参照は z10 またはそれ以降でのみサポートされます"
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr ""
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "'E' 出力修飾子用の無効な比較演算子です"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "'J' 出力修飾子用の無効な参照です"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "'O' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "'R' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "'S' 出力修飾子用にはメモリ参照が予期されます"
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "'S' 出力修飾子用の無効なアドレスです"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "'N' 出力修飾子用にはレジスタまたはメモリ式が予期されます"
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "'M' 出力修飾子用にはレジスタまたはメモリ式が予期されます"
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な定数です"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "無効な定数です - 出力修飾子の使用を試みてください"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 #| msgid "invalid constant for output modifier '%c'"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な定数です"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "無効な式です - 出力修飾子の使用を試みてください"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "出力修飾子 '%c' 用の無効な式です"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "プロトタイプが無い関数に AltiVec 引数が渡されました"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "戻りでのポインタの先の符号が異なります"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4191,22 +4191,22 @@
 msgid "created and used with different endianness"
 msgstr "作成時と使用時でエンディアンが異なります"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "無効な %%Y 被演算子です"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "無効な %%A 被演算子です"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "無効な %%B 被演算子です"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
@@ -4213,23 +4213,23 @@
 msgid "invalid %%C operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
 msgid "invalid %%D operand"
 msgstr "無効な %%P 被演算子です"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "無効な %%f 被演算子です"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "無効な %%s 被演算子です"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4416,30 +4416,30 @@
 msgid "bad test"
 msgstr "誤った test です"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "無効な %%D 値です"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "無効なマスクです"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "無効な %%d 値です"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "無効な %%t/%%b 値です"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "アドレスオフセットが定数ではありません"
 
@@ -4460,8 +4460,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "%<;%> が予期されます"
@@ -4483,14 +4483,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "%<(%> が予期されます"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "%<,%> が予期されます"
@@ -4521,7 +4521,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "%<)%> が予期されます"
@@ -4529,7 +4529,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "%<]%> が予期されます"
@@ -4539,7 +4539,7 @@
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "%<}%> が予期されます"
@@ -4546,7 +4546,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "%<{%> が予期されます"
@@ -4556,7 +4556,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "%<:%> が予期されます"
@@ -4569,24 +4569,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr ""
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "%<while%> が予期されます"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4594,18 +4594,18 @@
 msgid "expected %<.%>"
 msgstr "%<.%> が予期されます"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "%<@end%> が予期されます"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "%<>%> が予期されます"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "%<,%> または %<)%> が予期されます"
@@ -4613,17 +4613,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "%<=%> が予期されます"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "%<[%> が予期されます"
@@ -4632,7 +4632,7 @@
 msgid "(anonymous)"
 msgstr "(無名)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "%<<%> が予期されます"
@@ -4643,11 +4643,11 @@
 msgid "expected label"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "候補 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "候補 2:"
 
@@ -4886,11 +4886,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%s:%d:%d:   %qs から実体化されました\n"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "候補:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "候補:"
@@ -5062,85 +5062,85 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "正の幅が必要です"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "非負の幅が必要です"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 #| msgid "Unexpected element '%c' in format string at %L"
 msgid "Unexpected element %qc in format string at %L"
 msgstr "予期しない要素 '%c' が書式文字列内 (位置 %L) にあります"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "予期しない書式文字列終了です"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr "幅 0 の書式記述子です"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "前に左小括弧がありません"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 #| msgid "Left parenthesis required after '*'"
 msgid "Left parenthesis required after %<*%>"
 msgstr "'*' の後には左小括弧が必要です"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr ""
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr ""
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-msgid "Right parenthesis expected at %C"
-msgstr "正式な仮引数項を欠いています"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr ""
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr ""
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr ""
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+msgid "Right parenthesis expected at %C"
+msgstr "正式な仮引数項を欠いています"
+
+#: fortran/io.c:1040
 #, fuzzy
 msgid "Period required in format specifier"
 msgstr "認識できないフォーマット指定子"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -5150,81 +5150,81 @@
 msgid "Syntax error in expression at %C"
 msgstr "式の整数がオーバーフローしました"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "予期しないファイル終端 (EOF) です"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 #, fuzzy
 msgid "Integer overflow"
 msgstr "式の整数がオーバーフローしました"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr ""
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr ""
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 #, fuzzy
 msgid "Expected name"
 msgstr "MCU 名を指定する"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr ""
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr ""
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr ""
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr ""
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr ""
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 #, fuzzy
 msgid "Expected attribute bit name"
 msgstr "packed 属性は必要ありません"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 #, fuzzy
 msgid "Expected integer string"
 msgstr "セクションポインタを欠いています"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 #, fuzzy
 msgid "Expected real string"
 msgstr "終端されていないフォーマット文字列"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr ""
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr ""
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 #, fuzzy
 msgid "Bad type in constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "予期しない型が `id' (%s) に指定されました"
@@ -5496,12 +5496,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5892,7 +5892,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "-m32 と -m64 の両方を使用することはできません"
 
@@ -9631,7 +9631,7 @@
 msgstr "即値 TLS オフセットのビットサイズを指定する"
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 #, fuzzy
 #| msgid "Schedule code for given CPU"
@@ -9922,7 +9922,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
 msgid "Use LRA instead of reload."
@@ -10225,7 +10225,7 @@
 msgid "Use 80-bit long double."
 msgstr "128 ビット long double を使用する"
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 #| msgid "Use 64-bit long double"
@@ -10232,7 +10232,7 @@
 msgid "Use 64-bit long double."
 msgstr "64 ビット long double を使用する"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy
 #| msgid "Use 128-bit long double"
@@ -11601,109 +11601,109 @@
 msgid "64 bit ABI."
 msgstr "64 ビット ABI"
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr ""
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 #, fuzzy
 #| msgid "Additional debug prints"
 msgid "Additional debug prints."
 msgstr "追加のデバッグ情報を表示する"
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 #, fuzzy
 #| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
 msgstr "ESA/390 アーキテクチャ"
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 #| msgid "Enable decimal floating point hardware support"
 msgid "Enable decimal floating point hardware support."
 msgstr "十進浮動小数点ハードウェアのサポートを有効にする"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 #| msgid "Enable hardware floating point"
 msgid "Enable hardware floating point."
 msgstr "ハードウェア浮動小数点を有効にする"
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Use hardware transactional execution instructions."
 msgstr "ハードウェア浮動小数点命令を使用する"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 #, fuzzy
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr ""
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr ""
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 #| msgid "Disable hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "ハードウェア浮動小数点を無効にする"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr ""
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr ""
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 #| msgid "Generate string instructions for block moves"
 msgid "Use the mvcle instruction for block moves."
 msgstr "ブロック移動用の string 命令を生成する"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 #, fuzzy
 #| msgid "Warn if a function uses alloca or creates an array with dynamic size"
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "関数で alloca を使用するか、または動的サイズの配列を作成した場合に、警告する"
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 #, fuzzy
 #| msgid "Warn if a single function's framesize exceeds the given framesize"
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "一つの関数のフレームサイズが与えられたフレームサイズを超過する場合に警告する"
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 #, fuzzy
 #| msgid "z/Architecture"
 msgid "z/Architecture."
 msgstr "z/Architecture"
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -11765,11 +11765,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -12075,104 +12075,121 @@
 msgstr "UltraSPARC 可視命令集合 (VIS) を使用する"
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 #, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "UltraSPARC 可視命令集合 (VIS) を使用する"
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 #, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "UltraSPARC 可視命令集合 (VIS) を使用する"
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
 #, fuzzy
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "浮動小数の乗算/加算命令を生成する"
+
+#: config/sparc/sparc.opt:102
+#, fuzzy
 #| msgid "Use hardware floating point instructions"
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "ハードウェア浮動小数点命令を使用する"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 #| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "ポインタを 64 ビットとする"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 #| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "ポインタを 32 ビットとする"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "64 ビット ABI を使用する"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "32 ビット ABI を使用する"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 #, fuzzy
 #| msgid "Use stack bias"
 msgid "Use stack bias."
 msgstr "スタックバイアスを使用する"
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 #, fuzzy
 #| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "二倍ワードコピー用の強く整列された構造体を使用する"
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 #, fuzzy
 #| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "アセンブラとリンカで末尾呼び出し命令を最適化する"
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "与えられた CPU 用の機能とスケジュールコードを利用する"
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 #, fuzzy
 #| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
 msgstr "与えられた SPARC-V9 コードモデルを使用する"
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 #| msgid "-mdebug=\tEnable debug output"
 msgid "Enable debug output."
 msgstr "-mdebug=\tデバッグ出力を有効にする"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "厳密な 32 ビット psABI 構造体戻り値検査を有効にする。"
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -17849,7 +17866,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -18354,7 +18371,7 @@
 msgstr "整数または真偽型が予期されます"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 #| msgid "expected pointer"
 msgid "expected integer"
@@ -18656,143 +18673,143 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 #| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of non-ordered type"
 msgstr "gimple 条件内で無効な比較コードです"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 #, fuzzy
 #| msgid "-mmulticore can only be used with BF561"
 msgid "slice can only be compared to nil"
 msgstr "-mmulticore は BF561 でのみ使用できます"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 #, fuzzy
 msgid "map can only be compared to nil"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operation (%s)"
 msgstr "%%R への無効な被演算子です"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 #| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of non-comparable type"
 msgstr "gimple 条件内で無効な比較コードです"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 #| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of generated struct"
 msgstr "gimple 条件内で無効な比較コードです"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 #, fuzzy
 #| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of non-comparable struct"
 msgstr "gimple 条件内で無効な比較コードです"
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 #| msgid "invalid comparison code in gimple cond"
 msgid "invalid comparison of generated array"
 msgstr "gimple 条件内で無効な比較コードです"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of non-comparable array"
 msgstr "非左辺値配列の無効な使用です"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 #, fuzzy
 msgid "multiple-value function call in single-value context"
 msgstr "%s: 関数 `%s' の宣言が変換されていません\n"
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr "明示的な変換が必要です"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr "型 %s を型 %s として使用できません"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr ""
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr "引数の数が異なります"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr "引数の型が異なります"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr "結果の数が異なります"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr "結果の型が異なります"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "明示的な変換が必要です。存在しないメソッド %s%s%s です"
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "メソッド %s%s%s への互換性のない型です"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr ""
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr "インターフェース型へのポインタがメソッドを持っていません"
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr "型がメソッドを持っていません"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "曖昧なメソッド %s%s%s です"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "メソッド %s%s%s がありません"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, fuzzy, c-format
 #| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "メソッド %s%s%s にはポインタが必要です"
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, fuzzy, c-format
 #| msgid "method %s%s%s requires a pointer"
 msgid "method %s%s%s is marked go:nointerface"
@@ -18973,7 +18990,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "関数 %<va_start%> への引数が少なすぎます"
@@ -19039,29 +19056,29 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "無効な %<auto%> の使用です"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "無効な %<auto%> の使用です"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return はこのターゲットではサポートされていません"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -19069,7 +19086,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K %<__builtin_va_arg_pack ()%> の無効な使用法です"
@@ -19076,12 +19093,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%K %<__builtin_va_arg_pack_len ()%> の無効な使用法です"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけません"
@@ -19088,64 +19105,64 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "ターゲット形式は無限大をサポートしません"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "ターゲット形式は無限大をサポートしません"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> が引数の数が固定の関数内で使用されました"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> が引数無しで呼び出されました"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%> の第二引数が、最後の名前付き引数ではありません"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "%<va_start%> の第二引数が %<register%> 記憶域の場合の動作は不定です"
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%K %D の第一引数がポインタ、第二引数が整数定数でなければいけません"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%K %D の最後の引数が 0 から 3 の間の整数定数ではありません"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%K ヒープではないオブジェクト %qD を free する試みです"
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%K ヒープではないオブジェクトを free する試みです"
@@ -20066,12 +20083,12 @@
 msgstr "%qE 属性は %qT が既に定義されているため無視されます"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F が使用されましたが定義されていません"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
@@ -20168,12 +20185,12 @@
 msgid "cannot find '%s'"
 msgstr "'%s' が見つかりません"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pex_init に失敗しました: %m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -20183,7 +20200,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER が設定されなければいけません"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -20402,7 +20419,7 @@
 msgid "error writing %qs"
 msgstr "%qs へ書き込み中にエラーが発生しました"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "%s を開けません"
@@ -20483,17 +20500,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -20603,12 +20620,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -20623,12 +20640,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "フレームサイズ (%wd バイト) が %wd バイトより大きいです"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "最終命令ダンプファイル %qs が開けません: %m"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "最終命令ダンプファイル %qs を閉じられません: %m"
@@ -20643,7 +20660,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "ビットフィールド幅のため、比較が常に %d になります"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -20673,7 +20690,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -20683,7 +20700,7 @@
 msgid "total size of local objects too large"
 msgstr "局所オブジェクトの総サイズが大きすぎます"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> 内で制約を行うことは出来ません"
@@ -20784,62 +20801,68 @@
 msgid "input file %qs is the same as output file"
 msgstr "%qs は有効な出力ファイルではありません"
 
-#: gcc.c:4498
+#: gcc.c:4476
+#, fuzzy, gcc-internal-format
+#| msgid "output filename specified twice"
+msgid "output filename may not be empty"
+msgstr "出力ファイル名が二回指定されています"
+
+#: gcc.c:4501
 #, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "-save-temps が指定されたため、-pipe は無視されました"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "最後の入力ファイル以降の %<-x %s%> は効果がありません"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr "ライブラリ探索パス内にデフォルトリンカスクリプト %qs の位置確認ができません"
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "スイッチ %qs が %<-%> で開始されていません"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "一時応答ファイル %s を開けませんでした"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "一時応答ファイル %s に書き込むことが出来ませんでした"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "一時応答ファイル %s を閉じることが出来ませんでした"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "spec %qs が無効です"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "spec %qs に無効な %<%%0%c%> があります"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "spec %qs に無効な %<%%W%c%> があります"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "spec %qs に無効な %<%%x%c%> があります"
@@ -20847,232 +20870,232 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "spec 失敗: %<%%*%> はパターンマッチによって初期化されていません"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "spec 失敗: 認識できない spec オプション %qc です"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "不明な spec 関数 %qs です"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "spec 関数 %qs の引数内でエラーが発生しました"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "間違った形式の spec 関数名です"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "spec 関数用の引数がありません"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "間違った形式の spec 関数引数です"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "忠括弧で括られた spec %qs は無効です(位置 %qc)"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "忠括弧で括られた spec 本体 %qs は無効です"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s:比較デバッグファイル %s の長さを決定することが出来ません"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr "%s: -fcompare-debug 失敗です (長さ)"
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s: 比較デバッグファイル %s を開くことが出来ません"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "%s: -fcompare-debug 失敗です"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "spec 失敗: SYSROOT_SUFFIX_SPEC に二個以上の引数があります"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "spec 失敗: SYSROOT_HEADERS_SUFFIX_SPEC に二個以上の引数があります"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "認識できないコマンドラインオプション %<-fdump-%s%> です"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command line option %<-%s%>"
 msgstr "認識できないコマンドラインオプション %<-fdump-%s%> です"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "システムルートヘッダ接尾辞付きで設定されていません"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "入力ファイルがありません"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "複数ファイルがあるときに -o と -c、-S または -E を併せて指定できません"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: %s コンパイラはこのシステムにインストールされていません"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "-fcompare-debug 付きで再コンパイルしています"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr "-fcompare-debug 再コンパイルの間"
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr "最終命令ダンプを比較しています"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "フィールド `%s' が見つかりません"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: リンクが完了しなかったのでリンカの入力ファイルは使われませんでした"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "言語 %s は認識できません"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "multilib spec %qs は無効です"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr ""
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 #| msgid "multilib spec %qs is invalid"
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib spec %qs は無効です"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr ""
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr ""
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "環境変数 %qs が定義されていません"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "無効なバージョン番号 %qs です"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "%%:version-compare への引数が少なすぎます"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "%%:version-compare への引数が多すぎます"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "不明な演算子 %qs が %%:version-compare 内にあります"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "%%:compare-debug-dump-opt への引数が多すぎます"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "%%:compare-debug-self-opt への引数が多すぎます"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "%%:compare-debug-auxbase-opt への引数が少なすぎます"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "%%:compare-debug-auxbase-opt への引数が多すぎます"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr "%%:compare-debug-auxbase-opt への引数が .gk で終了していません"
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to %%:replace-extension"
 msgstr "関数への引数が少なすぎます"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments to function %<va_start%>"
 msgid "wrong number of arguments to %%:debug-level-gt"
@@ -21223,9 +21246,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "ここで宣言されています"
@@ -21652,235 +21675,235 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "%<void%> を返す関数の結果を使用しています"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr ""
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE が宣言されていません (この関数内での最初の使用)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "変数 %q+D が %<inline%> と宣言されています"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD の無効なテンプレート宣言です"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "結果の数が値の数と一致しません"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<}%> が %<else%> の前に予期されます"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification に失敗しました"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "このコードまで到達した場合、プログラムは中止されます"
@@ -22121,7 +22144,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
 #: ipa-devirt.c:1235
@@ -22222,7 +22245,7 @@
 
 #: ipa-devirt.c:1576
 #, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr ""
 
 #: ipa-devirt.c:1599
@@ -22620,194 +22643,194 @@
 msgid "multiple loop axes specified for routine"
 msgstr "型名用に記憶域クラスが指定されました"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr ""
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr ""
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
 msgid "invalid arguments"
 msgstr "無効な PHI 引数です"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "OpenMP 構造化ブロックへの無効なエントリです"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -22814,7 +22837,7 @@
 msgstr "OpenMP 構造化ブロックへの無効なエントリです"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid branch to/from an OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
@@ -22903,7 +22926,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "コマンドラインオプション %qs はこの設定ではサポートされていません"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "%qs への引数がありません"
@@ -23066,137 +23089,147 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr "print_specific_help へ認識できない include_flags 0x%x が渡されました"
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized argument to --help= option: %q.*s"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "--help 引数 %q.*s は曖昧です。より特定してください"
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "--help= オプションへの認識できない引数です: %q.*s"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 #| msgid "LTO support has not been enabled in this configuration"
 msgid "HSA has not been enabled during configuration"
 msgstr "`この設定内では LTO サポートが有効になっていません"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "構造体の整列は %d ではなく、小さな二の累乗でなければいけません"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "unknown stack check parameter \"%s\""
 msgid "unknown stack check parameter %qs"
 msgstr "不明なスタック検査パラメータ \"%s\" です"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
 # 規格に合わせて DWARF と大文字で表記する
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "DWARF バージョン %d はサポートされていません"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: --param 引数は NAME=VALUE の形式であるべきです"
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "無効な --param の値 %qs です"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs"
 msgstr "無効な --param の値 %qs です"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "無効な --param の値 %qs です"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "ターゲットシステムはデバッグ出力をサポートしていません"
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "デバッグ形式 \"%s\" は前の選択と競合しています"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "認識できないでバッグ出力レベル \"%s\" です"
 
-#: opts.c:2533
+#: opts.c:2540
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "デバッグ出力レベル %s は高すぎます"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "コアファイルサイズ最大制限を取得しています: %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "コアファイルサイズ制限を最大へ設定しています: %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "認識できない gcc デバッグオプションです: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: オプション -%s はありません"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -23552,7 +23585,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "レジスタが二つの大域レジスタ変数として使われました"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting types for %q+D"
 msgid "conflicts with %qD"
@@ -24172,13 +24205,13 @@
 msgid "error closing %s: %m"
 msgstr "%s を閉じているときにエラーが発生しました: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 #| msgid "-mas100-syntax is incompatible with -gdwarf"
 msgid "self-tests incompatible with -E"
 msgstr "-mas100-syntax と -gdwarf は併用できません"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -25116,47 +25149,47 @@
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -25259,34 +25292,34 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "in a call to built-in function %qD"
 msgstr "組み込み関数への無効な引数です"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "インライン関数 %q+D を弱いとして宣言できません"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, fuzzy, gcc-internal-format
 #| msgid "cannot optimize loop, the loop counter may overflow"
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "ループを最適化できません。ループカウンタが溢れるかもしれません"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr ""
@@ -25646,11 +25679,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -26649,7 +26682,7 @@
 msgid "type was previously declared %qE"
 msgstr "前はここで宣言されました"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
@@ -26931,7 +26964,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD のアドレスは常に %<true%> と評価されます"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "真偽値として使われる代入のまわりでは、丸括弧の使用をお勧めします"
@@ -27579,62 +27612,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "書式引数内に余分な型修飾子があります (第 %d 引数)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> は引数の型が %<%s%s%> であると予期されますが、第 %d 引数の型は %qT です"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%> は対応した %<%s%s%> 引数が予期されます"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%> は引数の型が %<%T%s%> であると予期されますが、第 %d 引数の型は %qT です"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%> は対応した %<%T%s%> 引数が予期されます"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> が型として定義されていません"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> が %<long%> または %<long long%> として定義されていません"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> が型として定義されていません"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> が型として定義されていません"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> が型として定義されていません"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> がポインタ型として定義されていません"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "書式解釈される引数が %<...%> ではありません"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime 書式は引数を書式解釈できません"
@@ -27735,7 +27768,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "Objective-C 文字列の前に連続した %<@%> があります"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "サポートされていない非標準の文字列リテラルの連結です"
@@ -27766,7 +27799,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr ""
@@ -27782,22 +27815,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE は初期化されていません"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr ""
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "増分式がありません"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無効な増分式です"
@@ -28352,8 +28385,8 @@
 msgid "wrong type argument to %s"
 msgstr "%s への間違った型の引数です"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "定数式内でオーバーフローしました"
@@ -29031,7 +29064,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "非関数 `%s' の引数に format 属性が指定されました"
@@ -29202,7 +29235,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "不明な -mdebug-%s スイッチです"
@@ -29535,7 +29568,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "引数は定数でなければいけません"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -29623,7 +29656,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "-mfpu 用の不明な値 %s です"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "-mcpu=%s スイッチが -march=%s スイッチと競合しています"
@@ -29719,9 +29752,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "%s\"%s\"%s は無効です"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 #| msgid "attribute %qE argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -29810,7 +29843,7 @@
 msgstr "-mmemory-latency 用の間違った値 %qs です"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -29996,238 +30029,238 @@
 msgid "insn addresses not freed"
 msgstr "誤ったアドレスです。レジスタではありません:"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections はこのターゲットではサポートされていません"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "セレクタは即値でなければなりません"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "マスクは即値でなければなりません"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE 属性引数は 0 と 255 の間であるべきです"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -G are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-fPIC と -G は併用できません"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "ターゲット CPU は ARM モードをサポートしていません"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "バックトレースサポートの有効化は Thumb 用にコンパイルしたときのみ意味があります"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "呼び出し先 ARM/Thumb 相互利用有効化は Thumb 用にコンパイルしたときのみ意味があります"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g に -mno-apcs-frame をつけると、きめ細かなデバッグはできないでしょう"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "-mtp=cp15 を 16 ビット Thumb で使用できません"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC は Thumb では使用できません"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
 # 公式な名前は Thumb であり THUMB ではない
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "target CPU does not support unaligned accesses"
@@ -30235,148 +30268,148 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-mpcrel -fPIC is not currently supported on selected cpu"
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mpcrel -fPIC は選択した CPU 上では現在のところサポートされていません"
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "ターゲット CPU は ARM/Thumb 相互利用をサポートしていません"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check と -mno-apcs-frame は併用できません"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic と -mapcs-reent は併用できません"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS 再入可能コードはサポートされていません。無視されました"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable と -msdata=%s は併用できません"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt は適切な操作用に AAPCS 互換 ABI を必要とします"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt ABI は iwmmxt 機能がある CPU を必要とします"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS は -mcaller-super-interworking をサポートしません"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS は -mcallee-super-interworking をサポートしません"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 かつ ldrh 無し"
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard および VFP"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard および VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "構造体サイズ境界は %s にのみ設定できます"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "構造体サイズ境界は %s にのみ設定できます"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "RTP PIC は -msingle-pic-base と併用できません"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= は -fpic をつけないと役に立ちません"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "PIC レジスタ用に '%s' を使用できません"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition はこのアーキテクチャ上ではサポートされていません"
 
 # 公式な名前は Thumb であり THUMB ではない
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "ターゲット CPU は Thumb 命令をサポートしていません"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 ハードウェア浮動小数 VFP ABI"
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -30384,78 +30417,83 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE 属性は関数へのみ適用されます"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute requires prototypes with named arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qE 属性は名前付き引数があるプロトタイプが必要です"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute has no effect on unit local functions"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE 属性はユニット局所関数に関しては効果がありません"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "スタックに積まれた仮引数の実際の位置を計算できません"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高位レジスタを pop する為に使用できる低位レジスタがありません"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid fpu for attribute(target(\"%s\"))"
@@ -30464,13 +30502,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\")) が不明です"
@@ -30577,180 +30615,192 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr "%qE 属性はユニット局所関数に関しては効果がありません"
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt function must have no arguments"
 msgid "%qs function cannot have arguments"
 msgstr "割り込み関数は引数無しでなければいけません"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "functions cannot return __fp16 type"
 msgid "%qs function cannot return a value"
 msgstr "関数が __fp16 型を返しません"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%qs appears to be a misspelled signal handler"
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs は綴りが間違ったシグナルハンドラのように見えます"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
+#, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
 #, fuzzy, gcc-internal-format
 #| msgid "'builtin_return_address' contains only 2 bytes of address"
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "'builtin_return_address' がアドレスの 2 バイトのみ含んでいます"
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "シンボルからのポインタオフセットが間違っているようです"
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "プログラムメモリアドレスとしてデータメモリをアクセスしています"
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, fuzzy, gcc-internal-format
 #| msgid "accessing program  memory with data memory address"
 msgid "accessing program memory with data memory address"
 msgstr "データメモリアドレスとしてプログラムメモリをアクセスしています"
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "レジスタの数が整数を引数を渡すために使われる"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, fuzzy, gcc-internal-format
 #| msgid "conflicting named address spaces (%s vs %s)"
 msgid "writing to address space %qs not supported"
 msgstr "名前付きアドレス空間 (%s と %s) が競合しています"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE 属性は変数および関数へのみ適用できます"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported for R8C target"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%qE 属性は R8C ターゲット用にはサポートされていません"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE は変数にのみ適用できます"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE 属性は整数定数引数のみ許可されています"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute has no effect"
 msgid "%qE attribute address out of range"
 msgstr "%qE 属性は効果がありません"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE は変数にのみ適用できます"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "static IO declaration for %q+D needs an address"
 msgstr "%q+D の再宣言は仮引数を隠します"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "IO definition for %q+D needs an address"
 msgstr "前の %q+D の宣言はここです"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "初期化されていない変数のみ .noinit セクション内に配置できます"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "初期化された変数のみプログラムメモリ領域内に配置できます"
+
+#: config/avr/avr.c:10160
+#, fuzzy, gcc-internal-format
+#| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "初期化された変数のみプログラムメモリ領域内に配置できます"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 #| msgid "%qE incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU %qs はアセンブラのみ用にサポートされています"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "NaN から整数への変換です"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "文字列定数の中でファイルの終端を検出しました"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%qs には定数引数が予期されます"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -31041,12 +31091,12 @@
 msgid "invalid IACC argument"
 msgstr "無効な IACC 引数です"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs には定数引数が予期されます"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "%qs 用の定数引数が範囲外です"
@@ -31242,7 +31292,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "コードモデル %qs は %s ビットモード内ではサポートされません"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "コードモデル %s は PIC モードをサポートしません"
@@ -31384,299 +31434,299 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "%spreferred-stack-boundary%s is not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "%spreferred-stack-boundary%s はこのターゲットではサポートされていません"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and %d"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s が %d と %d の間ではありません"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d が %d と 12 の間ではありません"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 #| msgid "-mno-fentry isn%'t compatible with SEH"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "ret 命令は実装されていません"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s が SSE が有効ではない状態で使用されています"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 命令セットが無効になっています。 387 数値演算を使用します"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 命令セットが無効になっています。SSE 数値演算を使用します"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry は SEH と互換性がありません"
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "-mrecip=%s 用の不明なオプションです"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\") は既に指定されています"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "2 バイト cop 命令は 64 ビット VLIW モードでは許可されていません"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall と regparm 属性は併用できません"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 属性には整数定数引数が必要です"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE 属性への引数が %d より大きいです"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall と stdcall 属性は併用できません"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall と cdecl 属性は併用できません"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall と fastcall 属性は併用できません"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl と thiscall 属性は併用できません"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is used for none class-method"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 属性が非クラスメソッド用に使用されています"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qT を呼び出しています<"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "multilib はサポートしません"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue は入れ子になった関数と両立できません"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector argument without MMX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "MMX vector return without MMX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE が有効でない状態での SSE ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル引数は ABI を変更します"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX が有効でない状態での MMX ベクトル戻し (return) は ABI を変更します"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "可変長配列メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "long double を持つ共用体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタを戻して (return) います"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "SSE が無効の状態で SSE レジスタ引数があります"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 が無効な状態で x87 レジスタを戻して (return) います"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, fuzzy, gcc-internal-format
 #| msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "SSE/SSE2 が有効でない状態で sseregparm 属性付きの %qD を呼び出しています"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 属性は 32 ビット用の -mfentry と併用できません"
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, fuzzy, gcc-internal-format
 #| msgid "%<-fsplit-stack%> is not supported by this compiler configuration"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -31684,320 +31734,320 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr ""
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand type used with operand code '%c'"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "被演算子コード '%c' に無効な被演算子型が使用されました"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 #| msgid "static linking is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "静的リンクはサポートされていません"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "前方での `%s' の宣言"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 #| msgid "nested functions not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "入れ子になった関数はこのターゲットではサポートされていません"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "parameter %qD set but not used"
 msgid "Parameter to builtin not valid: %s"
 msgstr "仮引数 %qD が設定されましたが使用されません"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 32-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後の引数は 1 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "最後の引数の前の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "引数は定数でなければいけません"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect rounding operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後の引数は 4 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後の引数は 5 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後の引数は 32 ビット即値でなければいけません"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE は isa オプション %s が必要です"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後の引数は即値でなければいけません"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後の引数は 2 ビット即値でなければいけません"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "第五引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "正しくない命令:"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最後の引数は 8 ビット即値でなければいけません"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 属性は 32 ビットでのみ使用できます"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE 属性への引数が 0 でも 1 でもありません"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi と sysv_abi 属性は互換性がありません"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "互換性がない %qE 属性は無視されました"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "割り込みサービスルーチンを Thumb モードでコード化することはできません"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown IRA algorithm %qs"
 msgid "unknown asm flag output %qs"
 msgstr "不明な IRA アルゴリズム %qs です"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand output code"
 msgid "invalid type for asm flag output"
 msgstr "無効な被演算子出力コード"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, fuzzy, gcc-internal-format
 #| msgid "unknown architecture %qs"
 msgid "Unknown architecture specific memory model"
 msgstr "不明なアーキテクチャ %qs です"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "サポートされていない組み合わせです: %s"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument type to builtin function"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "組み込み関数へのサポートされていない引数の型です"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -32122,7 +32172,7 @@
 msgid "argument %qd is not a constant"
 msgstr "引数 %qd が定数ではありません"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, null ポインタ"
@@ -32132,7 +32182,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: 不明な句読点 '%c'"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND NULL ポインタ"
@@ -32234,7 +32284,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread は fido 上でのみ使用出来ます"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "スタック制限式はサポートされていません"
@@ -32765,8 +32815,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr "間違った組み込みコードです"
@@ -33040,29 +33090,29 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "%qE 属性は型に関しては無視されます"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ 属性は自動記憶域クラスでのみ許可されています"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -33087,7 +33137,7 @@
 msgid "-g option disabled"
 msgstr "-g オプションが無効になりました"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
@@ -33231,164 +33281,164 @@
 msgid "junk at end of #pragma longcall"
 msgstr "#pragma longcall の末尾にゴミがあります"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "vec_extract only accepts 2 arguments"
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_extract は 2 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_insert は 3 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_insert は 3 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_insert は 3 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s は %d 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s は 1 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s は 2 この引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract は 2 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert は 3 個の引数のみ受け付けます"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 #| msgid "passing argument %d of %qE makes integer from pointer without a cast"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "passing argument %d 番目の %qE の引数を渡すときにポインタからキャスト無しに整数を作成しています"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ifunc is not supported in this configuration"
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "ifunc はこの設定ではサポートされていません"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr "-mrecip は -ffinite-math または -ffast-math が必要となります"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr "-mrecip は -fno-trapping-math または -ffast-math が必要となります"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr "-mrecip は -freciprocal-math または -ffast-math が必要となります"
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power は 64 ビット Darwin ではサポートされていません。インストールされている C および C++ ライブラリと互換性がありません"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use PowerPC instruction set"
 msgid "not configured for SPE instruction set"
 msgstr "PowerPC 命令セットを使用しない"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "target 属性または pragma が SPE ABI を変更します"
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple はリトルエンディアンシステム上ではサポートされていません"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring はリトルエンディアンシステム上ではサポートされていません"
@@ -33395,69 +33445,69 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "-mcmodel は他の toc オプションと互換性がありません"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "-msingle-float option equivalent to -mhard-float"
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "-msingle-float オプションは -mhard-float と等価です"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -33466,243 +33516,243 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "target 属性または pragma が long double のサイズを変更します"
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr "-mveclibabi= スイッチ用の不明なベクトルライブラリ ABI 型 (%s) です"
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "target 属性または pragma が AltiVec ABI を変更します"
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "target 属性または pragma が darwin64 ABI を変更します"
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "target 属性または pragma が単精度浮動小数点を変更します"
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "target 属性または pragma が倍精度浮動小数点を変更します"
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 #| msgid "%qs is not a valid option to the preprocessor"
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs は前処理の有効なオプションではありません"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "%d バイト整列の仮引数を渡す ABI は GCC 4.6 で変更になっています"
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, fuzzy, gcc-internal-format
 #| msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "複素浮動小数メンバを持つ構造体を渡す ABI は GCC 4.4 で変更になっています"
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "internal error: builtin function to %s already processed"
 msgid "internal error: builtin function %s already processed"
 msgstr "内部エラー: %s への組み込み関数は既に処理されています"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "第一引数は 5 ビット符号付きリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "__builtin_altivec_predicate の第一引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "__builtin_altivec_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s は 64 ビットモードでは無視されます"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %s only accepts a string argument"
@@ -33709,7 +33759,7 @@
 msgstr "%s は 1 個の引数のみ受け付けます"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "cpu %s is an invalid argument to builtin %s"
@@ -33716,300 +33766,305 @@
 msgstr "%qs は -mcpu= への引数としては無効です"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs is an invalid argument to -mcpu="
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "%qs は -mcpu= への引数としては無効です"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "第三引数は 4 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "第三引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 1-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "第三引数は 1 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "第二引数は 5 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "数値は 0 または 1 でなければいけません"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE must be in the range %d...%d"
 msgid "argument 3 must be in the range 0..15"
 msgstr "%d 番目の %qE の引数は %d...%d の範囲でなければいけません"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "dss への引数は 2 ビット符号無しリテラルでなければいけません"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "%<__builtin_prefetch%> への第三引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "__builtin_paired_predicate の第一引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "__builtin_paired_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "__builtin_spe_predicate の第一引数は定数でなければいけません"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "__builtin_spe_predicate の第一引数が範囲外です"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "この組み込み関数は fr450 上でのみ利用できます"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qD requires the %<-mconstant-cfstrings%> flag"
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "組み込み関数 %qD は %<-mconstant-cfstrings%> フラグを要求します"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ifunc is not supported in this configuration"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "ifunc はこの設定ではサポートされていません"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "内部エラー: 組み込み関数 %s が予期しない戻り型 %s を持っています"
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "内部エラー: 組み込み関数 %s の第 %d 引数が予期しない引数型 %s を持っています"
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "スタックフレームが大きすぎます"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target はこのマシン用にはサポートされていません"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<long double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "AltiVec 型内での真偽型 (boolean) の使用は無効です"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "AltiVec 型内での %<complex%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "AltiVec 型内での十進浮動小数点の使用は無効です"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "-mvsx 無しで 64 ビットコード用の AltiVec 型内での %<long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "AltiVec 型内での %<long%> の使用は廃止されました。%<int%> を使用してください"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "-mvsx 無しで AltiVec 型内での %<long long%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "-mvsx 無しで AltiVec 型内での %<double%> の使用は無効です"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "マイクロコード命令 %s\t[%s] #%d を発行しています"
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "条件付きマイクロコード命令 %s\t[%s] #%d を発行しています"
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "CPU \"%s\" は %s\"%s\"%s 用には無効です"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s\"%s\"%s は許可されていません"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s\"%s\"%s は無効です"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -34200,6 +34255,7 @@
 msgstr "-mas100-syntax と -gdwarf は併用できません"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 は PowerPC64 CPU が必要です"
@@ -34293,7 +34349,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -34321,7 +34377,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -34343,7 +34399,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -34358,40 +34414,40 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "%qs 用の定数引数が範囲外です"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin code"
@@ -34398,123 +34454,123 @@
 msgid "bad builtin icode"
 msgstr "間違った組み込みコードです"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "組み込み関数への無効な引数です"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局所変数の合計サイズがアーキテクチャの制限を超過しています"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "%qs のフレームサイズ: "
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs は動的スタック割り当てを使用します"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -fpic are not supported for this target"
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr "-fPIC and -fpic はこのターゲットではサポートされていません"
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture モードは %s 上ではサポートされていません"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 ビット ABI は ESA/390 モード内ではサポートされていません"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "ハードウェア十進浮動小数点命令は %s 上では使用出来ません"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "ハードウェア十進浮動小数点命令は ESA/390 モードでは使用出来ません"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp は -msoft-float と併用できません"
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float の組み合わせはサポートされていません"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "スタックサイズは 64k より大きくてはいけません"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard は -mstack-size を暗黙的に使用します"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%qs への引数は非負整数であるべきです"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qE attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
@@ -34521,7 +34577,7 @@
 msgstr "%qE 属性への引数が %d より大きいです"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 #| msgid "%<__int128%> is not supported by this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -34579,27 +34635,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax は RTP PIC 用にのみサポートされています"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s はこの設定ではサポートされていません"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 は -m64 と併用することは許可されていません"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "-mcmodel= スイッチ用の誤った値 %s です"
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= は 32 ビットシステム上ではサポートされていません"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "-fcall-saved-REG is not supported for out registers"
@@ -34899,22 +34956,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "%<#pragma pack%> 内で無効な定数です - 無視されました"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "-f%s は CONST16 命令ではサポートされていません"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "PIC が必要ですが CONST16 命令ではサポートされていません"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr ".bss セクションには未初期化変数のみ配置出来ます"
@@ -35002,7 +35059,7 @@
 msgid "could not read the BRIG file"
 msgstr "応答ファイル %s を書き込めませんでした"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 #| msgid "invalid PHI argument"
@@ -35413,9 +35470,9 @@
 msgstr "ラベル %qD はここで定義されています"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD はここで宣言されています"
@@ -35552,7 +35609,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> は関数プロトタイプスコープ以外では許可されていません"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -36625,7 +36682,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "宣言指定内に二個またはそれ以上の型があります"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> は GCC にとって長すぎます"
@@ -36776,17 +36833,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C は単なる %<complex%> を %<double complex%> を意味するものとしてはサポートしません"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C は複素整数型をサポートしません"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -36839,7 +36896,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "行末 (EOL) が予期されます"
@@ -36881,7 +36938,7 @@
 msgstr "不明な型名 %qE です"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "宣言指定が予期されます"
@@ -36897,7 +36954,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "%<;%>、識別子または %<(%> が予期されます"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr ""
@@ -36912,8 +36969,8 @@
 msgid "unexpected attribute"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "getter/setter attribute must be followed by %<=%>"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -36954,7 +37011,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "%<,%> または %<;%> が予期されます"
@@ -36982,7 +37039,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 は %<_Static_assert%> をサポートしません"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "文字列リテラルが予期されます"
@@ -37049,14 +37106,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "識別子が予期されます"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列挙型リストの最後にコンマがあります"
@@ -37194,7 +37251,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<}%> が %<else%> の前に予期されます"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> の前に %<if%> がありません"
@@ -37219,12 +37276,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr "ラベルは文または宣言の一部にのみなることができます。文になることとは出来ません"
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -37238,17 +37295,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "文が予期されます"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "%<if%> 文内の空の本体は中括弧で括ることを推奨します"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "%<else%> 文内の空の本体は中括弧で括ることを推奨します"
@@ -37258,7 +37315,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "%<else%> が曖昧になることを避けるために明示的に中括弧で括ることを推奨します"
@@ -37278,7 +37335,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr ""
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -37471,18 +37528,18 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> の第二引数は 1 でなければいけません"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -37537,64 +37594,64 @@
 msgid "no type or storage class may be specified here,"
 msgstr "型または記憶域クラスがここで指定されていません、"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明な property 属性です"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<#pragma pack%> の後に %<(%> がありません - 無視されました"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 属性は一回のみ指定できます"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名は %<:%> で終端されなければいけません"
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 属性は一回のみ指定できます"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> は最初に無ければいけません"
@@ -37610,12 +37667,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -37632,59 +37689,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD は変数ではありません"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<none%>"
 msgstr "%<new%> が予期されます"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "%<none%> または %<shared%> が予期されます"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "%<;%>、%<,%> または %<)%> が予期されます"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "%<catch%> が予期されます"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -37714,25 +37771,25 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "%<throw%> が予期されます"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>"
 msgid "expected %<scalar%>"
@@ -37744,63 +37801,63 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments"
 msgid "too many %<static%> arguments"
 msgstr "引数が多すぎます"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "packed 属性は必要ありません"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 属性の引数が整数定数ではありません"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 #| msgid "ordered comparison of pointer with integer zero"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "整数 0 とポインタとの順序比較です"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "%<+%>、%<*%>、%<-%>、%<&%>、%<^%>、%<|%>、%<&&%> または %<||%> が予期されます"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<runtime%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "スケジュール %<auto%> は %<chunk_size%> 仮引数をとりません"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "`無効なスケジュールの種類です"
@@ -37817,18 +37874,18 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -37848,19 +37905,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無効なマスクです"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -37872,72 +37929,72 @@
 msgid "invalid proc_bind kind"
 msgstr "`無効なスケジュールの種類です"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs は %qs 用には有効ではありません"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs は %qs と併用しなければいけません"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "ファイルスコープの可変フィールドです"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%> 変数 %qD の宣言が %<for%> ループ初期化宣言内にあります"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -37953,7 +38010,7 @@
 msgid "expected function name"
 msgstr "関数が予期されます"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "メンバ関数の名前を欠いています"
@@ -37963,44 +38020,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%> 用の無効な演算子です"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -38010,28 +38067,28 @@
 msgid "expected %<(%> or end of line"
 msgstr "%<(%> またはファイル終端 (EOF) が予期されます"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "for 文が予期されます"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr ""
@@ -38041,76 +38098,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "ループが完全な入れ子になっていません"
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "唯一の仮引数となる %<void%> には修飾子がつきません"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> は複合文内でのみ使用できます"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
 msgstr "%<operator%> が予期されます"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<using%>"
 msgid "expected %<point%>"
 msgstr "%<using%> が予期されます"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -38126,7 +38183,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> は %D の前に現れなければいけません。無視しています"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -38136,34 +38193,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<try%>"
 msgid "expected %<target%>"
 msgstr "%<try%> が予期されます"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "%<decltype%> が予期されます"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -38221,23 +38278,23 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%<#pragma omp section%> または %<}%> が予期されます"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE は最初に使用した後に %<threadprivate%> と宣言されています"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動変数 %qE は %<threadprivate%> になることは出来ません"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE は不完全型を持っています"
@@ -38253,56 +38310,56 @@
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "vectorlength must be an integer constant"
 msgstr "引数は定数でなければいけません"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "スタックサイズは 2 の累乗でなければいけません"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "case ラベルは整数定数式に出来ません"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "%<#pragma omp%> 句が予期されます"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -38313,7 +38370,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<::%>"
 msgid "expected %<:%> or numeral"
@@ -39051,7 +39108,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "左辺の初期化は format 属性の候補のようです"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "戻り型は format 属性の候補のようです"
@@ -39379,7 +39436,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C は %<goto *expr;%> を禁止しています"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%> と宣言されている関数が %<return%> 文を持っています"
@@ -39389,7 +39446,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -39415,7 +39472,7 @@
 msgid "function returns address of label"
 msgstr "関数が局所変数のアドレスを返します"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch の内容が整数ではありません"
@@ -39430,7 +39487,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case ラベルは整数定数式に出来ません"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "switch 文の外にある case ラベルです"
@@ -39450,17 +39507,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "ループまたは switch 文の外にある break 文です"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "ループの外にある continue 文です"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP のループ用に break 文が使用されています"
@@ -39471,7 +39528,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "ループまたは switch 文の外にある break 文です"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
@@ -39581,12 +39638,12 @@
 msgid "used vector type where scalar is required"
 msgstr "スカラーが必要な場所で構造体型の値が使用されています"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -39597,25 +39654,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%qs 句が多すぎます"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "メンバ関数の名前を欠いています"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -39628,18 +39685,18 @@
 msgstr "%qs 句が多すぎます"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -39646,55 +39703,55 @@
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "セクション属性は `%s' には使えません"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 #| msgid "type to vector delete is neither pointer or array type"
 msgid "%qE does not have pointer or array type"
@@ -39715,7 +39772,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE は %<reduction(%s)%> 用の無効な型を持っています"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -39726,17 +39783,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "可変長配列が使用されています"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE は %<threadprivate%> (%<copyin%> 用として) でなければいけません"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -39756,18 +39813,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -39780,33 +39837,33 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE は %<firstprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE は %<lastprivate%> 句内では変数ではありません"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -39829,61 +39886,61 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE は句 %qs 内では変数ではありません"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -39895,32 +39952,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "ベクトル型の delete ですが、ポインタでも配列型でもありません"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE は %qs (%qs 用) として前もって決められています"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -40497,159 +40554,159 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr ""
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr ""
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr ""
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (-fno-deduce-init-list でこれを無効に出来ます)"
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "一時オブジェクトのアドレスを取ろうとしています"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "constant refers to itself"
 msgid "constructor delegates to itself"
 msgstr "定数が自身を参照しています"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "コンストラクタ %<%T::%D%> を直接呼び出すことは出来ません"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "%<%D(%A)%> の呼び出しに適合する関数がありません"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "オーバーロードされた %<%s(%A)%> の呼び出しは曖昧です"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "デストラクタから値を返そうとしています"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "オブジェクト以外がメンバ関数 %qD を呼び出すことは出来ません"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr ""
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " 候補 1: %q+#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " 候補 2: %q+#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr ""
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -40751,292 +40808,292 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "クラス %qT 内の全てのメンバ関数が非公開です"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T はフレンドが無い非公開デストラクタのみ定義しています"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T はフレンドが無い非公開コンストラクタのみ定義しています"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D はオーバーロードすることが出来ません"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D は隠されています"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "        %qD"
 msgid "  by %qD"
 msgstr "        %qD"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D は無効です。無名共用体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D は無効です。無名構造体は非静的データメンバのみ持つことが出来ます"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "無名共用体内に非公開メンバ %q+#D があります"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous struct"
 msgid "private member %q#D in anonymous struct"
 msgstr "無名構造体内に非公開メンバ %q+#D があります"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous struct"
 msgid "protected member %q#D in anonymous struct"
 msgstr "無名構造体内内に保護されたメンバ %q+#D があります"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "ビットフィールド %q+#D が非整数型です"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "ビットフィールド %q+D の幅が整数定数ではありません"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "ビットフィールド %q+D の幅が負です"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "ビットフィールド %q+D の幅が 0 です"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D の幅が型の大きさを超えています"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D は %q#T の全ての値を持つには小さすぎます"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "コンストラクタを持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "デストラクタを持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "コピー代入演算子を持つメンバ %q+#D は共用体内では許可されていません"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D は共用体のメンバのため静的ではありません"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "コンストラクタが無いクラス内に非静的定数メンバ %q+#D があります"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "フィールド %q+D はが関数型として無効な宣言をされました"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "フィールド %q+D はメソッド型として無効な宣言をされました"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非メンバ `%s' を `mutable' とは宣言できません"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "共用体 %qT 内の複数のフィールドが初期化されました"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "フィールド %q+#D がクラス名と同じです"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T がポインタデータメンバを持っています"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "alignment of %qD is bigger than original declaration"
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "%qD の整列は元の宣言より大きいです"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "非仮想関数 %q+D 用の初期化子が指定されています"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "関数を inline にできません"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基底クラス %q#T が非仮想デストラクタを持っています"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "コンストラクタが無いクラス内に非静的参照 %q+#D があります"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -41044,161 +41101,161 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D は定数参照を取るように宣言されていますが、暗黙的な宣言では非定数参照を取ります"
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "直接の基底 %qT は曖昧なため %qT 内でアクセスできません"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "仮想基底 %qT は曖昧なため %qT 内ではアクセスできません"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D のオフセットは ABI に適合していないため将来のバージョンの GCC では変更になるかもしれません"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "配列 %qE のサイズが大きすぎます"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr ""
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "可変配列メンバの無効な使用法です"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T が再定義されています"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "構造体の最後ではない所に可変配列メンバがあります"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "構造体に可変配列メンバ以外のメンバがありません"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "`%s' は前にここで宣言されました"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T が再定義されています"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T は仮想関数を持っており非仮想デストラクタからアクセス可能です"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q#D does not match any in class %qT"
 msgid "type transparent %q#T does not have any fields"
 msgstr "%q#D 用のプロトタイプがクラス %qT 内のどれとも一致しません"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "メンバ関数の名前を欠いています"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "言語文字列 %<\"%E\"%> は認識できません"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "関数 %qD から型 %q#T への変換が適合しません"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "オーバーロードされた関数 %qD から型 %q#T への変換は曖昧です"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "メンバ %qD へのポインタと見なしています"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "型情報が不十分です"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE を型 %qT から型 %qT へ変換できません"
@@ -41208,12 +41265,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D が宣言されています"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -41244,350 +41301,350 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "関数 `%s' に対して不適切な保存クラス"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr ""
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
 msgstr "非関数 %qD の呼び出しです"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "`%s' はその定義の前にプロトタイプなしで使われました"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr ""
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "右シフト回数が負です"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 #| msgid "array subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "配列の添字が配列境界の外にあります"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not initialized with a constant expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "初期化子を欠いています"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "%<void *%> ポインタの参照を解除しています"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qE は初期化されていません"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D は const ではありません"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D は volatile です"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD は定数式で初期化されませんでした"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr ""
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr ""
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr ""
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F が %<static%> と宣言されましたが定義されていません"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "レジスタ変数 %qD が入れ子になった関数内で使用されています"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "初期化子の要素が定数式ではありません"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "初期化子内に非定数の配列インデックスがあります"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "定数式内でオーバーフローしました"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "ファイル \"%s\" に戻るはずでした"
@@ -42409,7 +42466,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "(`%s' の初期化は不完全です)"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -42424,7 +42481,7 @@
 msgid "%qD is not a type"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -44099,7 +44156,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "仮引数 `%s' が void と宣言されています"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "無効なデフォルトテンプレート引数"
@@ -44555,13 +44612,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr ""
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "前方での `%s' の宣言"
@@ -44571,8 +44628,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
@@ -44622,7 +44679,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "`%s' は前にここで定義されました"
@@ -44688,7 +44745,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
@@ -44704,7 +44761,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "非 void を戻す関数内に return 文がありません"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
@@ -44867,27 +44924,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "ビットフィールドの幅が %qD 非整数型 %qT です"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "無名構造体が名前つき型の中にありません"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "anonumous 名前空間の集合体は static でなければなりません"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "メンバがない無名共用体です"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> の戻り型は %qT でなければいけません"
@@ -44896,67 +44953,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<operator new%> の第一引数はデフォルト引数を持っていてはいけません"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> は第一引数として型 %<size_t%> (%qT) をとります"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, fuzzy, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "`operator delete' の戻り型は `void' でなければなりません"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, fuzzy, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "`operator delete' は第一引数として `void *' 型をとります"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
@@ -44965,47 +45022,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "`%s' が `static' と宣言されましたが未定義です"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "`%s' が使われましたが未定義です"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "仮引数リストからの仮引数名を欠いています"
@@ -45012,12 +45069,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr ""
@@ -45344,19 +45401,19 @@
 msgid "invalid initializer for array member %q#D"
 msgstr ""
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr ""
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 #| msgid "%qD should be initialized"
 msgid "%q#D should be initialized"
 msgstr "%qD は初期化されるべきです"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr ""
@@ -45457,7 +45514,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "クラスタイプ項を欠いています"
@@ -45477,7 +45534,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "メンバへのポインタでの無効な `%s' の使用"
@@ -45676,23 +45733,23 @@
 msgid "because the array element type %qT has variable size"
 msgstr "複合リテラルが可変サイズを持っています"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "%s を参照として宣言できません"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in unary expression"
 msgid "already captured %qD in lambda expression"
 msgstr "単項演算式内で無効な被演算子です"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr ""
@@ -45747,187 +45804,187 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "警告: "
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr ""
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, fuzzy, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "デストラクタを静的メンバ関数とすることはできません"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const %qD is invalid in C++"
 msgid "initializer for %q#D is invalid"
 msgstr "初期化されていない定数 %qD は C++ 内では無効です"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "   ポインタからメンバへの変換で"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "無効な宣言です"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, fuzzy, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr "キャストによる関数の型が適合しません"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "複雑なパラメタをもつ関数は inline にできません"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr ""
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr ""
@@ -46120,126 +46177,126 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr ""
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "`%s' の宣言が矛盾しています"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %D"
 msgstr "%qD は %qD 内では宣言されていません"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 msgid "only here as a friend"
 msgstr "領域 `%s' は関数として宣言されています"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %qD given attribute noinline"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "非インライン (noinline) 属性が与えられたインライン関数 %qD です"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "`%s' 属性の疑似命令が無視されました"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "このスイッチは廃止されました。代わりに -Wextra を使用してください"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr ""
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -46260,7 +46317,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -46285,7 +46342,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr ""
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr ""
@@ -46345,761 +46402,767 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "%s 宣言の後ろのセミコロンを欠いています"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr ""
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, fuzzy, gcc-internal-format
 msgid "invalid template-id"
 msgstr "無効な型: `void &'"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "`restrict' の用法が不適切です"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr ""
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr ""
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr ""
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr ""
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr ""
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "クラスタイプ項を欠いています"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr ""
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr ""
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "integer literal exceeds range of %qT type"
 msgstr "浮動小数定数が %qT の範囲を超えています"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "floating literal exceeds range of %qT type"
 msgstr "浮動小数定数が %qT の範囲を超えています"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant truncated to zero"
 msgid "floating literal truncated to zero"
 msgstr "浮動小数定数が 0 に切り詰められました"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr ""
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr ""
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "expected operator"
 msgid "expected binary operator"
 msgstr "演算子が予期されます"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<...%>"
 msgid "expected ..."
 msgstr "%<...%> が予期されます"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr "初期化子リストは複合式として取り扱われました"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "初期化子リストは複合式として取り扱われました"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in comparison expression"
 msgid "mismatched operator in fold-expression"
 msgstr "比較式内で型不一致です"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "-Wno-strict-prototypes は C++ では受け付けられません"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ はブレースでまとめられた式を禁じます"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr ""
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr ""
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, fuzzy, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "マクロ引数内でディレクトリを使うことはできません"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr ""
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, gcc-internal-format
 msgid "expected id-expression"
 msgstr ""
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr ""
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr ""
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr ""
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "関数 %<__builtin_next_arg%> への引数の数が間違っています"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ は複合リテラルを禁じます"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "braced list index is not allowed with array notation"
 msgstr "-client_name は -dynamiclib と併せて使用できません"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "無効な %qD の使用です"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "非スカラー型"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected expression-list or type-id"
 msgstr "式が予期されます"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, fuzzy, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "配列 new でのサイズは完全な型を持たねばなりません"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "古いスタイルのキャストを使用しています"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "|| と共に使われる && の周りでは括弧をつけることをお勧めします"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 #| msgid "expected template-argument"
 msgid "lambda-expression in template-argument"
 msgstr "テンプレート引数が予期されます"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qD "
 msgstr "読み取り専用変数 %qD の増分です"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "%qD declared here"
 msgid "%q#D declared here"
 msgstr "%qD はここで宣言されています"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C90 は複素数型をサポートしません"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "仮引数 `%s' で指定された記憶クラス"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重複した %<volatile%> です"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 #| msgid "attributes in parameter array declarator ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "仮引数配列宣言内の属性が無視されました"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "ラベル付き文が予期されます"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case ラベル %qE が switch 文の中にありません"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr ""
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, fuzzy, gcc-internal-format
 #| msgid "Discover pure and const functions"
 msgid "compound-statement in constexpr function"
 msgstr "純粋および定数関数を見つける"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr ""
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "式の中の文に不完全型があります"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr ""
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 #| msgid "break statement used with OpenMP for loop"
 msgid "break statement used with Cilk Plus for loop"
 msgstr "OpenMP のループ用に break 文が使用されています"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ は計算型 goto を禁じます"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr ""
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "空の宣言です"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+#| msgid "invalid initializer for member function %qD"
+msgid "invalid initializer for structured binding declaration"
+msgstr "メンバ関数 %qD 用の無効な初期化子です"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> がクラスの外側で使用されています"
@@ -47106,495 +47169,495 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, fuzzy, gcc-internal-format
 #| msgid "%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> は C++0x で意味が変更になります。削除してください"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D は %q#T 内では無効です"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "`%s' は関数でもメンバ関数でもありません -- friend とは宣言できません"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無効なリンク指定です"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "メンバ `%s' に対する無効な初期値"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D は静的宣言の後に非静的宣言が続いています"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, fuzzy, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "前時代的な古いスタイルの基底クラス初期化子です"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "識別子が予期されます"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%> の後に文字列が予期されます"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "二進演算内で無効な被演算子です"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "演算子が予期されます"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid parameter %qs"
 msgid "cv-qualified type parameter"
 msgstr "無効なパラメータ %qs です"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr ""
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr ""
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "マクロ引数リストにあり得ないトークン"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "テンプレート名が予期されます"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "テンプレート引数が予期されます"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr ""
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, gcc-internal-format
 msgid "expected type specifier"
 msgstr "型指定が予期されます"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C は前方仮引数宣言を禁じます"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, gcc-internal-format
 msgid "expected template-id for type"
 msgstr ""
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "型名が予期されます"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣言 %qD が何も宣言していません"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr ""
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%s に `%s' という名前のメンバはありません"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "%<;%> または %<{%> が予期されます"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr ""
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr ""
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T が複数定義されています"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ は enum の %s を禁じます"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD は名前空間名ではありません"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "インライン関数をインライン化できない場合に警告する"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "nested identifier required"
 msgstr "識別子が予期されます"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr ""
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "ここでは %<namespace%> 定義は許可されていません"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "ここでは関数定義は許可されていません"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, fuzzy, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "初期化子リストは非メンバ関数では使えません"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr ""
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "friend 関数 `%s' を初期化できません"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 #| msgid "function template %qD redeclared as a class template"
 msgid "non-function %qD declared as implicit template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr ""
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr ""
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -47603,7 +47666,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無効な宣言子です"
@@ -47610,344 +47673,344 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "宣言子が予期されます"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD は名前空間です"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "ポインタ演算子が予期されます"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr ""
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "重複する `virtual' 指定子"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 #| msgid "expected type-specifier"
 msgid "duplicate virt-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "`%s' の引数として無効な型"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "型指定子が予期されます"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "%<,%> または %<...%> が予期されます"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "\"%s\" はマクロ仮引数リストに現れてはなりません"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, fuzzy, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "メソッドは関数ポインタに変換できません"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr ""
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "strftime フォーマットは引数をフォーマットできません"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ は名前つき戻り値を許可しません"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr ""
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "クラス定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "構造体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "共用体定義の後には %<;%> が予期されます"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "%<{%> または %<:%> が予期されます"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "クラス %s 用のファイルを見つけられません。"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr ""
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD の宣言内に無効なクラス名です"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "関数テンプレート %qD がクラステンプレートとして再定義されました"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T の前の定義"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, gcc-internal-format
 msgid "expected class-key"
 msgstr ""
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr ""
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%> at end of member declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "メンバ宣言の最後には %<;%> が予期されます"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "例外仕様の検査をするコードを生成しない"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "void 式の不適切な使用"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "一つの空の宣言中に、二つの型が指定されています"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "識別子または %<(%> が予期されます"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<:%> または %<...%> が予期されます"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, fuzzy, gcc-internal-format
 #| msgid "unrestricted unions only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "制限のない共用体は -std=c++0x または -std=gnu++0x を指定した時のみ使用できます"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無効な宣言です"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr ""
@@ -47956,506 +48019,506 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "--driver は最早サポートされません"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "乗算命令を有効にする"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr ""
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "`%s' の extern 宣言がネストしています"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "宣言が何も宣言していません"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr ""
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "`>>' はテンプレートクラス名は `> >' とすべきです"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "テンプレート型統一中 `%s' が使用されました"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%> が %qD の前にあります"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ は `long long' を受け入れません"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr ""
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "%qE が重複しています"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "`%s' が重複しています"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "%<new%> が予期されます"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "%<delete%> が予期されます"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "%<return%> が予期されます"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "%<extern%> が予期されます"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%<decltype%> が予期されます"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "%<operator%> が予期されます"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "%<class%> が予期されます"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%<template%> が予期されます"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%<namespace%> が予期されます"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "%<using%> が予期されます"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%<asm%> が予期されます"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%<try%> が予期されます"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "%<catch%> が予期されます"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "%<throw%> が予期されます"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "%<__label__%> が予期されます"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%<@try%> が予期されます"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "%<@synchronized%> が予期されます"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "%<@throw%> が予期されます"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_atomic%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<static_assert%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "%<static_assert%> が予期されます"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "%<::%> が予期されます"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "%<...%> が予期されます"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "%<*%> が予期されます"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "%<~%> が予期されます"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "%<:%> または %<::%> が予期されます"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "%<class%>、%<typename%>、または %<template%> が予期されます"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 #| msgid "previously declared here"
 msgid "%q#T was previously declared here"
 msgstr "前はここで宣言されました"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "`%s' が別のシンボル種として再宣言されました"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "デフォルト引数内でファイルが終了しています"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, fuzzy, gcc-internal-format
 #| msgid "objective-c method declaration is expected"
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c メソッド定義が予期されます"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr ""
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr ""
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "識別子が必要です"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr ""
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, gcc-internal-format
 msgid "invalid type for property"
 msgstr ""
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<wait%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 #| msgid "a function-definition is not allowed here"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "ここでは関数定義は許可されていません"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "レジスタ変数 `%s' が入れ子関数の中で使われました"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不十分な型情報"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "大域 register 変数が関数定義の後ろにあります"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無効な初期化子です"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "式が予期されます"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "参照型に対して new を適用できません"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "メンバ関数の名前を欠いています"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "#pragma GCC java_exceptions の末尾にゴミ"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "演算子に対する無効な制約です"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize は関数内では許可されていません"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "ret 命令は実装されていません"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 #| msgid "expected namespace-name"
 msgid "expected variable-name"
 msgstr "名前空間名が予期されます"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<)%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "%<,%> または %<)%> が予期されます"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
@@ -48548,7 +48611,7 @@
 msgid "candidate is: %#D"
 msgstr "候補: %+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
@@ -49141,123 +49204,139 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr ""
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+#| msgid "the address of %qD will always evaluate as %<true%>"
+msgid "the address of %qD is not a valid template argument"
+msgstr "%qD のアドレスは常に %<true%> と評価されます"
+
+#: cp/pt.c:6634
 #, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6641
+#, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr ""
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr ""
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr ""
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr ""
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr ""
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr ""
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, fuzzy, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "#if 式の中では文字列定数が使えません"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "`restrict' の用法が不適切です"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr ""
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr ""
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "予期しない型が `id' (%s) に指定されました"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr ""
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr ""
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "予期しない型が `id' (%s) に指定されました"
@@ -49264,105 +49343,105 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "型が前方の外部宣言と一致しません"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE から %qT へ変換できません"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments to function %<va_start%>"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "関数 %<va_start%> への引数の数が間違っています"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "クロスコンパイル時の実数値テンプレート仮引数"
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr ""
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr ""
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD は関数テンプレートではありません"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "空の宣言です"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "内部一貫性がありません"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -49381,275 +49460,275 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "sizeof が関数型に適用されました"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "仮引数 `%s' は無効です"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "無効な宣言です"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, fuzzy, gcc-internal-format
 msgid "function returning an array"
 msgstr "関数が集合体を返しています"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, fuzzy, gcc-internal-format
 msgid "function returning a function"
 msgstr "`%s' は関数を返す関数として宣言されています"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "メンバ関数へのポインタが呼ばれましたが、クラススコープ内ではありません"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "不完全型のポインタへの間接参照"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "ポインタを参照として宣言できません"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "参照を参照として宣言できません"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "   ポインタからメンバへの変換で"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "大きさゼロの配列を作ろうとしています"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr ""
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "テンプレート内で `%s' を使用しています"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "static フィールド `%s' を欠いています"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void 式の不適切な使用"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE がここでは宣言されていません (関数内ではない)"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr ""
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT はテンプレート型ではありません"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr ""
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "初期化子の要素が定数ではありません"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "不正な文字列定数です"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr ""
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "%s: `%s' の初期化:\n"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ は減算にメソッドへのポインタを使うことを禁じます"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, fuzzy, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "自動テンプレート実体化を有効にする"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ は減算に関数へのポインタを使うことを禁じます"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
@@ -49661,96 +49740,96 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "インラインテンプレートの明示的な実体化のみを生成する"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "不完全な typedef `%s' の使用は不適切です"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "'#' にマクロ仮引数名が続いていません"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "非テンプレート %qD がテンプレートとして使用されています"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "マクロ引数 \"%s\" は文字列化されます"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "inline に出来ると見なされていない関数です"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無効なメソッド宣言です。メソッド名が必要です"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr ""
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "命令が制約を満たしません:"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -49910,171 +49989,171 @@
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "引数が構造体です"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "`this' は静的メンバ関数から使用できません"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "非メンバ関数での `this' の使用は無効です"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "トップレベルでの `this' の使用は無効です"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%s は型 %s ではありません (引数 %d)"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, fuzzy, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "テンプレート型仮引数には `class' や `typename' 予約語を使わねばなりません"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "無効なデフォルトテンプレート引数"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, fuzzy, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "`%s' の宣言は仮引数リストのシンボルを覆い隠します"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "インスタンス化されない型に対する無効な操作です"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "無効な宣言です"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "無名共用体内に保護されたメンバ %q+#D があります"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr ""
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "use of parameter outside function body"
 msgstr "alloc_size パラメータが範囲外です"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "合っていない引数です"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr ""
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr ""
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, fuzzy, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "要求されたメンバ `%s' は多重継承グラフの中で曖昧です"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "レジスタ '%c' が不明です"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -50081,320 +50160,320 @@
 msgstr "%qT はテンプレート型ではありません"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "仮引数宣言の中の記憶域クラス指定は無効です"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "ISO C++ はメンバ関数への `sizeof' の適用を禁じます"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: オプション `%s' はあいまいです\n"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE は %<reduction%> 用の無効な型を持っています"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "linear step expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "インスタンス変数 `%s' は private と宣言されています"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%qs expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%qs length expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "expression in static assertion is not an integer constant expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "静的アサーション内の式が整数定数式ではありません"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<async%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<device%> id must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qE がデータ句内で二回以上出現しています"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "インスタンス変数 `%s' は %s と宣言されています"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "%qs 句が多すぎます"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 #| msgid "index must be integer"
 msgid "%<grainsize%> expression must be integral"
 msgstr "添え字は整数でなければいけません"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_threads%> 値は正でなければいけません"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> がポインタ型として定義されていません"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "静的アサーションに失敗しました: %E"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr ""
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "<未解決オーバーロードされた関数型>"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "カンマ演算子の左側の式に効力がありません"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -50410,117 +50489,117 @@
 msgid "lambda-expression in a constant expression"
 msgstr "定数式がオーバーフローしました"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE 属性は関数型にのみ適用できます"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "`com_interface' 属性はクラス定義にのみ用いる事ができます"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "要求された init_priority は整数型の定数ではありません"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, fuzzy, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "init_priority 属性はクラス型オブジェクトのファイルスコープ定義でのみ使えます"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "要求された init_priority が範囲外です"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "要求された init_priority は内部で使用するために予約されています"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "init_priority 属性はこのプラットフォームではサポートされていません"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "`%s' の宣言により `this' のメンバが覆い隠されます"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%s: オプション `%s' には引数が必要です\n"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qE attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE 属性の引数が文字列定数ではありません"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> は有効な宣言子ではありません"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 属性は非クラス型に関しては無視されます"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "定義した後に %qT に適用される属性を無視しています"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 属性は関数へのみ適用出来ます。%s へは適用できません"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "`%s' 属性は関数に対してのみ適用されます"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "配列の添字が整数型ではありません"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "Tree 検査: %s があるべき所に %s があります(%s 内, %s:%d)"
@@ -51211,102 +51290,102 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "無効なバージョン番号形式"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr ""
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr ""
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr ""
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr ""
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr ""
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr ""
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr ""
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "戻り値の型が不完全型です"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "format 属性をの候補となりそうな関数について警告する"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "引数 %d 個の `%s' を渡します"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "一時オブジェクトへの参照を返そうとしています"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "非左辺値への参照が返されました"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr "非左辺値への参照が返されました"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr "要求された大域レジスタ変数 `%s' のアドレス"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "デストラクタから値を返そうとしています"
@@ -51313,56 +51392,56 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "コンストラクタの関数 try ブロックのハンドラからは return できません"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "コンストラクタから値を返そうとしています"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "戻り型が関数で、`return' に値がありません"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "初期化子がありません"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "戻り型が void の関数で、`return' に値があります"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -55348,87 +55427,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "`asm' の引数が定数文字列ではありません "
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -55617,12 +55696,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -56402,510 +56481,525 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr ""
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr ""
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "no description yet"
 msgid "$ descriptor at %L"
 msgstr "説明はまだありません"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr ""
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Zero width in format descriptor"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "幅 0 の書式記述子です"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "フォーマット文字列が null です"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "認識できないフォーマット指定子"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "認識できないフォーマット指定子"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "正式な仮引数項を欠いています"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "フォーマット文字列が null です"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr ""
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr ""
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "正式な仮引数項を欠いています"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "無効な指定! cc のバグ."
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "キャストは関数型を指定しています"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "ラベルの宣言 `%s' が重複しています"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr ""
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr ""
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr ""
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr "無効な文字定数が #if にあります"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr ""
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr ""
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr ""
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr ""
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr "-I- が二回指定されました"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "式文が無効です"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr ""
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr ""
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr ""
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr "式文が無効です"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr "正式な仮引数項を欠いています"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr ""
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "メソッド仕様内での構文解析エラー"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr ""
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "-I- が二回指定されました"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ラベル `%s' が使われましたが定義されていません"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "ラベル `%s' が使われましたが定義されていません"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "ラベル `%s' が使われましたが定義されていません"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "ラベル `%s' が使われましたが定義されていません"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr ""
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "式文が無効です"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr ""
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -57805,252 +57899,252 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr ""
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr ""
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "無効な宣言です"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr ""
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "'%s' トークンの所で文法エラー"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "%s への書き込みエラーです"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "ラベル %s があらゆる関数の外側で参照されました"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: 読み込み用にファイル `%s' を開くことができません: %s\n"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: ファイル `%s' に書き込み中にエラー: %s\n"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: ファイル `%s' を削除できません: %s\n"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: 警告: ファイル `%s' を `%s' 名前変更できません: %s\n"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: 副 info ファイル `%s' を削除できません: %s\n"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "シンボルの頭にアンダースコアをつける"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: 読み込み用にファイル `%s' を開くことができません: %s\n"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr ""
@@ -60436,7 +60530,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "spec 関数 %qs の引数内でエラーが発生しました"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -61934,448 +62028,438 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "%qE 属性は %s 属性と競合します"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%s に互換性のない型"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "関数 `%s' への引数が少なすぎます"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "データ領域 '%s' は前の宣言と矛盾します"
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "`%s' に `extern' と初期化子の両方があります"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "ラベル `%s' が定義されましたが使われていません"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -63462,12 +63546,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "環境変数 %qs が定義されていません"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr ""
@@ -65207,10 +65291,6 @@
 #~ msgid "Restrict doloop to the given nesting level"
 #~ msgstr "doloop を与えられた入れ子階層に制限する"
 
-#, fuzzy
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "浮動小数の乗算/加算命令を生成する"
-
 #~ msgid "Compile for a 68HC11"
 #~ msgstr "68HC11 用にコンパイルする"
 
Index: gcc/po/zh_TW.po
===================================================================
--- gcc/po/zh_TW.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/zh_TW.po	(.../branches/gcc-7-branch)
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.8.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2013-06-07 23:29+0800\n"
 "Last-Translator: Wei-Lun Chao <bluebat@member.fsf.org>\n"
 "Language-Team: Chinese (traditional) <zh-l10n@linux.org.tw>\n"
@@ -194,13 +194,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "錯誤地使用了浮點常數"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -563,62 +563,62 @@
 "以 -g、-f、-m、-O、-W 或 --param 開頭的選項將由 %s 自動傳遞給其呼叫的\n"
 " 不同子處理序。若要向這些處理序傳遞其它選項，必須使用 -W<字母> 選項。\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, fuzzy, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "處理 spec (%s)，該項是『%s』\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "目的：%s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "配置為：%s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "執行緒模型：%s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, fuzzy, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc 版本 %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, fuzzy, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "gcc 驅動程式版本 %s %sexecuting gcc 版本 %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "安裝：%s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "程式：%s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "函式庫：%s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -627,16 +627,16 @@
 "\n"
 "報告程式缺陷的步驟請參見：\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, fuzzy, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "(C)"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -645,7 +645,7 @@
 "本程式是自由軟體；請參看來源程式碼的版權宣告。本軟體沒有任何擔保；\n"
 "包括沒有適銷性和某一專用目的下的適用性擔保。\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, fuzzy, c-format
 msgid ""
 "\n"
@@ -658,7 +658,7 @@
 "==============\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, fuzzy, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -667,7 +667,7 @@
 "使用「-Wl，選項」到回合「選項」到鏈結器。\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, fuzzy, c-format
 msgid ""
 "Assembler options\n"
@@ -678,7 +678,7 @@
 "=================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, fuzzy, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -692,18 +692,18 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+#| msgid "  -n, --no-output                 Do not create an output file\n"
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -n, --no-output                 不建立輸出檔案\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 #| msgid "  -v, --version                   Print version number, then exit\n"
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -v, --version                    列印版本號並離開\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -n, --no-output                 不建立輸出檔案\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -719,14 +719,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -754,31 +754,31 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -f, --function                      Print function level info\n"
 msgstr "  -h, --help                      列印此輔助並離開\n"
 
-#: gcov-tool.c:422
+#: gcov-tool.c:421
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr "  -h, --help                      列印此輔助並離開\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:422
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr "  -h, --help                      列印此輔助並離開\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:423
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -o, --object                        Print object level info\n"
 msgstr "  -h, --help                      列印此輔助並離開\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -862,20 +862,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      列印此輔助並離開\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                顯示每個基本區塊的資訊\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      輸出包含分支概率\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, fuzzy, c-format
 #| msgid ""
 #| "  -c, --branch-counts             Given counts of branches taken\n"
@@ -885,16 +880,21 @@
 "                                    rather than percentages\n"
 msgstr "  -c, --branch-counts             給出跳轉的分支數，而不是百分比\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, fuzzy, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          顯示進度資訊\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        輸出每個函式的小結資訊\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      列印此輔助並離開\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1078,82 +1078,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s：圖為「%s」不可解\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "已執行的列數：%s (共 %d 列)\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "沒有可執行列\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s「%s」\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "執行的分支：%s (共有 %d 個)\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "至少執行一次的跳轉：%s(總數為 %d)\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "沒有跳轉\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "執行的呼叫：%s(共 %d)\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "沒有呼叫\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s：「%s」沒有列\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "call   %2d 回傳了 %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "call   %2d 從未被執行\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "branch %2d 被執行 %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "branch %2d 從未被執行\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "unconditional %2d 被執行 %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "無條件 %2d 從未執行\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, fuzzy, c-format
 msgid "Cannot open source file %s\n"
 msgstr "無法開放原始碼檔案 %s\n"
@@ -1266,102 +1266,102 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.c:1242
+#: opts.c:1249
 #, fuzzy
 msgid "[default]"
 msgstr "[預設]"
 
-#: opts.c:1253
+#: opts.c:1260
 #, fuzzy
 msgid "[enabled]"
 msgstr "[已啟用]"
 
-#: opts.c:1253
+#: opts.c:1260
 #, fuzzy
 msgid "[disabled]"
 msgstr "[已停用]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, fuzzy, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " 找不到任何選項與設想的特性是\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, fuzzy, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " 無找到。 使用 --help=%s 到顯示 * 所有 * 選項支援的由 %s 前端\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, fuzzy, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " 所有選項與設想的特性已顯示\n"
 
-#: opts.c:1372
+#: opts.c:1379
 #, fuzzy
 msgid "The following options are target specific"
 msgstr "下列選項是目標特定的"
 
-#: opts.c:1375
+#: opts.c:1382
 #, fuzzy
 msgid "The following options control compiler warning messages"
 msgstr "下列選項控制編譯器警告訊息"
 
-#: opts.c:1378
+#: opts.c:1385
 #, fuzzy
 msgid "The following options control optimizations"
 msgstr "下列選項控制最佳化"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 #, fuzzy
 msgid "The following options are language-independent"
 msgstr "下列選項是 language-independent"
 
-#: opts.c:1384
+#: opts.c:1391
 #, fuzzy
 msgid "The --param option recognizes the following as parameters"
 msgstr "--param 選項 recognizes 下列做為參數"
 
-#: opts.c:1390
+#: opts.c:1397
 #, fuzzy
 msgid "The following options are specific to just the language "
 msgstr "下列選項是特定的到僅語言 "
 
-#: opts.c:1392
+#: opts.c:1399
 #, fuzzy
 msgid "The following options are supported by the language "
 msgstr "下列選項被支援由語言 "
 
-#: opts.c:1403
+#: opts.c:1410
 #, fuzzy
 msgid "The following options are not documented"
 msgstr "下列選項未被文件"
 
-#: opts.c:1405
+#: opts.c:1412
 #, fuzzy
 msgid "The following options take separate arguments"
 msgstr "下列選項需分隔引數"
 
-#: opts.c:1407
+#: opts.c:1414
 #, fuzzy
 msgid "The following options take joined arguments"
 msgstr "下列選項需聯結的引數"
 
-#: opts.c:1418
+#: opts.c:1425
 #, fuzzy
 msgid "The following options are language-related"
 msgstr "下列選項被 language-related"
@@ -2967,8 +2967,8 @@
 msgid "<command-line>"
 msgstr "<command-line>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
@@ -2987,7 +2987,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "缺少運算元"
@@ -3007,8 +3007,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "無效的運算元程式碼「%c」"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, fuzzy, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "『%%&』使用的而無需任何本地動態 TLS 參考"
@@ -3024,18 +3024,18 @@
 msgstr "無效 %%r 值"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "無效 %%R 值"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "無效 %%N 值"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "無效 %%P 值"
@@ -3045,7 +3045,7 @@
 msgid "invalid %%h value"
 msgstr "無效 %%h 值"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "無效 %%L 值"
@@ -3066,7 +3066,7 @@
 msgstr "無效 %%U 值"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "無效 %%s 值"
@@ -3076,7 +3076,7 @@
 msgid "invalid %%C value"
 msgstr "無效 %%C 值"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "無效 %%E 值"
@@ -3087,7 +3087,7 @@
 msgstr "不明的不可預期重定位"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "無效的 %%xn 程式碼"
@@ -3154,7 +3154,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "無效的運算元輸出程式碼"
@@ -3165,29 +3165,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "無效的 UNSPEC 做為運算元"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "無效的 Shift 運算元"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "預測到的 Thumb 指令"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在條件序列中預測到的指令"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3195,110 +3195,110 @@
 msgid "invalid operand for code '%c'"
 msgstr "程式碼「%c」的運算元無效"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "指令永不執行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支援的運算元用於編碼『%c』"
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, fuzzy, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "位址運算元需求條件約束用於 X,- Y, 或 Z 暫存器"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 #, fuzzy
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "運算元到 %T/%t 必須是 reg+constint(_I)："
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 #, fuzzy
 msgid "bad address, not an I/O address:"
 msgstr "不當的位址，不是 I/O 位址："
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "不當的位址，不是常數："
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "位址錯誤，不是(reg+disp)："
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "錯誤的位址，不是 post_inc 或 pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "編譯器內部錯誤。錯誤的位址："
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "編譯器內部錯誤。不明的模式："
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "無效指令："
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "錯誤指令："
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "無效的 move 指令："
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "錯誤的 shift 指令"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "編譯器內部錯誤。不正確的移位量："
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 msgid "unsupported fixed-point conversion"
 msgstr "無效的類型在中定點轉換"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 #, fuzzy
 msgid "variable"
 msgstr "迴圈變數"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "參數 %q+D 重定義"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 msgid "structure field"
 msgstr "結構定義的在此"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 msgid "return type of function"
 msgstr "建立陣列的函式"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 #, fuzzy
 msgid "pointer"
 msgstr "空指標"
@@ -3321,7 +3321,7 @@
 msgstr "無效的 const_double 運算元"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3544,88 +3544,88 @@
 msgid "bad output_condmove_single operand"
 msgstr "錯誤的 output_condmove_single 運算元"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "無效的 UNSPEC 做為運算元"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "組譯輸出 %d 中左值無效"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "無效的運算元類型使用的與運算元編碼『%c』"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "無效的運算元大小用於運算元編碼『%c』"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『D』"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "運算元不是 offsettable 記憶體參考，無效的運算元編碼『H』"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "運算元並非條件編碼，無效的運算元編碼『Y』"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "無效的運算元程式碼「%c」"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "運算元的約束無效"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "不明的指令模式"
 
@@ -3663,7 +3663,7 @@
 msgid "invalid %%P operand"
 msgstr "無效的 %%P 運算元"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "無效的 %%p 值"
@@ -3720,7 +3720,7 @@
 msgstr "後自增位址不是一個暫存器"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "錯誤位址"
 
@@ -3754,7 +3754,7 @@
 msgstr "insn 含有無效的位址！"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "無效位址"
 
@@ -3845,298 +3845,298 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "嘗試在命令解譯器中執行「%s」以提升它的極值。\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 #, fuzzy
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx 需求硬體浮點數"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 #, fuzzy
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx 和 -mpaired 是不相容的"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 #, fuzzy
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx 需要索引的定址"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 #, fuzzy
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx 和 -mno-altivec 是不相容的"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 #, fuzzy
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec 停用 vsx"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--resource 需要 -o"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "產生低位位元組在前的程式碼"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--resource 需要 -o"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 #, fuzzy
 msgid "bad move"
 msgstr "不當的移動"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "無效 %%H 值"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "無效 %%f 值"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "無效 %%F 值"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "無效 %%G 值"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "無效 %%j 程式碼"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "無效 %%J 程式碼"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "無效 %%k 值"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "無效 %%K 值"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "無效 %%O 值"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "無效 %%q 值"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "無效 %%T 值"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "無效 %%u 值"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "無效 %%v 值"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "無效的 %%x 值"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "無效的 %%y 值，嘗試使用『Z』條件約束"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "不為每個函式產生單一的離開點"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "無法產生重新載入，為："
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, fuzzy, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "符號記憶體參考是只有支援的於 z10 或稍後"
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "無法分解位址"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "無效的比較運算子用於『E』輸出修飾鍵"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "無效的參考用於『J』輸出修飾鍵"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "無效的位址用於『O』輸出修飾鍵"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "無效的位址用於『R』輸出修飾鍵"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "記憶體參考預期的用於『S』輸出修飾鍵"
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "無效的位址用於『S』輸出修飾鍵"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "暫存器或記憶體運算式預期的用於『N』輸出修飾鍵"
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "暫存器或記憶體運算式預期的用於『公尺』輸出修飾鍵"
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "無效的常數用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "無效的常數 - 嘗試使用輸出修飾鍵"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "無效的常數用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "無效的運算式 - 嘗試使用輸出修飾鍵"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "無效的運算式用於輸出修飾鍵『%c』"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "傳遞 AltiVec 引數給無原型的函式"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "回傳指標時目的與指標有/無號不一致"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4162,43 +4162,43 @@
 msgid "created and used with different endianness"
 msgstr "建立和使用時使用了不同的高/低位位元組在前設定"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "無效的 %%Y 運算元"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "無效的 %%A 運算元"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "無效的 %%B 運算元"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "無效的 %%C 運算元"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "無效的 %%D 運算元"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "無效的 %%f 運算元"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "無效的 %%s 運算元"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4367,30 +4367,30 @@
 msgid "bad test"
 msgstr "錯誤的測試"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "無效的 %%D 值"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "無效遮罩"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "無效的 %%d 值"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "無效的 %%t/%%b 值"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "位址中無暫存器"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "位址偏移量不是一個常數"
 
@@ -4412,8 +4412,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要 %<;%>"
@@ -4435,14 +4435,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "預期 %<(%>"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "預期 %<,%>"
@@ -4473,7 +4473,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "預期 %<)%>"
@@ -4481,7 +4481,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "預期 %<]%>"
@@ -4492,7 +4492,7 @@
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "預期 %<}%>"
@@ -4499,7 +4499,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要 %<{%>"
@@ -4509,7 +4509,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "預期 %<:%>"
@@ -4524,24 +4524,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "運算式 %qE 具有抽象類別類型 %qT，不能用於 throw 運算式中"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "預期 %<while%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4550,18 +4550,18 @@
 msgid "expected %<.%>"
 msgstr "預期 %<.%>"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "預期 %<@end%>"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "預期 %<>%>"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "預期 %<,%>或 %<)%>"
@@ -4569,17 +4569,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要 %<=%>"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "預期 %<[%>"
@@ -4589,7 +4589,7 @@
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "預期 %<<%>"
@@ -4599,11 +4599,11 @@
 msgid "expected label"
 msgstr "預期的頻道"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "備選 1："
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "備選 2："
 
@@ -4856,11 +4856,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%s:%d：  在中 constexpr 擴展的 %qs"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "備選為："
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 #, fuzzy
 msgid "candidate is:"
 msgid_plural "candidates are:"
@@ -5052,82 +5052,82 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "實際引數到含義=出/INOUT"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "需要正的寬度"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "需要非負的寬度"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 msgid "Unexpected element %qc in format string at %L"
 msgstr "未預期的元件『%c』在中格式字串於 %L"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "非預期的格式字串結尾"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 #, fuzzy
 msgid "Zero width in format descriptor"
 msgstr "零寬度在中格式描述元"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "缺少前導左括號"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 msgid "Left parenthesis required after %<*%>"
 msgstr "左parenthesis 必要項之後『*』"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "需要 P 編譯描述符號"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 #, fuzzy
 msgid "P descriptor requires leading scale factor"
 msgstr "P 描述元需求前導伸縮比值"
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-msgid "Right parenthesis expected at %C"
-msgstr "缺少右括號於 %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 #, fuzzy
 msgid "Comma required after P descriptor"
 msgstr "逗號必要項之後 P 描述元"
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 #, fuzzy
 msgid "Positive width required with T descriptor"
 msgstr "正面的寬度必要項與 T 描述元"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 #, fuzzy
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "E 說明符不允許與 g0 描述元"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "需要正的指數寬度"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+msgid "Right parenthesis expected at %C"
+msgstr "缺少右括號於 %C"
+
+#: fortran/io.c:1040
 #, fuzzy
 msgid "Period required in format specifier"
 msgstr "週期必要項在中格式說明符"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, fuzzy, c-format
 msgid "%s tag"
 msgstr "%s 標籤"
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 #, fuzzy
 msgid "internal unit in WRITE"
 msgstr "內部單位在中寫入"
@@ -5134,7 +5134,7 @@
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, fuzzy, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s 標籤與查詢"
@@ -5144,75 +5144,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "%C 運算式語法錯誤"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "非預期的檔案結束"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "整數溢出"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "名稱太長"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "錯誤的名稱"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "需要名稱"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "需要左圓括號"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "需要右圓括號"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "需要整數"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "需要字串"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum()：找不到列舉"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "需要屬性位名"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "需要整數字串"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "轉換整數時發生錯誤"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "需要實數字串"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "需要運算式類型"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "錯誤的運算子"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "常數運算式中類型錯誤"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "非預期的模組結束"
 
@@ -5495,12 +5495,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "實際的字串長度是短於宣告的一個用於虛引數『%s』(%ld/%ld)"
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目標的分級重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5900,7 +5900,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "不能同時使用 -m32 和 -m64"
 
@@ -9638,7 +9638,7 @@
 msgstr "指定執行緒局部存儲偏移量立即數值的位大小"
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 #, fuzzy
 #| msgid "Schedule code for given CPU"
@@ -9914,7 +9914,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
 msgid "Use LRA instead of reload."
@@ -10215,7 +10215,7 @@
 msgid "Use 80-bit long double."
 msgstr "使用 128 位 long double"
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 #| msgid "Use 64-bit long double"
@@ -10222,7 +10222,7 @@
 msgid "Use 64-bit long double."
 msgstr "使用 64 位元 long double"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy
 #| msgid "Use 128-bit long double"
@@ -11557,111 +11557,111 @@
 msgid "64 bit ABI."
 msgstr "64 位元 ABI"
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 #, fuzzy
 #| msgid "Maintain backchain pointer"
 msgid "Maintain backchain pointer."
 msgstr "維護反鏈指標"
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 #, fuzzy
 #| msgid "Additional debug prints"
 msgid "Additional debug prints."
 msgstr "額外除錯輸出"
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 #, fuzzy
 #| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
 msgstr "ESA/390 結構"
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 msgid "Enable decimal floating point hardware support."
 msgstr "啟用十進位浮點數硬體支援"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 msgid "Enable hardware floating point."
 msgstr "啟用硬體浮點數"
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 msgid "Use hardware transactional execution instructions."
 msgstr "使用硬體浮點數指令"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 #, fuzzy
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 #, fuzzy
 #| msgid "Use packed stack layout"
 msgid "Use packed stack layout."
 msgstr "使用緊實的堆疊版面設置"
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 #, fuzzy
 msgid "Use bras for executable < 64k."
 msgstr "使用 bras 用於可執行檔案<64k"
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 msgid "Disable hardware floating point."
 msgstr "停用硬體浮點數"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 #, fuzzy
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "設定最大位元組數量該項必須是向左到堆疊大小之前陷阱指令被觸發"
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 #, fuzzy
 #| msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit"
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "在函式前言中產生額外程式碼以獲取堆疊大小越限"
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 msgid "Use the mvcle instruction for block moves."
 msgstr "產生字串指令用於區塊移動"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 #, fuzzy
 #| msgid "Warn if a function uses alloca or creates an array with dynamic size"
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "當函式使用 alloca 來建立彈性陣列時給出警告"
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 #, fuzzy
 #| msgid "Warn if a single function's framesize exceeds the given framesize"
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "當單一函式的圖框大小超過給定值時給出警告"
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 #, fuzzy
 #| msgid "z/Architecture"
 msgid "z/Architecture."
 msgstr "z/Architecture"
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 #, fuzzy
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr "設定分支成本用於條件分支指令。 Reasonable 值是小，non-negative 整數。 預設分支成本是 0。"
@@ -11722,12 +11722,12 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr "已知手臂 CPUs (用於使用與 -mcpu=和 -mtune=選項)："
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 #, fuzzy
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr "已知手臂架構 (用於使用與 -march=選項)："
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 #, fuzzy
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr "已知手臂 FPUs (用於使用與 -mfpu=選項)："
@@ -12023,105 +12023,125 @@
 msgstr "使用 UltraSPARC 視覺的指令集版本 1.0 延伸"
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 #, fuzzy
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "使用 UltraSPARC Fused Multiply-Add 延伸"
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 #, fuzzy
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "使用 UltraSPARC Fused Multiply-Add 延伸"
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
 #, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "產生浮點乘加指令"
+
+#: config/sparc/sparc.opt:102
+#, fuzzy
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "使用 UltraSPARC Population-Count 指令"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 #, fuzzy
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "使用 UltraSPARC Population-Count 指令"
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 #| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "指標是 64 位元"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 #| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "指標是 32 位元"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "使用 64 位元 ABI"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "使用 32 位元 ABI"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 #, fuzzy
 #| msgid "Use stack bias"
 msgid "Use stack bias."
 msgstr "使用堆疊偏移"
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 #, fuzzy
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "使用結構於 stronger 對齊用於 double-word 份數"
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 #, fuzzy
 #| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "在組譯器和連結器中最佳化尾呼叫指令"
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "使用指定 CPU 的特性和調度程式碼"
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 #, fuzzy
 #| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
 msgstr "使用給定的 SPARC-V9 程式碼模型"
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "Enable debug output."
 msgstr "啟用除錯輸出"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 #, fuzzy
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "啟用嚴格 32-bit psABI 結構回傳檢查。"
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 #, fuzzy
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr "啟用變通方法用於單一 erratum 的 AT697F 處理器"
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 #, fuzzy
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr "啟用變通方法用於單一 erratum 的 AT697F 處理器"
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
 #, fuzzy
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr "啟用變通方法用於單一 erratum 的 AT697F 處理器"
+
+#: config/sparc/sparc.opt:250
+#, fuzzy
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr "啟用變通方法用於單一 erratum 的 AT697F 處理器"
+
+#: config/sparc/sparc.opt:283
+#, fuzzy
 msgid "Specify the memory model in effect for the program."
 msgstr "指定記憶體式樣在中效果用於程式。"
 
@@ -17721,7 +17741,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -18241,7 +18261,7 @@
 msgstr "預期的布林值型態"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -18583,144 +18603,144 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr "範圍子句必須有陣列、切片、字串、映射，或頻道型態"
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 msgid "invalid comparison of non-ordered type"
 msgstr "無效的比較的 non-ordered 型態"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 #, fuzzy
 msgid "slice can only be compared to nil"
 msgstr "切片只能被比較到零"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 #, fuzzy
 msgid "map can only be compared to nil"
 msgstr "映射只能被比較到零"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 #, fuzzy
 msgid "func can only be compared to nil"
 msgstr "func 只能被比較到零"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 msgid "invalid operation (%s)"
 msgstr "無效的作業 (%s)"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 msgid "invalid comparison of non-comparable type"
 msgstr "無效的比較的 non-comparable 型態"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 msgid "invalid comparison of generated struct"
 msgstr "無效的比較的 non-comparable 結構"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 #, fuzzy
 msgid "invalid comparison of non-comparable struct"
 msgstr "無效的比較的 non-comparable 結構"
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 msgid "invalid comparison of generated array"
 msgstr "無效的比較的 non-comparable 陣列"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 #, fuzzy
 msgid "invalid comparison of non-comparable array"
 msgstr "無效的比較的 non-comparable 陣列"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 #, fuzzy
 msgid "multiple-value function call in single-value context"
 msgstr "多重值函式呼叫在中單一值語境"
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 #, fuzzy
 msgid "need explicit conversion"
 msgstr "需要明確的轉換"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, fuzzy, c-format
 msgid "cannot use type %s as type %s"
 msgstr "無法使用型態 %s 做為型態 %s"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 #, fuzzy
 msgid "different receiver types"
 msgstr "不同的收件者類型"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 #, fuzzy
 msgid "different number of parameters"
 msgstr "不同的參數數量"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 #, fuzzy
 msgid "different parameter types"
 msgstr "不同的參數類型"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 #, fuzzy
 msgid "different varargs"
 msgstr "不同的 varargs"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 #, fuzzy
 msgid "different number of results"
 msgstr "不同的結果數量"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 #, fuzzy
 msgid "different result types"
 msgstr "不同的結果類型"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, fuzzy, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "需要明確的轉換；缺少的方法 %s%s%s"
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "不相容的型態用於方法 %s%s%s"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "不相容的型態用於方法 %s%s%s (%s)"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 #, fuzzy
 msgid "pointer to interface type has no methods"
 msgstr "指標到介面類型沒有任何方法"
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 #, fuzzy
 msgid "type has no methods"
 msgstr "型態沒有任何方法"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, fuzzy, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "模稜兩可的方法 %s%s%s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "缺少方法 %s%s%s"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, fuzzy, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "方法 %s%s%s 需要指標"
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, fuzzy, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "方法 %s%s%s 需要指標"
@@ -18896,7 +18916,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "給函式 %<va_start%> 的參數太少"
@@ -18959,27 +18979,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "無效的記憶體式樣用於 %<__atomic_load%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "無效的記憶體式樣用於 %<__atomic_store%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "non-constant 引數 1 到 __atomic_always_lock_free"
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "non-integer 引數 1 到 __atomic_is_lock_free"
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return 在此目標平臺上不受支援"
@@ -18986,7 +19006,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%Kinvalid 使用的 %<__builtin_va_arg_pack()%>"
@@ -18993,12 +19013,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%Kinvalid 使用的 %<__builtin_va_arg_pack_len()%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> 的第二個引數必須是 1"
@@ -19005,63 +19025,63 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "目的格式不支援無限大浮點數"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "目的格式不支援無限大浮點數"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "在定參數的函式中使用了 %<va_start%>"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "錯誤的引數數量到函式 %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "呼叫 %<__builtin_next_arg%> 時沒有給定引數"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "錯誤的引數數量到函式 %<__builtin_next_arg%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%> 的第二個參數不是最後一個具名參數"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, fuzzy, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "未定義的行為時秒參數的 %<va_start%> 被宣告與 %<register%>貯藏體"
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%Kfirst 引數的 %D 必須是指標，秒整數常數"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%Klast 引數的 %D 不是整數常數介於 0 和 3"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, fuzzy, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kattempt 以釋放 non-heap 物件 %qD"
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, fuzzy, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kattempt 以釋放 non-heap 物件"
@@ -19977,12 +19997,12 @@
 msgstr "%<weakref%> 屬性忽略的因為變數被初始化的"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F 使用過但從未定義"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
@@ -20079,12 +20099,12 @@
 msgid "cannot find '%s'"
 msgstr "找不到「%s」"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "pexinit 失敗(_I)：%m"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, fuzzy, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s：%m"
@@ -20094,7 +20114,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_LTO_WRAPPER 必須是設定"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
@@ -20305,7 +20325,7 @@
 msgid "error writing %qs"
 msgstr "寫入 %qs 時錯誤"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "無法開啟 %s"
@@ -20385,17 +20405,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, fuzzy, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "多重 EH 身分被支援只有與組譯器支援.cfipersonality 指令(_P)"
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "non-delegitimized UNSPEC %s (%d) 找到在中變數位置"
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -20505,12 +20525,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kcall 到 %qs 宣告的與屬性錯誤：%s"
 
-#: expr.c:10811
+#: expr.c:10809
 #, fuzzy, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kcall 到 %qs 宣告的與屬性警告：%s"
@@ -20525,12 +20545,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "影格大小的 %wd 位元組是大於 %wd 位元組"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "無法開啟最後的 insn 傾印檔案 %qs：%m"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "無法關閉最後的 insn 傾印檔案 %qs：%m"
@@ -20545,7 +20565,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由於位元段寬度所限，比較結果永遠為 %d"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, fuzzy, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "假設帶正負號溢位不發生時簡化範圍測試"
@@ -20575,7 +20595,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "假設帶正負號溢位不發生時合併常數周圍比較"
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, fuzzy, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折疊檢查：原來的樹變更的由折疊"
@@ -20585,7 +20605,7 @@
 msgid "total size of local objects too large"
 msgstr "總計大小的區域物件太大"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%> 中不可能的約束"
@@ -20686,62 +20706,68 @@
 msgid "input file %qs is the same as output file"
 msgstr "%qs 不是一個有效的輸出檔案"
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, fuzzy, gcc-internal-format
+#| msgid "output filename specified twice"
+msgid "output filename may not be empty"
+msgstr "輸出檔案名稱指定了兩次"
+
+#: gcc.c:4501
+#, fuzzy, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "-pipe 忽略的因為 -save-temps 指定的"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, fuzzy, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "%<-x %s%>之後最後一筆輸入檔案沒有任何效果"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, fuzzy, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr "無法尋找位置預設鏈結器指令稿 %qs 在中函式庫搜尋路徑"
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, fuzzy, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "切換 %qs 不開始與 %<-%>"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, fuzzy, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr "spec-generated 切換就 %<-%>"
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "無法開啟暫時的回應檔案 %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "無法寫入暫時的回應檔案 %s"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "無法關閉暫時的回應檔案 %s"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, fuzzy, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "spec %qs 無效的"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "spec %qs 有無效的 %<%%0%c%>"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "spec %qs 有無效的 %<%%W%c%>"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "spec %qs 有無效的 %<%%x%c%>"
@@ -20749,228 +20775,228 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, fuzzy, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "spec 失敗：%<%%*%>未被初始化的由胚騰匹配"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, fuzzy, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "spec 失敗：無法辨識的 spec 選項 %qc"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "不明 spec 函式 %qs"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "在中引數到 spec 函式 %qs 時發生錯誤"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "spec 函式名格式錯誤"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "spec 函式沒有引數"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "spec 函式引數格式錯誤"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, fuzzy, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "braced spec %qs 無效於 %qc"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, fuzzy, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "braced spec 內文 %qs 無效"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s：無法決定長度的 compare-debug 檔案 %s"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr "%s：-fcompare-debug 失敗 (長度)"
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s：無法開啟 compare-debug 檔案 %s"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "%s：-fcompare-debug 失敗"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "spec 失敗：SYSROOT_SUFFIX_SPEC 參數多於一個"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "spec 失敗：SYSROOT_HEADERS_SUFFIX_SPEC 參數多於一個"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "無法辨識的命令列選項 %<-fdump-%s%>"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "無法辨識的命令列選項 %<-fdump-%s%>"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, fuzzy, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "無法已組配與 sysroot 頁首字尾"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "沒有輸入檔案"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, fuzzy, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "無法指定 -o 與 -c, -S 或 -E 與多重檔案"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s：此系統未安裝 %s 編譯器"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, fuzzy, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "重新編譯與 -fcompare-debug"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, fuzzy, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr "在的期間 -fcompare-debug recompilation"
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, fuzzy, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr "比較最後的 insns 傾印"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "-fuse-linker-plugin，找不到但是 %s "
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s：未使用連結器輸入檔案，因為連結尚未完成"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "語言 %s 未能被識別"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "multilib spec %qs 無效"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "multilib 互斥 %qs 無效"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "multilib 選取 %qs 無效"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "multilib 選取 %qs 無效"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "multilib 互斥 %qs 無效"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, fuzzy, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "環境變數 %qs 無法定義"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, fuzzy, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "無效的版本編號 %qs"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "%%：version-compare 的引數太少"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "%%：version-compare 的引數太多"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, fuzzy, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "不明運算子 %qs 在中 %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "太多引數到 %%:compare-debug-dump-opt"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "太多引數到 %%:compare-debug-self-opt"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "太少引數到 %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "太多引數到 %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr "引數到 %%:compare-debug-auxbase-opt 不結束在中.gk"
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "給予函式的引數太少"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "錯誤的引數數量到 %<__builtin_complex%>"
@@ -21119,9 +21145,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "宣告的在此"
@@ -21538,229 +21564,229 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, fuzzy, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "使用結果的函式回傳 %<void%>"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "組譯輸出 %d 中左值無效"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "non-memory 輸入 %d 必須保持在中記憶體"
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "記憶體輸入 %d 不可直接定址"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "threadprivate 變數 %qE 已用於 untied 任務"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "封閉任務"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "threadprivate 變數 %qE 已用於 untied 任務"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, fuzzy, gcc-internal-format
 msgid "enclosing task"
 msgstr "封閉任務"
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "封閉任務"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE 尚未指定在中封閉平行"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE undeclared (先使用在中這個函式)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "變數 %q+D 宣告為 %<inline%>"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "迭代變數 %qE 應該是私人的"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "迭代變數 %qE 不應為 firstprivate"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "迭代變數 %qE 不應為消除"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "迭代變數 %qE 不應為 firstprivate"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "迭代變數 %qE 應該是私人的"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, fuzzy, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 變數 %qE 是私人的在中外語境"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD 範本宣告無效"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "已排序的區域必須是接近巢狀的內部迴圈區域與已排序的子句"
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, fuzzy, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "結果數量不匹配值數量"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "預期 %<}%>之前 %<else%>expected %<}%> before %<else%>預期 %<}%>之前 %<else%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失敗"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "透過 %<...%> 傳遞時 %qT 被提升為 %qT"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您應該向 %<va_arg%> 傳遞 %qT 而不是 %qT)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果執行到這段程式碼，程式將中止"
@@ -22000,7 +22026,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
 #: ipa-devirt.c:1235
@@ -22101,7 +22127,7 @@
 
 #: ipa-devirt.c:1576
 #, fuzzy, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
 #: ipa-devirt.c:1599
@@ -22487,198 +22513,198 @@
 msgid "multiple loop axes specified for routine"
 msgstr "為類型名指定了存儲類別"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, fuzzy, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr "已排序的區域可能無法是接近巢狀的內部的重要或明確的任務區域"
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr ""
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments"
 msgstr "無效的 PHI 引數"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, fuzzy, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "障礙區域可能無法是接近巢狀的內部的 work-sharing、重要、已排序的，主或明確的任務區域"
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, fuzzy, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "work-sharing 區域可能無法是接近巢狀的內部的 work-sharing、重要、已排序的，主或明確的任務區域"
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, fuzzy, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr "主區域可能無法是接近巢狀的內部的 work-sharing 或明確的任務區域"
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr "已排序的區域必須是接近巢狀的內部迴圈區域與已排序的子句"
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr "已排序的區域必須是接近巢狀的內部迴圈區域與已排序的子句"
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr "已排序的區域可能無法是接近巢狀的內部的重要或明確的任務區域"
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr "已排序的區域必須是接近巢狀的內部迴圈區域與已排序的子句"
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, fuzzy, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr "重要區域可能無法被巢狀內部重要區域與同名"
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "無效的離開從 OpenMP 結構化訊息塊"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "無效的條目到 OpenMP 結構化訊息塊"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "無效的分支到/從 OpenMP 結構化訊息塊"
@@ -22765,7 +22791,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "此配置不支援命令列選項 %qs"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "缺少引數到 %qs"
@@ -22922,132 +22948,142 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
 #, fuzzy, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "transactional 記憶體未被支援與 non-call 異常"
+
+#: opts.c:1015
+#, fuzzy, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "transactional 記憶體未被支援與 non-call 異常"
+
+#: opts.c:1417
+#, fuzzy, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr "無法辨識的 include_flags 0x%x 傳遞到 print_specific_help"
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "無法辨識的引數到 --help=選項：%q.*s"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "無法辨識的引數到 --help=選項：%q.*s"
 
-#: opts.c:1828
+#: opts.c:1835
 #, fuzzy, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "--help 引數 %q.*s 是模稜兩可的，請是更多特定的"
 
-#: opts.c:1837
+#: opts.c:1844
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "無法辨識的引數到 --help=選項：%q.*s"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr "LTO 支援未被已啟用在中這個組態"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "結構的對齊必須是 2 的較小次方，而不是 %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "不明堆疊檢查參數「%s」"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "dwarf 版本 %d 未被支援"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s：--param 引數的形式應該為「名稱=值」"
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "無效的 --param 值 %qs"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs"
 msgstr "無效的 --param 值 %qs"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "無效的 --param 值 %qs"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "目的系統不支援除錯輸出"
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "除錯格式「%s」與先前的選擇衝突"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "無法辨識的除錯輸出層級「%s」"
 
-#: opts.c:2533
+#: opts.c:2540
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "除錯輸出層級 %s 太高"
 
-#: opts.c:2553
+#: opts.c:2560
 #, fuzzy, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "提取記憶體檔案大小最大值限制：%m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, fuzzy, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "設定記憶體檔案大小限制到最大值：%m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "無法辨識的 gcc 除錯選項：%c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s：沒有選項 -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -23397,7 +23433,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "暫存器的 %qD 用於多重全域暫存器變數"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "衝突與 %qD"
@@ -24000,12 +24036,12 @@
 msgid "error closing %s: %m"
 msgstr "關閉 %s 時發生錯誤：%m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr "%qs 是不相容的與 %qs"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -24918,47 +24954,47 @@
 msgid "in expansion of macro %qs"
 msgstr "%s:%d：  在中 constexpr 擴展的 %qs"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i 有多重 EH 邊緣"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr "BB %i 無法丟擲但是有 EH 邊緣"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "BB %i 最後一筆敘述有不正確設定 lp"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "BB %i 缺少 EH 邊緣"
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "不正確 EH 邊緣 %i->%i"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "BB %i 缺少邊緣"
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "BB %i 太多 fallthru 邊緣"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "BB %i 有不正確邊緣"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "BB %i 有不正確 fallthru 邊緣"
@@ -25060,33 +25096,33 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "無效的引數到內建函式"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "內聯函式 %q+D 宣告的 weak"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, fuzzy, gcc-internal-format
 #| msgid "cannot optimize loop, the loop counter may overflow"
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "無法最佳化循環，循環變數可能溢出"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr "%qE 上的運算結果可能是未定義的"
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "within this loop"
@@ -25441,11 +25477,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -26420,7 +26456,7 @@
 msgid "type was previously declared %qE"
 msgstr "型態是在之前宣告 %qE"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -26697,7 +26733,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "位址的 %qD 將一律評估做為 %<true%>"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建議在做為真值的賦值敘述前後加上括號"
@@ -27320,62 +27356,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "格式字串引數 %d 有多餘的類型限定"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%>預期引數的型態 %<%s%s%>，但是引數 %d 有型態 %qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s %<%s%.*s%>預期匹配 %<%s%s%>引數"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "%s %<%s%.*s%>預期引數的型態 %<%T%s%>，但是引數 %d 有型態 %qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%s %<%s%.*s%>預期匹配 %<%T%s%>引數"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> 未被定義為一個類型"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> 未被定義為 %<long%> 或 %<long long%>"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> 未被定義為一個類型"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> 未被定義為一個類型"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> 未被定義為一個類型"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> 未被定義為一個指標類型"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "待格式化的引數不是 %<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime 格式字串無法格式化引數"
@@ -27476,7 +27512,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "重複 %<@%>之前 Objective-C 字串"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, fuzzy, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "不受支援的 non-standard 串接的字串實字"
@@ -27506,7 +27542,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "無效的型態用於迭代變數 %qE"
@@ -27521,22 +27557,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE 未被初始化的"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制述詞"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "無效的控制述詞"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少遞增運算式"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "無效的遞增運算式"
@@ -28085,8 +28121,8 @@
 msgid "wrong type argument to %s"
 msgstr "錯誤的型態引數到 %s"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常數運算式溢出"
@@ -28763,7 +28799,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<_Cilk_spawn%> may only be used inside a function"
@@ -28926,7 +28962,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "不明的 -mdebug-%s 開關"
@@ -29249,7 +29285,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "引數必須是常數"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -29330,7 +29366,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "不當的值 %qs 用於 -mtune 切換"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "切換 -mcpu=%s 衝突與 -march=%s 切換"
@@ -29418,9 +29454,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "%s「%s」%s 無效"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "屬性 %qE 引數不是字串"
@@ -29506,7 +29542,7 @@
 msgstr "-mmemory-latency 開關的值 %qs 錯誤"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -29688,235 +29724,235 @@
 msgid "insn addresses not freed"
 msgstr "不當的位址，無法暫存器："
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections 在此目標平臺上不受支援"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "選擇子必須是立即數值"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "遮罩必須是一個立即數值"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE 屬性引數應該被介於 0 到 255"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, fuzzy, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-mvsx 和 -mpaired 是不相容的"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "目標 CPU 不支援手臂模式"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, fuzzy, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "啟用返回支援是只有有意義的時編譯用於姆指"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, fuzzy, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "啟用被呼叫端交互作用支援是只有有意義的時編譯用於姆指"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g 與 -mno-apcs-frame 並用可能不能給出有意義的除錯資訊"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, fuzzy, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "無法使用 -mtp=cp15 與 16-bit 姆指"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC 是不相容的與姆指"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "目的 CPU 不支援 THUMB 指令"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "目標 CPU 不支援 unaligned 存取"
@@ -29923,144 +29959,144 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mpcrel -fPIC 不是目前支援的於已選 cpu"
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "目的 CPU 不支援交互工作"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check 和 -mno-apcs-frame 互不相容"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic 和 -mapcs-reent 互不相容"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "不支援 APCS 重入程式碼。已忽略"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable 與 -msdata=%s 互不相容"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, fuzzy, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt 需求 AAPCS 相容 ABI 用於適當作業"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi 需要相應 CPU 的支援"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS 不支援 -mcaller-super-interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS 不支援 -mcallee-super-interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, fuzzy, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 以及沒有 ldrh"
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "結構大小邊界只能是設定為 8, 32 或 64"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "結構大小邊界只能是設定為 8 或 32"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, fuzzy, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "RTP PIC 是不相容的與 -msingle-pic-base"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= 不與 -fpic 並用時不起作用"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "「%s」不能做為 PIC 暫存器"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, fuzzy, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition 不支援於這個架構"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "目的 CPU 不支援 THUMB 指令"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, fuzzy, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "non-AAPCS 衍生的 PCS 變體"
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, fuzzy, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "variadic 函式必須使用基底 AAPCS 變體"
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, fuzzy, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS 變體"
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, fuzzy, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 hard-float VFP ABI"
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -30068,74 +30104,79 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE 屬性只有套用到函式"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE 屬性只有套用到函式，無法 %s"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD 必須不有可變個數引數數量"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE 屬性只有套用到函式，無法 %s"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE 屬性沒有任何效果於單位本地函式"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE 屬性只有套用到函數型式"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, fuzzy, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "無法計算真實位置的重疊參數"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "非預期的模組結束"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高暫存器彈堆疊時沒有可用的低暫存器"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, fuzzy, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr "無效的向量型態用於屬性 %qs"
@@ -30143,13 +30184,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "屬性 (目標 (「%s」)) 為未知"
@@ -30244,166 +30285,177 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr "函式屬性 %qs 和 %qs 沒有任何效果於 %qs 函式"
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qs 函式無法有引數"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "%qs 函式無法回傳值"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, fuzzy, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs 似乎是 misspelled %s 處理常式"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
+#, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
 #, fuzzy, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "『builtin_return_address』含有只有 2 位元組的位址"
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, fuzzy, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "指標偏移從符號也許不正確"
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, fuzzy, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "存取資料記憶體與程式記憶體位址"
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, fuzzy, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "存取程式記憶體與資料記憶體位址"
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "固定的暫存器 %s 用來回合參數到函式"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, fuzzy, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "寫入位址空間 %qs 不支援"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE 屬性只有套用到變數和函式"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%qE 屬性未被支援用於 R8C 目標"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE 屬性只有套用到變數"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE 屬性允許只有整數常數引數"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr "%qE 屬性沒有任何效果"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE 屬性只有套用到變數"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, fuzzy, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "程式碼模式 %qs 在 %s 位模式下不受支援"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "指標目標位址空間 %qs 必須是常數在中 %qT"
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "指標目標位址空間 %qs 必須是常數在中 %s %q+D"
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "變數 %q+D 必須是常數以便是置放進入唯讀區段依靠 %qs"
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "static IO declaration for %q+D needs an address"
 msgstr "%q+D 的宣告隱藏了一個參數"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "IO definition for %q+D needs an address"
 msgstr "%q+D 的上一個定義在此"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "只有未初始化的變數才能放在 .noinit 區段中"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, fuzzy, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "uninitialized 變數 %q+D 置放進入程式記憶儲存區"
+
+#: config/avr/avr.c:10160
+#, fuzzy, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "uninitialized 變數 %q+D 置放進入程式記憶儲存區"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU %qs 只支援組譯器"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "從 %s 轉換到 %s，位於 %L"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "%s 預期編譯時期整數常數"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%s 預期編譯時期長整數常數做為先引數"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -30688,12 +30740,12 @@
 msgid "invalid IACC argument"
 msgstr "無效的 IACC 引數"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs 需要一個常數引數"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "常數引數超過 %qs 的範圍"
@@ -30875,7 +30927,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "編碼式樣 %qs 不支援在中 x32 模式"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "編碼式樣 %s 不支援 PIC 模式"
@@ -31008,289 +31060,289 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-mpreferred-stack-boundary 未被支援用於這個目標"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 未被介於 %d 和 %d"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 未被介於 %d 和 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, fuzzy, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, fuzzy, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparm%s 使用的而無需 SSE 已啟用"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已停用，使用 387 指令"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已停用，使用 SSE 指令"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, fuzzy, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, fuzzy, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆疊試探需求 %saccumulate-outgoing-args%s 用於 correctness"
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, fuzzy, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry isn%'t 支援的用於 32-bit 在中組合與 -fpic"
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, fuzzy, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry isn%'t 相容與 SEH"
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "不明選項用於 -mrecip=%s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "選項 (「%s」) 已經指定的"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "2 位元組 cop 指令未被允許在中 64-bit VLIW 模式"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 屬性互不相容"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "regparam 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE 屬性需求整數常數引數"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "引數到 %qE 屬性大於 %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 屬性互不相容"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 屬性互不相容"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 屬性互不相容"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 屬性不是相容"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE 屬性被用於無 class-method"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, fuzzy, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "呼叫 %qT 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "不支援 multilib"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue 不是相容與巢狀的函式"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, fuzzy, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "AVX 向量引數而無需 AVX 已啟用變更 ABI"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻出現了 SSE 向量引數，這變更了 ABI"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "沒有啟用 SSE，卻有 SSE 向量回傳值，這變更了 ABI"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX，卻出現了 MMX 向量引數，這變更了 ABI"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "沒有啟用 MMX卻回傳 MMX 向量，這變更了 ABI"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與 flexible 陣列成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI 的傳遞聯合與長雙倍已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中回傳"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已停用 SSE 卻在 SSE 暫存器中傳遞參數"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, fuzzy, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 暫存器回傳與 x87 已停用"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "呼叫 %qD 與屬性 sseregparm 而無需 SSE/SSE2 已啟用"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 屬性 isn%'t 相容與 -mfentry 用於 32-bit"
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支援 fastcall 與巢狀的函式"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack 不支援 2 暫存器  參數用於巢狀的函式"
@@ -31297,303 +31349,303 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack 不支援 3 暫存器參數"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "擴充的暫存器不支援的運算元大小"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "擴充的暫存器沒有高半部分"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "擴充的暫存器不支援的運算元大小"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "non-integer 運算元使用的與運算元編碼『%c』"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "不支援堆疊限制運算式"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "%q+D 的前一個宣告"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs 的引數必須是一個 2 位無號原文"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "-ffpe-trap 的參數無效：%s"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最後一筆引數必須是 2-bit 即時"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "fifth 引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "第三引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最後一筆引數必須是 1-bit 即時"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "下一個到最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "引數必須是常數"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "錯誤指令："
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "對樹結區段的共享不正確"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最後一筆引數必須是 4-bit 即時"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最後一筆引數必須是 5-bit 即時"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最後一筆引數必須是 32-bit 即時"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, fuzzy, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE 需要不明 isa 選項"
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, fuzzy, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE 需要 isa 選項 %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最後一筆引數必須是即時"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "最後一筆引數必須是尺度 1,- 2,- 4, 8"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "錯誤指令："
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最後一筆引數必須是 8-bit 即時"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE 屬性只有可見於 32-bit"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "引數到 %qE 屬性是 neither 零，nor 一個"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, fuzzy, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 屬性不是相容"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE 不相容的屬性忽略"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, fuzzy, gcc-internal-format
 #| msgid "dereferenced pointers should have a name or a type tag"
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr "提領的指標應具有一個名稱或類型標記"
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, fuzzy, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr "插斷服務常式無法編碼的在中姆指模式"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "By-value 引數於 %L 未被允許在中這個語境"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "不明 IRA 演算法 %qs"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "無效的型態用於製作函式"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "不支援的組合：%s"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "不受支援的引數類型到內建函式"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -31716,7 +31768,7 @@
 msgid "argument %qd is not a constant"
 msgstr "引數 %qd 不是一個常數"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS，空指標"
@@ -31726,7 +31778,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND：不明的標點「%c」"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND 空指標"
@@ -31827,7 +31879,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interruptthread 是可用只有於 fido(_T)"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支援堆疊限制運算式"
@@ -32333,8 +32385,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, fuzzy, gcc-internal-format
 msgid "bad builtin code"
 msgstr "不當的內建編碼"
@@ -32596,29 +32648,29 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "%qE 屬性在類型上被忽略"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ 屬性不允許用於自動存儲類別"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -32643,7 +32695,7 @@
 msgid "-g option disabled"
 msgstr "-g 選項已被停用"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "對齊 (%u) 用於 %s 超出最大值對齊用於全域共同資料。 使用 %u"
@@ -32778,159 +32830,159 @@
 msgid "junk at end of #pragma longcall"
 msgstr "#pragma longcall 末尾有無用字元"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, fuzzy, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vecextract 只有接受 2 引數(_E)"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, fuzzy, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vecinsert 只有接受 3 引數(_I)"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, fuzzy, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vecinsert 只有接受 3 引數(_I)"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, fuzzy, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vecinsert 只有接受 3 引數(_I)"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s 只有接受 %d 引數"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s 只有接受 1 引數"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s 只有接受 2 引數"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, fuzzy, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vecextract 只有接受 2 引數(_E)"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, fuzzy, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vecinsert 只有接受 3 引數(_I)"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "傳遞參數 %d (屬於 %qE)時丟棄了指標目的類型的類型限定"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "ifunc 未被支援在中這個組態"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "對 AltiVec 內建函式來說無效的參陣列合"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, fuzzy, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr "-mrecip 需求 -ffinite-math 或 -ffast-math"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, fuzzy, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr "-mrecip 需求 -fno-trapping-math 或 -ffast-math"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, fuzzy, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr "-mrecip 需求 -freciprocal-math 或 -ffast-math"
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 需要 PowerPC64 架構，正在啟用"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 在 64 位元 Darwin 下不受支援；它與已安裝的 C 和 C++ 函式庫不相容"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, fuzzy, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr "無法已組配用於 SPE ABI"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr "不使用 PowerPC 指令集"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "目標屬性或 pragma 變更 SPE ABI"
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec 不支援在中這個目標"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, fuzzy, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "SPE 不支援在中這個目標"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple 在低位位元組在前的系統上不受支援"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring 在低位位元組在前的系統上不受支援"
@@ -32937,72 +32989,72 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, fuzzy, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "-mcmodel 不相容的與其他光碟內容表選項"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mdirect-move requires -mvsx"
 msgstr "--resource 需要 -o"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-vector requires -mvsx"
 msgstr "--resource 需要 -o"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode requires -mvsx"
 msgstr "--resource 需要 -o"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, fuzzy, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "-msingle-float 選項 equivalent 到 -mhard-float"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "--resource 需要 -o"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "--resource 需要 -o"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -33011,523 +33063,528 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "目標屬性或 pragma 變更長兩倍大小"
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr "不明 vectorization 函式庫 ABI 型態 (%s) 用於 -mveclibabi=切換"
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "目標屬性或 pragma 變更 AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "目標屬性或 pragma 變更 darwin64 ABI"
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "目標屬性或 pragma 變更單精確度浮點數"
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, fuzzy, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "目標屬性或 pragma 變更雙倍精度浮點數"
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs 並非有效選項到前置處理器"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 回傳向量參照：非標準的 ABI 擴充，不保證相容性"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量暫存器中回傳值，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI 用於傳遞參數與 %d-byte 對齊已變更在中 GCC 4.6"
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量暫存器中傳遞參數，因為 altivec 指令集已被停用，使用 -maltivec 啟用"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI 的傳遞結構與複雜浮點數成員已變更在中 GCC 4.4"
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 傳遞向量參照：非標準的 ABI 擴充，不保證相容性"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "內部錯誤：內建函式 %s 已經處理"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "引數 1 必須是一個 5 位有號字面值"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "__builtin_altivec_predicate 的第一個引數必須是常數"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "__builtin_altivec_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s 被忽略在中 64 位元模式"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr "%s 只有接受 1 引數"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr "%qs 是無效的引數到 -mcpu="
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "%qs 是無效的引數到 -mcpu="
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "引數 3 必須是一個 4 位無號字面值"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "引數 3 必須是 2-bit 無正負號實字"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "引數 1 必須是映射"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "引數 3 必須是 1-bit 無正負號實字"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "引數 2 必須是一個 5 位無號字面值"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "數字必須是 0 或 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "引數 %d 的 %qE 必須是在中範圍 %d...%d"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs 的引數必須是一個 2 位無號原文"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, fuzzy, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "無法解析的過載用於 Altivec 內建 %qF"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "dss 的引數必須是一個 2 位無號原文"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, fuzzy, gcc-internal-format
 #| msgid "second argument to %<__builtin_expect%> must be a constant"
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr "%<__builtin_expect%> 的第二個引數必須是一個常數"
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "%<__builtin_prefetch%> 的第三個引數必須是一個常數"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "引數 1 的 __builtin_paired_predicate 必須是常數"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "引數 1 的 __builtin_paired_predicate 是超出範圍"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "__builtin_spe_predicate 的第一個引數必須是常數"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "__builtin_spe_predicate 的第 1 個引數越界"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "內建函式 %s 是只有有效用於儲存格處理器"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "內建函式 %s 需求 -mvsx 選項"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "內建函式 %s 需求 -maltivec 選項"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "內建函式 %s 需求 -mspe 選項"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "內建函式 %s 需求 -mspe 選項"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "內建函式 %s 需求 -mspe 選項"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "內建函式 %s 需求 -mspe 選項"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "內建函式 %s 需求 -maltivec 選項"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "內建函式 %s 需求 -mpaired 選項"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "內建函式 %s 需求 -maltivec 選項"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "內建函式 %s 未被支援與目前的選項"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "內部錯誤：內建函式 %s 有未預期的傳回類型 %s"
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "內部錯誤：內建函式 %s，引數 %d 已未預期的引數類型 %s"
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "堆疊框架太大"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr "-fsplit-stack 不支援 3 暫存器參數"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "# pragma GCC 目標未被支援用於這個機器"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支援取樣 64 位元程式碼"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, fuzzy, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "您無法需位址的巢狀的函式如果您使用 -mno-pointers-to-nested-functions 選項。"
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<long double%> 無效"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用布林類型無效"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 類型中使用 %<complex%> 無效"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, fuzzy, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "使用的十進位浮點數類型在中 AltiVec 類型無效"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, fuzzy, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "使用的 %<long%> 在中 AltiVec 類型無效用於 64-bit 編碼而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "在 AltiVec 類型中使用 %<long%> 已過時；請改用 %<int%>"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, fuzzy, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "使用的 %<long long%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, fuzzy, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "使用的 %<double%> 在中 AltiVec 類型無效而無需 -mvsx"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "emitting microcode insn %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "emitting 條件 microcode insn %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "無效的 cpu「%s」用於 %s「%s」%s"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s「%s」%s 未被允許"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "%s「%s」%s 無效"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -33714,6 +33771,7 @@
 msgstr "-mas100-syntax 是不相容的與 -gdwarf"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 需要 PowerPC64 CPU"
@@ -33805,7 +33863,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -33832,7 +33890,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -33853,7 +33911,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -33867,162 +33925,162 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "常數引數超過 %qs 的範圍"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "<unresolved overloaded function type>"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "不當的內建 icode"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "無效的引數到內建函式"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部變數大小總和超過架構極值。"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "影格大小的函式 %qs 是 %wd 位元組超出使用者提供的堆疊限制的 %d 位元組。 unconditional 陷阱被已加入。"
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "影格大小的函式 %qs 是 %wd 位元組該項是超過半堆疊大小。動態檢查會無法是 reliable。沒有檢查發出用於這個函式。"
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "影格大小的 %qs 是 %wd 位元組"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs 使用動態堆疊指派"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr "%<mwords-little-endian%> 被不宜用而將被  移除的在中未來釋出"
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr "%<mwords-little-endian%> 被不宜用而將被  移除的在中未來釋出"
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture 模式在 %s 上不受支援"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支援"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "硬體十進位浮點數指令無法使用於 %s"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "硬體十進位浮點數指令無法使用在中 ESA/390 模式"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, fuzzy, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp can%'t 被已用於接合與 -msoft-float"
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支援"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "堆疊大小必須大於堆疊防護值"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "堆疊大小不能大於 64K"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard 意味著使用 -mstack-size"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "引數到 %qs 應該是 non-negative 整數"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "引數到 %qE 屬性大於 %d"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "%<__int128%>未被支援由這個目標"
@@ -34079,27 +34137,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax 是只有支援的用於 RTP PIC"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s 不為這個配置所支援"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 不允許與 -m64 一起使用"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "-mcmodel= 值(%s)不正確"
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "32 位元系統不支援 -mcmodel="
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "-fcall-saved-REG 未被支援用於出暫存器"
@@ -34385,22 +34444,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "無效的常數在中 %<# pragma pack%>- 忽略"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "浮點選項需要布林暫存器"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "CONST16 指令不支援 -f%s"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "需要 PIC，但 CONST16 指令不支援"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "只有未初始化的變數才能放在 .bss 區段中"
@@ -34488,7 +34547,7 @@
 msgid "could not read the BRIG file"
 msgstr "無法寫入回應檔案 %s"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -34897,9 +34956,9 @@
 msgstr "標貼 %qD 定義的在此"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD 宣告的在此"
@@ -35032,7 +35091,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不允許在中不同於函式原型範圍"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -36087,7 +36146,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "宣告指定了兩個以上的資料類型"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> 對 GCC 來說太長了"
@@ -36231,17 +36290,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支援單獨用 %<complex%> 表示 %<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支援複整數"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -36294,7 +36353,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "預期的列尾"
@@ -36335,7 +36394,7 @@
 msgstr "不明型態名稱 %qE"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定宣告"
@@ -36350,7 +36409,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "預期 %<;%>，識別碼或 %<(%>"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "前綴屬性被忽略用於方法"
@@ -36365,8 +36424,8 @@
 msgid "unexpected attribute"
 msgstr "未預期的屬性"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -36408,7 +36467,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用於變數或函式宣告"
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要 %<,%> 或 %<;%>"
@@ -36436,7 +36495,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支援 %<_Static_assert%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字串"
@@ -36502,14 +36561,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要識別碼"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "列舉表以逗號結尾"
@@ -36644,7 +36703,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "預期 %<}%>之前 %<else%>expected %<}%> before %<else%>預期 %<}%>之前 %<else%>"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, fuzzy, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> 而無需前一個 %<if%>"
@@ -36669,12 +36728,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr "標貼只能是部分的敘述和宣告並非敘述"
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -36688,17 +36747,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "需要敘述"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建議大括號周圍清空內文在中 %<if%> 敘述"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, fuzzy, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建議大括號周圍清空內文在中 %<else%> 敘述"
@@ -36708,7 +36767,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, fuzzy, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "建議明確的大括號到避免模稜兩可的 %<else%>"
@@ -36728,7 +36787,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "無效的迭代變數在中快速列舉類型"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -36909,17 +36968,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_complex%>運算元的不同的類型"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -36974,61 +37033,61 @@
 msgid "no type or storage class may be specified here,"
 msgstr "沒有型態或貯藏類別也許會被指定的在此，"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不明內容屬性"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "缺少%<=%>(之後 %<getter%>屬性)missing %<=%> (after %<getter%> attribute)缺少%<=%>(之後 %<getter%>屬性)"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "缺少%<=%>(之後 %<setter%>屬性)missing %<=%> (after %<setter%> attribute)缺少%<=%>(之後 %<setter%>屬性)"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%<setter%> 屬性也許會只有被指定的一旦"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, fuzzy, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 名稱必須終止與 %<:%>"
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%<getter%> 屬性也許會只有被指定的一旦"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<# pragma omp flush%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<# pragma omp section%>也許會只有被已用於 %<# pragma omp sections%>建構"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<# pragma GCC pchpreprocess%(_P)>必須是先"
@@ -37043,12 +37102,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "預期的整數運算式"
@@ -37063,53 +37122,53 @@
 msgid "%qD is not a variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD 並非變數"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%>"
 msgstr "預期 %<new%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "預期 %<none%> 或 %<shared%>"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "預期 %<;%>，%<,%>或 %<)%>"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "預期 %<catch%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多 %qs 子句"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -37137,22 +37196,22 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "『%s』於 %L 必須是 nonnegative"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "預期 %<throw%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "預期 %<class%>"
@@ -37162,58 +37221,58 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多引數"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "未預期的屬性"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE 屬性引數不是整數常數"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>預期 %<+%>，%<*%>，%<-%>，%<&%>，%<^%>，%<|%>，%<&&%>，%<||%>，%<min%>或 %<max%>"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "宣告中同時使用了 %<long%> 和 %<void%>"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, fuzzy, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<runtime%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, fuzzy, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "排程 %<auto%> 不需 %<chunksize%(_S)>參數"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "無效的排程 kind"
@@ -37228,17 +37287,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, fuzzy, gcc-internal-format
 #| msgid "code model %<large%> not supported yet"
 msgid "using parameters for %<linear%> step is not supported yet"
@@ -37259,18 +37318,18 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "無效遮罩"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "無效的排程 kind"
@@ -37280,68 +37339,68 @@
 msgid "invalid proc_bind kind"
 msgstr "無效的排程 kind"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs 無效用於 %qs"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs 必須被使用與 %qs"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "無效的輸入宣告"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "宣告的 %<extern%> 變數 %qD 在中 %<for%>迴圈初始宣告"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<--%> on bool variable %qD"
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "對於 bool 變數 %qD 使用 %<--%> 無效"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "預期的字串之後 %<# pragma message%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -37356,7 +37415,7 @@
 msgid "expected function name"
 msgstr "預期的函式"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -37367,42 +37426,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "無效的表單的 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "無效的運算子用於 %<# pragma omp atomic%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用兩不同的變數用於記憶體"
@@ -37412,27 +37471,27 @@
 msgid "expected %<(%> or end of line"
 msgstr "預期 %<(%>或列尾"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "用於敘述預期"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "預期的迭代宣告或初始化"
@@ -37442,73 +37501,73 @@
 msgid "not enough perfectly nested loops"
 msgstr "不足 perfectly 巢狀的迴圈"
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, fuzzy, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "崩潰的迴圈無法 perfectly 巢狀"
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代變數 %qD 不應為 firstprivate"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> 做為僅有的參數時不能被限定"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<# pragma omp barrier%>也許會只有被已用於複合陳述"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "預期 %<operator%>"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "預期 %<using%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -37523,7 +37582,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<# pragma align%>必須出現之前宣告的 %D, 忽略"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -37533,32 +37592,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "預期 %<try%>"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "預期 %<decltype%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<# pragma GCC pop_options%>而無需相應 %<# pragma GCC push_options%>"
@@ -37613,22 +37672,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "預期 %<# pragma omp section%>或 %<}%>"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, fuzzy, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE 宣告 %<threadprivate%> 之後先使用"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, fuzzy, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自動變數 %qE 無法 %<threadprivate%>"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE 有不完整型態"
@@ -37643,56 +37702,56 @@
 msgid "pragma simd must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "堆疊大小必須剛好是 2 的某次方"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "選擇子必須是 0 到 %wi 間的整常數"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "預期 %<# pragma omp%>子句"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "在這裡不允許使用 %<#pragma%>"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而無需 transactional 記憶體支援已啟用"
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之內 %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>無法在之內外 %<__transaction_atomic%>"
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函式"
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>無法在之內 %<__transaction_atomic%>"
@@ -37703,7 +37762,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "預期 %<:%>或 %<::%>"
@@ -38443,7 +38502,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手邊可能是 format 屬性的備選時"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "回傳類型可能是 format 屬性的備選"
@@ -38771,7 +38830,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允許 %<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被宣告為 %<noreturn%> 的函式卻有 %<return%> 敘述"
@@ -38781,7 +38840,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "%qE 不能做為函式"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, fuzzy, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr "邏輯的範圍在中條件敘述於 %L 未被允許"
@@ -38807,7 +38866,7 @@
 msgid "function returns address of label"
 msgstr "函式回傳局部變數的位址"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch 敘述中的值不是一個整數"
@@ -38822,7 +38881,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "大小寫標貼不是整數常數運算式"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 標籤出現在開關敘述外"
@@ -38842,17 +38901,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 敘述不在循環或開關敘述內"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 敘述出現在循環以外"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "中斷敘述使用的與 OpenMP 用於迴圈"
@@ -38863,7 +38922,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break 敘述不在循環或開關敘述內"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
@@ -38970,12 +39029,12 @@
 msgid "used vector type where scalar is required"
 msgstr "使用的向量型態位置純量被必要項"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -38985,26 +39044,26 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "太多 %qs 子句"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD 不是一個成員範本函式"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -39015,18 +39074,18 @@
 msgstr "太多 %qs 子句"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "陣列 new 的大小必須有整數類型"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -39033,54 +39092,54 @@
 msgstr "陣列 new 的大小必須有整數類型"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "陣列區段在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "用於遞增運算式沒有任何效果"
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "複製陣列區段進入 contiguous 區塊於程序條目"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qD 沒有積分或列舉類型型態"
@@ -39100,7 +39159,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE 有無效的型態用於 %<reduction(%s)%>"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -39110,17 +39169,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "變數長度陣列被使用"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE 必須是 %<threadprivate%> 用於 %<copyin%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -39140,18 +39199,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD 出現一次以上在中資料子句"
@@ -39163,32 +39222,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE 並非變數在中子句 %<firstprivate%>"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE 並非變數在中子句 %<lastprivate%>"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -39209,55 +39268,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "陣列區段無法允許的在中『%s』呼叫於 %L"
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE 出現一次以上在中資料子句"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE 並非變數在中子句 %qs"
@@ -39268,32 +39327,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的引數類型既非指標也非陣列"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE 被 predetermined %qs 用於 %qs"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -39850,158 +39909,158 @@
 msgid "use of multiversioned function without a default"
 msgstr "缺席函式 %q+D 與預設引數"
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "將 %qT 做為 %q#D 的 %<this%> 引數時丟棄了類型限定"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  在呼叫 %qD 時"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT 是 %qT 的一個不可存取的基礎類別"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "deducing %qT 做為 %qT"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, fuzzy, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "  (您可以停用這個與 -fno-deduce-init-list)"
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "太多引數到建構子 %q#D"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "常數參考它自己"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, fuzzy, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "無法呼叫建構子 %<%T::%D%>直接"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "  用於 function-style 演員陣容，移除冗餘 %<::%D%>"
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "沒有匹配函式用於呼叫到 %<%T::運算子 %T(%A)%#V%>"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "對 %<%T::%s(%A)%#V%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "對 %<%D(%A)%> 的呼叫沒有匹配的函式"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "對多載的 %<%s(%A)%> 的呼叫有歧義"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT 沒具名為 %qD 的非靜態資料成員"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "建構式回傳值"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "解構函式回傳值"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "沒有物件無法呼叫成員函式 %qD"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "傳遞 %qT 時選擇 %qT 而不是 %qT"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "選擇 %qD 而不是 %qD"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  當從 %qT 轉換為 %qT 時"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  因為前者的引數類型轉換序列更好"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "預設引數不匹配在中過載解析度"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr " candidate 1:%q+#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr " candidate 2:%q+#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 認為有歧義，盡管第一個備選的最差類型轉換要好於第二個備選的最差類型轉換"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "無法轉換 %qE 從 %qT 到 %qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暫時的約束到 %qD 只有持續直到建構子離開"
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "無效的初始化的 non-const 參考的型態 %qT 從 rvalue 的型態 %qT"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "將類型為 %qT 的參照初始化為類型為 %qT 的運算式無效"
@@ -40106,286 +40165,286 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "無法衍生從 %<final%> 基底 %qT 在中衍生類型 %qT"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "類別 %qT 中所有成員函式都是私有的"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T 僅定義了一個私有解構函式且沒有夥伴"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T 僅定義了一個私有建構式且沒有夥伴"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD 的最終多載在 %qT 中不唯一"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D 無法被多載"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q+#D 標記的最後的，但是不是虛擬"
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+#D 標記的強制變更，但是不強制變更"
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D 被隱藏"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  為 %q+D"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D 無效；匿名聯合只能有非靜態的資料成員"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D 無效的；匿名結構只能有非靜態資料成員"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "匿名聯合中出現私有成員 %q+#D"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr "私人的成員 %q+#D 在中匿名結構"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr "保護的成員 %q+#D 在中匿名結構"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "位元段 %q+#D 有非整數的類型"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "位元段 %q+D 的寬度不是一個整數常數"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "位元段 %q+D 寬度為負"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "位元段 %q+D 寬度為 0"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D 的寬度超過了它的類型"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D 太小而不能存放 %q#T 的所有可能值"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "有建構式的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "有解構函式的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "有複製賦值運算子的成員 %q+#D 不能用在聯合中"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D 不能是靜態的，因為它是聯合的成員"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "欄位 %q+D 無效地宣告為函式類型"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "欄位 %q+D 無效地宣告為方法類型"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, fuzzy, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "忽略包裝的屬性因為解裝 non-POD 欄位 %q+#D"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非成員 %qs 不能被宣告為 %<mutable%>"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "初始化了聯合 %qT 中的多個欄位"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "欄位 %q+#D 與類別同名"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T 有指標資料成員"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  但沒有多載 %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  或 %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  也沒有多載 %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "對齊的 %qD 是大於原來的宣告"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "為非虛方法 %q+D 指定了初始值設定項"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, fuzzy, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "方法強制變更兩者 %<transaction_pure%> 和 %qE 方法"
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "方法宣告 %qE 強迫 %qE 方法"
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "封入類別的 constexpr 非靜態成員函式 %q+#D 並非實字型態"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "%q+T 不是實字因為："
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "  %q+T 有 non-trivial 解構式"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, fuzzy, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr "  %q+T 不是彙總，沒有 trivial 預設建構函式，而沒有任何 constexpr 建構子該並非複製或移動建構子"
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "  基礎類別 %qT 的 %q+T 是 non-literal"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "  非靜態資料成員 %q+D 有 non-literal 型態"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "基礎類別 %q#T 有一個非虛解構函式"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "類別中有非靜態參照 %q+#D，卻沒有提供建構式"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -40393,157 +40452,157 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, fuzzy, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D 宣告到需常數參考，但是蘊含宣告會需 non-const"
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，直接基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由於存在歧義，虛基礎類別 %qT 在 %qT 中無法存取"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D 的偏移量與 ABI 不相容，並且在 GCC 的未來版本中可能會有變化"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "大小的陣列 %qE 太大"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "無效的使用的 %<...%>與 non-slice"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "對包含彈性陣列成員的結構的無效使用"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "flexible 陣列成員在中否則清空結構"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T 重定義"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "flexible 陣列成員無法於結束的結構"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "flexible 陣列成員在中否則清空結構"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D 已在此宣告過"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T 重定義"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T 有虛擬函式和可存取 non-virtual 解構式"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "型態透明類別 %qT 沒有任何欄位"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "型態透明類別 %qT 有基礎類別"
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "型態透明類別 %qT 有虛擬函式"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, fuzzy, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "試圖完成結構，但為先前的解析錯誤所插斷"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "語言字串 %<\"%E\"%> 不可識別"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "無法解析多載函式 %qD，基於向類型 %qT 的轉換"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "沒有可將函式 %qD 轉換到類型 %q#T 的匹配項"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "將多載函式 %qD 轉換為類型 %q#T 有歧義"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成員指標 %qD"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成員指標只能用 %<&%E%> 構成)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "類型資訊不充分"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "無法將 %qE 從類型 %qT 轉換到類型 %qT"
@@ -40553,12 +40612,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D 的宣告"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -40589,341 +40648,341 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "無效的傳回類型 %qT 的 constexpr 函式 %q+D"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T 有虛擬基礎類別"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, fuzzy, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr "constexpr 建構子沒有清空內文"
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "%<constexpr%> 建構子用於聯合 %qT 必須初始化精確的一個非靜態資料成員"
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, fuzzy, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "內文的 constexpr 函式 %qD 不是 return-statement"
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%q+D 不是可用做為 constexpr 函式因為："
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E並非常數運算式"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "呼叫非函式的 %qD"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "運算式 %qE 不指定 constexpr 函式"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "呼叫到 non-constexpr 函式 %qD"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD called 在中常數運算式"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD called 在中常數運算式"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD 使用的之前它的定義"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "呼叫有環狀依存性"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "右移次數為負"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "逗號運算式的左運算元不起作用"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "陣列下標超出陣列邊界"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提領 %<void *%> 指標"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "可變的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "存取 %qD 成員以代替初始化的 %qD 成員在中常數運算式"
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "成員 %qD 缺少初始值設定"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "提領 %<void *%> 指標"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "存取值的 %qE 透過 %qT glvalue 在中常數運算式"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "值的 %qD 不是可用在中常數運算式"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD 已用於它的本身初始設定式"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D 不是常數"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D 是易變的"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD 未被初始化的與常數運算式"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD 未被宣告 %<constexpr%>"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "constexpr 求值深度超出最大值的 %d (使用 -fconstexpr-depth=到增加最大值)"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "初始設定式元件並非常數運算式"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "未預期的運算式 %qE 的 kind %s"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 無法型態的完成常數運算式因為它有可變的 sub-objects"
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "轉換從指標類型 %qT 到算術型式 %qT 在中 constant-expression"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, fuzzy, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "運算式 %qE 有 side-effects"
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpretcast 從型態 %qT 輸入 %qT 演員陣容暫離限定元(_C)"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 物件 %qE 與執行緒本地或自動貯藏體並非常數運算式"
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, fuzzy, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 並非常數運算式因為 %qE 是的 polymorphic 型態"
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "暫時的的 non-literal 型態 %qT 在中常數運算式"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F 宣告為 %<static%> 卻從未定義過"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "函式 %qs 的存儲類別 %<__thread%> 無效"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "uninitialized 成員 %qD 在中 %<constexpr%> 建構子"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "除法由零並非 constant-expression"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "non-constant 陣列初始化"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE 並非常數運算式"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "未預期的 AST 的 kind %s"
@@ -41751,7 +41810,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  略過 %q+#D 的初始化"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, fuzzy, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "無效的離開從 OpenMP 結構化訊息塊"
@@ -41766,7 +41825,7 @@
 msgid "%qD is not a type"
 msgstr "%qD 並非型態"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD 使用時未帶範本參數"
@@ -43449,7 +43508,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "參數宣告 %<auto%>"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用範本名 %qE 時不帶引數表無效"
@@ -43910,13 +43969,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD 與其宣告所在的類別同名"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT 不是一個範本"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "與此處早先的宣告 %q+#D 衝突"
@@ -43926,8 +43985,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "對 %qD 的參照有歧義"
@@ -43978,7 +44037,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "範圍/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "前一個定義在此"
@@ -44042,7 +44101,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> 應當回傳一個對 %<*this%> 的參照"
@@ -44057,7 +44116,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "在有回傳值的函式中未發現 return 敘述"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由於 %<volatile%>，函式回傳類型不相容"
@@ -44216,27 +44275,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "寬度的 bit-field %qD 有 non-integral 型態 %qT"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "匿名結構不在具名類型內"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "命名空間欄位的匿名聚合必須是靜態的"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "匿名聯合沒有成員"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> 必須回傳 %qT"
@@ -44245,67 +44304,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, fuzzy, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "第一個參數的 %<operator new%> 無法有預設引數"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> 的第一個參數類型為 %<size_t%> (%qT)"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> 必須回傳 %qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> 的第一個參數類型為 %qT"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, fuzzy, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT 有欄位 %qD 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT 宣告的與更大可視性比型態的它的欄位 %qD"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, fuzzy, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT 有基底 %qT 其型態使用匿名命名空間"
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, fuzzy, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT 宣告的與更大可視性比它的基底 %qT"
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q+#D, 宣告的使用匿名型態，被使用但是永不定義"
@@ -44314,49 +44373,49 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "匿名型態不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D 未指明非限定類型，所以它不做為外部連結"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D, 宣告的使用本地型態 %qT，被使用但是永不定義"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告變數 %q#D 與鏈結"
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "型態 %qT 不具任何鏈結用來宣告函式 %q#D 與鏈結"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "使用了內聯函式 %q+D 但從未定義過"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "參數 %P (屬於 %q+#D)缺少預設引數"
@@ -44363,12 +44422,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, fuzzy, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "轉換 lambda 該項使用 %<...%>到函式指標"
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用的刪除的函式 %qD"
@@ -44679,18 +44738,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "無效的初始設定式用於陣列成員 %q#D"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "uninitialized 常數成員在中 %q#T"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%qD 應該被初始化的"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "uninitialized 參考成員在中 %q#T"
@@ -44792,7 +44851,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "陣列必須被初始化的與 brace-enclosed 初始設定式"
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT 並非類別型態"
@@ -44812,7 +44871,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "對非靜態成員函式 %qD 的使用無效"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "對非靜態資料成員 %qD 的無效使用"
@@ -45011,22 +45070,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr "複合字面值有可變的大小"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "無法擷取 %qE 由參考"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "無效的使用的不完整型態 %q#T"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "已經擷取 %qD 在中 lambda 運算式"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "%<this%> 未被擷取用於這個 lambda 函式"
@@ -45081,190 +45140,190 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(如果您使用 %<-fpermissive%>，G++ 會接受您的程式碼，但是允許使用未定義的名稱是過時的風格)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, fuzzy, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "mangling typeof，使用 decltype 做為替代"
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, fuzzy, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "mangling __underlying_type"
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, fuzzy, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "mangling 不明定點型態"
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "mangling %C"
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "省略的 %<?:%> 中運算元不能被修飾"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, fuzzy, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "字串實字在中函式模板簽名"
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, fuzzy, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=6 (或=0) 避免這個錯誤與變更在中 mangling"
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "%qD 修飾後的名稱將在 GCC 的未來版本中有變化"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "%qD 修飾後的名稱將在 GCC 的未來版本中有變化"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD 修飾後的名稱將在 GCC 的未來版本中有變化"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "非靜態常數成員 %q#D, can%'t 使用預設指派運算子"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, fuzzy, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "非靜態參考成員 %q#D, can%'t 使用預設指派運算子"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, fuzzy, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr "synthesized 方法 %qD 先必要項在此 "
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, fuzzy, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "聯合成員 %q+D 與 non-trivial %qD"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, fuzzy, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "缺席建構子呼叫 non-constexpr %q+D"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "初始設定式用於 %q+#D 無效"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "缺席預設建構函式不初始化 %q+#D"
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "非靜態資料成員 %qD 有 Java 類別型態"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "缺席預設建構函式不初始化任何非靜態資料成員"
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "lambda 閉合型態有刪除的預設建構函式"
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "lambda 閉合型態有刪除的複製指派運算子"
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, fuzzy, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q+#D 是隱含地宣告的做為刪除的因為 %qT 宣告移動建構子或移動指派運算子"
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, fuzzy, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q+#D 是隱含地刪除的因為預設定義會被不當形式的："
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "缺席宣告 %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, fuzzy, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr "不匹配預期的簽名 %qD"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 #, fuzzy
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr "函式 %q+D 缺席於它的先宣告與 exception-specification 該不同從蘊含宣告 %q#D"
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, fuzzy, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr "明確的缺席函式 %q+D 無法宣告的做為 constexpr 因為蘊含宣告不是 constexpr："
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "模板無法缺席"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD 無法缺席"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "缺席函式 %q+D 與預設引數"
@@ -45464,125 +45523,125 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> 在 %qT 內指定了建構式"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "沒有與 %<%T::%D%> 匹配的成員，在 %q#T 中"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD 的宣告不在包含 %qD 的命名空間中"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD 的宣告中有明確的限定"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr "%qE 未被宣告"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a friend"
 msgstr "%q+D 宣告為夥伴"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD 應當已在 %qD 內部宣告過"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD 屬性是無意義的自從成員的匿名命名空間提取本機符號"
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定 %qD 屬性被忽略"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "這裡不允許命名空間別名 %qD，假定為 %qD"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "此開關已過時；請改用 -Wextra"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "強 using 只在命名空間作用欄位有意義"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, fuzzy, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "目前的命名空間 %qD 不封閉 strongly 使用的命名空間 %qD"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空間搜尋的用於 %qE"
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "建議的替代方案："
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建議的替代方案："
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, fuzzy, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr "引數附屬查找尋找 %q+D"
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, fuzzy, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX 進入 pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX 離開 pop_everything ()\n"
@@ -45602,7 +45661,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -45627,7 +45686,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "要求用於成員 %qE 在中 non-class 型態 %qT"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>未被宣告"
@@ -45687,1217 +45746,1222 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(%qT 的定義末尾可能缺少一個分號)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "%qE 不是一個範本"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE 不是一個範本"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "無效的範本 ID"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮點實字無法出現在中 constant-expression"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, fuzzy, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "演員陣容到型態不同於積分或列舉類型型態無法出現在中 constant-expression"
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "%<typeid%> 運算子無法出現在中 constant-expression"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, fuzzy, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "non-constant 複合實字無法出現在中 constant-expression"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, fuzzy, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "函式呼叫無法出現在中 constant-expression"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, fuzzy, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "遞增無法出現在中 constant-expression"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, fuzzy, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "遞減無法出現在中 constant-expression"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "陣列參照無法出現在中 constant-expression"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "位址的標貼無法出現在中 constant-expression"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "呼叫到過載的運算子無法出現在中 constant-expression"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "指派無法出現在中 constant-expression"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "逗號運算子無法出現在中 constant-expression"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "呼叫到建構子無法出現在中 constant-expression"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "異動作業運算式無法出現在中 constant-expression"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%qs 無法出現在中 constant-expression"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "無效的使用的解構式 %qD 做為型態"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, fuzzy, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "無效的組合的多重 type-specifiers"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE 沒有命名一個類型"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE 沒有命名一個類型"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, fuzzy, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, fuzzy, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, fuzzy, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(也許您本意是想用 %<typename %T::%E%>)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in namespace %qE does not name a type"
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE 在命名空間 %qE 中沒有命名一個類型"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE 在命名空間 %qE 中沒有命名一個類型"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%E%>名稱建構子，不是型態"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "和 %qT 沒有任何模板建構子"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, fuzzy, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr "需要 %<typename%> 之前 %<%T::%E%>因為 %qT 是附屬範圍"
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE 在中 %q#T 不名稱型態"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE 在中 %q#T 不名稱型態"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, fuzzy, gcc-internal-format
 msgid "expected string-literal"
 msgstr "預期 string-literal"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, fuzzy, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr "不一致使用者定義的實字字尾 %qD 和 %qD 在中字串實字"
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, fuzzy, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr "wide 字串無效在中這個語境"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, fuzzy, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr "無法找到字元實字運算子 %qD 與 %qT 引數"
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr "浮點常數超出範圍的 %qT"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr "浮點常數超出範圍的 %qT"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, fuzzy, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr "浮點常數截短至零"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, fuzzy, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr "無法找到數值實字運算子 %qD"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, fuzzy, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "無法找到字串實字運算子 %qD 與 %qT，%qT 引數"
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "預期的宣告"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 msgid "expected binary operator"
 msgstr "預期的運算子"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 msgid "expected ..."
 msgstr "預期 %<...%>"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "binary expression in operand of fold-expression"
 msgstr "%s 運算式清單被看作複合運算式"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "異動作業運算式無法出現在中 constant-expression"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr "型態不匹配在中向量 Shift 運算式"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "定點類型不支援在中 C++"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ 不允許在運算式中使用大括號組"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, fuzzy, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "statement-expressions 未被允許外側函式 nor 在中 template-argument 清單"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, fuzzy, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "預期 primary-expression"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "%<this%> 不能用在此上下文中"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, fuzzy, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "模板宣告無法出現於區塊範圍"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "局部變數 %qD 不應出現在此上下文中"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "預期 id-expression"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, fuzzy, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "範圍 %qT 之前 %<~%>並非 class-name"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%<~%T%> 宣告為 %qT 的一個成員"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名 %qD 用於解構函式宣告"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "實字運算子字尾無法前繼的由 %<_%>被保留的用於未來標準化"
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "預期 unqualified-id"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, fuzzy, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "找到 %<:%>在中 nested-name-specifier，預期 %<::%>"
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "decltype 評估到 %qT，該項並非類別或列舉類型型態"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "incomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "巢狀名指定中使用了不完全的類型 %qT"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "預期 nested-name-specifier"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD 不是一個範本"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "預期 nested-name-specifier"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "類型可能無法被定義在中演員陣容"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "類型可能無法被定義在中 %<typeid%> 運算式"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "錯誤的引數數量到 %<__builtin_shuffle%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "錯誤的引數數量到 %<__builtin_complex%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ 不允許複合字面值"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "braced list index is not allowed with array notation"
 msgstr "-client_name 不能和 -dynamiclib 一起使用"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "錯誤地使用了 %qD"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%>並非類別成員"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, fuzzy, gcc-internal-format
 msgid "non-scalar type"
 msgstr "non-scalar 型態"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++不允許 %<alignof%> 與 non-type"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "類型可能無法被定義在中 %<noexcept%> 運算式"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "類型可能無法被定義在中 new-expression"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "括起的類型識別碼後面不能出現陣列邊界"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "請嘗試刪除類型識別碼兩邊的括號"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "需要運算式類型"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "類型可能無法被定義在中 new-type-id"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new 宣告中的運算式必須具有整數或列舉類型"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "使用舊式的類型轉換"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%<>>%>運算子被視為兩正確角度中括號在中 C++11"
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, fuzzy, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "建議 parentheses 周圍 %<>>%>運算式"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++不允許 ?:與省略的中間運算元"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "lambda-expression 在中 unevaluated 語境"
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "lambda-expression 在中 unevaluated 語境"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "預期的結束的 capture-list"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "明確的 by-copy 擷取的 %<this%> 冗餘與 by-copy 擷取預設"
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "範圍的 enums 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "擷取的 non-variable %qD "
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+#D 宣告的在此"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "擷取的變數 %qD 與 non-automatic 貯藏體持續時間"
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "明確的 by-copy 擷取的 %qD 冗餘與 by-copy 擷取預設"
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, fuzzy, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "明確的 by-reference 擷取的 %qD 冗餘與 by-reference 擷取預設"
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "variadic 模板只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C 不支援飽和類型"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "預設引數指定的用於 lambda 參數"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重複的 %<volatile%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "預期 labeled-statement"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case 標籤 %qE 未出現在 switch 敘述中"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, fuzzy, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "需要 %<typename%> 之前 %qE 因為 %qT 是附屬範圍"
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%>名稱建構子，不是型態"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++11 %<constexpr%> 只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "委派建構子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "預期 selection-statement"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "類型可能無法被定義在中條件"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "range-based %<for%> 運算式的型態 %qT 有不完整型態"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr "range-based %<for%> 運算式的型態 %qT 有 %<end%>成員並不是 %<begin%>"
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr "range-based %<for%> 運算式的型態 %qT 有 %<begin%>成員並不是 %<end%>"
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "不一致開始/結束類型在中 range-based %<for%> 敘述：%qT 和 %qT"
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "預期 iteration-statement"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "無限制的聯合只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr "中斷敘述使用的與 OpenMP 用於迴圈"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允許執行時可知的 goto 目的"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "預期 jump-statement"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多餘的 %<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, fuzzy, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>無法於起始部分的區塊"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合宣告和函式定義"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, fuzzy, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "明確的轉換運算子只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "空宣告"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
 #, fuzzy, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr "無效的初始設定式用於成員函式 %qD"
+
+#: cp/parser.c:13220
+#, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%> 使用的外側的類別"
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%> 變更平均在中 C++11; 請移除它"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "decl-specifier 無效的在中條件"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D 無效，在 %q#T 中"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "類別定義不能被宣告為夥伴"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, fuzzy, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "無效的連繫規格"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, fuzzy, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "類型可能無法被定義在中 %<decltype%> 運算式"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "類型可能無法被定義在中 new-type-id"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有建構子需成員初始設定式"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "無法展開初始設定式用於成員 %<%D%>"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "mem-initializer 用於 %qD 追隨建構子 delegation"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建構子 delegation 追隨 mem-initializer 用於 %qD"
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代錯誤的舊式基礎類別初始值設定"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(限定的初始值設定隱含地是一個類型)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介於 %<「」%>和字尾識別碼"
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "預期的字尾識別碼"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "預期的清空字串之後 %<operator%> 關鍵字"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "無效的運算元在中三進作業"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "預期的運算子"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "關鍵字 %<export%> 未實作，將被忽略"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "無效的使用的模板模板參數 %qT"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "預期 template-id"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以 %<<::%> 開始一個範本引數清單"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> 是 %<[%> 的另一種拼法。請在 %<<%> 和 %<::%> 間加上空格"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用 %<-fpermissive%> G++將接受您的編碼)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "範本引數表語法錯誤"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "預期 template-name"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用 %<%T::template %D%> 來表示這是一個範本"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "預期 template-argument"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "明確的實體化不應該使用 %<inline%> 說明符"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "明確的實體化不應該使用 %<constexpr%> 說明符"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化範本有 C 連結"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "預期的型態說明符"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C 不允許前向參數宣告"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "預期 template-id 用於型態"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "預期 type-name"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "elaborated-type-specifier 用於範圍的 enum 必須不使用 %<%D%>關鍵字"
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "宣告 %qD 不宣告任何事"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "屬性忽略的於 uninstantiated 型態"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "屬性忽略的於模板具現化"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "屬性忽略的於 elaborated-type-specifier 該並非前置宣告"
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD 是列舉類型模板"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD 沒有積分或列舉類型型態"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "預期 %<;%>或 %<{%>"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "無法加入列舉值清單到模板具現化"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "宣告的 %qD 在中命名空間 %qD 該項不封閉 %qD"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD 宣告出現在 %qD 中，而後者並不包含 %qD"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "額外合格不允許"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T 多次定義"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++禁止遞增 enum"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而無需名稱"
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必須使用簡單的識別碼"
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD 不是一個命名空間"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "預期 namespace-name"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 #| msgid "Enumerator cannot have attributes %C"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "列舉量不能有屬性 %C"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "內聯命名空間只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "當內聯函式無法被內聯時給出警告"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "nested identifier required"
 msgstr "需要識別碼"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空間 %qD 做為運算式"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%> 定義未被允許在此"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "lambda 運算式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "範本識別碼不允許出現在 using 宣告中"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "缺席和刪除的函式只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "存取宣告被不宜用在中 favour 的 using-declarations；建議：加入 %<using%> 關鍵字"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "類型可能無法被定義在中別名模板宣告"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "function-definition 未被允許在此"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "函式定義中不允許出現 asm 指定"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函式定義中不允許有屬性"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "預期的建構子、解構式，或類型轉換"
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "預期的初始設定式"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "初始設定式提供的用於函式"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值設定後出現的屬性被忽略"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "函式 %q+D 重宣告為內聯的"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "陣列邊界不是一個整數常數"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "無法定義成員的附屬 typedef %qT"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>並非型態"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "將建構式做為範本用法無效"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用 %<%T::%D%> 而不是 %<%T::%D%> 來以限定名指定建構式"
@@ -46906,7 +46970,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "無效的宣告子"
@@ -46913,340 +46977,340 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "%q+D 在宣告前使用"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "預期的宣告子"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD 是一個命名空間"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "無法表單成員指標的 non-class %q#T"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "預期 ptr-operator"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "重複的 cv 限定"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "重製 virt-specifier"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "在中模板引數用於型態 %qT "
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "無效的使用的 %qT"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "類型可能無法被定義在中模板引數"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "無效的 non-type 模板引數"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "預期 type-specifier"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "預期 %<,%>或 %<...%>"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "類型可能無法被定義在中參數類型"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "預設參數只允許出現在函式參數中"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "參數包裝 %qD 無法有預設引數"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板參數包裝無法有預設引數"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "參數包裝無法有預設引數"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ 不允許指定元素初始值設定"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++不允許 C99 指定的初始設定式"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "預期 class-name"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "預期 %<;%>之後類別定義"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "預期 %<;%>之後結構定義"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "預期 %<;%>之後聯合定義"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "預期 %<{%>或 %<:%>"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "無法指定 %<override%> 用於類別"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "全域合格的類別名稱無效"
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "限定名稱不名稱類別"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD 的宣告中類別名無效"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "明確特例化前必須有 %<template <>%>"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函式模板 %qD redeclared 做為類別模板"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "無法解析 typename 型態"
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T 的上一個定義"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "預期 class-key"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "在中 C++03 class-key 必須被使用時宣告朋友"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "夥伴宣告沒有指定類別或函式名"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函式定義上有 pure 指定"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "預期 %<;%>於結束的成員宣告"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "無效的 pure 說明符 (只有 %<=0%>被允許)"
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "brace-enclosed 初始設定式未被允許在此"
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, fuzzy, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "%<virtual%> 指定的一次以上在中 base-specified"
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, fuzzy, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr "超過一個存取說明符在中 base-specified"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "關鍵字 %<typename%> 不能在範本以外使用"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "關鍵字 %<typename%> 不允許用在此上下文中(基礎類別隱含地是一個類型)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "類型可能無法被定義在中 exception-specification"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "由於不同的異常規格"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "動態異常規格被不宜用在中 C++0x; 使用 %<noexcept%> 做為替代"
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "無效的使用的 %<auto%> 在中轉換運算子"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "複合陳述在中 constexpr 函式"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "類型可能無法被定義在中 exception-declarations"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s 屬性與 %s 屬性在 %L 處衝突"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要識別碼或 %<(%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "預期的參數包裝之前 %<...%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++0x 自動只有可用與 -std=c++11 或 -std=gnu++11"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "%<@required%>不是可用在中 Objective-C 1.0"
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "異動作業運算式無法出現在中 constant-expression"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, fuzzy, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "專用化成員 %<%T::%E%>需求 %<模板<>%>語法specializing member %<%T::%E%> requires %<template<>%> syntax專用化成員 %<%T::%E%>需求 %<模板<>%>語法"
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "無效的宣告的 %<%T::%E%>"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "範本參數表太少"
@@ -47255,428 +47319,428 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "範本參數表太多"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "具名回傳值不再被支援"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "實字運算子模板 %qD 有無效的參數清單。 預期 non-type 模板引數包裝 <char...>"
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "啟用 multiply 指令"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "無效的宣告的成員模板在中區域類別"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "C 連結的範本"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "無效的明確的特殊化"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "模板宣告的 %<typedef%>"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "沒有宣告任何東西"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "明確的模板特殊化無法有貯藏類別"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%<>>%>應該是 %<>>%>在之內巢狀的模板引數清單"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的 %<>>%>，使用 %<>%> 來結束範本引數清單"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "無效的使用的 %qD 在中連繫規格"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>之前 %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++1998 不支援 %<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "宣告中同時使用了 %<short%> 和 %<char%>"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重複的 %qE"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重複的 %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "預期 %<new%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "預期 %<delete%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "預期 %<return%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "預期 %<extern%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, fuzzy, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "預期 %<static_assert%>"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "預期 %<decltype%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "預期 %<operator%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "預期 %<class%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "預期 %<template%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "預期 %<namespace%>"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "預期 %<using%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "預期 %<asm%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "預期 %<try%>"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "預期 %<catch%>"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "預期 %<throw%>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "預期 %<__label__%>"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "預期 %<@try%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "預期 %<@synchronized%>"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "預期 %<@throw%>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "預期 %<__transaction_atomic%>"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "預期 %<__transaction_relaxed%>"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "預期 %<::%>"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "預期 %<...%>"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "預期 %<*%>"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "預期 %<~%>"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "預期 %<:%>或 %<::%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "預期 %<class%>，%<typename%>，或 %<template%>"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了 %qs 標記，在命名 %q#T 時"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q#T 是在之前宣告的在此"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD 重宣告時有不同的可存取性"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "做為消歧義的 %<template%> 只能用於範本內"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "檔案在預設參數處結束"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置錯誤的 %<@%D%> Objective-C++ 建構"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 訊息引數被預期"
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%> 必須指定一個類型做為引數"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "無效的 Objective-C++ 選擇子名"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "objective-c++ 方法宣告被預期"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "方法屬性必須被指定的於結束"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介於 Objective-C++ 方法"
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "無效的型態舉例來說變數"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%> 需要識別碼"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "屬性可能無法被指定的之前 %<@%D%>Objective-C++ 關鍵字"
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "前綴屬性被忽略之前 %<@%D%>"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "無效的型態用於內容"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "parenthesized 初始化未被允許在中 OpenMP %<for%> 迴圈"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代變數 %qD 不應為消除"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "不足做迴圈用於崩潰 !$OMP 做於 %L"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 #| msgid "attributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "函式定義中不允許有屬性"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "無效的初始值設定"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "預期 id-expression"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在回傳類型中定義新類型"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -47683,69 +47747,69 @@
 msgstr "%qD 不是一個成員範本函式"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而無需 transactional 記憶體支援已啟用"
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "垃圾於結束的 %<# pragma GCC pchpreprocess%(_P)>"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "運算元的約束無效"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "# pragma GCC 最佳化未被允許內部函式"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模組間最佳化淍未為 C++ 實作"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "在 %C 處需要變數名"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "預期 %<,%>或 %<)%>"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板可能無法是 %<virtual%>"
@@ -47838,7 +47902,7 @@
 msgid "candidate is: %#D"
 msgstr "備選為：%+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %+#D"
@@ -48425,124 +48489,139 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有任何鏈結"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "  variable-sized 陣列類型 %qT 並非有效模板引數"
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%qE 並非有效模板引數的型態 %qT 因為 %qD 沒有外部連結"
+
+#: cp/pt.c:6672
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為 cv 限定衝突"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是 lvalue"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D 並非有效模板引數用於型態 %qT 因為參考變數沒有常數位址"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE 並非有效模板引數用於型態 %qT 因為它不是物件與外部連結"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為物件 %qD 沒有外部連結"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它是一個指標"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "嘗試使用 %qE 代替"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE 不是類型 %qT 的有效範本引數，因為它的類型是 %qT"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "此上下文中不允許標準轉換"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略屬性於模板引數 %qT"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, fuzzy, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "injected-class-name %qD 使用的做為模板模板引數"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "無效的使用的解構式 %qE 做為型態"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某個範本參數的類型成員時，請使用 %<typename %E%>"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  需要一個 %qT 類型的常數，卻給出了 %qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  需要一個類別範本，卻給出了 %qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  需要一個類型，卻給出了 %qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  需要一個類型，卻給出了 %qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  需要一個類別範本，卻給出了 %qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  預期的模板的型態 %qD，得到 %qT"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "引數 %d 的類型/值不匹配，在 %qD 的範本參數清單中"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
@@ -48550,108 +48629,108 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "型態不匹配在中 nontype 參數包裝"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能將範本參數從 %qE 轉換到 %qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "範本參數 %d 無效"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "範本參數數目不正確(不應是 %d 個而應是 %d 個)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供給 %q+D"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "預設引數用於模板參數用於類別封閉 %qD"
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "為參數 %d (屬於 %q#D)指定了預設引數"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "提供給 %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D 並非函式模板"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非範本類型 %qT 做為範本"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "對於範本宣告 %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "內部一致性錯誤"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d (使用 -ftemplate-depth=到增加最大值) 替代 %qS"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "不匹配的引數包裝長度當展開 %<%T%>"
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, fuzzy, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "不匹配的引數包裝長度當展開 %<%E%>"
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "重定義 %q#D 的預設參數"
@@ -48669,275 +48748,275 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "變數 %qD 有函數型式"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "無效的參數類型 %qT"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在宣告 %q+D 中"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函式回傳了一個陣列"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函式回傳了一個函式"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員函式指標"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成對 void 的參照"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "表單指標到參考類型 %qT"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "表單參考到參考類型 %qT"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "無法宣告指標到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "無法宣告參考到經資格修飾函數型式 %qT"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "產生非類別類型 %qT 的成員指標"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "產生參照類型 %qT 的成員指標"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "建立參照 void 類型的成員指標"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "產生 %qT 的陣列"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT 不是類別、結構或聯合類型"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT 被解析到非列舉類型 %qT"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT 被解析到非類別類型 %qT"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, fuzzy, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr "ISO C++不允許初始設定式在中 lambda 運算式擷取清單"
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在範本中使用 %qs"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定型態 %qT 不匹配解構式名稱 ~%qT"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依賴名 %qE 被解析為非類型，但實體化卻產生了一個類型"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定類型，請使用 %<typename %E%>"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用無效欄位 %qD"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "無效的使用的包裝擴展運算式"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用 %<...%>到展開引數包裝"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被宣告在中這個範圍，而找不到任何宣告是由 argument-dependent 查找於點的實體化"
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "宣告在中附屬基底 %qT 找不到由資格不符的查找"
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用 %<this->%D%>做為替代"
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用 %<%T::%D%>做為替代"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%q+D 宣告的在此，稍後在中轉譯單位"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT 既不是類別也不是命名空間"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD 既不是類別也不是命名空間"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT 是/使用了匿名類型"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "模板引數用於 %qD 使用本地型態 %qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT 是一個可變類型"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型運算式 %qE 不是常數"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  試圖實體化 %qD"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "%q#T 的類別範本實體化有歧義"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "對非範本 %q#D 的明確實體化"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD 並非靜態資料成員的類別模板"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "沒有找到與 %qD 匹配的範本"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "型態 %qT 用於明確的實體化 %qD 不匹配宣告的型態 %qT"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "對 %q#D 的明確實體化"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "對 %q#D 重複的明確實體化"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++1998 禁止使用的 %<extern%> 於明確的實體化"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "為範本實體化化套用了存儲類型 %qD"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "明確的實體化的 non-class 模板 %qD"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "明確實體化非範本類型 %qT"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T 的明確實體化出現在範本定義之前"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允許在明確實體化時使用 %qE"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "對 %q#T 重複的明確實體化"
@@ -48949,96 +49028,96 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "明確實體化 %qD 時沒有可用的定義"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, fuzzy, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "模板具現化深度超出最大值的 %d 舉例說明 %q+D, 可能會從虛擬表格產生 (使用 -ftemplate-depth=到增加最大值)"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "無效的模板 non-type 參數"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T 並非有效型態用於模板 non-type 參數"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, fuzzy, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "deducing 從 brace-enclosed 初始設定式清單需求 # 包含 <initializer_list>"
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "非範本 %qD 做為範本"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "  模板引數推導/替代失敗："
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考慮內聯函式"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "無法 deduce %qT 從 %qE"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不滿足其約束："
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -49199,471 +49278,471 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  因為 %q+#D 已在基礎類別中宣告過"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, fuzzy, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "建議明確的大括號周圍清空內文在中 %<do%> 敘述"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "無法確定 asm 運算元 %qE 的類型"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, fuzzy, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "__label__ 宣告是只有允許的在中函式範圍"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "在靜態成員函式中使用成員 %q+D 無效"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "解構函式不能有參數"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "靜態成員函式中不能使用 %<this%>"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "在非成員函式中使用 %<this%> 無效"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "在頂層使用 %<this%> 無效"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "偽解構函式名的限定作用欄位無效"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的類型 %qT 不匹配解構函式名 ~%qT"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE 的類型不是 %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, fuzzy, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "複合實字的 non-object 型態 %qT"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "範本參數必須使用 %<class%> 或 %<typename%> 關鍵字"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "將類型 %qT 做為範本的範本參數的預設值無效"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "範本的範本參數的預設引數無效"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "在範本參數清單中定義了 %q#T"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "對限定類型 %qT 的定義無效"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "無效的基礎類別"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名聯合中出現保護成員 %q+#D"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD 未被擷取"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函式中使用 %<auto%> 變數"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "在包含函式中使用參數"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "使用的參數 %qD 外側函式內文"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "不匹配的引數"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "範本參數 %qD(類型為 %qT)不允許出現在整數運算式中，因為它的類型不是整數或列舉"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "命名空間 %qD 做為運算式"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "將類別範本 %qT 做為運算式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多繼承網格中對 %qD 的存取有歧義"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD 不能出現在常數運算式中"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE 的類型不明"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qT 不是列舉類型型態"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "參數包裝 __bases 只有有效在中模板宣告"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "無法套用 %<offsetof%> 到解構式 %<~%T%>"
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "無法套用 %<offsetof%> 到成員函式 %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "對 %qD 的參照有歧義"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE 有無效的型態用於 %<reduction%>"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD 並非變數在中子句 %<firstprivate%>"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD 並非變數在中子句 %<lastprivate%>"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> 值必須是正值"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, fuzzy, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "崩潰引數需要正面的常數整數運算式"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "切片結束必須是整數"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD 出現一次以上在中資料子句"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "排程資料塊大小運算式必須是積分"
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD 並非變數在中子句 %qs"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "太多 %qs 子句"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "numthreads 運算式必須是積分(_T)"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> 未被定義為一個指標類型"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD 不是檔案，命名空間或區塊範圍變數"
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE 指令無法在中 %qT 定義"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, fuzzy, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "差異介於 %qE 和 %qD 沒有整數類型"
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用兩不同的變數用於記憶體"
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 msgid "static assertion failed"
 msgstr "靜態假設失敗：%E"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "靜態假設失敗：%s"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, fuzzy, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "non-constant 條件用於靜態假設"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "引數到 decltype 必須是運算式"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "decltype 無法解析位址的多載化函式"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "第三運算元的條件運算式沒有任何效果"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "範本引數 %qE 混雜了範本參數"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -49679,110 +49758,110 @@
 msgid "lambda-expression in a constant expression"
 msgstr "運算式 %qE 並非 constant-expression"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "只能為類別定義套用 %qE 屬性"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "請求的 init_priority 不是一個整數常數"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能將 %qE 屬性用於某個類別的物件的檔案作用欄位定義"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "請求的 init_priority 越界"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "請求的 init_priority 保留為內部使用"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE 屬性在此平臺上不受支援"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "%qD 宣告為 %qT 的一個成員"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qD 屬性需要單一 NTBS 引數"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "引數的 %qE 屬性並非字串常數"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> 不是一個有效的宣告"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE 屬性在不是類別的類型上被忽略"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略屬性套用到 %qT 之後定義"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE 屬性套用只有到函式"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "零做為空指標常數"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失敗，於 %s:%d"
@@ -50472,107 +50551,107 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到類型 %qT 的轉換無效，從類型 %qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "不能從 %qT 轉換到 %qT，為引數 %qP(屬於 %qD)"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "無法轉換 %qT 到 %qT 在中預設引數"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "無法轉換 %qT 到 %qT 在中引數傳遞"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "無法轉換 %qT 到 %qT"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "無法轉換 %qT 到 %qT 在中初始化"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "無法轉換 %qT 到 %qT 在中回傳"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "無法轉換 %qT 到 %qT 在中指派"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "回傳值類型 %q#T 為不完全"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "參數 %qP 的 %qD 也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "參數也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "目標的轉換也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "目標的初始化也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "left-hand 側邊的指派也許是 candidate 用於格式屬性"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在傳遞引數 %P (屬於 %q+D)"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "回傳臨時變數的參照"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "回傳了一個非左值的參照"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "回傳了對局部變數的 %q+D 的參照"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "回傳了局部變數的 %q+D 的位址"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "解構函式回傳值"
@@ -50579,55 +50658,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能從建構式的異常處理中回傳"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "建構式回傳值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在回傳 %qT 的函式中，回傳敘述不帶回傳值"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<brace-enclosed initializer list>"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, fuzzy, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "不一致類型 %qT 和 %qT deduced 用於 lambda 傳回類型"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "不一致推導用於 %qT：%qT 然後 %qT"
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "在回傳「void」的函式中，回傳敘述帶回傳值"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> 不能回傳 NULL，除非它被宣告為 %<throw()%> (或 -fcheck-new 起作用)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, fuzzy, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "使用暫時的做為 lvalue"
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, fuzzy, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "使用 xvalue (rvalue 參考) 做為 lvalue"
@@ -54694,87 +54773,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "程序指標初始化目標於 %L 可能無法是程序指標"
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2008:指標函式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable 運算式在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "『%s』在中變數定義語境 (%s) 於 %L 並非變數"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "具名的常數『%s』在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "LOCK_TYPE 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虛引數『%s』與含義 (在中) 在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中指標關聯語境 (%s) 於 %L"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "變數『%s』是保護的和無法出現在中變數定義語境 (%s) 於 %L"
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "變數『%s』無法出現在中變數定義語境 (%s) 於 %L 在中 PURE 程序"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到 vector-indexed 目標無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Associate-name『%s』無法出現在中變數定義語境 (%s) 於 %L 因為它的目標於 %L 無法，還是"
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "『%s』於 %L 關聯的到運算式無法已用於變數定義語境 (%s)"
@@ -54966,12 +55045,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L 處定義賦值的第二個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第一個參數必須是 INTENT(IN)"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L 處運算子介面的第二個參數必須是 INTENT(IN)"
@@ -55766,512 +55845,527 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "Fortran 2003:DP 格式說明符不允許於 %C"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr "延伸：X 描述元需求前導空格計數於 %L"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr "延伸：$ 描述元於 %L"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ 應該是最後一筆說明符在中格式於 %L"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "延伸：缺少的正面的寬度之後 L 描述元於 %L"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr "延伸：缺少的正面的寬度之後 L 描述元於 %L"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "Fortran 2008:『G0』在中格式於 %L"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr "正面的寬度必要項在中格式說明符 %s 於 %L"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "週期必要項在中格式說明符 %s 於 %L"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "週期必要項在中格式說明符於 %L"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr "H 格式說明符於 %L 是 Fortran 95 刪除的特徵"
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "延伸：缺少的逗號於 %L"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s 在中格式字串於 %L"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr "外來字元在中格式於 %L"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr "格式敘述在中模組主要區塊於 %C"
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "%C 處的 ENTRY 敘述不能出現在 INTERFACE 中"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "%C 處缺少格式標籤"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "無效的值用於 %s 規格於 %C"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "重複 %s 指定，於 %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "變數 %s 無法含義 (在中) 於 %C"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "變數 %s 無法指派的在中 PURE 程序於 %C"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "重複的 %s 標籤指定，位於 %C"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "常數運算式在中格式標籤於 %L 必須是的型態預設字元"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "格式標籤於 %L 必須是的型態 default-kind 字元或的整數"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "刪除的特徵：指派的變數在中格式標籤於 %L"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L has not been assigned a format label"
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "變數「%s」在 %L 尚未指派到格式標籤"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, fuzzy, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr "純量『%s』在中格式標籤於 %L 不是指派的變數"
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr "延伸：Non-character 在中格式標籤於 %L"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "Non-character 假設的形狀陣列元素在中格式標籤於 %L"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "Non-character 假設的大小陣列元素在中格式標籤於 %L"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "Non-character 指標陣列元素在中格式標籤於 %L"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "%s 標記在 %L 處必須具有類型 %s"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "%s 標籤於 %L 必須是字元串的預設 kind"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "%s 標記在 %L 處必須是標量"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr "Fortran 2003：%L 處的 IOMSG 標記"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Fortran 95 需求預設整數在中 %s 標籤於 %L"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr "Fortran 2008:Nondefault 邏輯的在中 %s 標籤於 %L"
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr "單位尚未指定於 %L"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr "延伸：轉換標籤於 %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Fortran 2003:%s 說明符在中 %s 敘述於 %C 有值『%s』"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "%s 說明符在中 %s 敘述於 %C 有無效的值『%s』"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "延伸：%s 說明符在中 %s 敘述於 %C 有值『%s』"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "%s 說明符在中 %s 敘述於 %C 有無效的值『%s』"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "OPEN 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr "單位說明符不允許與 NEWUNIT 於 %C"
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr "NEWUNIT 說明符必須有檔案=或狀態=『暫用』於 %C"
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "開啟敘述於 %C 必須有單位或 NEWUNIT 指定的"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:非同步=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:空白=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:十進位=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:編碼=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:四捨五入=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:符號=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "CLOSE 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "關閉敘述於 %L 需要單元號碼"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "單元號碼在中關閉敘述於 %L 必須是 non-negative"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s 敘述不允許在中 PURE 程序於 %C"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr "單元號碼在中敘述於 %L 必須是 non-negative"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "單元號碼在中敘述於 %L 必須是 non-negative"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003：%C 處的 FLUSH 敘述"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing format with default unit at %C"
 msgstr "%C 處缺少格式標籤"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "%C 處重複的 UNIT 指定"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "%C 處重複的格式指定"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "符號「%s」在名稱清單「%s」是 INTENT(IN)，位於 %C"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "%C 處重複的 NML 指定"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "符號『%s』於 %C 必須是名稱表列群組名稱"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "%C 處的 END 標記不允許出現在輸出敘述中"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "單位尚未指定於 %L"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "%L 處指定的 UNIT 必須是 INTEGER 運算式或一個 CHARACTER 變數"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "無效的表單的寫入敘述於 %L, 單位必要項"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "內部單位與向量註標於 %L"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "%L 處外部 IO UNIT 不能是陣列"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "名稱表列『%s』在中讀取敘述於 %L 含有符號『%s』該項可能無法出現在中變數定義語境"
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, fuzzy, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 是 polymorphic 和需要定義的輸入/輸出程序"
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, fuzzy, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr "Fortran 2003:名稱表列物件『%s』在中名稱表列『%s』於 %L 與 ALLOCATABLE 或指標成分"
+
+#: fortran/io.c:3317
+#, fuzzy, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 有 ALLOCATABLE 或指標成分和因而需要定義的輸入/輸出程序"
+
+#: fortran/io.c:3328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "延伸：逗號之前 i/o 項目清單於 %L"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR 標記標籤 %d 在 %L 處未定義"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END 標記標籤 %d 在 %L 處未定義"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR 標記標籤 %d 在 %L 處未定義"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT 標籤 %d 在 %L 處未定義"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "%C 處 I/O 迭代語法錯誤"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "%C READ 敘述需要變數"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "需要 %s 敘述，於 %C 處"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 敘述在 %C 處語法錯誤"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "Fortran 2003:內部檔案於 %L 與名稱表列"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "非同步=說明符於 %L 必須是初始化運算式"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:填充=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:DELIM=於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "%C 處的 PRINT 名稱清單是一個擴充"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "%C 處 I/O 清單中需要逗號"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "%C 處的 PRINT 敘述不允許出現在 PURE 程序中"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE 敘述不允許出現在 %C 處的 PURE 程序中"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENGTH 標籤無效的在中查詢敘述於 %C"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "查詢敘述於 %L 無法包含兩者檔案和單位說明符"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "%L 處的 INQUIRE 敘述需要 FILE 或 UNIT 限定符"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "單元號碼在中敘述於 %L 必須是 non-negative"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "查詢敘述於 %L 需要擱置=說明符與識別號=說明符"
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003:等待於 %C 不允許在中 Fortran 95"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "等待敘述不允許在中 PURE 程序於 %C"
@@ -57177,260 +57271,260 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "缺少通用規格在中使用敘述於 %C"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr "Fortran 2003:重新命名運算子在中使用敘述於 %C"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "名稱『%s』於 %C 已使用的做為外部模組名稱。"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "Fortran 2008:Coarray 宣告於 %C"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "%C 處的 ENTRY 敘述不能出現在巢狀的子程式中"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "%C SAVE 敘述語法錯誤"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "Reading module %s at line %d column %d: %s"
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "讀出模組 %s，於列 %d 行 %d：%s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "Writing module %s at line %d column %d: %s"
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "讀入模組 %s，於列 %d 行 %d：%s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, fuzzy, gcc-internal-format
 #| msgid "Module %s at line %d column %d: %s"
 msgid "Module %qs at line %d column %d: %s"
 msgstr "模組 %s 位於列 %d 行 %d：%s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "寫入模組檔案時發生錯誤：%s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, fuzzy, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "『%s』的模組『%s』，匯入的於 %C, 也是名稱的目前的程式單元"
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "符號『%s』引用於 %L 找不到在中模組『%s』"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, fuzzy, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "使用者運算子『%s』引用於 %L 找不到在中模組『%s』"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Intrinsic 運算子『%s』引用於 %L 找不到在中模組『%s』"
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "無法開啟模組檔案「%s」寫入，在 %C 處：%s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "寫入模組檔案「%s」時發生錯誤：%s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "無法刪除模組檔案『%s』：%s"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "無法重新命名模組檔案『%s』到『%s』：%s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "無法刪除暫時的模組檔案『%s』：%s"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "符號『%s』已經宣告"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, fuzzy, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "符號『%s』，引用於 %L, 不是在中已選標準"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "符號『%s』引用於 %L 找不到在中 intrinsic 模組 ISO_C_BINDING"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "符號『%s』已經宣告"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, fuzzy, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "使用的 intrinsic 模組『%s』於 %C 衝突與非內建模組名稱使用的在之前"
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, fuzzy, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "使用的 NUMERIC_STORAGE_SIZE 具名的常數從 intrinsic 模組 ISO_FORTRAN_ENV 於 %L 是不相容的與選項 %s"
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "使用的 NUMERIC_STORAGE_SIZE 具名的常數從 intrinsic 模組 ISO_FORTRAN_ENV 於 %C 是不相容的與選項 %s"
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "符號『%s』引用於 %L 找不到在中 intrinsic 模組 ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%C 處非預期的 CASE 敘述"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003:ISO_FORTRAN_ENV intrinsic 模組於 %C"
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, fuzzy, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "找不到 intrinsic 模組具名的『%s』於 %C"
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "Fortran 2003:「使用::模組」於 %C"
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "Fortran 2003:ISO_C_BINDING 模組於 %C"
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "無法開啟模組檔案「%s」讀取，在 %C 處：%s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, fuzzy, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "使用的非內建模組『%s』於 %C 衝突與 intrinsic 模組名稱使用的在之前"
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, fuzzy, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "檔案『%s』開啟的於 %C 並非 GFORTRAN 模組檔案"
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr "無法使用相同模組我們正在建立！"
@@ -59832,7 +59926,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "無法解析特定的函式『%s』於 %L"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -61342,448 +61436,438 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "Fortran 2003:通用名稱『%s』的函式『%s』於 %L 相同名稱做為衍生類型於 %L"
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "假設的大小陣列『%s』在中名稱表列『%s』於 %L 未被允許"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與假設的形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列陣列物件『%s』與 nonconstant 形狀在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "Fortran 2003:名稱表列物件『%s』與 nonconstant 字元長度在中名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, fuzzy, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 是 polymorphic 和需要定義的輸入/輸出程序"
-
-#: fortran/resolve.c:13924
-#, fuzzy, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "Fortran 2003:名稱表列物件『%s』在中名稱表列『%s』於 %L 與 ALLOCATABLE 或指標成分"
-
-#: fortran/resolve.c:13942
-#, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』被宣告私人的和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "名稱表列物件『%s』已 use-associated 私人的成分和無法成員的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "名稱表列物件『%s』有私人的成分和無法成員的公用的名稱表列『%s』於 %L"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "程序屬性衝突與名稱表列屬性在中『%s』於 %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "參數陣列『%s』於 %L 無法自動或的已推遲形狀"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "隱含地型態的參數『%s』於 %L 不匹配稍後隱含的型態"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "不相容的衍生類型在中參數於 %L"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "共同區塊『%s』於 %L 無法有外部屬性"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "保護的屬性衝突與外部屬性於 %L"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "程序屬性衝突與保護的屬性於 %L"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "『%s』於 %L 有 CONTIGUOUS 屬性但是不是陣列指標或 assumed-shape 陣列"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "假定大小的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "假定外形的陣列在 %L 處必須是啞引數"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L 處的符號不是一個 DUMMY 變數"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "『%s』於 %L 無法有值屬性因為它並非虛引數"
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "字元虛設變數『%s』於 %L 與值屬性必須有常數長度"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C 可交流的字元虛設變數『%s』於 %L 與值屬性必須有長度一個"
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "衍生類型『%s』於 %L 是的型態『%s』，該項未被定義"
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "假設的形狀陣列『%s』於 %L 未被允許在中初始化運算式"
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "變數『%s』於 %L 無法同時有 ALLOCATABLE 和繫結©屬性"
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "變數『%s』於 %L 無法同時有指標和繫結©屬性"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "迴圈變數於 %C 無法 coarray"
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "變數『%s』於 %L 無法繫結©因為它是 neither 共同區塊 nor 宣告的於模組等級範圍"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003:公用的 %s『%s』於 %L 的私人的衍生類型『%s』"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "變數 %s 於 %L 的型態 LOCK_TYPE 或與 subcomponent 的型態 LOCK_TYPE 必須是 coarray"
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "含義 (出) 虛引數『%s』於 %L 是假設的大小和因而無法有預設初始設定式"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "虛引數『%s』於 %L 的 LOCK_TYPE 不應該是含義 (出)"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函數計算結果『%s』於 %L 不應該是 coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "變數『%s』於 %L 的型態 (C_PTR) 或型態 (C_FUNPTR) 不應該是 coarray"
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "變數『%s』於 %L 與 coarray 成分應該是 nonpointer，nonallocatable 純量"
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "變數『%s』於 %L 是 coarray 和不是 ALLOCATABLE，儲存 nor 虛引數"
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Coarray 變數『%s』於 %L 不應該有 codimensions 與已推遲形狀"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Allocatable coarray 變數『%s』於 %L 必須已已推遲形狀"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "變數『%s』於 %L 是含義 (出) 和可以因而無法是 allocatable coarray 或有 coarray 成分"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "Coarray 虛設變數『%s』於 %L 不允許在中繫結©程序『%s』"
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "名稱表列 %s 無法重新命名的由使用關聯到 %s"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate 於 %L 不是儲存"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "區塊資料元素『%s』於 %L 必須是在中共同"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "資料陣列『%s』於 %L 必須被指定的在中前一個宣告"
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "資料元素『%s』於 %L 無法有 coindex"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "資料元素『%s』於 %L 是指標和因而必須是全部陣列"
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Nonconstant 陣列區段於 %L 在中資料敘述"
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "資料敘述於 %L 有更多變數比值"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "開始的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "結束的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步驟的 implied-do 迴圈於 %L 無法被簡化到常數"
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "資料敘述於 %L 有更多值比變數"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "標籤 %d 於 %L 經定義但未被使用"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "標籤 %d 於 %L 經定義但無法被使用"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 必須有序列屬性為等價物件"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 無法有 ALLOCATABLE 成分為等價物件"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "衍生類型變數『%s』於 %L 與預設初始化無法在中等價與變數在中共同"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "衍生類型變數『%s』於 %L 與指標成分無法等價物件"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L 處 EQUIVALENCE 敘述語法錯誤"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "還是所有或沒有任何物件在中等價設定於 %L 應該有保護的屬性"
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, fuzzy, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "共同區塊成員『%s』於 %L 無法等價物件在中 pure 程序『%s』"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "具名的常數『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "陣列『%s』於 %L 與 non-constant 邊界無法等價物件"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "結構成分『%s』於 %L 無法等價物件"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字串長度為零"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003:公用的函式『%s』於 %L 的私人的型態『%s』"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "ENTRY「%s」在 %L 處沒有 IMPLICIT 類型"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "使用者運算子程序『%s』於 %L 必須是函式"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "使用者運算子程序『%s』於 %L 無法假設的字元長度"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "使用者運算子程序『%s』於 %L 必須至少有一個引數"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "第一個引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "秒引數的運算子介面於 %L 無法可選的"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "運算子介面於 %L 必須有，最多，兩引數"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "包含的程序『%s』於 %L 的 PURE 程序必須也是 PURE"
@@ -62886,12 +62970,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "指標物件於 %C 不應該被 coindexed"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, fuzzy, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr "Fortran 2003:內部檔案於 %L 與名稱表列"
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "錯誤的 IO 基礎類別型(%d)"
@@ -64746,9 +64830,6 @@
 #~ msgid "Variables this size and smaller go in the tiny section. (default 4)"
 #~ msgstr "變數這個大小和較小前往在中微小的區段。(預設 4)"
 
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "產生浮點乘加指令"
-
 #~ msgid "Warn if .class files are out of date"
 #~ msgstr "當 .class 檔案已過時時給出警告"
 
@@ -66147,10 +66228,6 @@
 #~ msgstr "字元變數於 %L 有負長度 %d，長度已被設定為零"
 
 #, fuzzy
-#~ msgid "NAMELIST object '%s' in namelist '%s' at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
-#~ msgstr "名稱表列物件『%s』在中名稱表列『%s』於 %L 有 ALLOCATABLE 或指標成分和因而需要定義的輸入/輸出程序"
-
-#, fuzzy
 #~ msgid "Possible front-end bug: Deferred array size without pointer, allocatable attribute or derived type without allocatable components."
 #~ msgstr "可能的前端錯誤：已推遲陣列大小而無需指標，allocatable 屬性或衍生類型而無需 allocatable 成分。"
 
Index: gcc/po/id.po
===================================================================
--- gcc/po/id.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/id.po	(.../branches/gcc-7-branch)
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.4.1\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2009-11-10 09:00+0700\n"
 "Last-Translator: Arif E. Nugroho <arif_endro@yahoo.com>\n"
 "Language-Team: Indonesian <translation-team-id@lists.sourceforge.net>\n"
@@ -208,13 +208,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "konstanta pecahan disalah gunakan"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -593,63 +593,63 @@
 " dilewatkan ke berbagai sub-proses dipanggil oleh %s. Dalam tujuan untuk melewatkan\n"
 " ke pilihan lain di proses ini pilihan -W<huruf> harus digunakan.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, fuzzy, c-format
 #| msgid "Processing spec %c%s%c, which is '%s'\n"
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Memproses spesifikasi %c%s%c, yang mana '%s'\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Target: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Dikonfigurasikan dengan: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Model Thread: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "versi gcc %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "gcc versi driver %s%smenjalankan gcc versi %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "memasang: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "aplikasi: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "perpustakaan: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -658,16 +658,16 @@
 "\n"
 "Untuk instruksi pelaporan bug, mohon lihat:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "(C)"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -677,7 +677,7 @@
 "ADA GARANSI; bahkan tidak untuk DIPERDAGANGKAN atau KECOCOKAN UNTUK SEBUAH TUJUAN TERTENTU.\n"
 "\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -690,7 +690,7 @@
 "===============\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -699,7 +699,7 @@
 "Gunakan \"-Wl,OPSI\" untuk melewatkan \"OPSI\" ke penghubung.\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -710,7 +710,7 @@
 "============\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -724,18 +724,18 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+#| msgid "  -n, --no-output                 Do not create an output file\n"
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -n, --no-output                 Jangan buat sebuah berkas keluaran\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 #| msgid "  -v, --version                   Print version number, then exit\n"
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -v, --version                   Tampilkan nomor versi, dan keluar\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -n, --no-output                 Jangan buat sebuah berkas keluaran\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -751,14 +751,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -786,31 +786,31 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -f, --function                      Print function level info\n"
 msgstr "  -h, --help                      Tampilkan bantuan ini, kemudian keluar\n"
 
-#: gcov-tool.c:422
+#: gcov-tool.c:421
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr "  -h, --help                      Tampilkan bantuan ini, kemudian keluar\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:422
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr "  -h, --help                      Tampilkan bantuan ini, kemudian keluar\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:423
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -o, --object                        Print object level info\n"
 msgstr "  -h, --help                      Tampilkan bantuan ini, kemudian keluar\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -899,20 +899,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Tampilkan bantuan ini, kemudian keluar\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Tampilkan informasi untuk setiap blok dasar\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Masukan kemungkinan percabangan dalam keluaran\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, fuzzy, c-format
 #| msgid ""
 #| "  -c, --branch-counts             Given counts of branches taken\n"
@@ -924,17 +919,22 @@
 "  -c, --branch-counts             Berikan jumlah dari percabangan yang diambil\n"
 "                                    daripada persentasi\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, fuzzy, c-format
 #| msgid "  --help                   Display this information\n"
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  --help                   Tampilkan informasi ini\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Keluarkan ringkasan untuk setiap fungsi\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Tampilkan bantuan ini, kemudian keluar\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1130,82 +1130,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s:graph tidak terselesaikan untuk '%s'\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Baris dijalankan:%s dari %d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Tidak baris yang dijalankan\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s '%s'\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Percabangan dijalankan:%s dari %d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "Diambil paling tidak sekali:%s dari %d\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Tidak ada percabangan\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Pemanggilan dijalankan:%s dari %d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Tidak ada panggilan\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s:tidak ada baris untuk '%s'\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "call   %2d mengembalikan %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "call   %2d tidak pernah dijalankan\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "branch %2d diambil %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "branch %2d tidak pernah dijalankan\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "tidak terkondisi %2d diambil %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "tidak terkondisi %2d tidak pernah dijalankan\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, fuzzy, c-format
 #| msgid "%s:cannot open source file\n"
 msgid "Cannot open source file %s\n"
@@ -1322,91 +1322,91 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, fuzzy, c-format
 #| msgid "(%s %s %s %s %s"
 msgid "%s  Same as %s."
 msgstr "(%s %s %s %s %s"
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[aktif]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[non-aktif]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Tidak ada pilihan dengan karakteristik yang diinginkan ditemukan\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, fuzzy, c-format
 #| msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end\n"
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Tidak ditemukan apapun. Gunakan --help=%s untuk menunjukan *seluruh* pilihan yang didukung oleh %s front-end\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Seluruh pilihan dengan karakteristik yang diinginkan telah ditampilkan\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "Pilihan berikut adalah target spesifik"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "Pilihan berikut mengontrol pesan peringatan kompiler"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "Pilihan berikut mengontrol optimisasi"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "Pilihan berikut adalah independen terhadap bahasa pemrograman"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "Pilihan --param dikenal sebagai parameters"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "Pilihan berikut hanya spesifik terhadap bahasa "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "Pilihan berikut tidak didukung oleh bahasa "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "Pilihan berikut tidak terdokumentasi"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "Pilihan berikut mengambil argumen terpisah"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "Pilihan berikut mengambil argumen tergabung"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "Pilihan berikut adalah berhubungan dengan bahasa"
 
@@ -3069,8 +3069,8 @@
 msgid "<command-line>"
 msgstr "<baris-perintah>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "Unsupported operand for code '%c'"
@@ -3091,7 +3091,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "hilang operan"
@@ -3114,8 +3114,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -3131,18 +3131,18 @@
 msgstr "nilai %%r tidak valid"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "nilai %%R tidak valid"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "nilai %%N tidak valid"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "nilai %%P tidak valid"
@@ -3152,7 +3152,7 @@
 msgid "invalid %%h value"
 msgstr "nilai %%h tidak valid"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "nilai %%L tidak valid"
@@ -3173,7 +3173,7 @@
 msgstr "nilai %%U tidak valid"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "nilai %%s tidak valid"
@@ -3183,7 +3183,7 @@
 msgid "invalid %%C value"
 msgstr "nilai %%C tidak valid"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "nilai %%E tidak valid"
@@ -3194,7 +3194,7 @@
 msgstr "relokasi unspek tidak diketahui"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "kode %%xn tidak valid"
@@ -3262,7 +3262,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "operan kode keluaran tidak valid"
@@ -3273,29 +3273,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "UNSPEC tidak valid sebagai operan"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "operan shift tidak valid"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "instruksi Thumb terprediksi"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "instruksi terprediksi dalam urutan berkondisi"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3303,113 +3303,113 @@
 msgid "invalid operand for code '%c'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "instruksi tidak pernah dijalankan"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "alamat operan membutuhkan batasan untuk X, Y, atau Z register"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 #, fuzzy
 #| msgid "output operand %d must use %<&%> constraint"
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "keluaran operan %d harus menggunakan batasan %<&%>"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 #, fuzzy
 #| msgid "bad address, not (reg+disp):"
 msgid "bad address, not an I/O address:"
 msgstr "alamat buruk, bukan (reg+disp):"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 #, fuzzy
 #| msgid "address offset not a constant"
 msgid "bad address, not a constant:"
 msgstr "ofset alamat bukan sebuah konstanta"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "alamat buruk, bukan (reg+disp):"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "alamat buruk, bukan post_inc atau pre_dec:"
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "internal kompiler error. Alamat buruk:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "internal kompiler error. Kode tidak diketahui:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "insn tidak valid:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "insn tidak benar:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "insn move tidak dikenal:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "shift insn buruk:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "internal kompiler error. shift tidak benar:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 #| msgid "invalid types in fixed-point conversion"
 msgid "unsupported fixed-point conversion"
 msgstr "tipe tidak valid dalam konversi titik tetap"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "redefinisi dari parameter %q+D"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 msgid "structure field"
 msgstr ""
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 #| msgid "function return type cannot be function"
 msgid "return type of function"
 msgstr "tipe kembali fungsi tidak dapat berupa fungsi"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr ""
 
@@ -3432,7 +3432,7 @@
 msgstr "operan const_double tidak valid"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3656,99 +3656,99 @@
 msgid "bad output_condmove_single operand"
 msgstr "operan output_condmove_single buruk"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "UNSPEC tidak valid sebagai operan"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid use of asm flag output"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'O'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 #| msgid "invalid operand for code '%c'"
 msgid "invalid operand size for operand code 'Z'"
 msgstr "operan tidak valid untuk kode '%c'"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'D'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "operan bukan sebuah kode kondisi, kode operan 'D' tidak valid"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "kode operan '%c' tidak valid"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "batasan untuk operan tidak valid"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "mode insn tidak diketahui"
 
@@ -3787,7 +3787,7 @@
 msgid "invalid %%P operand"
 msgstr "operan %%P tidak valid"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "nilai %%p tidak valid"
@@ -3845,7 +3845,7 @@
 msgstr "alamat post-increment bukan sebuah register"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "alamat buruk"
 
@@ -3884,7 +3884,7 @@
 msgstr "alamat tidak valid"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "alamat tidak valid"
 
@@ -3977,312 +3977,312 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "Mencoba menjalankan '%s' dalam shell untuk meningkatkan batasannya.\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 #, fuzzy
 #| msgid "Use hardware floating point"
 msgid "-mvsx requires hardware floating point"
 msgstr "Gunakan piranti keras titik pecahan"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-f%s dan -msdata=%s tidak kompatibel"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 #, fuzzy
 #| msgid "Disable indexed addressing"
 msgid "-mvsx needs indexed addressing"
 msgstr "Non-aktifkan pengalamatan terindeks"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 #, fuzzy
 #| msgid "-f%s and -msdata=%s are incompatible"
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-f%s dan -msdata=%s tidak kompatibel"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "--resource membutuhkan -o"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 #, fuzzy
 #| msgid "Generate code in little endian mode"
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "Hasilkan kode dalam mode little endian"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "--resource membutuhkan -o"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 #, fuzzy
 #| msgid "bad test"
 msgid "bad move"
 msgstr "tes buruk"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "nilai %%H tidak valid"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "nilai %%f tidak valid"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "nilai %%F tidak valid"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "nilai %%G tidak valid"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "kode %%j tidak valid"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "kode %%J tidak valid"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "nilai %%k tidak valid"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "nilai %%K tidak valid"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "nilai %%O tidak valid"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "nilai %%q tidak valid"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "nilai %%T tidak valid"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "nilai %%u tidak valid"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "nilai %%v tidak valid"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "nilai %%x tidak valid"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "nilai %%ytidak valid, coba menggunakan batasan 'Z'"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 #| msgid "Do not generate a single exit point for each function"
 msgid "Could not generate addis value for fusion"
 msgstr "Jangan hasilkan sebuah titik keluar tunggal untuk setiap fungsi"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 #| msgid "unable to generate reloads for:"
 msgid "Unable to generate load/store offset for fusion"
 msgstr "tidak dapat menghasilkan reloads untuk:"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "tidak dapat menguraikan alamat"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid reference for 'J' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, fuzzy, c-format
 #| msgid "invalid operand for 'O' modifier"
 msgid "invalid address for 'O' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'O'"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'R' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, fuzzy, c-format
 #| msgid "invalid operand for 'b' modifier"
 msgid "invalid address for 'S' output modifier"
 msgstr "operan tidak valid untuk pemodifikasi 'b'"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, fuzzy, c-format
 #| msgid "invalid operand output code"
 msgid "invalid constant - try using an output modifier"
 msgstr "operan kode keluaran tidak valid"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, fuzzy, c-format
 #| msgid "invalid expression for min lvalue"
 msgid "invalid expression - try using an output modifier"
 msgstr "ekspresi tidak valid untuk minimal lvalue"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, fuzzy, c-format
 #| msgid "invalid operand for 'o' modifier"
 msgid "invalid expression for output modifier '%c'"
 msgstr "operan tidak valid untuk pemodifikasi 'o'"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "Argumen AltiVec dilewatkan ke fungsi yang tidak berprototipe"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "target penunjuk dalam kembali berbeda dalam signedness"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4308,22 +4308,22 @@
 msgid "created and used with different endianness"
 msgstr "dibuat dan digunakan dengan endianness berbeda"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "operan %%Y tidak valid"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "operan %%A tidak valid"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "operan %%B tidak valid"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
@@ -4330,23 +4330,23 @@
 msgid "invalid %%C operand"
 msgstr "operan %%P tidak valid"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, fuzzy, c-format
 #| msgid "invalid %%P operand"
 msgid "invalid %%D operand"
 msgstr "operan %%P tidak valid"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "operan %%f tidak valid"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "operan %%s tidak valid"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4528,30 +4528,30 @@
 msgid "bad test"
 msgstr "tes buruk"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "nilai %%D tidak valid"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "topeng tidak valid"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "nilai %%d tidak valid"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "nilai %%t/%%b tidak valid"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "tidak ada register dalam alamat"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "ofset alamat bukan sebuah konstanta"
 
@@ -4574,8 +4574,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "diduga %<,%>"
@@ -4597,14 +4597,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "diduga %<(%>"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<,%>"
@@ -4636,7 +4636,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<)%>"
@@ -4645,7 +4645,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<]%>"
@@ -4658,7 +4658,7 @@
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<}%>"
@@ -4666,7 +4666,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "diduga %<{%>"
@@ -4676,7 +4676,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<:%>"
@@ -4692,25 +4692,25 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "ekspresi %qE dari tipe kelas abstrak %qT tidak dapat digunakan dalam ekspresi throw"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<while%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4720,20 +4720,20 @@
 msgid "expected %<.%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@end%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<>%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%>"
@@ -4742,17 +4742,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "diduga %<=%>"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<[%>"
@@ -4764,7 +4764,7 @@
 msgid "(anonymous)"
 msgstr "<anonim>"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<<%>"
@@ -4776,11 +4776,11 @@
 msgid "expected label"
 msgstr "Diduga nama"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "kandidat 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "kandidat 2:"
 
@@ -5038,11 +5038,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "kandidat adalah:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 #, fuzzy
 #| msgid "candidate 1:"
 msgid "candidate is:"
@@ -5240,89 +5240,89 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "Lebar positif dibutuhkan"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "lebar tidak negatif dibutuhkan"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 #| msgid "Unexpected element '%c' in format string at %L"
 msgid "Unexpected element %qc in format string at %L"
 msgstr "Elemen tidak terduga '%c' dalam format string di %L"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "Akhir dari format string tidak terduga"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr "lebar nol dalam format deskripsi"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "Hilang leading left parenthesis"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 #| msgid "template argument required for %<%s %T%>"
 msgid "Left parenthesis required after %<*%>"
 msgstr "argumen template dibutuhkan untuk %<%s %T%>"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "Diduga P edit deskripsi"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "P pendeskripsi membutuhkan awalah faktor pengali"
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-#| msgid "Missing right parenthesis at %C"
-msgid "Right parenthesis expected at %C"
-msgstr "Hilang paranthesis kanan di %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 #, fuzzy
 #| msgid "Positive width required with T descriptor"
 msgid "Comma required after P descriptor"
 msgstr "Lebar positif dibutuhkan dengan deskripsi T"
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr "Lebar positif dibutuhkan dengan deskripsi T"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "Penspesifikasi E tidak diperbolehkan dengan pendeskripsi g0"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "Lebar positif eksponen dibutuhkan"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+#| msgid "Missing right parenthesis at %C"
+msgid "Right parenthesis expected at %C"
+msgstr "Hilang paranthesis kanan di %C"
+
+#: fortran/io.c:1040
 #, fuzzy
 #| msgid "Period required in format specifier at %C"
 msgid "Period required in format specifier"
 msgstr "Period dibutuhkan dalam format penspesifikasi di %C"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -5332,75 +5332,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "Sintaks error dalam ekspresi di %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "Tidak terduga EOF"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Integer overflow"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "Nama terlalu panjang"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Nama buruk"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Diduga nama"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "Diduga parenthesis kiri"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "Diduga parenthesis kanan"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "Diduga integer"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "Diduga string"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum(): Enum tidak ditemukan"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "Diduga nama atribut bit"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "Diduga integer string"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "Error mengubah integer"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "Diduga real string"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "Diduga tipe ekspresi"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "Operator buruk"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "Tidak terduga akhir dari modul"
 
@@ -5697,12 +5697,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "Argumen aktual berisi terlalu sedikit elemen untuk argumen dummy '%s' (%lu/%lu) di %L"
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -6108,7 +6108,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "tidak boleh digunakan bersamaan -m32 dan -m64"
 
@@ -9987,7 +9987,7 @@
 msgstr "Spesifikasikan ukuran bit dari ofset TLS langsung"
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 #, fuzzy
 #| msgid "Schedule code for given CPU"
@@ -10282,7 +10282,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 #, fuzzy
 #| msgid "Use ROM instead of RAM"
 msgid "Use LRA instead of reload."
@@ -10591,7 +10591,7 @@
 msgid "Use 80-bit long double."
 msgstr "Gunakan 128-bit long double"
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 #| msgid "Use 64-bit long double"
@@ -10598,7 +10598,7 @@
 msgid "Use 64-bit long double."
 msgstr "Gunakan 64-bit long double"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy
 #| msgid "Use 128-bit long double"
@@ -11992,117 +11992,117 @@
 msgid "64 bit ABI."
 msgstr "64 bit ABI"
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 #, fuzzy
 #| msgid "Maintain backchain pointer"
 msgid "Maintain backchain pointer."
 msgstr "jaga backchain penunjuk"
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 #, fuzzy
 #| msgid "Additional debug prints"
 msgid "Additional debug prints."
 msgstr "Tampilan debug tambahan"
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 #, fuzzy
 #| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
 msgstr "arsitektur ESA/390"
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 #| msgid "Enable decimal floating point hardware support"
 msgid "Enable decimal floating point hardware support."
 msgstr "Aktifkan dukungan perangkat keras desimal titik pecahan"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 #| msgid "Enable hardware floating point"
 msgid "Enable hardware floating point."
 msgstr "Aktifkan perangkat keras titik pecahan"
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 #| msgid "Use hardware quad FP instructions"
 msgid "Use hardware transactional execution instructions."
 msgstr "Gunakan hardware quad FP instruksi"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr ""
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 #, fuzzy
 #| msgid "Use packed stack layout"
 msgid "Use packed stack layout."
 msgstr "Gunakan packed stack layout"
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 #, fuzzy
 #| msgid "Use bras for executable < 64k"
 msgid "Use bras for executable < 64k."
 msgstr "Gunakan bras untuk executable < 64k"
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 #| msgid "Disable hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "Non-aktifkan perangkat keras titik pecahan"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 #, fuzzy
 #| msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered"
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "Set jumlah maksimum dari bytes yang harus disisakan ke ukuran stack sebelum sebuah instruksi trap triggered"
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 #, fuzzy
 #| msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit"
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "Keluarkan kode tambahan dalam prolog fungsi untuk trap jika ukuran stack melebihi batas yang diberikan"
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 #| msgid "Generate string instructions for block moves"
 msgid "Use the mvcle instruction for block moves."
 msgstr "Hasilkan string instruksi untuk perpindahan blok"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 #, fuzzy
 #| msgid "Warn if a function uses alloca or creates an array with dynamic size"
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "Peringatkan jika sebuah fungsi menggunakan alloca atau membuat sebuah array dengan ukuran dinamis"
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 #, fuzzy
 #| msgid "Warn if a single function's framesize exceeds the given framesize"
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "Peringatkan jika sebuah fungsi tunggal framesize melebihi framesize yang diberikan"
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 #, fuzzy
 #| msgid "z/Architecture"
 msgid "z/Architecture."
 msgstr "z/Arsitektur"
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -12164,11 +12164,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -12478,104 +12478,122 @@
 msgstr "Gunakan ekstensi set instruksi UltraSPARC Visual"
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 #, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "Gunakan ekstensi set instruksi UltraSPARC Visual"
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 #, fuzzy
 #| msgid "Use UltraSPARC Visual Instruction Set extensions"
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "Gunakan ekstensi set instruksi UltraSPARC Visual"
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
 #, fuzzy
+#| msgid "Generate floating-point multiply-add instructions"
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr "Hasilkan titik pecahan instruksi perkalian-penambahan"
+
+#: config/sparc/sparc.opt:102
+#, fuzzy
 #| msgid "Use decimal floating point instructions"
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "Gunakan instruksi desimal titik pecahan"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 #| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "Penunjuk adalah 64 bit"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 #| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "Penunjuk adalah 32 bit"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "Gunakan 64 bit ABI"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "Gunakan 32 bit ABI"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 #, fuzzy
 #| msgid "Use stack bias"
 msgid "Use stack bias."
 msgstr "Gunakan stack bias"
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 #, fuzzy
 #| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "Gunakan struct di alignmen lebih kuat untun double-word salinan"
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 #, fuzzy
 #| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "Optimisasi tail call instruksi dalam perakit dan penghubung"
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "Gunakan feature dari dan jadwalkan kode untuk CPU yang diberikan"
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 #, fuzzy
 #| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
 msgstr "Gunakan kode model SPARC-V9 yang diberikan"
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "Enable debug output."
 msgstr "Aktifkan keluaran debug"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "Aktifkan pemeriksaan kembali strict 32 bit ps ABI struktur."
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -18390,7 +18408,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -18935,7 +18953,7 @@
 msgstr "diduga bukan tuple"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -19304,157 +19322,157 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 #| msgid "invalid application of %qs to a void type"
 msgid "invalid comparison of non-ordered type"
 msgstr "aplikasi tidak valid dari %qs ke sebuah tipe void"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 #, fuzzy
 #| msgid "%Hduplicate class will only be compiled once"
 msgid "slice can only be compared to nil"
 msgstr "%H duplikasi class hanya akan dikompile sekali"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 #, fuzzy
 #| msgid "%qs can only be specified for functions"
 msgid "map can only be compared to nil"
 msgstr "%qs hanya dapat dispesifikasikan untuk fungsi"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 #, fuzzy
 #| msgid "%Hduplicate class will only be compiled once"
 msgid "func can only be compared to nil"
 msgstr "%H duplikasi class hanya akan dikompile sekali"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 #| msgid "invalid operand to %%R"
 msgid "invalid operation (%s)"
 msgstr "operan tidak valid ke %%R"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 #| msgid "invalid application of %qs to incomplete type %qT "
 msgid "invalid comparison of non-comparable type"
 msgstr "apliasi tidak valid dari %qs ke tipe tidak lengkap %qT"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 #| msgid "invalid operand in the instruction"
 msgid "invalid comparison of generated struct"
 msgstr "operan tidak valid dalam instruksi"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of generated array"
 msgstr "penggunaan tidak valid dari bukan-lvalue array"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 #, fuzzy
 #| msgid "invalid use of non-lvalue array"
 msgid "invalid comparison of non-comparable array"
 msgstr "penggunaan tidak valid dari bukan-lvalue array"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 #, fuzzy
 #| msgid "Warn about implicit conversion"
 msgid "need explicit conversion"
 msgstr "Peringatkan tentang konversi implisit"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, fuzzy, c-format
 #| msgid "cannot convert type %qT to type %qT"
 msgid "cannot use type %s as type %s"
 msgstr "tidak dapat mengubah tipe %qT ke tipe %qT"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 #, fuzzy
 #| msgid "invalid receiver type %qs"
 msgid "different receiver types"
 msgstr "tipe penerima %qs tidak valid"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "different number of parameters"
 msgstr "redefinisi dari parameter %q+D"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 #, fuzzy
 #| msgid "invalid parameter type %qT"
 msgid "different parameter types"
 msgstr "tipe parameter %qT tidak valid"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr ""
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 msgid "different result types"
 msgstr ""
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible type for method %s%s%s"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, fuzzy, c-format
 #| msgid "incompatible type for argument %d of %qE"
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "tipe tidak kompatibel untuk argumen %d dari %qE"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 #, fuzzy
 #| msgid "error while parsing methods"
 msgid "type has no methods"
 msgstr "error ketika parsing metoda"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, fuzzy, c-format
 #| msgid "ambiguous abbreviation %s"
 msgid "ambiguous method %s%s%s"
 msgstr "kependekan %s ambigu"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, fuzzy, c-format
 #| msgid "missing argument to \"%s\""
 msgid "missing method %s%s%s"
 msgstr "hilang argumen ke \"%s\""
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -19640,7 +19658,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "terlalu sedikit argumen ke fungsi %<va_start%>"
@@ -19707,29 +19725,29 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%>"
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "penggunaan tidak valid dari %<auto%>"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "__builtin_set_thread_pointer is not supported on this target"
@@ -19737,7 +19755,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K penggunakan tidak valid dari %<__builtin_va_arg_pack ()%>"
@@ -19744,12 +19762,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%K penggunaan tidak valid dari %<__builtin_va_arg_pack_len ()%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%> argumen kedua harus berupa 1"
@@ -19756,65 +19774,65 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "format target tidak mendukung infinity"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "format target tidak mendukung infinity"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "%<va_start%> digunakan dalam fungsi dengan argumen tetap"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "jumlah dari argumen ke fungsi %<va_start%> salah"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "%<__builtin_next_arg%> dipanggil tanpa sebuah argumen"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "parameter kedua dari %<va_start%> bukan argumen bernama terakhir"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "perilaku tidak terdefinisi ketika parameter kedua dari %<va_start%> dideklarasikan dengan penyimpanan %<register%>"
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%K argumen pertama dari %D harus berupa sebuah penunjuk, integer kedua konstanta"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, fuzzy, gcc-internal-format
 #| msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%K argumen terakhir dari %K bukan sebuah konstanta integer diantara 0 dan 3"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%Kmencoba membebaskan sebuah objek bukan heap %qD"
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%Kmencoba membebaskan sebuah objek bukan heap"
@@ -20774,12 +20792,12 @@
 msgstr "%qE atribut diabaikan karena %qT telah didefinisikan"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F digunakan tetapi tidak pernah didefinisikan"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
@@ -20881,13 +20899,13 @@
 msgid "cannot find '%s'"
 msgstr "tidak dapat menemukan '%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
 msgid "pex_init failed: %m"
 msgstr "pex_init gagal"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -20898,7 +20916,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, fuzzy, gcc-internal-format
 #| msgid "pex_init failed"
@@ -21123,7 +21141,7 @@
 msgid "error writing %qs"
 msgstr "error menulis %qs"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "tidak dapat membuka %s"
@@ -21206,17 +21224,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -21330,12 +21348,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%K panggilan ke %qs dideklarasikan dengan atribut error: %s"
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K panggilan ke %qs dideklarasikan dengan atribut peringatan: %s"
@@ -21350,13 +21368,13 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "ukuran frame %wd bytes adalah lebih besar dari %wd bytes"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not open final insn dump file %qs: %m"
 msgstr "tidak dapat membuka berkas dump %qs: %s"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 #| msgid "could not open dump file %qs: %s"
 msgid "could not close final insn dump file %qs: %m"
@@ -21372,7 +21390,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "perbandingan selalu %d karena lebar dari bit-field"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "diasumsikan signed overflow tidak terjadi ketika menyederhanakan pemeriksaan jangkauan"
@@ -21402,7 +21420,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "diasumsikan signed overflow tidak terjadi ketika mengkombinasi konstan diantar sebuah perbandingan"
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "pemeriksaan fold: pohon asal diubah oleh fold"
@@ -21413,7 +21431,7 @@
 msgid "total size of local objects too large"
 msgstr "%J ukuran total dari objek lokal terlalu besar"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "batasan tidak memungkinkan dalam %<asm%>"
@@ -21521,68 +21539,74 @@
 msgid "input file %qs is the same as output file"
 msgstr "%qs bukan sebuah berkas keluaran yang valid"
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, fuzzy, gcc-internal-format
+#| msgid "output filename specified twice"
+msgid "output filename may not be empty"
+msgstr "nama berkas keluaran dispesifikasikan dua kali"
+
+#: gcc.c:4501
+#, fuzzy, gcc-internal-format
 #| msgid "warning: -pipe ignored because -save-temps specified"
 msgid "-pipe ignored because -save-temps specified"
 msgstr "peringatan: -pipe diabaikan karenan -save-temps sudah dispesifikasikan"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, fuzzy, gcc-internal-format
 #| msgid "warning: '-x %s' after last input file has no effect"
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "peringatan: '-x %s' setelah berkas masukan terakhir tidak memilik pengaruh"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, fuzzy, gcc-internal-format
 #| msgid "switch '%s' does not start with '-'"
 msgid "switch %qs does not start with %<-%>"
 msgstr "switch '%s' tidak diawali dengan '-'"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "tidak dapat membuka berkas balasan %s sementara"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "tidak dapat menulis ke berkas balasan %s sementara"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "tidak dapat menutup berkas balasan %s sementara"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' invalid"
 msgid "spec %qs invalid"
 msgstr "spesifikasi '%s' tidak valid"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' has invalid '%%0%c'"
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "spesifikasi '%s' memiliki '%%0%c' tidak valid"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' has invalid '%%W%c"
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "spesifikasi '%s' memiliki '%%W%c' tidak valid"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, fuzzy, gcc-internal-format
 #| msgid "spec '%s' has invalid '%%x%c'"
 msgid "spec %qs has invalid %<%%x%c%>"
@@ -21591,254 +21615,254 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, fuzzy, gcc-internal-format
 #| msgid "spec failure: '%%*' has not been initialized by pattern match"
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "spec gagal: '%%*' belum diinisialisasi oleh pencocokan pola"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, fuzzy, gcc-internal-format
 #| msgid "spec failure: unrecognized spec option '%c'"
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "spec gagal: pilihan spec tidak dikenal '%c'"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 #| msgid "unknown spec function '%s'"
 msgid "unknown spec function %qs"
 msgstr "fungsi spesifikasi '%s' tidak diketahui"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 #| msgid "error in args to spec function '%s'"
 msgid "error in args to spec function %qs"
 msgstr "error dalam argumen ke fungsi spesifikasi '%s'"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "spesifikasi nama fungsi salah format"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "tidak ada argumen untuk spesifikasi fungsi"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "argumen spesifikasi fungsi salah format"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, fuzzy, gcc-internal-format
 #| msgid "braced spec '%s' is invalid at '%c'"
 msgid "braced spec %qs is invalid at %qc"
 msgstr "braced spesifikasi '%s' tidak valid di '%c'"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, fuzzy, gcc-internal-format
 #| msgid "braced spec body '%s' is invalid"
 msgid "braced spec body %qs is invalid"
 msgstr "braced spesifikasi tubuh '%s' tidak valid"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "could not write to response file %s"
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "tidak dapat menulis ke berkas response %s"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s:could not open output file '%s'\n"
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s:tidak dapat membuka berkas keluaran '%s'\n"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr ""
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "spec gagal: lebih dari satu arg ke SYSROOT_SUFFIX_SPEC"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "spec gagal: lebih dari sat arg ke SYSROOT_HEADERS_SUFFIX_SPEC"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "pilihan baris perintah \"%s\" tidak dikenal"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option \"%s\""
 msgid "unrecognized command line option %<-%s%>"
 msgstr "pilihan baris perintah \"%s\" tidak dikenal"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "tidak dikonfigurasikan dengan akhiran header sysroot"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "tidak ada berkas masukan"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, fuzzy, gcc-internal-format
 #| msgid "cannot specify -o with -c or -S with multiple files"
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "tidak dapat menspesifkasikan -o dengan -c atau -S dengan beberapa berkas"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: %s kompiler tidak terpasang di sistem ini"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr ""
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, fuzzy, gcc-internal-format
 #| msgid "comparison is always %d"
 msgid "comparing final insns dumps"
 msgstr "perbandingan selalu %d"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "field %qs not found"
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "field %qs tidak ditemukan"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s: berkas masukan penghubung tidak digunakan karena proses penyambungan belum selesai"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "bahasa %s tidak dikenal"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 #| msgid "multilib spec '%s' is invalid"
 msgid "multilib spec %qs is invalid"
 msgstr "spesifikasi multilib '%s' tidak valid"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, fuzzy, gcc-internal-format
 #| msgid "multilib exclusions '%s' is invalid"
 msgid "multilib exclusions %qs is invalid"
 msgstr "ekslusi multilib '%s' tidak valid"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select '%s' is invalid"
 msgid "multilib select %qs %qs is invalid"
 msgstr "pemilihan multilib '%s' tidak valid"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 #| msgid "multilib select '%s' is invalid"
 msgid "multilib select %qs is invalid"
 msgstr "pemilihan multilib '%s' tidak valid"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, fuzzy, gcc-internal-format
 #| msgid "multilib exclusion '%s' is invalid"
 msgid "multilib exclusion %qs is invalid"
 msgstr "eksklusi multilib '%s' tidak valid"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, fuzzy, gcc-internal-format
 #| msgid "environment variable \"%s\" not defined"
 msgid "environment variable %qs not defined"
 msgstr "variabel lingkungan \"%s\" tidak terdefinisi"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, fuzzy, gcc-internal-format
 #| msgid "invalid version number `%s'"
 msgid "invalid version number %qs"
 msgstr "nomor versi `%s' tidak valid"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "terlalu sedikit argumen ke %%:perbandingan-versi"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "terlalu banyak argumen ke %%:perbandingan-versi"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, fuzzy, gcc-internal-format
 #| msgid "unknown operator '%s' in %%:version-compare"
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "operator tidak dikenal '%s' dalam %%:perbandingan-versi"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %%:version-compare"
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "terlalu banyak argumen ke %%:perbandingan-versi"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %%:version-compare"
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "terlalu banyak argumen ke %%:perbandingan-versi"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to %%:version-compare"
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "terlalu sedikit argumen ke %%:perbandingan-versi"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to %%:version-compare"
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "terlalu banyak argumen ke %%:perbandingan-versi"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too few arguments to function"
 msgid "too few arguments to %%:replace-extension"
 msgstr "terlalu sedikit argumen ke fungsi"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of arguments to function %<va_start%>"
 msgid "wrong number of arguments to %%:debug-level-gt"
@@ -21999,9 +22023,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "declared here"
@@ -22432,250 +22456,250 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, fuzzy, gcc-internal-format
 #| msgid "no return statement in function returning non-void"
 msgid "using result of function returning %<void%>"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "masukan %d bukan memori harus tetap berada dalam memori"
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "masukan memori %d tidak secara langsung dapat dialamatkan"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in target region"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing target region"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "threadprivate variable %qE used in untied task"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, fuzzy, gcc-internal-format
 #| msgid "%Henclosing parallel"
 msgid "enclosing task"
 msgstr "%Hparallel yang melingkupi"
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "error closing %s: %m"
 msgid "enclosing %qs"
 msgstr "error menutup %s: %m"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, fuzzy, gcc-internal-format
 #| msgid "%qs not specified in enclosing parallel"
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qs tidak dispesifikan dalam parallel yang melingkupi"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%H%qE tidak dideklarasikan (pertama digunakan dalam fungsi ini)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "variabel %q+D dideklarasikan %<inline%>"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 #| msgid "%Hiteration variable %qE is unsigned"
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%H variabel iterasi %qE unsigned"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should be private"
 msgstr "iterasi variabel %qs seharusnya private"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qD should not be firstprivate"
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be reduction"
 msgstr "iterasi variabel %qs seharusnya bukan reduksi"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should not be reduction"
 msgid "iteration variable %qE should not be linear"
 msgstr "iterasi variabel %qs seharusnya bukan reduksi"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qD should not be firstprivate"
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 #| msgid "iteration variable %qs should be private"
 msgid "iteration variable %qE should not be private"
 msgstr "iterasi variabel %qs seharusnya private"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once in map clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, fuzzy, gcc-internal-format
 #| msgid "%s variable %qs is private in outer context"
 msgid "%s variable %qE is private in outer context"
 msgstr "%s variabel %qs private dalam konteks luar"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "deklarasi template dari %qD tidak valid"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "daerah terurut harus secara dekat nested didalam sebuah daerah loop dalam sebuah clause terurut"
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<}%> before %<else%>"
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification gagal"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT dipromosikan ke %qT ketika dilewatkan melalui %<...%>"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(jadi anda harus melewatkan %qT bukan %qT ke %<va_arg%>)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jika kode ini dicapai, aplikasi akan digagalkan"
@@ -22921,7 +22945,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
 #: ipa-devirt.c:1235
@@ -23023,7 +23047,7 @@
 
 #: ipa-devirt.c:1576
 #, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr ""
 
 #: ipa-devirt.c:1599
@@ -23433,204 +23457,204 @@
 msgid "multiple loop axes specified for routine"
 msgstr "class penyimpanan dispesifikasikan untuk nama tipe"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region may not be closely nested inside of critical or explicit task region"
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr "daerah terurut mungkin tidak secara dekat nested didalam daerah kritis atau eksplist daerah tugas"
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr ""
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 #| msgid "invalid IACC argument"
 msgid "invalid arguments"
 msgstr "argumen IACC tidak valid"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, fuzzy, gcc-internal-format
 #| msgid "barrier region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "daerah barrier mungkin tidak secara dekat nested didalam dari work-sharing, critical, terurut atau eksplisit daerah tugas"
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "work-sharing region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "daerah work-sharing mungkin tidak secara dekat nested didalam dari work-sharing, critical, terurut atau eksplisit daerah tugas"
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, fuzzy, gcc-internal-format
 #| msgid "master region may not be closely nested inside of work-sharing or explicit task region"
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr "daerah master mungkin tidak secara dekat nested didalam daerah work-sharing atau eksplist daerah tugas"
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr "daerah terurut harus secara dekat nested didalam sebuah daerah loop dalam sebuah clause terurut"
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr "daerah terurut harus secara dekat nested didalam sebuah daerah loop dalam sebuah clause terurut"
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region may not be closely nested inside of critical or explicit task region"
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr "daerah terurut mungkin tidak secara dekat nested didalam daerah kritis atau eksplist daerah tugas"
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr "daerah terurut harus secara dekat nested didalam sebuah daerah loop dalam sebuah clause terurut"
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, fuzzy, gcc-internal-format
 #| msgid "critical region may not be nested inside a critical region with the same name"
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr "daerah kritis mungkin tidak nested didalam sebuah daerah kritikal dengan nama sama"
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid exit from OpenMP structured block"
 msgid "invalid exit from %s structured block"
 msgstr "exit tidak valid dari blok struktur OpenMP"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid entry to OpenMP structured block"
 msgid "invalid entry to %s structured block"
@@ -23637,7 +23661,7 @@
 msgstr "masukan tidak valid ke blok struktur OpenMP"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid branch to/from an OpenMP structured block"
 msgid "invalid branch to/from %s structured block"
@@ -23726,7 +23750,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "pilihan baris perintah %qs tidak didukung dalam konfigurasi ini"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, fuzzy, gcc-internal-format
 #| msgid "missing argument to \"%s\""
 msgid "missing argument to %qs"
@@ -23903,140 +23927,150 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr "tidak dikenal include_flags 0x%x dilewatkan ke print_specific_help"
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 #| msgid "warning: unrecognized argument to --help= option: %.*s\n"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "peringatan: argumen tidak dikenal ke pilihan --help=: %.*s\n"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 #| msgid "warning: unrecognized argument to --help= option: %.*s\n"
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "peringatan: argumen tidak dikenal ke pilihan --help=: %.*s\n"
 
-#: opts.c:1828
+#: opts.c:1835
 #, fuzzy, gcc-internal-format
 #| msgid "warning: --help argument %.*s is ambiguous, please be more specific\n"
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "warning: --help argumen %.*s adalah ambigu, mohon lebih spesifik\n"
 
-#: opts.c:1837
+#: opts.c:1844
 #, fuzzy, gcc-internal-format
 #| msgid "warning: unrecognized argument to --help= option: %.*s\n"
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "peringatan: argumen tidak dikenal ke pilihan --help=: %.*s\n"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 #| msgid "%s is not supported by this configuration"
 msgid "HSA has not been enabled during configuration"
 msgstr "%s tidak didukung untuk konfigurasi ini"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "alignmen struktur harus berupa kelipatan kecil dari dua, bukan %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 #| msgid "unknown stack check parameter \"%s\""
 msgid "unknown stack check parameter %qs"
 msgstr "tidak diketahui parameter pemeriksaan stack \"%s\""
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "dwarf version %d is not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: --param argumen seharusnya dari bentuk NAME=NILAI"
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "nilai ---param %qs tidak valid"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs"
 msgstr "nilai ---param %qs tidak valid"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "nilai ---param %qs tidak valid"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "target sistem tidak mendukung keluaran debug"
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 #| msgid "debug format \"%s\" conflicts with prior selection"
 msgid "debug format %qs conflicts with prior selection"
 msgstr "format debug \"%s\" konflik dengan pemilihan sebelumnya"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognised debug output level \"%s\""
 msgid "unrecognized debug output level %qs"
 msgstr "tingkat keluaran debug \"%s\" tidak dikenal"
 
-#: opts.c:2533
+#: opts.c:2540
 #, fuzzy, gcc-internal-format
 #| msgid "debug output level %s is too high"
 msgid "debug output level %qs is too high"
 msgstr "tingkat keluaran debug %s terlalu tinggi"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "memperoleh batas maksimum ukuran berkas core: %m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "menset batas maksimum ukuran berkas core ke: %m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "pilihan debuggin gcc: %c tidak dikenal"
 
-#: opts.c:2627
+#: opts.c:2634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-Werror=%s: No option -%s"
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s: Tidak ada pilihan -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -24401,7 +24435,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "register digunakan untuk dua variabel register global"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, fuzzy, gcc-internal-format
 #| msgid "  conflict with %q+D"
 msgid "conflicts with %qD"
@@ -25030,13 +25064,13 @@
 msgid "error closing %s: %m"
 msgstr "error menutup %s: %m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 #| msgid "assert: %s is assign compatible with %s"
 msgid "self-tests incompatible with -E"
 msgstr "assert: %s adalah assign kompatibel dengan %s"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -26009,53 +26043,53 @@
 msgid "in expansion of macro %qs"
 msgstr ""
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i has multiple EH edges"
 msgstr "BB %i tidak dapat throw tetapi memiliki EH edges"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i can not throw but has EH edges"
 msgid "BB %i can not throw but has an EH edge"
 msgstr "BB %i tidak dapat throw tetapi memiliki EH edges"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "BB %i pernyataan terakhir memiliki daerah set tidak benar"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unnecessary EH edge %i->%i"
 msgid "Incorrect EH edge %i->%i"
 msgstr "EH edge %i->%i tidak diperlukan"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i too many fallthru edges"
 msgstr "insn salah dalam ujung fallthru"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "BB %i last statement has incorrectly set region"
 msgid "BB %i has incorrect edge"
 msgstr "BB %i pernyataan terakhir memiliki daerah set tidak benar"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong insn in the fallthru edge"
 msgid "BB %i has incorrect fallthru edge"
@@ -26161,35 +26195,35 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "in a call to built-in function %qD"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D declared but never defined"
 msgid "in a call to function %qD declared here"
 msgstr "fungsi inline %q+D dideklarasikan tetapi tidak pernah didefinisikan"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, fuzzy, gcc-internal-format
 #| msgid "cannot optimize loop, the loop counter may overflow"
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "tidak dapat mengoptimisasi loop, pertemuan loop mungkin overflow"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "within this loop"
@@ -26557,11 +26591,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -27588,7 +27622,7 @@
 msgid "type was previously declared %qE"
 msgstr "setelah deklarasi sebelumnya %q+D"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -27875,7 +27909,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "alamat dari %qD akan selalu dievaluasi sebagai %<true%>"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "disarankan parentheses disekitar assignmen digunakan sebagai nilai kebenaran"
@@ -28531,66 +28565,66 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "kelebihan tipe kualifier dalam format argumen (argumen %d)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%s%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "format %q.*s diduga bertipe %<%s%s%>, tetapi argumen %d memiliki tipe %qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%qs diduga sebuah konstanta argumen"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, fuzzy, gcc-internal-format
 #| msgid "format %q.*s expects type %<%T%s%>, but argument %d has type %qT"
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "format %q.*s diduga bertipe %<%T%s%>, tetapi argumen %d memiliki tipe %qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, fuzzy, gcc-internal-format
 #| msgid "%qs expects a constant argument"
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%qs diduga sebuah konstanta argumen"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%> tidak didefinisikan sebagai sebuah tipe"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%> tidak didefinisikan sebagai %<long%> atau %<long long>"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%> tidak didefinisikan sebagai sebuah tipe"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%> tidak didefinisikan sebagai sebuah tipe"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe pointer"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "args yang akan diformat bukan %<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime format tidak dapat memformat argumen"
@@ -28696,7 +28730,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "%Hsalah tempat %<@%D%> Objective-C++ konstruk"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "tidak didukung bukan-standar pemotongan dari string literals"
@@ -28727,7 +28761,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
@@ -28743,22 +28777,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE tidak terinisialisasi"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "hilang predikat pengontrol"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "predikat pengontrol tidak valid"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "hilang ekspresi peningkatan"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "ekspresi peningkatan tidak valid"
@@ -29326,8 +29360,8 @@
 msgid "wrong type argument to %s"
 msgstr "tipe argumen salah ke abs"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "overflow dalam konstanta ekspresi"
@@ -30038,7 +30072,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 #| msgid "%<friend%> can only be specified inside a class"
 msgid "%<_Cilk_spawn%> may only be used inside a function"
@@ -30214,7 +30248,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "pilihan -mdebug-%s tidak dikenal"
@@ -30559,7 +30593,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 #| msgid "index mask must be an immediate"
 msgid "%Klane index must be a constant immediate"
@@ -30648,7 +30682,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "nilai %s tidak diketahui untuk pilihan -mfpu"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "switch -mcpu=%s conflicts with -march= switch"
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
@@ -30745,9 +30779,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "-mcpu=%s tidak valid"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 #| msgid "alias argument not a string"
 msgid "attribute %<target%> argument not a string"
@@ -30837,7 +30871,7 @@
 msgstr "nilai buruk %qs untuk -mmemory-latency"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -31025,237 +31059,237 @@
 msgid "insn addresses not freed"
 msgstr "Alamat buruk, bukan register:"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "this builtin is not supported for this target"
 msgstr "-fdata-sections tidak didukung untuk target ini"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "pemilih harus berupa sebuah immediate"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "mask harus berupa sebuah immediate"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, fuzzy, gcc-internal-format
 #| msgid "`%s' attribute argument should be between 0 to 255"
 msgid "the range of mask should be in 0 to 255"
 msgstr "argumen atribut `%s' seharusnya berada diantara 0 sampai 255"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -G are incompatible"
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-fPIC dan -G tidak kompatibel"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "target CPU tidak mendukung kode ARM"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "aktifkan dukungan backtrace hanya berarti ketika mengkompile untuk Thumb"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "aktifkan dukungan callee kerja sama yang berarti ketika mengkompile untuk Thumb"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g dengan -mno-apcs-frame mungkin tidak memberikan debugging yang masuk akal"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "tidak dapat menggunakan -mtp=cp15 dengan 16-bit Thumb"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC tidak kompatibel dengan Thumb"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "target CPU tidak mendukung instruksi THUMB"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support ARM mode"
 msgid "target CPU does not support unaligned accesses"
@@ -31263,150 +31297,150 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-mpcrel -fPIC is not currently supported on selected cpu"
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mpcrel -fPIC saat ini tidak didukung dalam cpu yang dipilih"
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "target CPU tidak mendukung kerja-sama"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check tidak kompatibel dengan -mno-apcs-frame"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic dan -macps-reent tidak kompatibel"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "APCS reentrant kode tidak didukung. Diabaikan"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable dan -msdata=%s tidak kompatibel"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt membutuhkan sebuah AAPCS kompatibel ABI untuk operasi yang sesuai"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi membutuhkan sebuah iwmmxt kapabel cpu"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "target CPU tidak mendukung kerja-sama"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support interworking"
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "target CPU tidak mendukung kerja-sama"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard dan VFP"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard dan VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "ukuran batas struktur hanya dapat diset ke %s"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, fuzzy, gcc-internal-format
 #| msgid "structure size boundary can only be set to %s"
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "ukuran batas struktur hanya dapat diset ke %s"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "RTP PIC tidak kompatibel dengan -msingle-pic-base"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= tidak berguna tanpa -fpic"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "tidak dapat menggunakan '%s' untuk register PIC"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, fuzzy, gcc-internal-format
 #| msgid "-freorder-blocks-and-partition does not work on this architecture"
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition tidak bekerja dalam arsitektur ini"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "target CPU tidak mendukung instruksi THUMB"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -31415,77 +31449,82 @@
 msgid "%qE attribute only applies to functions"
 msgstr "atribut %qs hanya berlaku ke fungsi"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD tidak boleh memiliki argumen dengan jumlah bervariabel"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute have effect only on public objects"
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE atribut hanya memiliki efek dalam objek publik"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "tidak dapat menghitung lokasi ril dari parameter terstack"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "Unexpected thumb1 far jump"
 msgstr "Tidak terduga akhir dari modul"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "tidak ada register bawah yang tersedia unruk popping register atas"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid vector type for attribute %qE"
 msgid "invalid fpu for attribute(target(\"%s\"))"
@@ -31494,13 +31533,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "atribut(target(\"%s\")) tidak diketahui"
@@ -31608,182 +31647,194 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot have default arguments"
 msgid "%qs function cannot have arguments"
 msgstr "%qD tidak dapat memiliki argumen baku"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 #| msgid "Function does not return a value"
 msgid "%qs function cannot return a value"
 msgstr "Fungsi tidak mengembalikan sebuah nilai"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, fuzzy, gcc-internal-format
 #| msgid "%qs appears to be a misspelled signal handler"
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs sepertinya salah nama signal handler"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Number of registers used to pass integer arguments"
 msgid "fixed register %s used to pass parameter to function"
 msgstr "Jumlah dari register yang digunakan untuk melewati argumen integer"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, fuzzy, gcc-internal-format
 #| msgid "weak declaration of %q+D not supported"
 msgid "writing to address space %qs not supported"
 msgstr "deklarasi lemah dari %q+D tidak didukung"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variadic functions"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%qE atribut hanya berlaku untuk fungsi variadic"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute only applies to variables"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute does not apply to types"
 msgid "%qE attribute address out of range"
 msgstr "atribut %qs tidak mengaplikasi ke tipe"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qs atribut hanya berlaku ke variabel"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %q+D shadows a parameter"
 msgid "static IO declaration for %q+D needs an address"
 msgstr "deklarasi dari %q+D membayangi sebuah parameter"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "IO definition for %q+D needs an address"
 msgstr "definisi sebelumnya dari %q+D ada disini"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "hanya variabel yang belum terinisialisasi yang dapat ditempatkan dalam daerah .noinit"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, fuzzy, gcc-internal-format
 #| msgid "only initialized variables can be placed into program memory area"
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "hanya variabel terinisialisasi yang dapat ditempatkan kedalam daerah memori aplikasi"
+
+#: config/avr/avr.c:10160
+#, fuzzy, gcc-internal-format
+#| msgid "only initialized variables can be placed into program memory area"
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "hanya variabel terinisialisasi yang dapat ditempatkan kedalam daerah memori aplikasi"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 #| msgid "MCU %qs supported for assembler only"
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU %qs hanya didukung untuk perakit saja"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, fuzzy, gcc-internal-format
 #| msgid "Conversion from %s to %s at %L"
 msgid "conversion from address space %qs to address space %qs"
 msgstr "Konversi dari %s ke %s di %L"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of module in string constant"
 msgid "%s expects a compile time integer constant"
 msgstr "Tidak terduga akhir dari modul dalam konstanta string"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -32084,12 +32135,12 @@
 msgid "invalid IACC argument"
 msgstr "argumen IACC tidak valid"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs diduga sebuah konstanta argumen"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
@@ -32287,7 +32338,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "model kode %qs tidak mendukung dalam mode %s bit"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "model kode %s tidak mendukung kode PIC"
@@ -32434,318 +32485,318 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 #| msgid "-fprefetch-loop-arrays not supported for this target"
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "-fprefetch-loop-array tidak didukung untuk target ini"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%spreferred-stack-boundary=%d%s is not between %d and 12"
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "%spreferred-stack-boundary=%d%s tidak berada diantara %d dan 12"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d tidak berada diantara %d dan 12"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 #| msgid "%<-march=%s%> is not compatible with the selected ABI"
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "%<-march=%s%> tidak kompatibel dengan ABI yang dipilih"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "%ssseregparam%s digunakan tanpa SSE aktif"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "set instruksi SSE non-aktif, menggunakan 387 aritmetik"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "set instruksi 387 non-aktif, menggunakan aritmetik SSE"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "stack probing membutuhkan %saccumulate-outgoing-args%s untuk pembenaran"
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown -m%s= option specified: '%s'"
 msgid "unknown option for -mrecip=%s"
 msgstr "pilihan -m%s= tidak diketahui dispesifikasikan: '%s'"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "pilihan(\"%s\") telah dispesifikasikan"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Specify when instructions are allowed to access code"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "Spesifikasikan kapan instruksi diperbolehkan untuk mengakses kode"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "atribut fastcall dan regparm tidak kompatibel"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute requires an integer constant argument"
 msgid "%qE attribute requires an integer constant argument"
 msgstr "atribut %qs membutuhkan sebuah argumen konstanta integer"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qE attribute larger than %d"
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "atribut fastcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, fuzzy, gcc-internal-format
 #| msgid "fastcall and stdcall attributes are not compatible"
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "atribut fastcall dan stdcall tidak kompatibel"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "atribut stdcall dan cdecl tidak kompatibel"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, fuzzy, gcc-internal-format
 #| msgid "stdcall and fastcall attributes are not compatible"
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "atribut stdcall dan fastcall tidak kompatibel"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "Memanggil %qT dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "does not support multilib"
 msgid "X32 does not support ms_abi attribute"
 msgstr "tidak mendukung multilib"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, fuzzy, gcc-internal-format
 #| msgid "AVX vector argument without AVX enabled changes the ABI"
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "argumen vektor AVX tanpa AVX aktif mengubah ABI"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "argumen vektor SSE tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "SSE vektor kembali tanpa SSE aktif mengubah ABI"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "argumen vektor MMX tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "MMX vektor kembali tanpa MMX aktif mengubah ABI"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan struct dengan sebuah anggota array flexible telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "register SSE kembali dengan SSE tidak aktif"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "argumen register SSE dengan SSE tidak aktif"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "x87 register kembali dengan x87 tidak aktif"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, fuzzy, gcc-internal-format
 #| msgid "Calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "Memanggil %qD dengan atribut sseregparm tanpa mengaktifkan SSE/SSE2"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "%s tidak didukung untuk fungsi nested"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, fuzzy, gcc-internal-format
 #| msgid "%s not supported for nested functions"
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
@@ -32753,331 +32804,331 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support flexible array members"
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 tidak mendukung keanggotaan array fleksibel"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "ukuran operan tidak didukung untuk register ekstended"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "register extended tidak memiliki setengah tinggi"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "ukuran operan tidak didukung untuk register ekstended"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, fuzzy, gcc-internal-format
 #| msgid "non-integral used in condition"
 msgid "non-integer operand used with operand code 'z'"
 msgstr "bukan integral digunakan dalam kondisi"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr ""
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 #| msgid "stack limit expression is not supported"
 msgid "Virtual function multiversioning not supported"
 msgstr "ekspresi batas stack tidak didukung"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+D"
 msgid "previous declaration of %D"
 msgstr "deklarasi sebelumnya dari %q+D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 #| msgid "__builtin_eh_return not supported on this target"
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "__builtin_eh_return tidak didukung dalam target ini"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs must be a 2-bit unsigned literal"
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument to -ffpe-trap is not valid: %s"
 msgid "Parameter to builtin not valid: %s"
 msgstr "Argumen ke -ffpe-trap tidak valid: %s"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 #| msgid "the third argument must be a 8-bit immediate"
 msgid "the third argument must be an 8-bit immediate"
 msgstr "argumen ketiga harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 1-bit immediate"
 msgid "the last argument must be an 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be a 3-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 1 bit immediate"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "argumen selanjutnya ke terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 #| msgid "argument must be a constant"
 msgid "the third argument must be comparison constant"
 msgstr "argumen harus berupa sebuah konstanta"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect comparison mode"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect sharing of tree nodes"
 msgid "incorrect rounding operand"
 msgstr "pembagian tidak benar dari titik pohon"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 5-bit immediate"
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 5 bit immediate"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 2-bit immediate"
 msgid "the last argument must be a 32-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 2 bit immediate"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE membutuhkan pilihan isa tidak diketahui"
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE membutuhkan pilihan isa %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumen terakhir harus berupa sebuah immediate"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be a 4-bit immediate"
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "argumen terakhir harus berupa sebuah 4 bit immediate"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, fuzzy, gcc-internal-format
 #| msgid "the fifth argument must be a 8-bit immediate"
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "argumen kelima harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 #| msgid "incorrect insn:"
 msgid "incorrect hint operand"
 msgstr "insn tidak benar:"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 #| msgid "the last argument must be an 8-bit immediate"
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "argumen terakhir harus berupa sebuah 8 bit immediate"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only available for 64-bit"
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qs atribut hanya tersedia untuk 64 bit"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "atribut ms_abi dan sysv_abi tidak kompatibel"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, fuzzy, gcc-internal-format
 #| msgid "%qs incompatible attribute ignored"
 msgid "%qE incompatible attribute ignored"
 msgstr "atribut %qs tidak kompatibel diabaikan"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "Interrupt Sevice Routines tidak dapat dikodekan dalam mode Thumb"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 #| msgid "unknown ira algorithm \"%s\""
 msgid "unknown asm flag output %qs"
 msgstr "algoritma ira \"%s\" tidak diketahui"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 #| msgid "invalid lvalue in asm output %d"
 msgid "invalid type for asm flag output"
 msgstr "lvalue tidak valid dalam keluaran asm %d"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown architecture '%s'"
 msgid "Unknown architecture specific memory model"
 msgstr "Arsitektur '%s' tidak dikenal"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unsupported combination: %s"
 msgid "unsupported simdlen %d"
 msgstr "kombinasi tidak didukung: %s"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 #| msgid "unused arguments in $-style format"
 msgid "unsupported argument type %qT for simd\n"
 msgstr "argumen yang tidak digunakan dalam $-gaya format"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -33208,7 +33259,7 @@
 msgid "argument %qd is not a constant"
 msgstr "argumen %qd bukan sebuah konstanta"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, penunjuk kosong"
@@ -33218,7 +33269,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND: Punctuation '%c' tidak diketahui"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND penunjuk kosong"
@@ -33326,7 +33377,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread hanya tersedia di fido"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ekspresi batas stack tidak didukung"
@@ -33859,8 +33910,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr "kode bawaan buruk"
@@ -34133,29 +34184,29 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on types"
 msgid "%qE attribute requires a void return type"
 msgstr "%qE attribut diabaikan dalam tipe"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ atribut tidak diijinkan dengan class auto storage"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -34180,7 +34231,7 @@
 msgid "-g option disabled"
 msgstr "-g pilihan tidak aktif"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "alignmen (%u) untuk %s melebihi maksimal alignmen untuk global common data. Menggunakan %u"
@@ -34324,167 +34375,167 @@
 msgid "junk at end of #pragma longcall"
 msgstr "sampah diakhir dari #pragma longcall"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "vec_extract only accepts 2 arguments"
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_extract hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_insert hanya menerima 3 argumen"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_insert hanya menerima 3 argumen"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_insert hanya menerima 3 argumen"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s hanya menerima %d argumen"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s hanya menerima 1 argumen"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract hanya menerima 2 argumen"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert hanya menerima 3 argumen"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "melewatkan argumen %d dari %qE mengabaikan kualifier frompointer target type"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%Jalias definitions not supported in this configuration"
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "%J definisi alias tidak didukung dalam konfigurasi ini"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "kombinasi parameter untuk AltiVec intrinsik tidak valid"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 membutuhkan arsitektur PowerPC64, mengaktifkan"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power tidak didukung untuk 64 bit Darwin; ini tidak kompatibel dengan perpustakaan C dan C++ yang terpasang"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, fuzzy, gcc-internal-format
 #| msgid "not configured for ABI: '%s'"
 msgid "not configured for SPE ABI"
 msgstr "tidak dikonfigurasikan untuk ABI: '%s'"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 #| msgid "Do not use PowerPC instruction set"
 msgid "not configured for SPE instruction set"
 msgstr "Jangan gunakan set instruksi PowerPC"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec tidak didukung dalam target ini"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, fuzzy, gcc-internal-format
 #| msgid "Spe not supported in this target"
 msgid "SPE not supported in this target"
 msgstr "Spe tidak didukung dalam target ini"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple tidak didukung di sistem little endian"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring tidak didukung di sistem little endian"
@@ -34491,73 +34542,73 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mdirect-move requires -mvsx"
 msgstr "--resource membutuhkan -o"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-vector requires -mvsx"
 msgstr "--resource membutuhkan -o"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode requires -mvsx"
 msgstr "--resource membutuhkan -o"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, fuzzy, gcc-internal-format
 #| msgid "-msingle-float option equivalent to -mhard-float"
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "pilihan -msingle-float ekuivalen dengan -mhard-float"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "--resource membutuhkan -o"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "--resource membutuhkan -o"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -34566,242 +34617,242 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "unknown vectorization library ABI type (%s) for %sveclibabi=%s %s"
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr "perpusatakaan vektorisasi tidak dikenal tipe ABI (%s) untuk pilihan %sveclibabi=%s %s"
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dikembalikan dengan referensi: ekstensi bukan standar ABI dengan tidak ada garansi kompabilitas"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "tidak dapat memberikan nilai kembali dalam register vektor karena instruksi altivec tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The ABI of passing union with long double has changed in GCC 4.4"
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "ABI dari melewatkan union dengan long double telah berubah dalam GCC 4.4"
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "tidak dapat melewatkan argumen dalam vektor register karena instruksi altivek tidak aktif, gunakan -maltivec untuk mengaktifkannya"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, fuzzy, gcc-internal-format
 #| msgid "The ABI of passing structure with complex float member has changed in GCC 4.4"
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "ABI dari melewatkan structure dengan anggota float kompleks telah berubah dalam GCC 4.4"
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC vektor dilewatkan dengan referensi: bukan ekstensi standar ABI dengan tidak ada garansi kompabilitas"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Treat the input file as already preprocessed"
 msgid "internal error: builtin function %s already processed"
 msgstr "Perlakukan berkas masukan seperti sudah terproses"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumen 1 harus berupa sebuah 5 bit signed literal"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "argumen 1 dari __builtin_altivec_predicate harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "argumen 1 dari __builtin_altivec_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%srtd%s is ignored in 64bit mode"
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s diabaikan dalam mode 64 bit"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "argumen 1 dari __builtin_spe_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %s only accepts a string argument"
@@ -34808,7 +34859,7 @@
 msgstr "%s hanya menerima 1 argumen"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "cpu %s is an invalid argument to builtin %s"
@@ -34815,301 +34866,306 @@
 msgstr "argumen ke fungsi bawaan tidak valid"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, fuzzy, gcc-internal-format
 #| msgid "argument 3 must be a 4-bit unsigned literal"
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argumen 3 harus berupa sebuah 4 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 1 must be 0 or 2"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumen 2 harus berupa sebuah 5 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 #| msgid "number must be 0 or 1"
 msgid "argument 2 must be 0 or 1"
 msgstr "angka harus berupa 0 atau 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 #| msgid "Argument of ATANH at %L must be inside the range -1 to 1"
 msgid "argument 3 must be in the range 0..15"
 msgstr "Argumen dari ATANH di %L harus berada didalam jangkauan -1 ke 1"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argumen ke %qs harus berupa sebuah 2 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "tidak teresolf overload untuk Altivec bawaan %qF"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "argumen ke dss harus berupa sebuah 2 bit unsigned literal"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "argumen ketiga ke %<__builtin_prefetch%> harus berupa sebuah konstan"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "argumen 1 dari __builtin_paired_predicate harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "argumen 1 dari __builtin_paired_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "argumen 1 dari __builtin_spe_predicate harus berupa sebuah konstanta"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "argumen 1 dari __builtin_spe_predicate diluar dari jangkauan"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "this builtin function is only available on the fr450"
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "fungsi bawaan ini hanya tersedia di fr450"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mspe option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %q+D declared as non-function"
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "fungsi bawaan %q+D dideklarasikan sebagai bukan-fungsi"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "built-in function %qs not supported for MIPS16"
 msgid "Builtin function %s is not supported with the current options"
 msgstr "fungsi bawaan %qs tidak didukung untuk MIPS16"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "stack frame terlalu besar"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target tidak didukung untuk mesin ini"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "tidak ada profiling dari kode 64 bit untuk ABI ini"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<long double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe boolean dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "penggunaan dari %<complex%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "penggunaan dari tipe titik pecahan desimal dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long%> in AltiVec types is invalid for 64-bit code"
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec tidak valid untuk kode 64 bit"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "penggunaan dari %<long%> dalam tipe AltiVec sudah ditinggalkan; gunakan %<int%>"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<long long%> in AltiVec types is invalid"
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "penggunaan dari %<long long%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<double%> in AltiVec types is invalid"
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "penggunaan dari %<double%> dalam tipe AltiVec tidak valid"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "mengeluarkan instruksi microcode %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "mengeluarkan kondisional instruksi microcode %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid use of '%%%c'"
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "penggunaan dari '%%%c' tidak valid"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%H%<#pragma%> is not allowed here"
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%H%<#pragma%> tidak diijinkan disini"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "spec '%s' is invalid"
 msgid "%s\"%s\"%s is invalid"
 msgstr "spesifikasi '%s' tidak valid"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -35301,6 +35357,7 @@
 msgstr "-mapcs-stack-check tidak kompatibel dengan -mno-apcs-frame"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 membutuhkan sebuah cpu PowerPC64"
@@ -35394,7 +35451,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -35422,7 +35479,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -35444,7 +35501,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -35459,40 +35516,40 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "konstanta argumen diluar dari jangkauan untuk %qs"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 #| msgid "unresolved overload for Altivec builtin %qF"
 msgid "unresolved overloaded builtin"
 msgstr "tidak teresolf overload untuk Altivec bawaan %qF"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, fuzzy, gcc-internal-format
 #| msgid "bad builtin code"
@@ -35499,126 +35556,126 @@
 msgid "bad builtin icode"
 msgstr "kode bawaan buruk"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "argumen ke fungsi bawaan tidak valid"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "ukuran total dari variabel lokal melebihi batas arsitektur"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 #| msgid "frame size of %qs is "
 msgid "frame size of %qs is %wd bytes"
 msgstr "ukuran frame dari %qs adalah "
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs menggunakan alokasi dinamis stack"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, fuzzy, gcc-internal-format
 #| msgid "-fPIC and -fpic are not supported for this target"
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr "-fPIC dan -fpic tidak didukung untuk target ini"
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "mode z/Arsitektur tidak didukung di %s"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64 bit ABI tidak didukung di mode ESA/390"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia di %s"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Hardware decimal floating point instructions not available on %s"
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia di %s"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "Hardware decimal floating point instructions not available in ESA/390 mode"
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "Instruksi perangkat keras titik pecahan desimal tidak tersedia dalam mode ESA/390"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, fuzzy, gcc-internal-format
 #| msgid "-mhard-dfp can't be used in conjunction with -msoft-float"
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp tidak dapat digunakan dalam konjungsi dengan -msoft-float"
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float tidak didukung dalam kombinasi"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "ukuran stack harus lebih besar dari nilai penjaga stack"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "ukuran stack harus lebih besar  dari 64k"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard mengimplikasikan penggunaan dari -mstack-size"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 #| msgid "argument to \"%s\" should be a non-negative integer"
 msgid "arguments to %qs should be non-negative integers"
 msgstr "argumen ke \"%s\" seharusnya sebuah integer tidak negatif"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 #| msgid "argument to %qs attribute larger than %d"
 msgid "argument to %qs is too large (max. %d)"
@@ -35625,7 +35682,7 @@
 msgstr "argumen ke atribut %qs lebih besar daripada %d"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 #| msgid "stack limits not supported on this target"
 msgid "value %qs is not supported by attribute %<target%>"
@@ -35689,27 +35746,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax hanya didukung untuk RTP PIC"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s tidak didukung untuk konfigurasi ini"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 tidak diijinkan dengan -m64"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "nilai (%s) buruk untuk pilihan -mcmodel="
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "-mcmodel= tidak didukung di sistem 32 bit"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 #| msgid "-fdata-sections not supported for this target"
 msgid "-fcall-saved-REG is not supported for out registers"
@@ -36019,22 +36077,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "konstanta tidak valid dalam %<#pragma pack%> - diabaikan"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "register boolean dibutuhkan untuk pilihan titik pecahan"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "-f%s tidak didukung dengan instruksi CONST16"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "PIC dibutuhkan tetapi tidak didukung dengan instruksi CONST16"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "hanya variabel tidak terinisialisasi yang dapat ditempatkan didaerah .bss"
@@ -36128,7 +36186,7 @@
 msgid "could not read the BRIG file"
 msgstr "tidak dapat menulis ke berkas response %s"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 #| msgid "invalid option argument %qs"
@@ -36555,9 +36613,9 @@
 msgstr "label %q+D didefinisikan tetapi tidak digunakan"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD declared here"
@@ -36698,7 +36756,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%> tidak diijinkan dalam hal lain selain lingkup prototipe fungsi"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -37850,7 +37908,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "dua atau lebih tipe data dalam penspesifikasi deklarasi"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> terlalu panjang untuk GCC"
@@ -38001,17 +38059,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C tidak mendukung plain %<complex%> yang berarti %<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C tidak mendukung tipe integer kompleks"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -38065,7 +38123,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of line"
@@ -38109,7 +38167,7 @@
 msgstr "nama register: %s tidak dikenal"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "diduga penspesifikasi deklarasi"
@@ -38126,7 +38184,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored for methods"
@@ -38144,8 +38202,8 @@
 msgid "unexpected attribute"
 msgstr "Diduga nama atribut bit"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -38187,7 +38245,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "diduga %<,%> atau %<,%>"
@@ -38217,7 +38275,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 tidak mendukung %<long long%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "diduga string literal"
@@ -38288,14 +38346,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "diduga pengidentifikasi"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "koma di akhir dari daftar pengenumerasi"
@@ -38433,7 +38491,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "diduga %<}%> sebelum %<else%>"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> tanpa sebuah sebelumnya %<if%>"
@@ -38458,12 +38516,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr "sebuah label hanya dapat menjadi bagian dari sebuah pernyataan dan sebuah deklarasi bukan sebuah pernyataan"
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -38477,17 +38535,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "diduga pernyataan"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<if%>"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "disarankan kurung diantara tubuh kosong dalam sebuah pernyataan %<else%>"
@@ -38497,7 +38555,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, fuzzy, gcc-internal-format
 #| msgid "%Hsuggest explicit braces to avoid ambiguous %<else%>"
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
@@ -38520,7 +38578,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "register tidak valid dalam instruksi"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -38715,18 +38773,18 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "%<__builtin_longjmp%> argumen kedua harus berupa 1"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -38784,35 +38842,35 @@
 msgid "no type or storage class may be specified here,"
 msgstr "kelas penyimpanan dispesifikasikan untuk %qs"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, fuzzy, gcc-internal-format
 #| msgid "missing %<(%> after %<#pragma pack%> - ignored"
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "hilang %<(%> setelah %<#pragma pack%> - diabaikan"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, fuzzy, gcc-internal-format
 #| msgid "%Jaddress area attribute cannot be specified for functions"
 msgid "the %<getter%> attribute may only be specified once"
@@ -38819,33 +38877,33 @@
 msgstr "%J alamat daerah atribut tidak dapat dispesifikasikan untuk fungsi"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%> hanya bisa digunakan dalam %<#pragma omp section%> konstruk"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "for, while or do statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%> harus menjadi pertama"
@@ -38861,12 +38919,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -38883,59 +38941,59 @@
 msgid "%qD is not a variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD bukan sebuah variabel"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<none%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<data%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -38965,25 +39023,25 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<tofrom%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<scalar%>"
@@ -38995,65 +39053,65 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<static%> arguments"
 msgstr "terlalu banyak %qs clauses"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected element"
 msgid "unexpected argument"
 msgstr "Elemen tidak diduga"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "argumen atribut %qs bukan sebuah konstanta integer"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "argumen collapes membutuhkan konstanta positif ekspresi integer"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, or %<||%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "diduga %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, atau %<||%>"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "baik %<long%> dan %<void%> dalam penspesifikasi deklarasi"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "jadwal %<runtime%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "penjadwalan %<auto%> tidak mengambil sebuah parameter %<chunk_size%>"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "jenis penjadwalan tidak valid"
@@ -39070,19 +39128,19 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -39105,19 +39163,19 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid depend kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 #| msgid "invalid mask"
 msgid "invalid map kind"
 msgstr "topeng tidak valid"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid schedule kind"
 msgid "invalid dist_schedule kind"
@@ -39129,71 +39187,71 @@
 msgid "invalid proc_bind kind"
 msgstr "jenis penjadwalan tidak valid"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma acc%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs tidak valid untuk %qs"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 #| msgid "%qs must be used with %qs"
 msgid "%qs must be the first clause of %qs"
 msgstr "%qs harus digunakan dengan %qs"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %q+D in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "deklarasi dari variabel %<extern%> %q+D dalam %<for> inisial deklarasi loop"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -39210,7 +39268,7 @@
 msgid "expected function name"
 msgstr "diduga nama class"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is not a function,"
 msgid "%qD does not refer to a function"
@@ -39221,44 +39279,44 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma align%> must appear before the declaration of %D, ignoring"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operator for %<#pragma omp atomic%>"
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "operator tidak valid untuk %<#pragma omp atomic%>"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -39268,28 +39326,28 @@
 msgid "expected %<(%> or end of line"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 #| msgid "for statement expected"
 msgid "_Cilk_for statement expected"
 msgstr "diduga pernyataan for"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "diduga iterasi deklarasi atau inisialisasi"
@@ -39299,76 +39357,76 @@
 msgid "not enough perfectly nested loops"
 msgstr "tidak cukup secara sempurna nested loops"
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "collapsed loops tidak secara sempurna nested"
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "iterasi variabel %qD seharusnya bukan first private"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> hanya memiliki parameter tidak boleh dikualifikasikan"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%> hanya mungkin digunakan dalam pernyataan compound"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<for%> after %qs"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<point%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -39384,7 +39442,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%> harus muncul sebelum deklarasi dari %D, abaikan"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -39394,34 +39452,34 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<target%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<declare%>"
 msgstr "diduga %<{%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma GCC pop_options%> without a corresponding %<#pragma GCC push_options%>"
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
@@ -39480,23 +39538,23 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp section%> or %<}%>"
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "diduga %<#pragma omp section%> atau %<}%>"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE dideklarasikan %<threadprivate%> setelah penggunaan pertama"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "variabel otomatis %qE tidak dapat berupa %<threadprivate%>"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%> %qE memiliki tipe tidak lengkap"
@@ -39512,56 +39570,56 @@
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "vectorlength must be an integer constant"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 #| msgid "stack size must be an exact power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "ukuran stack harus berupa sebuah kelipatan tepat dari 2"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 #| msgid "selector must be an integer constant in the range 0..%wi"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "pemilih harus berupa sebuah konstanta integer dalam jangkauan 0..%wi"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<#pragma omp%> clause"
 msgid "expected %<#pragma simd%> clause"
 msgstr "diduga clause %<#pragma omp%>"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -39572,7 +39630,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or numeral"
@@ -40348,7 +40406,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "inisialisasi sisi tangan kiri mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
@@ -40679,7 +40737,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C melarang %<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "fungsi dideklarasikan %<noreturn%> memiliki sebuah pernyataan %<return%>"
@@ -40689,7 +40747,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, fuzzy, gcc-internal-format
 #| msgid "Logical range in CASE statement at %L is not allowed"
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
@@ -40716,7 +40774,7 @@
 msgid "function returns address of label"
 msgstr "fungsi mengembalikan alamat dari variabel lokal"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch kuantiti bukan sebuah integer"
@@ -40732,7 +40790,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "ukuran dari array bukan sebuah integral konstan ekspresi"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "label case tidak dalam label pernyataan switch"
@@ -40752,17 +40810,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "pernyataan break tidak dalam loop atau switch"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "pernyataan continue tidak dalam sebuah loop"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "pernyataan break digunakan dengan OpenMP untuk loop"
@@ -40773,7 +40831,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "pernyataan break tidak dalam loop atau switch"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
@@ -40885,12 +40943,12 @@
 msgid "used vector type where scalar is required"
 msgstr "menggunakan nilai tipe struct dimana skalar dibutuhkan"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -40901,27 +40959,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "%Hterlalu banyak %qs clauses"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %qs clause"
@@ -40934,19 +40992,19 @@
 msgstr "%Hterlalu banyak %qs clauses"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "low bound %qE of array section does not have integral type"
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 #| msgid "size in array new must have integral type"
 msgid "length %qE of array section does not have integral type"
@@ -40953,57 +41011,57 @@
 msgstr "ukuran dalam array baru harus memiliki tipe integral"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "zero length array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array %qs is used"
 msgid "negative length in array section in %qs clause"
 msgstr "array dengan panjang bervariabel %qs digunakan"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, fuzzy, gcc-internal-format
 #| msgid "Copy array sections into a contiguous block on procedure entry"
 msgid "array section is not contiguous in %qs clause"
 msgstr "Salin bagian array kedalam sebuah blok kontinu dalam masukan prosedur"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not have class type"
 msgid "%qE does not have pointer or array type"
@@ -41024,7 +41082,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction(%s)%>"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr ""
@@ -41035,17 +41093,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "array dengan panjang bervariabel digunakan"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE harus berupa %<threadprivate%> untuk %<copyin%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -41065,18 +41123,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in reduction clauses"
@@ -41089,33 +41147,33 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<aligned%> clause"
@@ -41138,63 +41196,63 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE appears more than once in data clauses"
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE muncul lebih dari sekali dalam clause data"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is not an argument in %<uniform%> clause"
@@ -41206,32 +41264,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "tipe dari vektor delete bukan penunjuk ataupun tipe array"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE adalah predetermined %qs untuk %qs"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -41829,167 +41887,167 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "passing %qT as %<this%> argument of %q#D discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "melewatkan %qT sebagai %<this%> argumen dari %q#D mengabaikan kualifier"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "  dalam panggilan ke %qD"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT bukan sebuah dasar yang bisa diakses dari %qT"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "deducing %qT as %qT"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 #| msgid "Missing arguments to %s intrinsic at %L"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "Hilang argumen ke %s intrinsik di %L"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "konstruktor tidak dapat dideklarasikan virtual"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, fuzzy, gcc-internal-format
 #| msgid "mangling function-style cast with more than one argument"
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "mangling function-style cast dengan lebih dari satu argumen"
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "tidak pasangan fungsi untuk panggilan ke %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%D(%A)%>"
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "tidak ada fungsi yang cocok untuk panggilan ke %<%D(%A)%>"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "panggilan dari overloaded %<%s(%A)%> adalah ambigu"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has no non-static data member named %qD"
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "%qT memiliki anggota data tidak statis bernama %qD"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "tidak dapat memanggil anggota fungsi %qD tanpa objek"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "melewatkan %qT memilih %qT diatas %qT"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "memilih %qD diatas %qD"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "  untuk konversi dari %qT ke %qT"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "  karena urutan konversi untuk argumen lebih baik"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "argumen baku tidak cocok dalam kelebihan beban resolusi"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " kandidat 1: %q+#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " kandidat 2: %q+#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ mengatakan bahwa ini adalah ambigu, meskipun melalui konversi terburuk untuk yang pertama lebih baik daripada konversi terburuk untuk yang kedua:"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert %qE to %qT"
 msgid "could not convert %qE from %qT to %qT"
 msgstr "tidak dapat mengubah %qE ke %qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initialization of non-const reference of type %qT from a temporary of type %qT"
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "inisialisasi dari referensi bukan const dari tipe %qT dari sebuah tipe sementara %qT tidak valid"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "inisialisasi dari referensi dari tipe %qT dari ekspresi dari tipe %qT tidak valid"
@@ -42097,298 +42155,298 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "tidak dapat mengubah dari dasar %qT ke tipe turunan %qT melalui basis maya %qT"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "semua anggota fungsi dalam kelas %qT adalah private"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T hanya mendefinisikan sebuah desktruktor private dan tidak memiliki teman"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T hanya mendefinisikan konstruktor private dan tidak memiliki teman"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "tidak ada unik final overrider untuk %qD dalam %qT"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D cannot be overloaded"
 msgid "%qD can be marked override"
 msgstr "%q+#D tidak dapat overloaded"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D telah disembunyikan"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "  oleh %q+D"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous union hanya dapat mempunnya anggota data tidak statis"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D tidak valid; sebuah anonymous struct hanya dapat memiliki anggota data tidak statis"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "anggota private %q+#D dalam union anonymous"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous struct"
 msgid "private member %q#D in anonymous struct"
 msgstr "anggota private %q+#D dalam struct anonymous"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous struct"
 msgid "protected member %q#D in anonymous struct"
 msgstr "anggota terproteksi %q+#D dalam struct anonymous"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bit-field %q+#D dengan tipe bukan integral"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bit-field %q+D lebar bukan sebuah konstanta integer"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "lebar negatif dalam bit-field %q+D"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "lebar nol untuk bit-field %q+D"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "lebar dari %q+D melebihi tipenya"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D terlalu kecil untuk menjaga seluruh nilai dari %q#T"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "anggota %q#D dengan konstruktor tidak diijinkan dalam union"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "anggota %q+#D dengan desktruktor tidak diijinkan dalam union"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "anggota %q+#D dengan penempatan salinan operator tidak diijinkan dalam union"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D mungkin bukan statis karena ini adalah anggota dari sebuah union"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "field %q+D secara tidak valid mendeklarasikan tipe fungsi"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "field %q+D secara tidak valid mendeklrasikan tipe metoda"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "mengabaikan atribut packed karena dari unpacked non-POD field %q+#D"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 #| msgid "non-member %qs cannot be declared %<mutable%>"
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "bukan-anggota %qs tidak dapat dideklarasikan %<mutable%>"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "multiple field dalam union %qT tida terinisialisasi"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "field %q+#D dengan nama sama seperti class"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T memiliki anggota data penunjuk"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  tetapi tidak override %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  atau %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  tetapi tidak override %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "penginisialisasi dispesifikasikan untuk metode %q+D bukan virtual"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of non-static member function %qD"
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q+T is not literal because:"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  %q+T has a non-trivial destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %qD has non-literal type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "  non-static data member %qD has volatile type"
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "base class %q#T has a non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "kelas dasar %q#T memiliki desktruktor tidak virtual"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "referensi bukan-statis %q+#D dalam kelas tanpa sebuah konstruktor"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -42396,166 +42454,166 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "direct base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "virtual base %qT tidak dapat diakses dalam %qT karena adanya ambigu"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "ofset dari %q+D adalah bukan ABI komplian dan mungkin berubah dalam versi GCC yang akan datang"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qs is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "ukuran dari array %qs adalah terlalu besar"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "penggunaan tidak valid dari struktur dengan anggota array fleksibel"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "array member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "redefinisi dari %q#T"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "%J anggota array fleksibel tidak diakhir dari struct"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "%Jflexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "%J anggota array fleksibel dalam sebaliknya struct kosong"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D declared here"
 msgid "next member %q#D declared here"
 msgstr "  %q+#D dideklarasikan disini"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "redefinisi dari %q#T"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T memiliki fungsi maya dan dapat diakses bukan virtual desktruktor"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 #| msgid "class %qT does not have any field named %qD"
 msgid "type transparent %q#T does not have any fields"
 msgstr "kelas %qT tidak memiliki field apapun bernama %qD"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has virtual member functions"
 msgid "type transparent class %qT has virtual functions"
 msgstr "tipe %qs memiliki anggota fungsi virtual"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "mencoba menyelesaikan struct, tetapi ditendang keluar karena error parse sebelumnya"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "bahasa string %<\"%E\"%> tidak dikenal"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "tidak dapat meresolf fungsi overloaded %qD berdasar dari konversi ke tipe %qT"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "tidak cocok mengubah fungsi %qD ke tipe %q#T"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "mengubah fungsi overloaded %qD ke tipe %q#T adalah ambigu"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "mengasumsikan penunjuk ke anggota %qD"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(sebuah penunjuk ke anggota hanya dapat dibentuk dengan %<&%E%>)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "tidak cukup informasi mengenai tipe"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "tidak dapat mengubah %qE dari tipe %qT ke tipe %qT"
@@ -42565,12 +42623,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "deklarasi dari %q#D"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -42603,385 +42661,385 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "tipe kembali abstrak tidak valid untuk fungsi %q+#D"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#T has virtual base classes"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, fuzzy, gcc-internal-format
 #| msgid "%Jbase class %q#T should be explicitly initialized in the copy constructor"
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "%J kelas dasar %q#T seharusnya secara eksplisit diinisialisasikan dalam konstruktor salinan"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, fuzzy, gcc-internal-format
 #| msgid "invalid conversion in return statement"
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "konversi tidak valid dalam pernyataan return"
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%q+E is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "expression %qE does not designate a constexpr function"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
 msgstr "panggilan ke bukan-fungsi %qD"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 #| msgid "PARAMETER '%s' is used at %L before its definition is complete"
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "PARAMTER '%s' digunakan di %L sebelum definisinya lengkap"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD called in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was used with no prototype before its definition"
 msgid "%qD used before its definition"
 msgstr "%q+D telah digunakan dengan tidak ada prototipe sebelum definisinya"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 #| msgid "protocol %qs has circular dependency"
 msgid "call has circular dependency"
 msgstr "protokol %qs memiliki ketergantungan circular"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, fuzzy, gcc-internal-format
 #| msgid "Warn on calls to these functions"
 msgid "constexpr call flows off the end of the function"
 msgstr "Peringatkan di panggilan ke fungsi ini"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "jumlah geser kanan negatif"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "shift expression %q+E overflows"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray subscript is outside array bounds"
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "%H array subscript diluar dari cakupan array"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized array element"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qE is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer for member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "hilang penginisialisasi untuk anggota %qD"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "dereferensi penunjuk %<void *%>"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not initialized"
 msgid "%qD used in its own initializer"
 msgstr "%qE tidak terinisialisasi"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a class"
 msgid "%q#D is not const"
 msgstr "%q#T bukan sebuah kelas"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D is private"
 msgid "%q#D is volatile"
 msgstr "%q+#D adalah private"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot appear in a constant-expression"
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 #| msgid "%qD was not declared in this scope"
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD belum pernah dideklarasikan dalam lingkup ini"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "%qD does not have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qD is not an integral constant-expression"
 msgid "modification of %qE is not a constant expression"
 msgstr "ukuran dari array %qD bukan sebuah integral konstan-ekspresi"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 #| msgid "enumeral and non-enumeral type in conditional expression"
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "tipe enumeral dan bukan enumeral dalam ekspresi kondisional"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 #| msgid "conversion to %qT alters %qT constant value"
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "konversi ke %qT mengubah nilai konstanta %qT"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 #| msgid "integral expression %qE is not constant"
 msgid "expression %qE is not a constant expression"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "statement is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "unexpected expression %qE of kind %s"
 msgstr "diduga ekspresi"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, fuzzy, gcc-internal-format
 #| msgid "cast from type %qT to type %qT casts away constness"
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away constness"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "reinterpret_cast dari tipe %qT ke tipe %qT menghilangkan constness"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "use of %<this%> in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 #| msgid "register variable %qD used in nested function"
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "variabel register %qD digunakan dalam fungsi nested"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "division by zero is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 #| msgid "Bad type in constant expression"
 msgid "%<delete[]%> is not a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "nonconstant array index in initializer"
 msgid "non-constant array initialization"
 msgstr "indeks array bukan konstan dalam penginisialisasi"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "overflow in constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "overflow dalam konstanta ekspresi"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Unexpected end of file in '%s'"
 msgid "unexpected AST of kind %s"
@@ -43869,7 +43927,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  melewati inisialisasi dari %q+#D"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "exit tidak valid dari blok struktur OpenMP"
@@ -43884,7 +43942,7 @@
 msgid "%qD is not a type"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD digunakan tanpa parameter template"
@@ -45663,7 +45721,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "parameter dideklarasikan %<auto%>"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of template-name %qE without an argument list"
 msgid "invalid use of template-name %qE without an argument list"
@@ -46151,13 +46209,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD memiliki nama sama seperti kelas yang telah dideklarasikan"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT mungkin bukan sebuah template"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration %q+#D here"
 msgid "previous declaration here"
@@ -46168,8 +46226,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
@@ -46220,7 +46278,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 #| msgid "%Jprevious definition here"
 msgid "previous definition here"
@@ -46289,7 +46347,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%> seharusnya mengembalikan referensi ke %<*this%>"
@@ -46305,7 +46363,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "tidak ada pernyataaan kembali dalam fungsi yang mengembalikan bukan void"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 #| msgid "function return types not compatible due to %<volatile%>"
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
@@ -46471,28 +46529,28 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bit-field %qD dengan tipe bukan integral"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a static data member of a class template"
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "anonymous struct tidak didalam tipe bernama"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "kumpulan namespace scope anonymous harus berupa statis"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "anonymous union dengan tida ada anggota"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%> harus mengembalikan tipe %qT"
@@ -46501,71 +46559,71 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "parameter pertama dari %<operator new%> tidak dapat memiliki sebuah argumen baku"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%> mengambil tipe %<size_t%> (%qT) sebagai parameter pertama"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%> harus mengembalikan tipe %qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%> mengambil tipe %qT sebagai parameter pertama"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT memiliki sebuah field %qD yang tipe menggunakan namespace anonymous"
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari tipe dari fieldnya %qD"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT memiliki sebuah base %qT yang menggunakan tipe namespace anonymous"
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT dideklarasikan dengan visibility lebih besar dari basenya %qT"
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using unnamed type, is used but never defined"
@@ -46575,51 +46633,51 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D does not refer to the unqualified type, so it is not used for linkage"
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D tidak merefer ke tipe tidak terkualifikasi, jadi ini tidak digunakan untuk linkage"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 #| msgid "%q+F declared %<static%> but never defined"
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+F dideklarasikan %<static%> tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 #| msgid "previous declaration of %q+#D with %qL linkage"
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "deklarasi sebelumnya dari %q+#D dengan %qL linkage"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "fungsi inline %q+D digunakan tetapi tidak pernah didefinisikan"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "argumen baku hilang untuk parameter %P dari %q+#Ddd"
@@ -46626,12 +46684,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, fuzzy, gcc-internal-format
 #| msgid "deleted function %q+D"
 msgid "use of deleted function %qD"
@@ -46976,7 +47034,7 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "nilai inisial tidak valid untuk anggota %qs"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "uninitialized const member in %q#T"
@@ -46983,13 +47041,13 @@
 msgstr "anggota const tidak terinisialisasi %qD"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D will be initialized after"
 msgid "%q#D should be initialized"
 msgstr "%qD akan diinisialisasi setelah"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized reference member %qD"
 msgid "uninitialized reference member in %q#T"
@@ -47097,7 +47155,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "array harus diinisialisasi dengan sebuah kurung melingkupi penginisialisasi"
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT bukan sebuah tipe kelas"
@@ -47117,7 +47175,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "penggunaan tidak valid dari anggota fungsi %qD bukan statis"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "penggunaan tidak valid dari anggota data tidak statis %qD"
@@ -47325,25 +47383,25 @@
 msgid "because the array element type %qT has variable size"
 msgstr "compound literal memiliki ukuran variabel"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare reference to %q#T"
 msgid "cannot capture %qE by reference"
 msgstr "tidak dapat mendeklarasikan referensi ke %q#T"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 #| msgid "cannot increment a pointer to incomplete type %qT"
 msgid "capture by copy of incomplete type %qT"
 msgstr "tidak dapat meningkatkan sebuah penunjuk ke tipe tidak lengkap %qT"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operand in unary expression"
 msgid "already captured %qD in lambda expression"
 msgstr "operan tidak valid dalam ekspresi unary"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> is unavailable for static member functions"
 msgid "%<this%> was not captured for this lambda function"
@@ -47399,120 +47457,120 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(jika anda menggunakan %<-fpermissive%>, G++ akan menerima kode anda, tetapi mengijinkan penggunaan dari sebuah nama tidak dideklarasikan sudah ditinggalkan)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "mangling typeof, lebih baik gunakan decltype"
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, fuzzy, gcc-internal-format
 #| msgid "mangling unknown fixed point type"
 msgid "mangling __underlying_type"
 msgstr "mangling tipe fixed point tidak diketahui"
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "mangling tipe fixed point tidak diketahui"
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "mangling %C"
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "diabaikan operan tengah ke %<?:%> operan tidak dapat mangled"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "nama mangled dari %qD tidak akan berubah dalam versi yang akan datang dari GCC"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "nama mangled dari %qD tidak akan berubah dalam versi yang akan datang dari GCC"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, fuzzy, gcc-internal-format
 #| msgid "the mangled name of %qD will change in a future version of GCC"
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "nama mangled dari %qD tidak akan berubah dalam versi yang akan datang dari GCC"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q#D, can't use default assignment operator"
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "anggota const bukan static %q#D, tidak dapatmenggunakan operator assignmen baku"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference member %q#D, can't use default assignment operator"
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "anggota reference bukan static %q#D, tidak dapat menggunakan operator assignmen baku"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr "metode yang disintesa %qD pertama dibutuhkan disini "
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, fuzzy, gcc-internal-format
 #| msgid "%Juninitialized member %qD with %<const%> type %qT"
 msgid "union member %q+D with non-trivial %qD"
 msgstr "%J anggota tidak terinisialisasi %qD dengan %<const%> tipe %qT"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr ""
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 #| msgid "initializer for %qT must be brace-enclosed"
 msgid "initializer for %q#D is invalid"
 msgstr "penginisialisasi untuk %qT harus berupa kurung dilingkupi"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "copying non-static data member %q#D of rvalue reference type"
@@ -47519,78 +47577,78 @@
 msgstr "anggota data bukan statis %qD memiliki tipe kelas Java"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 #| msgid "repeated using declaration %q+D"
 msgid "defaulted declaration %q+D"
 msgstr "diulang menggunakan deklarasi %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, fuzzy, gcc-internal-format
 #| msgid "array does not match the region tree"
 msgid "does not match expected signature %qD"
 msgstr "array tidak cocok dengan daerah pohon"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 #| msgid "%qD cannot be defaulted"
 msgid "a template cannot be defaulted"
 msgstr "%qD tidak dapat dibakukan"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD tidak dapat dibakukan"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "defaulted function %q+D with default argument"
@@ -47794,100 +47852,100 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "tidak ada anggota yang cocok %<%T::%D%> dalam %q#T"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "deklarasi dari %qD bukan dalam sebuah lingkup namespace %qD"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "eksplisit kualifikasi dalam deklarasi dari %qD"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not declared in %qD"
 msgid "%qD has not been declared within %D"
 msgstr "%qD tidak dideklarasikan dalam %qD"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a friend"
 msgstr "%q+D dideklarasikan sebagai sebuah friend"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD seharusnya telah dideklarasikan didalam %qD"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD atribut tidak berarti karena anggota dari anonymous namespace memperoleh simbol lokal"
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "atribut %qD direktif diabaikan"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "namespace alias %qD tidak diijinkan disini, diasumsikan %qD"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 #| msgid "This switch is deprecated; use -Wextra instead"
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "Pilihan ini sudah ditinggalkan; lebih baik gunakan -Wextra"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "strong using hanya berarti di lingkup namespace"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "namespace %qD sekarang tidak melingkupi secara kuat namespace %qD yang digunakan"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr ""
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -47894,29 +47952,29 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, fuzzy, gcc-internal-format
 #| msgid "  %q+#D"
 msgid "  %qE"
 msgstr "  %q+#D"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr "argumen tergantung pencarian menemukan %q+D"
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX memasuki pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX meninggalkan pop_everything ()\n"
@@ -47938,7 +47996,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -47967,7 +48025,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "%Hpermintaan untuk anggota %qE dalam tipe bukan kelas %qT"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> has not been declared"
 msgid "%<%T::%E%> has not been declared"
@@ -48038,120 +48096,120 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(mungkin sebuah semikolom hilang setelah definisi dari %qT)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE is not a template"
 msgid "%qE is not a class template"
 msgstr "%H%qE bukan sebuah template"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE is not a template"
 msgid "%qE is not a template"
 msgstr "%H%qE bukan sebuah template"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid template-id"
 msgid "invalid template-id"
 msgstr "%Htemplate-id tidak valid"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids using pointer to a function in subtraction"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "ISO C++ melarang menggunakan penunjuk ke sebuah fungsi  dalam pengurangan"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "sebuah cast ke sebuah tipe selain dari sebuah integral atau tipe enumerasi tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a function call cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an increment cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot appear in a constant-expression"
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%s tidak dapat muncul dalam sebuah konstanta ekspresi"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qD as a type"
@@ -48158,59 +48216,59 @@
 msgstr "%Hpenggunaan tidak valid dari desktruktor %qD memiliki sebuah tipe"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid combination of multiple type-specifiers"
 msgid "invalid combination of multiple type-specifiers"
 msgstr "%Hkombinasi tidak valid dari multiple penspesifikasi tipe"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not name a type"
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%H%qE tidak bernama sebuah tipe"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE does not name a type"
 msgid "%qE does not name a type"
 msgstr "%H%qE tidak bernama sebuah tipe"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(mungkin %<typename %T::%E%> telah diinginkan)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE in namespace %qE does not name a type"
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%H%qE dalam namespace %qE tidak bernama sebuah tipe"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE in namespace %qE does not name a type"
 msgid "%qE in namespace %qE does not name a type"
@@ -48217,652 +48275,658 @@
 msgstr "%H%qE dalam namespace %qE tidak bernama sebuah tipe"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 #| msgid "type %qs has no default constructor to call"
 msgid "and %qT has no template constructors"
 msgstr "tipe %qs tidak memiliki konstruktor baku untuk memanggil"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE in class %qT does not name a type"
 msgid "%qE in %q#T does not name a template type"
 msgstr "%H%qE dalam kelas %qT tidak bernama sebuah tipe"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE in class %qT does not name a type"
 msgid "%qE in %q#T does not name a type"
 msgstr "%H%qE dalam kelas %qT tidak bernama sebuah tipe"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, fuzzy, gcc-internal-format
 #| msgid "expected string literal"
 msgid "expected string-literal"
 msgstr "diduga string literal"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "a wide string is invalid in this context"
 msgstr "Argumen dengan nilai di %L tidak diperbolehkan dalam konteks ini"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "integer literal exceeds range of %qT type"
 msgstr "konstanta floating melebihi jangkauan dari %qT"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant exceeds range of %qT"
 msgid "floating literal exceeds range of %qT type"
 msgstr "konstanta floating melebihi jangkauan dari %qT"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, fuzzy, gcc-internal-format
 #| msgid "floating constant truncated to zero"
 msgid "floating literal truncated to zero"
 msgstr "konstanta floating dipotong ke nol"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, fuzzy, gcc-internal-format
 #| msgid "unable to find a register to spill in class %qs"
 msgid "unable to find numeric literal operator %qD"
 msgstr "tidak dapat menemukan sebuah register untuk spill dalam kelas %qs"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "expected declaration"
 msgstr "deklarasi kosong"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "elemental binary operation"
 msgid "expected binary operator"
 msgstr "operasi binari elemen"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected EOF"
 msgid "expected ..."
 msgstr "Tidak terduga EOF"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "binary expression in operand of fold-expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 #| msgid "%s expression list treated as compound expression"
 msgid "conditional expression in operand of fold-expression"
 msgstr "%s daftar ekspresi diperlakukan sebagai ekspresi compound"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 #| msgid "type mismatch in comparison expression"
 msgid "mismatched operator in fold-expression"
 msgstr "tipe tidak cocok dalam ekspresi perbandingan"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfixed-point types not supported in C++"
 msgid "fixed-point types not supported in C++"
 msgstr "%Htipe titik tetap tidak didukung dalam C++"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ melarang braced-groups didalam ekspresi"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, fuzzy, gcc-internal-format
 #| msgid "%Hstatement-expressions are not allowed outside functions nor in template-argument lists"
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "%Hpernyataan ekspresi tidak diijinkan diluar fungsi atau didalam daftar template argumen"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected primary-expression"
 msgstr "diduga ekspresi"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<this%> may not be used in this context"
 msgid "%<this%> may not be used in this context"
 msgstr "%H%<this%> mungkin tidak digunakan dalam konteks ini"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, fuzzy, gcc-internal-format
 #| msgid "Objective-C declarations may only appear in global scope"
 msgid "a template declaration cannot appear at block scope"
 msgstr "deklarasi Objective-C mungkin hanya muncul dalam lingkup global"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, fuzzy, gcc-internal-format
 #| msgid "%Hlocal variable %qD may not appear in this context"
 msgid "local variable %qD may not appear in this context"
 msgstr "%Hvariabel lokal %qD mungkin tidak muncul dalam konteks ini"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression"
 msgstr "diduga ekspresi"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, fuzzy, gcc-internal-format
 #| msgid "%Hscope %qT before %<~%> is not a class-name"
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%Hlingkup %qT sebelum %<~%> bukan sebuah class-name"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %<~%T%> as member of %qT"
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%Hdeklarasi dari %<~%T%> sebagai anggota dari %qT"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, fuzzy, gcc-internal-format
 #| msgid "%Htypedef-name %qD used as destructor declarator"
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "%Htypedef-nama %qD digunakan sebagai desktruktor deklarator"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 #| msgid "expected specifier-qualifier-list"
 msgid "expected unqualified-id"
 msgstr "diduga specifier-qualifier-list"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, fuzzy, gcc-internal-format
 #| msgid "%qT resolves to %qT, which is not an enumeration type"
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 #| msgid "%Hincomplete type %qT used in nested name specifier"
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 #| msgid "%Hincomplete type %qT used in nested name specifier"
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "%Htipe %qT tidak lengkap digunakan dalam nama penspesifikasi nested"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD bukan sebuah template"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected nested-name-specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in casts"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 #| msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "jumlah dari argumen ke fungsi %<__builtin_next_arg%> salah"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ melarang compound literals"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "braced list index is not allowed with array notation"
 msgstr "-client_name tidak diperbolehkan dengan -dynamiclib"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, fuzzy, gcc-internal-format
 #| msgid "%<%D::%D%> is not a member of %qT"
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> bukan sebuah anggota dari %qT"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a new-expression"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, fuzzy, gcc-internal-format
 #| msgid "%Harray bound forbidden after parenthesized type-id"
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "%Harray bound dilarang setelah parenthesized tipe id"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "mencoba menghapus tanda kurung disekitar tipe-id"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a new-type-id"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpression in new-declarator must have integral or enumeration type"
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "%Hekspresi dalam pendeklarasi new harus memiliki integral atau tipe enumerasi"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "penggunaan dari gaya-lama cast"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> operator will be treated as two right angle brackets in C++0x"
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%H%<>>%> operator akan diperlakukan sebagai dua sudut brackets dalam C++0x"
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "disarankan tanda kurung disekeliling ekspresi %<>>%>"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 #| msgid "%Hparse error in template argument list"
 msgid "lambda-expression in template-argument"
 msgstr "%Hparse error dalam daftar argumen template"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected end of module"
 msgid "expected end of capture-list"
 msgstr "Tidak terduga akhir dari modul"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, fuzzy, gcc-internal-format
 #| msgid "increment of read-only variable %qD"
 msgid "capture of non-variable %qD "
 msgstr "peningkatan dari variabel baca-saja %qD"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%q#D declared here"
 msgstr "%q+D dideklarasikan disini"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support saturating types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C tidak mendukung tipe yang bersaturasi"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "default argument specified for lambda parameter"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "duplikasi %<volatile%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 #| msgid "attributes after parenthesized initializer ignored"
 msgid "attributes at the beginning of statement are ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected labeled-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcase label %qE not within a switch statement"
 msgid "case label %qE not within a switch statement"
 msgstr "%Hlabel case %qE tidak dalam sebuah pernyataan switch"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> names constructor in %qT"
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> names konstruktor dalam %qT"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, fuzzy, gcc-internal-format
 #| msgid "Discover pure and const functions"
 msgid "compound-statement in constexpr function"
 msgstr "Temukan fungsi pure dan const"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected selection-statement"
 msgstr "diduga deklarasi atau pernyataan"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in conditions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 #| msgid "expression statement has incomplete type"
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "ekspresi pernyataan memiliki tipe tidak lengkap"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration or statement"
 msgid "expected iteration-statement"
 msgstr "diduga deklarasi atau pernyataan"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 #| msgid "break statement used with OpenMP for loop"
 msgid "break statement used with Cilk Plus for loop"
 msgstr "pernyataan break digunakan dengan OpenMP untuk loop"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ melarang gotos yang sudah dihitung"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected jump-statement"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "kelebihan %<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__label__%> not at the beginning of a block"
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%H%<__label__%> tidak berada diawal dari sebuah blok"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr ""
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmixing declarations and function-definitions is forbidden"
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "%Hpencampuran deklarasi dan definisi fungsi dilarang"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "deklarasi kosong"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
 #, fuzzy, gcc-internal-format
+#| msgid "invalid member function declaration"
+msgid "invalid initializer for structured binding declaration"
+msgstr "deklarasi anggota fungsi tidak valid"
+
+#: cp/parser.c:13220
+#, fuzzy, gcc-internal-format
 #| msgid "%H%<friend%> used outside of class"
 msgid "%<friend%> used outside of class"
 msgstr "%H%<friend%> digunakan diluar dari kelas"
@@ -48869,129 +48933,129 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<auto%> will change meaning in C++0x; please remove it"
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%H%<auto%> akan mengubah arti dalam C++0x; mohon hapus itu"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "decl-specifier invalid in condition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D tidak valid dalam %q#T"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, fuzzy, gcc-internal-format
 #| msgid "%Hclass definition may not be declared a friend"
 msgid "class definition may not be declared a friend"
 msgstr "%Hdefinisi kelas mungkin tidka dideklarasikan sebagai friend"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "templates may not be %<virtual%>"
 msgstr "%Htemplate mungkin bukan %<virtual%>"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid linkage-specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in a conversion-type-id"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, fuzzy, gcc-internal-format
 #| msgid "%Honly constructors take base initializers"
 msgid "only constructors take member initializers"
 msgstr "%Hhanya konstruktor yang mengambil penginisialisasi dasar"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcannot expand initializer for member %<%D%>"
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "%Htidak dapat mengekspand penginisialisasi untuk anggota %<%D%>"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, fuzzy, gcc-internal-format
 #| msgid "static declaration of %q+D follows non-static declaration"
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "deklarasi statis dari %q+D mengikuti deklarasi bukan statis"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "anachronistic gaya-lama kelas dasar penginisialisasi"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (sebuah anggota terkualifikasi secara implisit adalah sebuah tipe)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected suffix identifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected empty string after %<operator%> keyword"
 msgstr "diduga sebuah string setelah %<#pragma message%>"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 #| msgid "invalid operands in binary operation"
 msgid "invalid encoding prefix in literal operator"
 msgstr "operan tidak valid dalam operasi binary"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected operator"
@@ -48998,69 +49062,69 @@
 msgstr "operan tidak terduga"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "kata kunci %<export%> tidak terimplementasi, dan akan diabaikan"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid constrained type parameter"
 msgstr "batasan untuk operan tidak valid"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "cv-qualified type parameter"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack %qD cannot have a default argument"
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "%Htemplate parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter packs cannot have default arguments"
 msgid "template parameter packs cannot have default arguments"
 msgstr "%Htemplate parameter pack tidak dapat memiliki argumen baku"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-id"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%<<::%> tidak dapat berawal sebuah daftar template argumen"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%> adalah sebuah penyebutan alternatif untuk %<[%>. Masukan spasi diantara %<<%> dan %<::%>"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, fuzzy, gcc-internal-format
 #| msgid "(if you use %<-fpermissive%> G++ will accept your code)"
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(jika anda menggunakan %<-fpermissive%> G++ akan menerima kode anda)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, fuzzy, gcc-internal-format
 #| msgid "%Hparse error in template argument list"
 msgid "parse error in template argument list"
@@ -49067,7 +49131,7 @@
 msgstr "%Hparse error dalam daftar argumen template"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-name"
@@ -49074,342 +49138,342 @@
 msgstr "diduga pernyataan"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnon-template %qD used as template"
 msgid "non-template %qD used as template"
 msgstr "%Hbukan-template %qD digunakan sebagai template"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "gunakan %<%T::template %D%> untuk mengindikasikan bahwa ini adalah template"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected parameter pack before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected template-argument"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid non-type template argument"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template type %qT"
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate specialization with C linkage"
 msgid "template specialization with C linkage"
 msgstr "%Hspesialisasi template dengan C linkage"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected type specifier"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C melarang deklarasi parameter kedepan"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected template-id for type"
 msgstr "Diduga tipe ekspresi"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, fuzzy, gcc-internal-format
 #| msgid "Expected name"
 msgid "expected type-name"
 msgstr "Diduga nama"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "deklarasi %qD tidak mendeklarasikan apapun"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "atribut diabaikan di tipe uninstantiasi"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "atribut diabaikan di template instantiation"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "atribut diabaikan di elaborated type penspesifikasi yang tidak memforward sebuah deklarasi"
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%qD is an enumeration template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qT"
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%qD bukan sebuah anggota dari %qT"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<;%> or %<{%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, fuzzy, gcc-internal-format
 #| msgid "Enable automatic template instantiation"
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "Aktifkan instantiation template otomatis"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in namespace %qD which does not enclose %qD"
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam namespace %qD yang tidak dilingkupi %qD"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdeclaration of %qD in %qD which does not enclose %qD"
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%Hdeklarasi dari %qD dalam %qD yang tidak dilingkup %qD"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 #| msgid "%Hextra qualification not allowed"
 msgid "extra qualification not allowed"
 msgstr "%Hekstra pengkualifikasi diabaikan"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "multiple definisi dari %q#T"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ melarang menaikkan sebuah enum"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is not a namespace-name"
 msgid "%qD is not a namespace-name"
 msgstr "%H%qD bukan sebuah nama namespace"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected namespace-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "Peringatkan ketika sebuah fungsi inline tidak dapat diinline"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "nested identifier required"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "penggunaan dari namespace %qD  sebagai ekspresi"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha template-id may not appear in a using-declaration"
 msgid "a template-id may not appear in a using-declaration"
 msgstr "%Hsebuah template-id mungkin tidak muncul dalam sebuah using deklarasi"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in alias template declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a function-definition is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, fuzzy, gcc-internal-format
 #| msgid "%Han asm-specification is not allowed on a function-definition"
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "%Hsebuah spesifikasi asm tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "attributes are not allowed on a function-definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected initializer"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinitializer provided for function"
 msgid "initializer provided for function"
 msgstr "%Hpenginisialisasi disediakan untuk fungsi"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "atribut setelah tanda kurung penginisialisasi diabaikan"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 #| msgid "function %q+D redeclared as inline"
 msgid "non-function %qD declared as implicit template"
 msgstr "fungsi %q+D redeklarasi sebagai inline"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member reference type %qT"
 msgid "cannot define member of dependent typedef %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<%T::%E%> is not a type"
 msgid "%<%T::%E%> is not a type"
 msgstr "%H%<%T::%E%> bukan sebuah tipe"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of constructor as a template"
 msgid "invalid use of constructor as a template"
 msgstr "%Hpenggunaan tidak valid dari konstruktor sebagai sebuah template"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "penggunaan %<%T::%D%> daripada %<%T::%D%> untuk menamai konstruktor dalam sebuah nama berkualifikasi"
@@ -49418,7 +49482,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "invalid declarator"
@@ -49426,388 +49490,388 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 #| msgid "invalid function declaration"
 msgid "qualified-id in declaration"
 msgstr "deklarasi fungsi tidak valid"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "expected declarator"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD is a namespace"
 msgid "%qD is a namespace"
 msgstr "%H%qD adalah sebuah namespace"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 #| msgid "creating pointer to member of non-class type %qT"
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, fuzzy, gcc-internal-format
 #| msgid "unexpected operand"
 msgid "expected ptr-operator"
 msgstr "operan tidak terduga"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate cv-qualifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 #| msgid "multiple inline callers"
 msgid "multiple ref-qualifiers"
 msgstr "multiple pemanggil inline"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate cv-qualifier"
 msgid "duplicate virt-specifier"
 msgstr "%Hduplikasi cv kualifikasi"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 #| msgid "missing makefile target after %qs"
 msgid "missing template arguments after %qT"
 msgstr "hilang target makefile setelah %qs"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %qD"
 msgid "invalid use of %qT"
 msgstr "penggunaan tidak valid dari %qD"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in template arguments"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in template argument"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "expected type-specifier"
 msgstr "diduga pengidentifikasi"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<,%> or %<...%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in parameter types"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdefault arguments are only permitted for function parameters"
 msgid "default arguments are only permitted for function parameters"
 msgstr "%Hargumen baku hanya diijinkan untuk parameter fungsi"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack %qD cannot have a default argument"
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%H%s parameter pack %qD tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate parameter pack cannot have a default argument"
 msgid "template parameter pack cannot have a default argument"
 msgstr "%Htemplate parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 #| msgid "%H%sparameter pack cannot have a default argument"
 msgid "parameter pack cannot have a default argument"
 msgstr "%H%s parameter pack tidak dapat memiliki sebuah argumen baku"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ does not allow designated initializers"
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ tidak mengijinkan designated penginisialisasi"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-name"
 msgstr "diduga nama class"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after class definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared inline after its definition"
 msgid "expected %<;%> after struct definition"
 msgstr "%q+D dideklarasikan inline setelah definisinya"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, fuzzy, gcc-internal-format
 #| msgid "Unexpected junk after function declaration at %C"
 msgid "expected %<;%> after union definition"
 msgstr "Tidak terduga sampah setelah deklarasi fungsi di %C"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<{%> or %<:%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 #| msgid "cannot find file for class %s"
 msgid "cannot specify %<override%> for a class"
 msgstr "tidak dapat menemukan berkas untuk class %s"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "qualified name does not name a class"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid class name in declaration of %qD"
 msgid "invalid class name in declaration of %qD"
 msgstr "%Hnama kelas tidak valid dalam deklarasi dari %qD"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, fuzzy, gcc-internal-format
 #| msgid "%Han explicit specialization must be preceded by %<template <>%>"
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "%Hsebuah eksplisit spesialisasi harus diawali oleh %<template <>%>"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfunction template %qD redeclared as a class template"
 msgid "function template %qD redeclared as a class template"
 msgstr "%Htemplate fungsi %qD redeklarasikan sebagai sebuah template kelas"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "%Hprevious definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%Hdefinisi sebelumnya dari %q+#T"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, fuzzy, gcc-internal-format
 #| msgid "expected class name"
 msgid "expected class-key"
 msgstr "diduga nama class"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<class%> or %<typename%>"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, fuzzy, gcc-internal-format
 #| msgid "%Ha class-key must be used when declaring a friend"
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "%Hsebuah class-key harus digunakan ketikan mendeklarasikan sebuah friend"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfriend declaration does not name a class or function"
 msgid "friend declaration does not name a class or function"
 msgstr "%Hdeklarasi friend tidak bernama sebuah kelas atau fungsi"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, fuzzy, gcc-internal-format
 #| msgid "%Hpure-specifier on function-definition"
 msgid "pure-specifier on function-definition"
 msgstr "%Hpenspesifikasi pure di definisi fungsi"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 #| msgid "%<[*]%> not in a declaration"
 msgid "stray %<,%> at end of member declaration"
 msgstr "%<[*]%> tidak dalam sebuah deklarasi"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<(%> or end of line"
 msgid "expected %<;%> at end of member declaration"
 msgstr "diduga %<(%> atau akhir dari baris"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, fuzzy, gcc-internal-format
 #| msgid "invalid AE type specified (%s)\n"
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "tipe AE yang dispesifikasikan (%s) tidak valid\n"
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<namespace%> definition is not allowed here"
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%H%<namespace%> definisi tidak diijinkan disini"
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed outside of templates"
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan diluar dari templates"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, fuzzy, gcc-internal-format
 #| msgid "%Hkeyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "%Hkata kunci %<typename%> tidak diijinkan dalam konteks ini (kelas dasar  adalah sebuah tipe implisit)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in an exception-specification"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "karena perbedaan eksepsi spesifikasi"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "penggunaan tidak valid dari %<auto%> dalam operator konversi"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in exception-declarations"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute conflicts with %s attribute at %L"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%s atribut konflik dengan %s atribut di %L"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier or %<(%>"
 msgid "expected an identifier for the attribute name"
 msgstr "diduga pengidentifikasi atau %<(%>"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexpected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%Hdiduga parameter pack sebelum %<...%>"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, fuzzy, gcc-internal-format
 #| msgid "%s only available with -std=c++0x or -std=gnu++0x"
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "%s hanya tersedia dengan -std=c++0x atau -std=gnu++0x"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, fuzzy, gcc-internal-format
 #| msgid "invalid redeclaration of %q+D"
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "redeklarasi tidak valid dari %q+D"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo few template-parameter-lists"
 msgid "too few template-parameter-lists"
@@ -49817,486 +49881,486 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, fuzzy, gcc-internal-format
 #| msgid "%Htoo many template-parameter-lists"
 msgid "too many template-parameter-lists"
 msgstr "%Hterlalu banyak template-parameter-lists"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnamed return values are no longer supported"
 msgid "named return values are no longer supported"
 msgstr "%Hnilai kembali bernama tidak lagi didukung"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "Use media instructions"
 msgid "empty introduction-list"
 msgstr "Gunakan instruksi media"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid declaration of member template in local class"
 msgid "invalid declaration of member template in local class"
 msgstr "%Hdeklarasi tidak valid dari anggota template dalam kelas lokal"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplate with C linkage"
 msgid "template with C linkage"
 msgstr "%Htemplate dengan C linkage"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 #| msgid "invalid base-class specification"
 msgid "invalid explicit specialization"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 #| msgid "template declaration of %q#D"
 msgid "template declaration of %<typedef%>"
 msgstr "template deklarasi dari %q#D"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "redeklarasi tidak mendeklarasikan apapun"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, fuzzy, gcc-internal-format
 #| msgid "%Hexplicit template specialization cannot have a storage class"
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Heksplisit template spesialisasi tidak dapat memiliki sebuah kelas penyimpanan"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<>>%> should be %<> >%> within a nested template argument list"
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%H%<>>%> seharusnya %<> >%> didalam sebuah daftar argumen template nested"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, fuzzy, gcc-internal-format
 #| msgid "%Hspurious %<>>%>, use %<>%> to terminate a template argument list"
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "%Hspurious %<>>%>, gunakan %<>%> untuk mengakhiri sebuah daftar argumen template"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of %qD in linkage specification"
 msgid "invalid use of %qD in linkage specification"
 msgstr "%Hpenggunaan tidak valid dari %qD dalam spesifikasi linkage"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<__thread%> before %qD"
 msgid "%<__thread%> before %qD"
 msgstr "%H%<__thread%> sebelum %qD"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 tidak mendukung %<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 #| msgid "both %<_Sat%> and %<char%> in declaration specifiers"
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "baik %<_Sat%> dan %<char%> dalam penspesifikasi deklarasi"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %qE"
 msgid "duplicate %qD"
 msgstr "duplikasi %qE"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, fuzzy, gcc-internal-format
 #| msgid "%Hduplicate %qs"
 msgid "duplicate %qs"
 msgstr "%Hduplikasi %qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<new%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<delete%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<return%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<extern%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, fuzzy, gcc-internal-format
 #| msgid "expected statement"
 msgid "expected %<static_assert%>"
 msgstr "diduga pernyataan"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<decltype%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<operator%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<class%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<template%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<namespace%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<using%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<asm%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<catch%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<__label__%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@try%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@synchronized%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<@throw%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<none%> or %<shared%>"
 msgid "expected %<__transaction_relaxed%>"
 msgstr "diduga %<none%> atau %<shared%>"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<::%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<...%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<*%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<{%>"
 msgid "expected %<~%>"
 msgstr "diduga %<{%>"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<:%> or %<...%>"
 msgid "expected %<:%> or %<::%>"
 msgstr "diduga %<:%> atau %<...%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%>, %<;%> or %<}%>"
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "diduga %<,%>, %<,%> atau %<}%>"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "%qs tag digunakan dalam penamaan %q#T"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 #| msgid "%q+T has a previous declaration here"
 msgid "%q#T was previously declared here"
 msgstr "%q+T telah dideklarasikan sebelumnya disini"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qD redeclared with different access"
 msgid "%qD redeclared with different access"
 msgstr "%H%qD redeklarasi dengan akses berbeda"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<template%> (as a disambiguator) is only allowed within templates"
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "%H%<template%> (sebagai sebuah disambiguator) hanya diijinkan dalam templates"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 #| msgid "%Hfile ends in default argument"
 msgid "file ends in default argument"
 msgstr "%Hberkas berakhir dalam argumen baku"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, fuzzy, gcc-internal-format
 #| msgid "%Hmisplaced %<@%D%> Objective-C++ construct"
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "%Hsalah tempat %<@%D%> Objective-C++ konstruk"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, fuzzy, gcc-internal-format
 #| msgid "%H%<@encode%> must specify a type as an argument"
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%H%<@encode%> harus menspesifikasikan sebuah tipe sebagai sebuah argumen"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid Objective-C++ selector name"
 msgid "invalid Objective-C++ selector name"
 msgstr "%Hpemilih nama Objective-C++ tidak valid"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, fuzzy, gcc-internal-format
 #| msgid "expected declaration specifiers"
 msgid "objective-c++ method declaration is expected"
 msgstr "diduga penspesifikasi deklarasi"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, fuzzy, gcc-internal-format
 #| msgid "%Jsection attribute cannot be specified for local variables"
 msgid "method attributes must be specified at the end"
 msgstr "%J atribut daerah tidak dapat dispesifikasikan untuk variabel lokal"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type for iteration variable %qE"
 msgid "invalid type for instance variable"
 msgstr "tipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, fuzzy, gcc-internal-format
 #| msgid "%Hidentifier expected after %<@protocol%>"
 msgid "identifier expected after %<@protocol%>"
 msgstr "%Hpengidentifikasi diduga setelah %<@protocol%>"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored for %qE"
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE atribut diabaikan untuk %qE"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 #| msgid "invalid type argument"
 msgid "invalid type for property"
 msgstr "tipe argumen tidak valid"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 #| msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "inisialisasi berkurung tidak diijinkan dalam loop OpenMP %<for%>"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "iterasi variabel %qD seharusnya bukan reduksi"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, fuzzy, gcc-internal-format
 #| msgid "not enough DO loops for collapsed !$OMP DO at %L"
 msgid "not enough for loops to collapse"
 msgstr "tidak cukup DO loops untuk kolaps !$OMP DO di %L"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 #| msgid "%Hattributes are not allowed on a function-definition"
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "%Hatribut tidak diijinkan dalam sebuah definisi fungsi"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "penginisialisasi tidak valid"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 #| msgid "expected expression"
 msgid "expected id-expression (arguments)"
 msgstr "diduga ekspresi"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 #| msgid "%Hnew types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "%Htipe baru mungkin tidak didefinisikan dalam sebuah tipe kembali"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a namespace scope function"
@@ -50303,74 +50367,74 @@
 msgstr "%qD bukan sebuah anggota dari fungsi template"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, fuzzy, gcc-internal-format
 #| msgid "%Hjunk at end of %<#pragma GCC pch_preprocess%>"
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%Hsampah diakhir dari %<#pragma GCC pch_preprocess%>"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 #| msgid "invalid constraints for operand"
 msgid "invalid grainsize for _Cilk_for"
 msgstr "batasan untuk operan tidak valid"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize tidak diikuti didalam fungsi"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "inter-module optimisasi tidak diimplementasikan untuk C++"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "Diduga nama variabel di %C"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<,%> or %<;%>"
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "diduga %<,%> atau %<,%>"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, fuzzy, gcc-internal-format
 #| msgid "%Htemplates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
@@ -50468,7 +50532,7 @@
 msgid "candidate is: %#D"
 msgstr "kandidat adalah: %+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 #| msgid "%s %+#D"
 msgid "%s %#D"
@@ -51099,132 +51163,149 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument of type %qT because %qE is not a variable"
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qE bukan sebuah variabel"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+#| msgid "%qE is not a valid template argument for type %qT"
+msgid "the address of %qD is not a valid template argument"
+msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT"
+
+#: cp/pt.c:6634
 #, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+#| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%qE bukan sebuah argumen template yang valid dari tipe %qT karena %qD tidak memiliki eksternal linkage"
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena konflik dalam cv kualifikasi"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is a non-constant expression"
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%qE bukan sebuah template argumen yang valid untuk tipe %qT karena ini bukan sebuah ekspresi konstan"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini bukan sebuah lvalue"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena objek %qD bukan eksternal linkage"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini adalah sebuah penunjuk"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "lebih baik coba gunakan %qE"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE bukan sebuah argumen template yang valid untuk tipe %qT karena ini dari tipe %qT"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "konversi baku tidak diijinkan dalam konteks ini"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, fuzzy, gcc-internal-format
 #| msgid "Conflict in attributes of function argument at %C"
 msgid "ignoring attributes on template argument %qT"
 msgstr "Konflik dalam atribut dari argumen fungsi di %C"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring attributes in template argument %qE"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, fuzzy, gcc-internal-format
 #| msgid "name of class shadows template template parameter %qD"
 msgid "injected-class-name %qD used as template template argument"
 msgstr "nama dari template kelas bayangan parameter template %qD"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid use of destructor %qD as a type"
 msgid "invalid use of destructor %qE as a type"
 msgstr "%Hpenggunaan tidak valid dari desktruktor %qD memiliki sebuah tipe"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "merefer ke sebuah anggota tipe dari sebuah parameter template, gunakan %<typename %E%>"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  diduga sebuah konstanta dari tipe %qT, diperoleh %qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  diduga sebuah template kelas, diperoleh %qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  diduga sebuah tipe, diperoleh %qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  diduga sebuah tipe, diperoleh %qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  diduga sebuah template kelas, diperoleh %qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a template of type %qD, got %qD"
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  diduga sebuah template dari tipe %qD, diperoleh %qD"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tipe/nilai tidak cocok di argumen %d dalam daftar parameter template untuk %qD"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
@@ -51232,110 +51313,110 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "tipe tidak cocok dalam paket parameter bukan tipe"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "tidak dapat mengubah argumen template %qE ke %qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "wrong number of template arguments (%d, should be %d)"
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "jumlah dari argumen template salah (%d, seharusnya %d)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "disediakan untuk %q+D"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 #| msgid "default argument given for parameter %d of %q#D"
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "argumen baku diberikan untuk parameter %d dari %q#D"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "disediakan untuk %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a function template"
 msgid "%q#D is not a function template"
 msgstr "%qD bukan sebuah template fungsi"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "tipe bukan template %qT digunakan sebuah sebuah template"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "untuk deklarasi template %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "kegagalan konsistensi internal"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 #| msgid "use of %qs in template"
 msgid "use of invalid variable template %qE"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth-NN to increase the maximum) instantiating %qD"
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "kedalaman template instantiation melebihi maksimal dari %d (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal) instantiating %qD"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "panjang argumen pack tidak cocok akan diekspan %<%T%>"
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "panjang argumen pack tidak cocok ketika mengekspan %<%E%>"
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of default argument for %q#D"
 msgid "  when instantiating default argument for call to %D"
@@ -51354,283 +51435,283 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "variabel %qD memiliki tipe fungsi"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "tipe parameter %qT tidak valid"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "dalam deklarasi %q+D"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "fungsi mengembalikan sebuah array"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "fungsi mengembalikan sebuah fungsi"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "membuat penunjuk ke anggota fungsi dari tipe bukan kelas %qT"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "membentuk referensi ke void"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming pointer to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, fuzzy, gcc-internal-format
 #| msgid "forming %s to reference type %qT"
 msgid "forming reference to reference type %qT"
 msgstr "membentuk %s ke tipe referensi %qT"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming pointer to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 #| msgid "cannot declare %s to qualified function type %qT"
 msgid "forming reference to qualified function type %qT"
 msgstr "tidak dapat mendeklarasikan %s untuk fungsi yang dikualifikasikan dengan tipe %qT"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "membuat penunjuk ke anggota dari tipe bukan kelas %qT"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "membuat penunjuk ke anggota referensi tipe %qT"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "membuat penunjuk ke anggota dari tipe void"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "membuat array dari %qT"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT bukan sebuah tipe class, struct, atau union"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe enumerasi"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT meresolf ke %qT, yang bukan sebuah tipe class"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "penggunaan dari %qs dalam template"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, fuzzy, gcc-internal-format
 #| msgid "qualified type %qT does not match destructor name ~%qT"
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "dependent-name %qE diparse sebagai sebuah bukan-tipe, tetapi instantiation menghasilkan sebuah tipe"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "katakan %<typename %E%> jika sebuah tipe adalah berarti"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "menggunakan field tidak valid %qD"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "penggunaan tidak valid dari ekspresi ekspansi pack"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "gunakan %<...%> untuk mengekspan argumen pack"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 #| msgid "%H%qE undeclared here (not in a function)"
 msgid "%qD declared here, later in the translation unit"
 msgstr "%H%qE tidak dideklarasikan disini (bukan dalam sebuah fungsi)"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT bukan sebuah class atau namespace"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD bukan sebuah class atau namespace"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT adalah/menggunakan tipe anonymous"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "argumen template untuk %qD menggunakan tipe lokal %qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT adalah sebuah tipe variabel termodifikasi"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "ekspresi integral %qE bukan konstan"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  mencoba untuk instantiate %qD"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#T"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 #| msgid "ambiguous class template instantiation for %q#T"
 msgid "ambiguous template instantiation for %q#D"
 msgstr "template class instantiation ambigu untuk %q#T"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 #| msgid "%s %+#D"
 msgid "%s %#S"
 msgstr "%s %+#D"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD bukan sebuah anggota data statis dari sebuah template class"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "template tidak cocok untuk %qD yang ditemukan"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "tipe %qT untuk instantiation eksplisit %qD tidak cocok dengan tipe yang dideklarasikan %qT"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "duplikasi eksplisit instantiation dari %q#D"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 melarang penggunaan dari %<extern%> di instantiation eksplisit"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "class penyimpanan %qD diaplikasikan ke template instantiation"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 #| msgid "explicit instantiation of non-template %q#D"
 msgid "explicit instantiation of non-class template %qD"
 msgstr "instantiation eksplisit dari bukan-template %q#D"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "eksplisit instantiation dari tipe bukan template %qT"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "eksplisit instantiation dari %q#T sebelum definisi dari template"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ melarang penggunaan dari %qE di instantiasi eksplisit"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "duplikasi instansiasi eksplisit dari %q#T"
@@ -51642,102 +51723,102 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "eksplisit instansiasi dari %qD tetapi tidak ada definisi yang tersedia"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, fuzzy, gcc-internal-format
 #| msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth-NN to increase the maximum)"
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "kedalaman template instansiasi melebihi maksimal dari %d instantiating %q+D, kemungkinan dari pembuatan tabel virtual (gunakan -ftemplate-depth-NN untuk meningkatkan maksimal)"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 #| msgid "using template type parameter %qT after %qs"
 msgid "invalid template non-type parameter"
 msgstr "menggunakan parameter tipe template %qT setelah %qs"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T is not a valid type for a template constant parameter"
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T bukan sebuah tipe valid untuk sebuah parameter template konstan"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, fuzzy, gcc-internal-format
 #| msgid "deducing auto from brace-enclosed initializer list requires #include <initializer_list>"
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "deduksi auto dari daftar penginisialisasi dikurung membutuhkan #include <daftar_penginisialisasi>"
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 #| msgid "%qD used without template parameters"
 msgid "non-class template %qT used without template arguments"
 msgstr "%qD digunakan tanpa parameter template"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %d is invalid"
 msgid "class template argument deduction failed:"
 msgstr "template argumen %d tidak valid"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "fungsi tidak dipertimbangkan untuk inlining"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 #| msgid "unable to deduce %qT from %qE"
 msgid "unable to deduce lambda return type from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "tidak dapat mendeduksi %qT dari %qE"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "insn tidak memenuhi batasannya:"
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -51903,175 +51984,175 @@
 msgid "  since %q+#D declared in base class"
 msgstr "  karena %q+#D dideklarasikan dalam kelas dasar"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "disarankan eksplisit tanda kurung disekitar tubuh kosong dalam pernyataan %<do%>"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "tipe dari operan asm %qE tidak dapat ditentukan"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "deklarasi __label__ hanya diperbolehkan dalam lingkup fungsi"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "penggunaan tidak valid dari anggota %q+D dalam anggota fungsi statis"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "argumen ke destruktor tidak diijinkan"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> tidak tersedia untuk anggota fungsi static"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "penggunaan tidak valid dari %<this%> dalam fungsi bukan anggota"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "penggunaan tidak valid ari %<this%> di tingkat paling atas"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "tidak valid pengkualifikasi lingkup dalam nama pseudo-destruktor"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "tipe kualifikasi %qT tidak cocok dengan nama destruktor ~%qT"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE bukan dari tipe %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "compound literal dari tipe bukan-objek %qT"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "tipe parameter template harus menggunakan kata kunci %<class%> atau %<typename%>"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "penggunaan tidak valid dari tipe %qT sebagai nilai baku untuk sebuah parameter template"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "argumen baku tidak valid untuk sebuah parameter template template"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "definisi dari %q#T didalam daftar parameter template"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "definisi tidak valid dari tipe pengkualifikasi %qT"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "spesifikasi kelas dasar tidak valid"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "cannot capture member %qD of anonymous union"
 msgstr "anggota terproteksi %q+#D dalam union anonymous"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a type"
 msgid "%qD is not captured"
 msgstr "%qD bukan sebuah tipe"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of local variable with automatic storage from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, fuzzy, gcc-internal-format
 #| msgid "use of %<auto%> variable from containing function"
 msgid "use of parameter from containing function"
 msgstr "penggunaan dari variabel %<auto%> dari fungsi yang berisi"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 #| msgid "alloc_size parameter outside range"
 msgid "use of parameter outside function body"
 msgstr "alloc_size parameter diluar dari jangkauan"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "argumen tidak cocok"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "parameter template %qD dari tipe %qT tidak diijinkan dalam sebuah ekspresi konstanta integral karena ini bukan tipe integral atau enumerasi"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "penggunaan dari namespace %qD  sebagai ekspresi"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "penggunaan dari template class %qT sebagai ekspresi"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "permintaan untuk anggota %qD adalah ambigu dalam multiple inheritance lattice"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD tidak dapat muncul dalam sebuah ekspresi konstan"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "tipe dari %qE tidak dikenal"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is not a template type"
 msgid "%qT is not an enumeration type"
@@ -52078,334 +52159,334 @@
 msgstr "%qT bukan sebuah tipe template"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, fuzzy, gcc-internal-format
 #| msgid "storage class specifiers invalid in parameter declarations"
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "penspesifikasi kelas penyimpanan dalam parameter deklarasi"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke destruktor %<~%T%>"
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "tidak dapat mengaplikasikan %<offsetof%> ke anggota fungsi %qD"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 #| msgid "reference to %qD is ambiguous"
 msgid "user defined reduction lookup is ambiguous"
 msgstr "referensi ke %qD adalah ambigu"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE memiliki tipe tidak valid untuk %<reduction%>"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "linear step expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<firstprivate%>"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD bukan sebuah variabel dalam clause %<lastprivate%>"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%> nilai harus positif"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%qs length expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 #| msgid "%Hcollapse argument needs positive constant integer expression"
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%Hkolaps argumen membutuhkan konstanta positif integer ekspresi"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<async%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<device%> id must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, fuzzy, gcc-internal-format
 #| msgid "%qD appears more than once in data clauses"
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD muncul lebih dari sekali dalam data clauses"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, fuzzy, gcc-internal-format
 #| msgid "schedule chunk size expression must be integral"
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "schedule chunk ukuran ekspresi harus integral"
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable in clause %qs"
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD bukan sebuah variabel dalam clause %qs"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "reimplementation of class %qs"
 msgid "template %qE in clause %qs"
 msgstr "reimplementasi dari class %qs"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 #| msgid "num_threads expression must be integral"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "num_threads ekspresi harus integral"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%<tree%> is not defined as a pointer type"
 msgid "%<tile%> argument needs integral type"
 msgstr "%<tree%> tidak didefinisikan sebagai sebuah tipe pointer"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%> %qD bukan berkas, namespace atau blok scope variabel"
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%> %qE direktif tidak dalam definisi %qT"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, fuzzy, gcc-internal-format
 #| msgid "%Hdifference between %qE and %qD does not have integer type"
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%Hperbedaan antara %qE dan %qD tidak memiliki tipe integer"
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, fuzzy, gcc-internal-format
 #| msgid "%Hinvalid type for iteration variable %qE"
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%Htipe tidak valid untuk iterasi variabel %qE"
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed: %s"
 msgstr "static assertion gagal: %E"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "kondisi bukan konstan untuk assertion static"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "argumen ke decltype harus berupa sebuah ekspresi"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, fuzzy, gcc-internal-format
 #| msgid "%s cannot resolve address of overloaded function"
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s tidak dapat meresolf alamat dari fungsi overloaded"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "operan tangan-kiri dari ekspresi koma tidak memiliki efek"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "template argumen %qE melibatkan parameter template"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -52422,122 +52503,122 @@
 msgid "lambda-expression in a constant expression"
 msgstr "Tipe buruk dalam ekspresi konstanta"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 #| msgid "%qs attribute only applies to function types"
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "atribut %qs hanya berlaku ke fungsi tipe"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE atribut hanya dapat diaplikasikan ke definisi class"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "permintaan init_priority bukan sebuah konstanta integer"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "hanya dapat menggunakan atribut %qE di definisi lingkup-berkas dari objek dari tipe class"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "permintaan init_priority diluar dari jangkauan"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "permintaan init_priority disimpan untuk penggunaan internal"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "atribut %qE tidak didukung di platform ini"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %qD as %s"
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "deklarasi dari %qD sebagai %s"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 #| msgid "%qD attribute requires a single NTBS argument"
 msgid "the %qE attribute requires arguments"
 msgstr "%qD atribut membutuhkan sebuah argumen NTBS tunggal"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 #| msgid "argument of %qs attribute is not a string constant"
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "argumen dari atribut %qs bukan sebuah konstanta string"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 #| msgid "%<%T::%D%> is not a valid declarator"
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "%<%T::%D%> bukan sebuah deklarator yang valid"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE atribut diabaikan dalam tipe bukan-class"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring attributes applied to %qT after definition"
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "mengabaikan atribut yang diaplikasikan ke %qT setelah definisi"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 #| msgid "%J%qE attribute applies only to functions"
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "atribut %J%qE berlaku hanya untuk fungsi"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 #| msgid "%s attribute applied to %s %s at %L"
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%s atribut diaplikasikan ke %s %s di %L"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, fuzzy, gcc-internal-format
 #| msgid "array bound is not an integer constant"
 msgid "zero as null pointer constant"
 msgstr "array bound bukan sebuah konstanta integer"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "pemeriksaan lang_*: gagal dalam %s, di %s:%d"
@@ -53267,118 +53348,118 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "konversi tidak valid ke tipe %qT dari tipe %qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "tidak dapat mengubah %qT ke %qT untuk argumen %qP ke %qD"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "tidak dapat mengubah %qT ke %qT untuk argumen %qP ke %qD"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in return"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, fuzzy, gcc-internal-format
 #| msgid "cannot convert %qT to %qT in %s"
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "tidak dapat mengubah %qT ke %qT dalam %s"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "tipe kembali %q#T tidak lengkap"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, fuzzy, gcc-internal-format
 #| msgid "argument %d of %qE might be a candidate for a format attribute"
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "argumen %d dari %qE mungkin menjadi sebuah kandidat untuk sebuah format atribut"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, fuzzy, gcc-internal-format
 #| msgid "return type might be a candidate for a format attribute"
 msgid "parameter might be a candidate for a format attribute"
 msgstr "tipe kembali mungkin berupa sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, fuzzy, gcc-internal-format
 #| msgid "argument of function call might be a candidate for a format attribute"
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "argumen dari fungsi panggilan mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, fuzzy, gcc-internal-format
 #| msgid "assignment left-hand side might be a candidate for a format attribute"
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "penempatan sisi tangan-kiri mungkin menjadi sebuah kandidat untuk sebuah atribut format"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "dalam melewatkan argumen %P dari %q+D"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "mengembalikan referensi ke sementara"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "referensi ke bukan-lvalue dikembalikan"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "referensi ke variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "alamat dari variabel lokal %q+D dikembalikan"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "mengembalikan sebuah nilai dari sebuah destruktor"
@@ -53385,56 +53466,56 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "tidam dapat kembali dari sebuah penanganan dari sebuah fungsi-coba-blok dari sebuah konstruktor"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "mengembalikan sebuah nilai dari sebuah konstruktor"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "pernyataan-kembali dengan tidak ada nilai, dalam fungsi mengembalikan %qT"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 #| msgid "missing initializer"
 msgid "returning initializer list"
 msgstr "hilang penginisialisasi"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "pernyataan kembali dengan sebuah nilai, dalam fungsi mengembalikan 'void'"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> harus tidak mengembalikan KOSONG kecuali ini dideklarasikan %<throw()%> (atau ada dalam pengaruh -fcheck-new )"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -57779,91 +57860,91 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Noninteger exponent in an initialization expression at %L"
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003: eksponen bukan integer dalam sebuah ekspresi inisialisasi di %L"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, fuzzy, gcc-internal-format
 #| msgid "Argument to '%s' at %L is not a variable"
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "Argumen ke '%s' di %L bukan sebuah variabel"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' cannot appear in the expression at %L"
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "Variabel '%s' tidak dapat muncul dalam ekspresi di %L"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "Variabel %s tidak dapat ditempatkan dalam prosedur PURE di %C"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -58066,12 +58147,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari penempatan didefinisikan di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen pertama dari antar-muka operator di %L harus berupa INTENT(IN)"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "Argumen kedua dari antar-muka operator di %L harus berupa INTENT(IN)"
@@ -58948,560 +59029,577 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "Fortran 2003: penspesifikasi format DP tidak diijinkan di %C"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: X descriptor requires leading space count at %C"
 msgid "X descriptor requires leading space count at %L"
 msgstr "Ekstensi: X pendeskripsi membutuhkan awalan spasi dihitung di %C"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: $ descriptor at %C"
 msgid "$ descriptor at %L"
 msgstr "Ekstensi: $ pendeskripsi di %C"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "$ should be the last specifier in format at %C"
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ seharusnya penspesifikasi terakhir dalam format di %C"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %C"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Ekstensi: Hilang lebar positif setelah pendeskripsi L di %C"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %C"
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Ekstensi: Hilang lebar positif setelah pendeskripsi L di %C"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 #| msgid "%s in format string at %L"
 msgid "%<G0%> in format at %L"
 msgstr "%s dalam format string di %L"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Positive width required in format specifier %s at %L"
 msgstr "Period dibutuhkan dalam format penspesifikasi di %C"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Period required in format specifier %s at %L"
 msgstr "Period dibutuhkan dalam format penspesifikasi di %C"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Period required in format specifier at %C"
 msgid "Period required in format specifier at %L"
 msgstr "Period dibutuhkan dalam format penspesifikasi di %C"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "The H format specifier at %C is a Fortran 95 deleted feature"
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr "Penspesifikasi format H di %C adalah sebuah feature Fortran 95 yang dihapus"
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing comma at %C"
 msgid "Missing comma at %L"
 msgstr "Ekstensi: Hilang koma di %C"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s dalam format string di %L"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Tab character in format at %C"
 msgid "Extraneous characters in format at %L"
 msgstr "Ekstensi: Karakter tab dalam format di %C"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr "Pernyataan format dalam modul blok utama di %C"
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul dalam sebuah ANTAR-MUKA"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Hilang label format di %C"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "Nilai tidak valid untuk %s spesifikasi di %C"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "Duplikasi %s spesifikasi di %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "Variabel %s tidak dapat berupa INTENT(IN) di %C"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "Variabel %s tidak dapat ditempatkan dalam prosedur PURE di %C"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "Duplikasi %s label spesifikasi di %C"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "Ekspresi konstant dalam FORMAT tag di %L harus berupa tipe baku KARAKTER"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "FORMAT tag at %L must be of type CHARACTER or INTEGER"
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "FORMAT tag di %L harus berupa tipe KARAKTER atau INTEGER"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Deleted feature: ASSIGNED variable in FORMAT tag at %L"
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "Featur terhapus: DITEMPATKAN variabel dalam FORMAT tag di %L"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L has not been assigned a format label"
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "Variabel '%s' di %L belum ditempatkan sebuah label format"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, fuzzy, gcc-internal-format
 #| msgid "Scalar '%s' in FORMAT tag at %L is not an ASSIGNED variable"
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr "Skalar '%s' dalam FORMAT tag di %L bukan sebuah variabel DITEMPATKAN"
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Non-character in FORMAT tag at %L"
 msgid "Non-character in FORMAT tag at %L"
 msgstr "Ekstensi: Bukan-karakter dalam tag FORMAT di %L"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Character array in FORMAT tag at %L"
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "Ekstensi: Karakter array dalam FORMAT tag di %L"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Character array in FORMAT tag at %L"
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "Ekstensi: Karakter array dalam FORMAT tag di %L"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Character array in FORMAT tag at %L"
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "Ekstensi: Karakter array dalam FORMAT tag di %L"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "%s tag di %L harus berupa tipe %s"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Concat operator at %L must concatenate strings of the same kind"
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "Operator konkatenasi di %L harus konkatenasi string dari tipe yang sama"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "%s tag di %L harus berupa skalar"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: IOMSG tag at %L"
 msgid "IOMSG tag at %L"
 msgstr "Fortran 2003: IOMSG tag di %L"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Fortran 95 membutuhkan INTEGER baku dalam tag %s di %L"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Bad INTENT specification at %C"
 msgid "NEWUNIT specifier at %L"
 msgstr "Spesifikasi INTENT buruk di %C"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: CONVERT tag at %L"
 msgid "CONVERT tag at %L"
 msgstr "Ekstensi: CONVERT tag di %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: %s specifier in %s statement at %C has value '%s'"
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Fortran 2003: penspesifikasi %s dalam pernyataan %s di %C memiliki nilai '%s'"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 #| msgid "%s specifier in %s statement at %C has invalid value '%s'"
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "penspesifikasi %s dalam pernyataan %s di %C memiliki nilai tidak valid '%s'"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 #| msgid "Extension: %s specifier in %s statement at %C has value '%s'"
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "Ekstensi: penspesifikasi %s dalam pernyataan %s di %C memiliki nilai '%s'"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 #| msgid "%s specifier in %s statement at %C has invalid value '%s'"
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "penspesifikasi %s dalam pernyataan %s di %C memiliki nilai tidak valid '%s'"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "pernyataan OPEN tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "E specifier not allowed with g0 descriptor"
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr "Penspesifikasi E tidak diperbolehkan dengan pendeskripsi g0"
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "pernyataan INQUIRE di %L membutuhkan baik BERKAS atau penspesifikasi SATUAN"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: ASYNCHRONOUS= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: BLANK= at %C not allowed in Fortran 95"
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: BLANK= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DECIMAL= at %C not allowed in Fortran 95"
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: DECIMAL= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ENCODING= at %C not allowed in Fortran 95"
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: ENCODING= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: PAD= di %C belum terimplementasi dalam Fortran 95"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: SIGN= at %C not allowed in Fortran 95"
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: SIGN= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "pernyataan CLOSE tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ASSIGNED GOTO statement at %L requires an INTEGER variable"
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "pernyataan GOTO ASSIGNED di %L membutuhkan sebuah variabel INTEGER"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Expression in CASE statement at %L must be of type %s"
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "Ekspresi dalam pernyataan CASE di %L harus berupa tipe %s"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "pernyataan %s tidak diperbolehkan dalam prosedur PURE di %C"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing ')' in statement at or before %L"
 msgid "UNIT number missing in statement at %L"
 msgstr "Hilang ')' dalam pernyataan di atau sebelum %L"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "STAT tag in %s statement at %L must be a variable"
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "STAT tag dalam pernyataan %s di %L harus berupa sebuah variabel"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: FLUSH statement at %C"
 msgid "FLUSH statement at %C"
 msgstr "Fortran 2003: pernyataan FLUSH di %C"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing format with default unit at %C"
 msgstr "Hilang label format di %C"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Duplikasi SATUAN spesifikasi di %C"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Duplikasi format spesifikasi di %C"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' in namelist '%s' is INTENT(IN) at %C"
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "Simbol '%s' dalam daftar nama '%s' adalah INTENT(IN) di %C"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Duplikasi spesifikasi NML di %C"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' at %C must be a NAMELIST group name"
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "Simbol '%s' di %C harus berupa sebuah nama grup DAFTAR-NAMA"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "tag AKHIR di %C tidak diperbolehkan dalam pernyataan keluaran"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "-I- specified twice"
 msgid "UNIT not specified at %L"
 msgstr "-I- dispesifikasikan dua kali"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "spesifikasi SATUAN di %L harus berupa sebuah ekspresi INTEGER atau sebuah KARAKTER variabel"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "Form tidak valid dari pernyataan WRITE di %L, dibutuhkan UNIT"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "Satuan internal dengan vektor subscrip di %L"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "Eksternal IO UNIT tidak dapat berupa sebuah array di %L"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, fuzzy, gcc-internal-format
+#| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr "NAMELIST objek '%s' dalam daftar-nama '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
+
+#: fortran/io.c:3317
+#, fuzzy, gcc-internal-format
+#| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr "NAMELIST objek '%s' dalam daftar-nama '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
+
+#: fortran/io.c:3328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Comma before i/o item list at %L"
 msgid "Comma before i/o item list at %L"
 msgstr "Ekstensi: Koma sebalum i/o daftar item di %L"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR tag label %d di %L tidak didefinisikan"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END tag label %d di %L tidak didefinisikan"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR tag label %d di %L tidak didefinisikan"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT label %d di %L tidak didefinisikan"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Sintaks error dalam iterasi I/O di %C"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Diduga variabel dalam pernyataan BACA di %C"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Diduga ekspresi dalam pernyataan %s di %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Sintaks error dalam pernyataan %s di %C"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Internal file at %L with namelist"
 msgid "Internal file at %L with namelist"
 msgstr "Fortran 2003: Berkas internal di %L dengan daftar-nama"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "ASYNCHRONOUS= penspesifikasi di %L harus berupa ekspresi inisialisasi"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: PAD= at %C not allowed in Fortran 95"
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: PAD= di %C belum terimplementasi dalam Fortran 95"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: DELIM= at %C not allowed in Fortran 95"
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: DELIM= di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "daftar-nama PRINT di %C adalah sebuah ekstensi"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "Diduga koma dalam daftar I/O di %C"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "pernyataan PRINT di %C tidak diperbolehkan dalam prosedur PURE"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "pernyataan INQUIRE tidak diperbolehkan dalam prosedur di %C"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "IOLENTH tag tidak valid dalam pernyataan INQUIRE di %C"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "pernyataan INQUIRE di %L tidak dapat berisi baik BERKAS dan penspesifikasi SATUAN"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "pernyataan INQUIRE di %L membutuhkan baik BERKAS atau penspesifikasi SATUAN"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Argument of SELECT statement at %L cannot be %s"
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "Argumen dari pernyataan SELECT di %L tidak dapat berupa %s"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "pernyataan INQUIRE di %L membutuhkan sebuah PENDING= penspesifikasi dengan ID= penspesifikasi"
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: WAIT at %C not allowed in Fortran 95"
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "Fortran 2003: WAIT di %C tidak diijinkan dalam Fortran 95"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "pernyataan WAIT tidak diperbolehkan dalam prosedur PURE di %C"
@@ -60483,282 +60581,282 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "Hilang spesifikasi umum dalam pernyataan USE di %C"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: Renaming operators in USE statements at %C"
 msgid "Renaming operators in USE statements at %C"
 msgstr "Fortran 2003: Mengubah nama operator dalam pernyataan USE di %C"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 #| msgid "The name '%s' at %C has already been used as an external module name."
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Nama '%s' di %C telah digunakan sebagai nama modul eksternal"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Junk after PROCEDURE declaration at %C"
 msgid "SUBMODULE declaration at %C"
 msgstr "Sampah setelah deklarasi PROCEDURE di %C"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "pernyataan MASUKAN di %C tidak dapat muncul didalam sebuah subprogram terkontain"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Sintaks error dalam pernyataan SAVE di %C"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "Reading module %s at line %d column %d: %s"
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "Membaca modul %s di baris %d kolom %d: %s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "Writing module %s at line %d column %d: %s"
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "Menulis modul %s di baris %d kolom %d: %s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, fuzzy, gcc-internal-format
 #| msgid "Module %s at line %d column %d: %s"
 msgid "Module %qs at line %d column %d: %s"
 msgstr "Modul %s di baris %d kolom %d: %s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Error menulis berkas modul: %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, fuzzy, gcc-internal-format
 #| msgid "User operator '%s' referenced at %L not found in module '%s'"
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "Operator pengguna '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic operator '%s' referenced at %L not found in module '%s'"
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "Operator intrinsik '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Tidak dapat membuka berkas modul '%s' untuk menulis di %C: %s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 #| msgid "Error writing module file '%s' for writing: %s"
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Error menulis berkas modul '%s' untuk menulis: %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "tidak dapat menghapus berkas modul '%s': %s"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "tidak dapat mengubah nama berkas modul '%s' ke '%s': %s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Tidak dapat menghapus berkas modul sementara '%s': %s"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs at %C already declared"
 msgstr "Simbol '%s' telah terdeklarasi"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in module '%s'"
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul '%s'"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul intrinsik ISO_C_BINDING"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "Simbol '%s' telah terdeklarasi"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, fuzzy, gcc-internal-format
 #| msgid "Use of intrinsic module '%s' at %C conflicts with non-intrinsic module name used previously"
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "Penggunaan daro modul intrinsik '%s' di %C konflik dengan tidak-intrinsik nama modul digunakan sebelumnya"
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, fuzzy, gcc-internal-format
 #| msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %s"
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "Penggunaan dari NUMERIC_STORAGE_SIZE konstanta bernama dari modul intrinsik ISO_FORTRAN_ENV di %L adalah tidak kompatibel dengan pilihan %s"
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "Penggunaan dari NUMERIC_STORAGE_SIZE konstanta bernama dari modul intrinsik ISO_FORTRAN_ENV di %C adalah tidak kompatibel dengan pilihan %s"
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "Simbol '%s' direferensikan di %L tidak ditemukan dalam modul intrinsik ISO_FORTRAN_ENV"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s statement at %C is not within a loop"
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "pernyataan %s di %C tidak dalam jangkauan sebuah loop"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_FORTRAN_ENV intrinsic module at %C"
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003: ISO_FORTRAN_ENV modul intrinsik di %C"
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Fortran 2003: ISO_C_BINDING module at %C"
 msgid "ISO_C_BINDING module at %C"
 msgstr "Fortran 2003: ISO_C_BINDING modul di %C"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, fuzzy, gcc-internal-format
 #| msgid "Can't find an intrinsic module named '%s' at %C"
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "Tidak dapat menemukan modul intrinsik bernama '%s' di %C"
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Tidak dapat membuka berkas modul '%s' untuk pembacaan di %C: %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, fuzzy, gcc-internal-format
 #| msgid "Use of non-intrinsic module '%s' at %C conflicts with intrinsic module name used previously"
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "Penggunaan dari modul tidak intrinsik '%s' di %C konflik dengan nama modul intrinsik yang digunakan sebelumnya"
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, fuzzy, gcc-internal-format
 #| msgid "File '%s' opened at %C is not a GFORTRAN module file"
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "Berkas '%s' dibuka di %C bukan sebuah berkas modul GFORTRAN"
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building!"
@@ -63399,7 +63497,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "Tidak dapat meresolf fungsi spesifik '%s'di %L"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, fuzzy, gcc-internal-format
 #| msgid "Function '%s' at %L has no IMPLICIT type"
 msgid "Function %qs at %L has no IMPLICIT type"
@@ -65039,497 +65137,486 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, fuzzy, gcc-internal-format
 #| msgid "Assumed size array '%s' in namelist '%s' at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Ukuran array yang diasumsikan '%s' dalam daftar nama '%s' di %C tidak diperbolehkan"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must not have assumed shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' tidak boleh memiliki bentuk yang diasumsikan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST array object '%s' must have constant shape in namelist '%s' at %L"
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "NAMELIST array objek '%s' harus memiliki bentuk konstan dalam daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:13914
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
+#: fortran/resolve.c:13903
 #, fuzzy, gcc-internal-format
-#| msgid "NAMELIST object '%s' in namelist '%s' at %L cannot have ALLOCATABLE components"
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "NAMELIST objek '%s' dalam daftar-nama '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN"
-
-#: fortran/resolve.c:13942
-#, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' was declared PRIVATE and cannot be member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' telah dideklarasikan PRIVATE dan tidak dapat berupa anggota dari PUBLIK namelist '%s' di %L"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has use-associated PRIVATE components and cannot be member of namelist '%s' at %L"
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "NAMELIST objek '%s' memiliki use-associated komponen PRIVATE dan tidak dapat berupa anggota dari daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, fuzzy, gcc-internal-format
 #| msgid "NAMELIST object '%s' has PRIVATE components and cannot be a member of PUBLIC namelist '%s' at %L"
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "NAMELIST objek '%s' meemiliki komponen PRIVATE dan tidak dapat berupa anggota dari PUBLIK daftar-nama '%s' di %L"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with NAMELIST attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut NAMELIST dalam '%s' di %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, fuzzy, gcc-internal-format
 #| msgid "Parameter array '%s' at %L cannot be automatic or of deferred shape"
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "Parameter array '%s' di %L tidak dapat berupa otomatis atau bentuk deferred"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, fuzzy, gcc-internal-format
 #| msgid "Implicitly typed PARAMETER '%s' at %L doesn't match a later IMPLICIT type"
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "Tipe PARAMETER secara implisit '%s' di %L tidak cocok dengan tipe IMPLISIT kemudian"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "Tipe turunan tidak kompatibel dalam PARAMETER di %L"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "atribut PROSEDUR konflik dengan atribut INTENT dalam '%s' di %L"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "Ukuran array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array at %L must be a dummy argument"
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "Bentuk array yang diasumsikan di %L harus berupa sebuah argumen dummy"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Simbol di %L bukan sebuah variabel DUMMY"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "'%s' di %L tidak dapat memiliki VALUE atribut karena ini bukan sebuah argumen dummy"
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, fuzzy, gcc-internal-format
 #| msgid "Character dummy variable '%s' at %L with VALUE attribute must have constant length"
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "Karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang konstant"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, fuzzy, gcc-internal-format
 #| msgid "C interoperable character dummy variable '%s' at %L with VALUE attribute must have length one"
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "C interoperable karakter dummy variabel '%s' di %L dengan atribut NILAI harus memiliki panjang satu"
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, fuzzy, gcc-internal-format
 #| msgid "The derived type '%s' at %L is of type '%s', which has not been defined"
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "Tipe turunana '%s' di %L adalah tipe '%s',  yang mana belum didefinisikan"
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Assumed shape array '%s' at %L is not permitted in an initialization expression"
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "Diasumsikan bentuk array '%s' di %L tidak diijinkan dalam sebuah ekspresi inisialisasi"
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut DAPAT DIALOKASIKAN dan BIND(C)"
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "Variabel '%s' di %L tidak dapat memiliki dua atribut PENUNJUK dan BIND(C)"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "Variabel '%s' di %L tidak dapat berupa BIND(C) karena ini bukan sebuah blok UMUM atau dideklarasikan dalam tingkat cakupan modul"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, fuzzy, gcc-internal-format
 #| msgid "Fortran 2003: PUBLIC %s '%s' at %L of PRIVATE derived type '%s'"
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003: PUBLIK %s '%s' di %L dari tipe turunan '%s' PRIVATE"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, fuzzy, gcc-internal-format
 #| msgid "The INTENT(OUT) dummy argument '%s' at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "INTENT(OUT) dummy argumen '%s' di %L adalah UKURAN DIASUMSIKAN dan jadi tidak dapat memiliki sebuah penginisialisasi baku"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy argument '%s' at %L cannot be INTENT(OUT)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "Dummy argumen '%s' di %L tidak dapat berupa INTENT(OUT)"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L cannot be an array or an array section"
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "Argumen dengan nilai di %L tidak dapat berupa sebuah array atau sebuah daerah array"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L cannot have a deferred shape"
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "Array '%s' di %L tidak dapat memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, fuzzy, gcc-internal-format
 #| msgid "Allocatable array '%s' at %L must have a deferred shape"
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "Array dapat dialokasikan '%s' di %L harus memiliki sebuah bentuk deferred"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy procedure at %L not allowed in ELEMENTAL procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Prosedur dummy di %L tidak diperbolehkan dalam prosedur ELEMENTAL"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Daftar-nama %s tidak dapat diubah namanya dengan assosiasi USE ke %s"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "Threadprivate di %L bukan SAVEd"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, fuzzy, gcc-internal-format
 #| msgid "BLOCK DATA element '%s' at %L must be in COMMON"
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "DATA BLOK elemen '%s' di %L harus berupa dalam COMMON"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, fuzzy, gcc-internal-format
 #| msgid "DATA array '%s' at %L must be specified in a previous declaration"
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "DATA array '%s' di %L harus dispesifikasikan dalam sebuah deklarasi sebelumnya"
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 #| msgid "Dummy '%s' at %L cannot have an initializer"
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "Dummy '%s' di %L tidak dapat memiliki sebuah penginisialisasi"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "Daerah array tidak konstant di %L dalam pernyataan DATA"
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "pernyataan DATA di %L memiliki lebih variabel daripada nilai"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "pernyataan DATA di %L memiliki lebih banyak nilai daripada variabel"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Label %d di %L didefinisikan tetapi tidak digunakan"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Label %d di %L didefinisikan tetapi tidak dapat digunakan"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L harus memiliki atribut URUTAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L tidak dapat memiliki komponen DAPAT DIALOKASIKAN untuk menjadi sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "Tipe variabel turunan '%s' di %L dengan inisialisasi baku tidak dapat berada dalam EKUIVALEN dengan sebuah variabel dalam COMMON"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, fuzzy, gcc-internal-format
 #| msgid "Derived type variable '%s' at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "Tipe variabel turunan '%s' di %L dengan komponen penunjuk tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Sintaks error dalam pernyataan EKUIVALEN di %L"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "Baik semua atau kosong dari objek dalam EKUIVALEN set di %L yang memiliki atribut TERPROTEKSI"
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, fuzzy, gcc-internal-format
 #| msgid "Common block member '%s' at %L cannot be an EQUIVALENCE object in the pure procedure '%s'"
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "Anggota blok umum '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN dalam prosedur pure '%s'"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, fuzzy, gcc-internal-format
 #| msgid "Named constant '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Konstanta bernama '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, fuzzy, gcc-internal-format
 #| msgid "Array '%s' at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "Array '%s' di %L dengan cakupan tidak-konstan tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, fuzzy, gcc-internal-format
 #| msgid "Structure component '%s' at %L cannot be an EQUIVALENCE object"
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "Komponen struktur '%s' di %L tidak dapat berupa sebuah objek EKUIVALEN"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "Substring di %L memiliki panjang nol"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, fuzzy, gcc-internal-format
 #| msgid "PUBLIC function '%s' at %L cannot be of PRIVATE type '%s'"
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fungsi PUBLIK '%s' di %L tidak dapat berupa tipe PRIVATE '%s'"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 #| msgid "ENTRY '%s' at %L has no IMPLICIT type"
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "MASUKAN '%s' di %L tidak memiliki tipe IMPLISIT"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must be a FUNCTION"
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "Prosedur operator pengguna '%s' di %L harus berupa sebuah FUNGSI"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L cannot be assumed character length"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "Prosedur operator pengguna '%s' di %L tidak dapat berupa panjang karakter diasumsikan"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, fuzzy, gcc-internal-format
 #| msgid "User operator procedure '%s' at %L must have at least one argument"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Prosedur operator pengguna '%s' di %L harus memiliki paling tida satu argumen"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "Argumen pertama dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "Argumen kedua dari antar-muka operator di %L tidak dapat berupa pilihanonal"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "Antar-muka operator di %L harus memiliki, paling tidak, dua argumen"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, fuzzy, gcc-internal-format
 #| msgid "Contained procedure '%s' at %L of a PURE procedure must also be PURE"
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
@@ -66706,12 +66793,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "variabel lingkungan \"%s\" tidak terdefinisi"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "IO basetype buruk (%d)"
@@ -69350,9 +69437,6 @@
 #~ msgid "Deprecated. Use -Os instead"
 #~ msgstr "Ditinggalkan. Gunakan -Os lebih baik"
 
-#~ msgid "Generate floating-point multiply-add instructions"
-#~ msgstr "Hasilkan titik pecahan instruksi perkalian-penambahan"
-
 #~ msgid "Use the mips-tfile postpass"
 #~ msgstr "Gunakan postpass mips-tfile"
 
Index: gcc/po/fi.po
===================================================================
--- gcc/po/fi.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/fi.po	(.../branches/gcc-7-branch)
@@ -32,7 +32,7 @@
 msgstr ""
 "Project-Id-Version: gcc 6.1-b20160131\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2016-02-06 01:01+0200\n"
 "Last-Translator: Lauri Nurmi <lanurmi@iki.fi>\n"
 "Language-Team: Finnish <translation-team-fi@lists.sourceforge.net>\n"
@@ -221,13 +221,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "liukulukuvakiota käytetty väärin"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -584,62 +584,62 @@
 " valitsimien välittämiseen näille prosesseille on käytettävä -W<kirjain>-\n"
 " valitsimia.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, fuzzy, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "Käsitellään opastesivuja hakemistossa %s...\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "Kohde: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, fuzzy, c-format
 msgid "Configured with: %s\n"
 msgstr "POP2-tuen asetuksia ei ole tehty.\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Säiemalli: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc-versio %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr ""
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr "Vika ei ole toistettavissa, joten se on todennäköisesti laitteisto- tai käyttöjärjestelmäongelma.\n"
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "asennus: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "ohjelmat: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "kirjastot: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -648,16 +648,16 @@
 "\n"
 "Ohjeet vikailmoitusten tekoon ovat osoitteessa:\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "©"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -667,7 +667,7 @@
 "Tällä ohjelmistolla EI OLE TAKUUTA; ei edes KAUPALLISESTI HYVÄKSYTTÄVÄSTÄ\n"
 "LAADUSTA tai SOPIVUUDESTA TIETTYYN TARKOITUKSEEN.\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -680,7 +680,7 @@
 "======================\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -689,7 +689,7 @@
 "Käytä ”-Wl,VALITSIN” välittämään ”VALITSIN” linkittimelle.\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -700,7 +700,7 @@
 "====================\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -714,18 +714,18 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+#| msgid "  -n, --no-output                 Do not create an output file\n"
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -o <tiedosto>            Ohjaa tuloste <tiedostoon>\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 #| msgid "  -v, --version                   Print version number, then exit\n"
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -v, --verbose     toimi äänekkäästi (tulostetaan lisätietoa)\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -n, --no-output                 Do not create an output file\n"
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -o <tiedosto>            Ohjaa tuloste <tiedostoon>\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -741,14 +741,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -776,19 +776,13 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "  -h, --help                      Näytä tämä ohje ja poistu\n"
-
-#: gcov-tool.c:422
-#, fuzzy, c-format
-#| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -f, --function                      Print function level info\n"
 msgstr "  -h, --help                      Näytä tämä ohje ja poistu\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:421
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -F, --fullname                      Print full filename\n"
@@ -796,13 +790,19 @@
 "Tulosta työhakemiston täydellinen nimi.\n"
 "\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:422
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr "  -h, --help                      Näytä tämä ohje ja poistu\n"
+
+#: gcov-tool.c:423
+#, fuzzy, c-format
+#| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -o, --object                        Print object level info\n"
 msgstr "  -h, --help                      Näytä tämä ohje ja poistu\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -886,20 +886,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Näytä tämä ohje ja poistu\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                Näytä tietoja jokaisesta peruslohkosta\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      Sisällytä haarojen todennäköisyydet tulosteeseen\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, fuzzy, c-format
 #| msgid ""
 #| "  -c, --branch-counts             Given counts of branches taken\n"
@@ -911,16 +906,21 @@
 "  -c, --branch-counts             Toteutuneiden haarojen lukumäärät,\n"
 "                                    ei prosenttilukuja\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, fuzzy, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "näytä edistymisviesti MÄÄRÄn tietueen välein (oletus 10)"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        Tulosta yhteenvedot jokaisesta funktiosta\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Näytä tämä ohje ja poistu\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1108,82 +1108,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s ei tue: dump_bb_for_graph"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "Rivejä suoritettu:%s/%d\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "Ei suoritettavia rivejä\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s ”%s”\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "Haaroja suoritettu:%s/%d\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "Ei haaroja\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "Kutsuja suoritettu:%s/%d\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "Ei kutsuja\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, fuzzy, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "Rivejä suoritettu:%s/%d\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "kutsu  %2d palautti %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "kutsu  %2d ei suoritettu koskaan\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, fuzzy, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "kutsu  %2d palautti %s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, fuzzy, c-format
 msgid "branch %2d never executed\n"
 msgstr "kutsu  %2d ei suoritettu koskaan\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, fuzzy, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "kutsu  %2d palautti %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, fuzzy, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "kutsu  %2d ei suoritettu koskaan\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, fuzzy, c-format
 msgid "Cannot open source file %s\n"
 msgstr "lähdetiedostoa %s ei löydy"
@@ -1299,91 +1299,91 @@
 msgid "Uses of this option are diagnosed."
 msgstr "%s: oletetaan RTC:n käyttävän UTC:tä...\n"
 
-#: opts.c:1096
+#: opts.c:1103
 #, fuzzy, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, fuzzy, c-format
 #| msgid "(%s %s %s %s %s"
 msgid "%s  Same as %s."
 msgstr "on vaarallista toimia rekursiivisesti hakemistossa %s (sama kuin %s)"
 
-#: opts.c:1242
+#: opts.c:1249
 #, fuzzy
 msgid "[default]"
 msgstr " (oletus)"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[käytössä]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[ei käytössä]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " Yhtään valitsinta halutuilla ominaisuuksilla ei löytynyt\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " Mitään ei löytynyt.  Käytä --help=%s näyttämään *kaikki* valitsimet, joita %s-edusta tukee.\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " Kaikki valitsimet halutuilla ominaisuuksilla on jo näytetty\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "Seuraavat valitsimet ovat kohdekohtaisia"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr ""
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "Seuraavat valitsimet ohjaavat optimointeja"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "Seuraavat valitsimet ovat kielestä riippumattomia"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr ""
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "Seuraavat valitsimet ovat liittyvät kieleen "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "Kieli tukee seuraavia valitsimia "
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "Seuraavia valitsimia ei ole dokumentoitu"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr ""
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr ""
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "Seuraavat valitsimet ovat kieleen liittyviä"
 
@@ -2947,8 +2947,8 @@
 msgid "<command-line>"
 msgstr "<komentorivi>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "fr30_print_operand: tuntematon koodi"
@@ -2967,7 +2967,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "puuttuva operandi"
@@ -2987,8 +2987,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "virheellinen etuliite ”0b” liukulukuvakiolle"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -3004,18 +3004,18 @@
 msgstr "virheellinen %%r-arvo"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "virheellinen %%R-arvo"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "virheellinen %%N-arvo"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "virheellinen %%P-arvo"
@@ -3025,7 +3025,7 @@
 msgid "invalid %%h value"
 msgstr "virheellinen %%h-arvo"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "virheellinen %%L-arvo"
@@ -3046,7 +3046,7 @@
 msgstr "virheellinen %%U-arvo"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "virheellinen %%s-arvo"
@@ -3056,7 +3056,7 @@
 msgid "invalid %%C value"
 msgstr "virheellinen %%C-arvo"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "virheellinen %%E-arvo"
@@ -3067,7 +3067,7 @@
 msgstr "uudelleensijoitusvirhe"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "virheellinen %%xn-koodi"
@@ -3130,7 +3130,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, fuzzy, c-format
 msgid "invalid operand output code"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
@@ -3140,29 +3140,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Virheellinen käsky"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr ""
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3170,116 +3170,116 @@
 msgid "invalid operand for code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "kutsu  %2d ei suoritettu koskaan\n"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr ""
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 #, fuzzy
 msgid "bad address, not an I/O address:"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "virheellinen merkkijonovakio"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 #, fuzzy
 msgid "bad address, not (reg+disp):"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr ""
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, fuzzy, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 #, fuzzy
 msgid "internal compiler error.  Unknown mode:"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "virheellinen käsky:"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 #, fuzzy
 msgid "incorrect insn:"
 msgstr "tämä on käsky:"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "tuntematon move-käsky:"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "virheellinen shift-käsky:"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 #, fuzzy
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "kääntäjän sisäinen virhe.  Virheellinen osoite:"
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 msgid "unsupported fixed-point conversion"
 msgstr "kiintopistevakiot ovat GCC-laajennos"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 #, fuzzy
 #| msgid "Loop variable"
 msgid "variable"
 msgstr "Silmukkamuuttuja"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "parametri %q+D määritelty uudelleen"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 #| msgid "struct defined here"
 msgid "structure field"
 msgstr "struct määritelty täällä"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 #| msgid "creating array of functions"
 msgid "return type of function"
 msgstr "luodaan funktioiden taulukko"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 #, fuzzy
 #| msgid "null pointer"
 msgid "pointer"
@@ -3303,7 +3303,7 @@
 msgstr "virheellinen const_double-operandi"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3543,87 +3543,87 @@
 msgid "bad output_condmove_single operand"
 msgstr ""
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "virheellinen const_double-operandi"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "fr30_print_operand: virheellinen %%F-koodi"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "fr30_print_operand: virheellinen %%x-koodi"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "tuntematon move-käsky:"
@@ -3664,7 +3664,7 @@
 msgid "invalid %%P operand"
 msgstr "virheellinen %%P-operandi"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "virheellinen %%p-arvo"
@@ -3723,7 +3723,7 @@
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "virheellinen osoite"
 
@@ -3758,7 +3758,7 @@
 msgstr "virheellinen käsky:"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr ""
 
@@ -3852,292 +3852,292 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 #, fuzzy
 msgid "-mvsx requires hardware floating point"
 msgstr "Älä käytä laitteistoliukulukuja"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 #, fuzzy
 msgid "-mno-altivec disables vsx"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 #, fuzzy
 #| msgid "--resource requires -o"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 #, fuzzy
 msgid "bad move"
 msgstr "Siirrä alas"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 #, fuzzy
 msgid "Bad 128-bit move"
 msgstr "Käytä 128-bittistä long double -tyyppiä"
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 #| msgid "invalid %%H value"
 msgid "invalid %%e value"
 msgstr "virheellinen %%E-arvo"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "virheellinen %%f-arvo"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "virheellinen %%F-arvo"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "virheellinen %%G-arvo"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "virheellinen %%j-koodi"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "virheellinen %%J-koodi"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "virheellinen %%k-arvo"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "virheellinen %%K-arvo"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "virheellinen %%O-arvo"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "virheellinen %%q-arvo"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "virheellinen %%T-arvo"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "virheellinen %%u-arvo"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "virheellinen %%v-arvo"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "virheellinen %%x-arvo"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 msgid "Could not generate addis value for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 msgid "Unable to generate load/store offset for fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 #, fuzzy
 msgid "Bad GPR fusion"
 msgstr "Virheelliset merkit"
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, fuzzy, c-format
 msgid "cannot decompose address"
 msgstr "Pyydettyä osoitetta ei voi asettaa"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "AltiVec-argumentti välitetty funktiolle, jolla ei ole prototyyppiä"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 msgid "types differ in signedness"
 msgstr "Tiedostot %s ja %s eroavat\n"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 #, fuzzy
 #| msgid "target format does not support infinity"
 msgid "binary operator does not support vector bool operand"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4163,43 +4163,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "virheellinen %%Y-operandi"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "virheellinen %%A-operandi"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "virheellinen %%B-operandi"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, c-format
 msgid "invalid %%C operand"
 msgstr "virheellinen %%C-operandi"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, c-format
 msgid "invalid %%D operand"
 msgstr "virheellinen %%D-operandi"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "virheellinen %%f-operandi"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "virheellinen %%s-operandi"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4367,32 +4367,32 @@
 msgid "bad test"
 msgstr "test ja/tai ["
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "virheellinen %%D-arvo"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 #, fuzzy
 msgid "invalid mask"
 msgstr "PEITE"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "virheellinen %%d-arvo"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "virheellinen %%t/%%b-arvo"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 #, fuzzy
 msgid "no register in address"
 msgstr "Rekisteröi"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 #, fuzzy
 msgid "address offset not a constant"
 msgstr "siirros vakiomerkkijonon rajojen ulkopuolelle"
@@ -4414,8 +4414,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "”)” oli odotus"
@@ -4437,14 +4437,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "”)” oli odotus"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "”)” oli odotus"
@@ -4475,7 +4475,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "”)” oli odotus"
@@ -4483,7 +4483,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "”)” oli odotus"
@@ -4494,7 +4494,7 @@
 msgstr "odotettiin %<,%>, %<;%> tai %<}%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "”)” oli odotus"
@@ -4501,7 +4501,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "”)” oli odotus"
@@ -4511,7 +4511,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "”)” oli odotus"
@@ -4524,24 +4524,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr ""
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4550,18 +4550,18 @@
 msgid "expected %<.%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -4569,17 +4569,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "”)” oli odotus"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "”)” oli odotus"
@@ -4588,7 +4588,7 @@
 msgid "(anonymous)"
 msgstr "(nimetön)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "”)” oli odotus"
@@ -4598,11 +4598,11 @@
 msgid "expected label"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "ehdokas 1:"
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "ehdokas 2:"
 
@@ -4837,11 +4837,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "ehdokkaat ovat:"
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "ehdokas on:"
@@ -5037,85 +5037,85 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 #, fuzzy
 msgid "Positive width required"
 msgstr "Positiivinen leveys vaadittu muotomäärittelijässä %s kohdassa %L"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 #, fuzzy
 msgid "Nonnegative width required"
 msgstr "bittikentän %qs leveys negatiivinen"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 msgid "Unexpected element %qc in format string at %L"
 msgstr "päättämätön muotoilumerkkijono"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 #, fuzzy
 msgid "Unexpected end of format string"
 msgstr "Odottamaton END-lause kohdassa %C"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 #, fuzzy
 msgid "Zero width in format descriptor"
 msgstr "%s-muotoilun leveys on nolla"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 #, fuzzy
 msgid "Missing leading left parenthesis"
 msgstr "Puuttuva oikea sulje kohdassa %C"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 msgid "Left parenthesis required after %<*%>"
 msgstr "sijoituksen vasemman operandin on oltava lvalue"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 #, fuzzy
 msgid "Expected P edit descriptor"
 msgstr "Odotettiin geneeristä nimeä tai operaattorimäärittelijää kohdassa %C"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr ""
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-#| msgid "Missing right parenthesis at %C"
-msgid "Right parenthesis expected at %C"
-msgstr "Puuttuva oikea sulje kohdassa %C"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 #, fuzzy
 msgid "Positive width required with T descriptor"
 msgstr "Positiivinen leveys vaadittu muotomäärittelijässä %s kohdassa %L"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr ""
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr ""
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+#| msgid "Missing right parenthesis at %C"
+msgid "Right parenthesis expected at %C"
+msgstr "Puuttuva oikea sulje kohdassa %C"
+
+#: fortran/io.c:1040
 #, fuzzy
 msgid "Period required in format specifier"
 msgstr "Piste vaadittu muotomääritteessä kohdassa %L"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, fuzzy, c-format
 msgid "%s tag"
 msgstr "<tunnistevirhe>"
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 #, fuzzy
 msgid "internal unit in WRITE"
 msgstr "<sisäinen>"
@@ -5122,7 +5122,7 @@
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, fuzzy, c-format
 msgid "%s tag with INQUIRE"
 msgstr "<tunnistevirhe>"
@@ -5132,88 +5132,88 @@
 msgid "Syntax error in expression at %C"
 msgstr "Syntaksivirhe IF-lausekkeessa kohdassa %C"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 #, fuzzy
 msgid "Unexpected EOF"
 msgstr "Odottamaton tiedoston loppu arkistossa"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "Kokonaisluvun ylivuoto"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "Liian pitkä nimi"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "Virheellinen nimi"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "Odotettu nimi"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 #, fuzzy
 msgid "Expected left parenthesis"
 msgstr "Odotettiin oikeaa sulkumerkkiä lausekkeessa kohdassa %C"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 #, fuzzy
 msgid "Expected right parenthesis"
 msgstr "Odotettiin oikeaa sulkumerkkiä lausekkeessa kohdassa %C"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 #, fuzzy
 msgid "Expected integer"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 #, fuzzy
 msgid "Expected string"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 #, fuzzy
 msgid "find_enum(): Enum not found"
 msgstr "%<enum %E%>:n uudelleenmäärittely"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 #, fuzzy
 msgid "Expected attribute bit name"
 msgstr "odotettiin %<=%>, %<,%>, %<;%>, %<asm%> tai %<__attribute__%>"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 #, fuzzy
 msgid "Expected integer string"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 #, fuzzy
 msgid "Error converting integer"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 #, fuzzy
 msgid "Expected real string"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 #, fuzzy
 msgid "Expected expression type"
 msgstr "odotettiin lauseketta"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 #, fuzzy
 msgid "Bad operator"
 msgstr "  eikä %<operator=(const %T&)%>"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 #, fuzzy
 msgid "Bad type in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "Odottamaton END-lause kohdassa %C"
@@ -5506,12 +5506,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "virheellinen taulukkosijoitus"
@@ -5887,7 +5887,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "ei voi käyttää sekä valitsinta -m32 että -m64"
 
@@ -9221,7 +9221,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr ""
@@ -9460,7 +9460,7 @@
 msgid "target the software simulator."
 msgstr "# Ei kohde:"
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 #, fuzzy
 msgid "Use LRA instead of reload."
 msgstr "käytä sen sijaan __attribute__ ((vector_size))"
@@ -9735,12 +9735,12 @@
 msgid "Use 80-bit long double."
 msgstr "Käytä 80-bittistä long double -tyyppiä."
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 msgid "Use 64-bit long double."
 msgstr "Käytä 64-bittistä long double -tyyppiä."
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 msgid "Use 128-bit long double."
 msgstr "Käytä 128-bittistä long double -tyyppiä."
@@ -10929,100 +10929,100 @@
 msgid "64 bit ABI."
 msgstr "64-bittinen ABI."
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 #, fuzzy
 msgid "Maintain backchain pointer."
 msgstr "lähde ei ole osoitin"
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 #, fuzzy
 msgid "Additional debug prints."
 msgstr "aseta vianjäljityksen taso"
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 #, fuzzy
 #| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
 msgstr "ESA/390-arkkitehtuuri"
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 msgid "Enable decimal floating point hardware support."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 msgid "Enable hardware floating point."
 msgstr "Käytä laitteistoliukulukuja."
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 msgid "Use hardware transactional execution instructions."
 msgstr "Estä kaikkien laitteistoliukulukukäskyjen käyttö"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 #, fuzzy
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr ""
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr ""
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 #| msgid "Do not use hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "Älä käytä laitteistoliukulukuja"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr ""
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr ""
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 #| msgid "Use the bit-field instructions"
 msgid "Use the mvcle instruction for block moves."
 msgstr "Käytä bittikenttäkäskyjä"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr ""
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr ""
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 #, fuzzy
 #| msgid "ESA/390 architecture"
 msgid "z/Architecture."
 msgstr "ESA/390-arkkitehtuuri"
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -11079,11 +11079,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -11337,95 +11337,111 @@
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 #, fuzzy
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr ""
+
+#: config/sparc/sparc.opt:102
 #, fuzzy
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 #, fuzzy
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 #| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "Osoittimet ovat 64-bittisiä"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 #| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "Osoittimet ovat 32-bittisiä"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "Käytä 64-bittistä ABIa"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "Käytä 32-bittistä ABIa"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 #, fuzzy
 msgid "Use stack bias."
 msgstr "pinon ylivuoto"
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr ""
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr ""
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 #, fuzzy
 #| msgid "Generate code for the Android platform."
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr "Tuota koodia Android-alustalle."
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr ""
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 #, fuzzy
 msgid "Use given SPARC-V9 code model."
 msgstr "epäkelpo lvalue sijoituksessa"
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "Enable debug output."
 msgstr "Ota käyttöön vianjäljitystuloste"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr ""
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -16538,7 +16554,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -16999,7 +17015,7 @@
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "odotettiin kokonaislukulauseketta"
@@ -17326,137 +17342,137 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 msgid "invalid comparison of non-ordered type"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 msgid "invalid operation (%s)"
 msgstr "Virheellinen tiedostotoiminto: %s"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 msgid "invalid comparison of non-comparable type"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 msgid "invalid comparison of generated struct"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 msgid "invalid comparison of generated array"
 msgstr "virheelliset määreet ei-jäsenfunktion tyypissä"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 msgid "invalid comparison of non-comparable array"
 msgstr ""
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 #, fuzzy
 msgid "need explicit conversion"
 msgstr "    Ei ilmaistuja jäseniä\n"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, fuzzy, c-format
 msgid "cannot use type %s as type %s"
 msgstr "määrittelemättömän tyypin %<%s %E%> epäkelpo käyttö"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 #, fuzzy
 msgid "different receiver types"
 msgstr "eri"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 #, fuzzy
 msgid "different number of parameters"
 msgstr "useita parametreja nimellä %qD"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 #, fuzzy
 msgid "different parameter types"
 msgstr "eri"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 #, fuzzy
 msgid "different varargs"
 msgstr "eri"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 #, fuzzy
 msgid "different number of results"
 msgstr "eri"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 #, fuzzy
 msgid "different result types"
 msgstr "eri"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "C99:n universaalit merkkinimet ovat epäyhteensopivia C90:n kanssa"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 #, fuzzy
 msgid "type has no methods"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, fuzzy, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "%s: valitsin on moniselitteinen; vaihtoehdot:"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "%s: puuttuva argumentti parametrille %s\n"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -17632,7 +17648,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "liian vähän argumentteja funktiolle %<va_start%>"
@@ -17694,27 +17710,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
@@ -17721,7 +17737,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
@@ -17728,12 +17744,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "epäkelpo argumentti funktiolle %<__builtin_frame_address%>"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%>-fuktion toisen argumentin pitää olla 1"
@@ -17740,63 +17756,63 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, fuzzy, gcc-internal-format
 #| msgid "target format does not support infinity"
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "funktiota %<va_start%> käytetty funktiossa, jolla on kiinteä määrä argumentteja"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "väärä määrä argumentteja funktiolle %<va_start%>"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "funktiota %<__builtin_next_arg%> kutsuttu ilman argumenttia"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>-funktion toinen parametri ei ole viimeinen nimetty argumentti"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "argumentin %d antamisessa funktiolle %qE tehdään osoitin kokonaisluvusta ilman tyyppimuunnosta"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -18707,12 +18723,12 @@
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "nimike %q+D määritelty mutta käytettämättä"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, fuzzy, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "sisäkkäinen funktio %q+D esitelty mutta ei koskaan määritelty"
@@ -18807,12 +18823,12 @@
 msgid "cannot find '%s'"
 msgstr "lähdetiedostoa %s ei löydy"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "cap_init epäonnistui"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s: %m"
@@ -18822,7 +18838,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "COLLECT_GCC-ympäristömuuttujan on oltava asetettuna"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, fuzzy, gcc-internal-format
 msgid "atexit failed"
@@ -19035,7 +19051,7 @@
 msgid "error writing %qs"
 msgstr "virhe kirjoitettaessa i-solmua"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "tiedostoa %s ei voi avata"
@@ -19115,17 +19131,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, fuzzy, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr "ei huomioida tuntematonta esikäsittelintä \"%c\""
@@ -19235,12 +19251,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%Kkutsu kohteeseen %qs esitelty attribuuttivirheellä: %s"
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%Kkutsu kohteeseen %qs esitelty attribuuttivaroituksella: %s"
@@ -19255,12 +19271,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr ""
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
@@ -19275,7 +19291,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "vertailu on aina %d johtuen bittikentän leveydestä"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -19305,7 +19321,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -19315,7 +19331,7 @@
 msgid "total size of local objects too large"
 msgstr "paikallisten objektien kokonaiskoko on liian suuri"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, fuzzy, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "virheellinen ”asm”: "
@@ -19415,62 +19431,68 @@
 msgid "input file %qs is the same as output file"
 msgstr "syötetiedosto %qs on sama kuin tulostiedosto"
 
-#: gcc.c:4498
+#: gcc.c:4476
+#, fuzzy, gcc-internal-format
+#| msgid "output file not specified"
+msgid "output filename may not be empty"
+msgstr "tulostiedostoa ei ole annettu"
+
+#: gcc.c:4501
 #, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr ""
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr ""
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, fuzzy, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "valitsin %qs ei ole enää tuettu"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "Tiedoston ”%s” avaaminen epäonnistui."
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "Väliaikaista varmuuskopiotiedostoa ei voitu luoda tallennettaessa tiedostoa \"%s\""
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "Väliaikaista varmuuskopiotiedostoa ei voitu luoda tallennettaessa tiedostoa \"%s\""
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, fuzzy, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "virheellinen --param-arvo %qs"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
@@ -19478,109 +19500,109 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr ""
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, fuzzy, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "tunnistamaton muotomäärite"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "liian monta argumenttia funktiolle %qs"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, fuzzy, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "Väärän muotoinen tai virheellinen nimi"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, fuzzy, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "liikaa argumentteja funktiolle"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, fuzzy, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "liian vähän argumentteja funktiolle %qE"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, fuzzy, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "bittikentällä %qs on epäkelpo tyyppi"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr ""
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr ""
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "Tiedoston \"%s\" avaaminen käyttäen merkistökoodausta \"%s\" ei onnistunut."
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "muunnos %s -> %s epäonnistui"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized command line option %<-fdump-%s%>"
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "tunnistamaton komentorivivalitsin %<-fdump-%s%>"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "tunnistamaton komentorivivalitsin %<-fdump-%s%>"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "ei konfiguroitu sysroot-otsakkeiden loppuliitteellä"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "ei syötetiedostoja"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr ""
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr ""
@@ -19587,122 +19609,122 @@
 "\n"
 "%s: ***** TIEDOSTOJÄRJESTELMÄÄ MUUTETTIIN *****\n"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, fuzzy, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "aseta vianjäljityksen tulostetiedoston nimi"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, fuzzy, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "kirjastoa lib%s ei löytynyt"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "Kieli:"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "virheellinen tiedostonumero sarakemäärityksessä: %s"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "%<long long%> virheellinen %qs:lle"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, fuzzy, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "DJGPP-ympäristömuuttujaa ei ole määritelty"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, fuzzy, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "Virheellinen hajanaisversion arvo"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "liian vähän argumentteja kohteelle %%:version-compare"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "liian monta argumenttia kohteelle %%:version-compare"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, fuzzy, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "liian vähän argumentteja kohteelle %%:version-compare"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "liian monta argumenttia kohteelle %%:compare-debug-dump-opt"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "liian monta argumenttia kohteelle %%:compare-debug-self-opt"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "liian vähän argumentteja kohteelle %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "liian monta argumenttia kohteelle %%:compare-debug-auxbase-opt"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "liian vähän argumentteja kohteelle %%:version-compare"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
@@ -19849,9 +19871,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "esitelty täällä"
@@ -20272,217 +20294,217 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, fuzzy, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "%<return%> arvon kanssa voidin palauttavassa funktiossa"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr ""
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "# Ei kohde:"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 #| msgid "close: %s"
 msgid "enclosing %qs"
 msgstr "          %s"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE esittelemättä (ensimmäinen käyttökerta tässä funktiossa)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, fuzzy, gcc-internal-format
 #| msgid "local variable %qD may not appear in this context"
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "paikallinen muuttuja %qD ei voi esiintyä tässä yhteydessä"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "odotettiin %<operator%>"
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "%qD ei ole malli"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, fuzzy, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "argumenttien määrä ei vastaa prototyyppiä"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, fuzzy, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
@@ -20489,17 +20511,17 @@
 " EPÄONNISTUI\n"
 "\n"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "%qT muunnetaan tyypiksi %qT, kun se viedään %<...%>:n läpi"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(eli kannattaisi antaa %qT eikä %qT funktiolle %<va_arg%>)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "jos tämä koodi saavutetaan, ohjelma keskeytyy"
@@ -20739,7 +20761,7 @@
 #: ipa-devirt.c:1229
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition here"
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "edellinen määrittely täällä"
 
 #: ipa-devirt.c:1235
@@ -20840,7 +20862,7 @@
 
 #: ipa-devirt.c:1576
 #, fuzzy, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
 #: ipa-devirt.c:1599
@@ -21231,193 +21253,193 @@
 msgid "multiple loop axes specified for routine"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, fuzzy, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr "väärin aseteltu [:upper:]- ja/tai [:lower:]-rakenne"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr ""
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments"
 msgstr "%<...%> argumentteina.)"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid exit from %s structured block"
 msgstr "%qs-attribuutin virheellinen argumentti"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid argument of %qs attribute"
 msgid "invalid entry to %s structured block"
@@ -21424,7 +21446,7 @@
 msgstr "%qs-attribuutin virheellinen argumentti"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
@@ -21511,7 +21533,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "komentorivivalitsin %qs on kelvollinen kohteelle %s, mutta ei kohteelle %s"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "polku puuttuu %qs:n jälkeen"
@@ -21668,130 +21690,140 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
+#, fuzzy, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
+
+#: opts.c:1015
+#, fuzzy, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
+
+#: opts.c:1417
 #, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, fuzzy, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr "Kelvolliset argumentit --quoting-style-valitsimelle ovat:"
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "tuntematon komentorivivalitsin ”%s”"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "tuntematon komentorivivalitsin ”%s”"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.c:1837
+#: opts.c:1844
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "tuntematon komentorivivalitsin ”%s”"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "tuntematon konetila %qs"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "dwarfin versio %d ei ole tuettu"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s: --param-argumenttien tulee olla muotoa NIMI=ARVO"
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "virheellinen --param-arvo %qs"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs"
 msgstr "virheellinen --param-arvo %qs"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "virheellinen --param-arvo %qs"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr ""
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 #| msgid "unrecognized register name %qs"
 msgid "unrecognized debug output level %qs"
 msgstr "tunnistamaton rekisterinimi %qs"
 
-#: opts.c:2533
+#: opts.c:2540
 #, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr ""
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "tunnistamaton gcc:n vianjäljitysvalitsin: %c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "%s: valitsin ”%s” on moniselitteinen\n"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -22132,7 +22164,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "sisäkkäisessä funktiossa käytetty globaalia rekisterimuuttujaa %qD"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "nimellä %qD"
@@ -22738,12 +22770,12 @@
 msgid "error closing %s: %m"
 msgstr "virhe suljettaessa laitetta %s"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr "Muodostin %qs"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -23656,47 +23688,47 @@
 msgid "in expansion of macro %qs"
 msgstr " (ei ~-laajennusta)"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr ""
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -23798,32 +23830,32 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "Virheellinen vähimmäisargumenttimäärä (%d) funktiolle %s"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "muuttuja %qD esitelty %<inline%>:ksi"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr "operaatio %qE:lle voi olla määrittelemätön"
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "within this loop"
@@ -24178,11 +24210,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -25159,7 +25191,7 @@
 msgid "type was previously declared %qE"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
@@ -25439,7 +25471,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD:n osoite tulee aina olemaan %<true%>"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "ehdotetaan sulkeita totuusarvona käytetyn sijoituksen ympärille"
@@ -26070,62 +26102,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "ylimääräisiä tyyppimääreitä muotoiluargumentissa (argumentti %d)"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "muotoilu %q.*s odottaa tyyppiä %<%s%s%>, mutta %d. argumentin tyyppi on %qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "muotoilu %q.*s odottaa %<%T%s%>-tyyppiä, mutta %d. argumentin tyyppi on %qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, fuzzy, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, fuzzy, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<%T::%E%> ei ole tyyppi"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "lueteltu tyyppi määritelty täällä"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "ei voi muuntaa osoitintyypiksi"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "muotoiltavat argumentit eivät ole %<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
@@ -26226,7 +26258,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr ""
@@ -26256,7 +26288,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
@@ -26272,22 +26304,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE:a ei ole alustettu"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "’(’ puuttuu predikaatin jäljestä"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "Muotoillun tulosteen hallinta:"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "puuttuva kasvatuslauseke"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "virheellinen kasvatuslauseke"
@@ -26837,8 +26869,8 @@
 msgid "wrong type argument to %s"
 msgstr "abs-funktiolle annettu väärä tyyppiargumentti"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
@@ -27517,7 +27549,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<_Cilk_spawn%> may only be used inside a function"
@@ -27678,7 +27710,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "%s: tuntematon valitsin ”%s”\n"
@@ -28004,7 +28036,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "%<__builtin_expect%>-funktion toisen argumentin pitää olla vakio"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
@@ -28088,7 +28120,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "tuntematon cc_attr-arvo"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "valitsin -mcpu=%s on ristiriidassa valitsimen -march=%s kanssa"
@@ -28175,9 +28207,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "Kohdehakemisto ”%s” ei ole kelvollinen hakemisto"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE-attribuutti tarvitsee merkkijonovakioargumentin"
@@ -28264,7 +28296,7 @@
 msgstr ""
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, fuzzy, gcc-internal-format
 msgid "bad builtin fcode"
@@ -28446,234 +28478,234 @@
 msgid "insn addresses not freed"
 msgstr "tämä on käsky:"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "Ei ole tuettu"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, fuzzy, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "mountin käyttöön vaaditaan pääkäyttäjän oikeudet"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, fuzzy, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "PEITE"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, fuzzy, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr ""
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "kohdemuoto ei tue äärettömyyttä"
@@ -28680,142 +28712,142 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-mpcrel -fPIC is not currently supported on selected cpu"
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mpcrel -fPIC ei ole nykyisin tuettu valitulle prosessorille"
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check on yhteensopimaton valitsimen -mno-apcs-frame kanssa"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic ja -mapcs-reent ovat yhteensopimattomat"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "valitsimet -l ja -s eivät ole yhteensopivia"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS ei tue valitsinta -mcaller-super-interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS ei tue valitsinta -mcallee-super-interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr ""
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr ""
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr ""
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, fuzzy, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "kohdemuoto ei tue äärettömyyttä"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -28823,77 +28855,82 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE-attribuutti pätee vain funktioihin, ei %s"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE-attribuutti pätee vain funktioihin, ei %s"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD:lla ei saa olla vaihtuvaa määrää argumentteja"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE-attribuutti pätee vain funktioihin, ei %s"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid vector type for attribute %qs"
 msgid "invalid fpu for attribute(target(\"%s\"))"
@@ -28902,13 +28939,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "kohde ”%s” ei täsmää kohdehahmon kanssa"
@@ -29003,166 +29040,178 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "funktion paluuarvon tyyppi ei voi olla funktio"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, fuzzy, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE-attribuutti soveltuu vain muuttujiin ja funktioihin"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%Jlohkoattribuutteja ei tueta tälle kohteelle"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, fuzzy, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "ehtolausekkeessa on osoitintyyppiristiriita"
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr "%J%qD:n esittely varjostaa parametria"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+D was here"
 msgid "IO definition for %q+D needs an address"
 msgstr "%q+D:n edellinen määrittely oli täällä"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr ""
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
+#, fuzzy, gcc-internal-format
+#| msgid "variable %qD has initializer but incomplete type"
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "muuttujalla %qD on alustin, mutta vaillinainen tyyppi"
+
+#: config/avr/avr.c:10160
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr ""
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "muunnos tyypistä %qT tyyppiin %qT"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "case-nimike ei pelkisty kokonaislukuvakioksi"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, fuzzy, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "vertailu ”etumerkitön lauseke >= 0” on aina tosi"
@@ -29446,12 +29495,12 @@
 msgid "invalid IACC argument"
 msgstr "virheellinen IACC-argumentti"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs odottaa vakioargumenttia"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, fuzzy, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "%qs odottaa vakioargumenttia"
@@ -29633,7 +29682,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "koodimalli %s ei tue PIC-tilaa"
@@ -29763,289 +29812,289 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, fuzzy, gcc-internal-format
 #| msgid "inter-module optimizations not implemented for C++"
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "tuntematon valitsin -%s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "Tämä pikanäppäin on jo käytössä toiminnolle %s"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "epäkelpo osoitintila %qs"
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, fuzzy, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE-attribuutti tarvitsee kokonaislukuvakioargumentin"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%Jei voi asettaa %qE-attribuuttia määrittelyn jälkeen"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, fuzzy, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "attribuutit stdcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "attribuutit stdcall ja fastcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, fuzzy, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja stdcall eivät ole yhteensopivia"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, fuzzy, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "attribuutit fastcall ja cdecl eivät ole yhteensopivia"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C does not support saturating types"
 msgid "X32 does not support ms_abi attribute"
 msgstr "ISO C ei tue saturoituvia tyyppejä"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "ISO C kieltää sisäkkäiset funktiot"
@@ -30052,202 +30101,202 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr ""
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "%s: %s: täsmäävyyttä ei löydy"
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "Varoita ylikuormitetuista virtuaalifunktioiden nimistä"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "edellinen esittely %q+D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr "SISÄÄNRAKENNETTU CD %s\n"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "virheellinen salasana"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr ""
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "argumentin <%s>:lle on oltava yksittäinen merkki"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr ""
@@ -30254,97 +30303,97 @@
 "Vihje: %s\n"
 "\n"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "puhdistusargumentti ei ole tunniste"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE-attribuutti pätee vain funktioihin"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE-attribuuttia ei huomioida"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, fuzzy, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr "taulukon indeksin tyyppi on %<char%>"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "Funktio %qs"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "virheellinen lvalue asm-tulosteessa %d"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, fuzzy, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "Tuntematon arkkitehtuuri ”%s”"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "tuntematon värimoodi"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -30466,7 +30515,7 @@
 msgid "argument %qd is not a constant"
 msgstr "argumentti %qd ei ole vakio"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS, null-osoitin"
@@ -30476,7 +30525,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND nollaosoitin"
@@ -30577,7 +30626,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr ""
@@ -31083,8 +31132,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, fuzzy, gcc-internal-format
 msgid "bad builtin code"
 msgstr "<sisäänrakennettu>"
@@ -31343,27 +31392,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "%Jlohkoattribuutti ei ole sallittu %qD:lle"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -31388,7 +31437,7 @@
 msgid "-g option disabled"
 msgstr "[ei käytössä]"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
@@ -31523,157 +31572,157 @@
 msgid "junk at end of #pragma longcall"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, fuzzy, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, fuzzy, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, fuzzy, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, fuzzy, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%q+D sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "sijoitus hylkää kohdeosoitintyypin määreitä"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "virheellinen parametri %qs"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 vaatii PowerPC64-suorittimen, otetaan käyttöön"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, fuzzy, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr "31-bittinen ABI"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr "Käytä PowerPC-64 -käskykantaa"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "-mvsx ja -mno-altivec ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, fuzzy, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "Ei ole tuettu"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "valitsin -mmultiple ei ole tuettu little-endian-järjestelmissä"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "valitsin -mstring ei ole tuettu little-endian-järjestelmissä"
@@ -31680,73 +31729,73 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, fuzzy, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr "--stat vaatii tiedostonimiä"
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mdirect-move requires -mvsx"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, fuzzy, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr "valitsin vaatii argumentin -- %s"
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-vector requires -mvsx"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode requires -mvsx"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, fuzzy, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
@@ -31755,527 +31804,532 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "operaattori ”defined” vaatii tunnisteen"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr "operaattori ”defined” vaatii tunnisteen"
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr "operaattori ”defined” vaatii tunnisteen"
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mvsx-timode might need -mlra"
 msgstr "-mvsx ja -mpaired ovat yhteensopimattomat"
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr "valitsin --resource vaatii valitsimen -o"
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "”%s” ei ole kelvollinen esikääntäjän valitsin"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "sisäistä funktiota %qs ei voi ottaa pois käytöstä"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 #| msgid "argument 1 must be a 5-bit signed literal"
 msgid "argument 1 must be an 8-bit field value"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "argumentin 1 on oltava 5-bittinen etumerkillinen literaali"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument %d must be an unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr "%J%qD sallii vain nolla tai kaksi argumenttia"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "kokonaislukuargumentti %s ei kelpaa"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, fuzzy, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "argumentin 2 on oltava 5-bittinen etumerkitön literaali"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "%<__builtin_prefetch%>-funktion kolmannen argumentin pitää olla vakio"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "sisäinen funktio %q+D esitelty ei-funktiona"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "#pragma redefine_extname ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 ei tue joustavia taulukon jäseniä"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma extern_prefix ei ole tuettu tällä kohteella"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, fuzzy, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "tyhjä %s ei ole sallittu"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "virheellinen argumentti %s %s:lle"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, fuzzy, gcc-internal-format
 #| msgid "--resource requires -o"
 msgid "-mno-power9-vector turns off -mpower9-dform"
@@ -32464,6 +32518,7 @@
 msgstr "-mapcs-stack-check on yhteensopimaton valitsimen -mno-apcs-frame kanssa"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 vaatii PowerPC64-suorittimen"
@@ -32555,7 +32610,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, fuzzy, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "virheellinen %%H-arvo"
@@ -32584,7 +32639,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -32604,7 +32659,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -32618,160 +32673,160 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr ""
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "%<__builtin_args_info%>-funktion argumentti on rajojen ulkopuolella"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr "<sisäänrakennettu>"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "<sisäänrakennettu>"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "%<__builtin_prefetch%>-funktion toinen argumentti on epäkelpo; käytetään nollaa"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "pinokehys ei ole 8:n tavun monikerta: %wd"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, fuzzy, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr "#pragma extern_prefix ei ole tuettu tällä kohteella"
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr ""
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bittinen ABI ei ole tuettu ESA/390-tilassa"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, fuzzy, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr ""
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "%q+D:n ensimmäisen argumentin pitäisi olla %<int%>"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "blocks-argumentti on liian suuri, maksimi on %llu"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
@@ -32828,27 +32883,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr ""
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "weakref ei ole tuettu tässä konfiguraatiossa"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr ""
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "virheellinen aikakatkaisuarvo: %s"
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
-msgstr ""
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mmultiple is not supported on little endian systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
+msgstr "valitsin -mmultiple ei ole tuettu little-endian-järjestelmissä"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "säiekohtaista muistia ei tueta tällä kohteella"
@@ -33134,22 +33190,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "virheelinen sijainti ilmaisulle %<#pragma %s%>, jätetään huomiotta"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr ""
@@ -33237,7 +33293,7 @@
 msgid "could not read the BRIG file"
 msgstr "Tiedoston ”%s” palauttaminen epäonnistui."
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -33646,9 +33702,9 @@
 msgstr "nimiö %qD määritelty täällä"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD esitelty täällä"
@@ -33783,7 +33839,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -34844,7 +34900,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "yli yksi tietotyyppi esittelymääritteissä"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%> on liian pitkä GCC:lle"
@@ -34988,17 +35044,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C ei tue pelkkää %<complex%>-tyyppiä merkityksellä %<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C ei tue kompleksikokonaislukutyyppejä"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -35051,7 +35107,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
@@ -35093,7 +35149,7 @@
 msgstr "%qE ei nimeä tyyppiä"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "useita tallennusluokkia esittelymääritteissä"
@@ -35108,7 +35164,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
@@ -35123,8 +35179,8 @@
 msgid "unexpected attribute"
 msgstr "Odottamattomat argumentit"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "pakattu attribuutti on tarpeeton %q+D:lle"
@@ -35164,7 +35220,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "tallennusluokan voi antaa vain objekteille ja funktioille"
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "odotettiin %<,%> tai %<;%>"
@@ -35192,7 +35248,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 ei tue syntaksia %<[*]%> taulukkoesittelijöissä"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "odotettiin merkkijonoliteraalia"
@@ -35257,14 +35313,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "odotettu tunniste"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "luetellun tyypin luettelon lopussa on pilkku"
@@ -35399,7 +35455,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "#else #else:n jälkeen"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%> ilman edeltävää %<if%>:iä"
@@ -35424,12 +35480,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -35443,17 +35499,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<if%>-lauseessa"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<else%>-lauseessa"
@@ -35463,7 +35519,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "ehdotetaan aaltosulkeita epäselvän %<else%>:n välttämiseksi"
@@ -35483,7 +35539,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -35665,17 +35721,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "?:-lausekkeen operandeilla on eri tyypit, %qT ja %qT"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -35730,62 +35786,62 @@
 msgid "no type or storage class may be specified here,"
 msgstr "tallennusluokka annettu %qs:lle"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "<tuntematon>"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%s:n perästä puuttuu operandi"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, fuzzy, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "kuori on annettava polkuineen"
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 #| msgid "%<this%> may not be used in this context"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "Odotettiin =-merkkiä PARAMETER-lauseessa kohdassa %C"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
@@ -35801,12 +35857,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "%s: liian monta arvoa"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 #| msgid "expected integer expression"
 msgid "expected integer expression before ')'"
@@ -35822,55 +35878,55 @@
 msgid "%qD is not a variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "%qD is not a pointer variable"
 msgstr "%qD ei ole muuttuja"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, fuzzy, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<none%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "odotettiin %<none%> tai %<shared%>"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "%s: Liian monta argumenttia\n"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -35900,24 +35956,24 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> value must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<scalar%>"
@@ -35929,61 +35985,61 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "%s: liian monta argumenttia\n"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "%qs attribuuttia ei huomioida"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE-attribuutti sallii vain kokonaislukuvakioargumentin"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%>, %<min%> or %<max%>"
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, fuzzy, gcc-internal-format
 #| msgid "both %<long%> and %<void%> in declaration specifiers"
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "sekä %<long%> että %<void%> esittelymääritteissä"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
@@ -36000,18 +36056,18 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr ""
@@ -36031,17 +36087,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "%qE määritelty vääränlaisena tunnisteena"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 #| msgid "invalid const_double operand"
 msgid "invalid dist_schedule kind"
@@ -36052,70 +36108,70 @@
 msgid "invalid proc_bind kind"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<namespace%>"
 msgid "expected %<#pragma acc%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "Funktio %qs"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "käytetty sekä %<__thread%> että %qs"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%Jluetellun tyypin jäsenen %qd uudelleenesittely"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, fuzzy, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr "muuttuja tai kenttä %qs esitelty tyhjäksi"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "%<extern%>-muuttujan %qD esittely %<for%>-silmukan alkuesittelyssä"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "rajat määrittelemättömän taulukon epäkelpo käyttö"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 #| msgid "expected a string after %<#pragma message%>"
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
@@ -36130,7 +36186,7 @@
 msgid "expected function name"
 msgstr "odotettiin luokan nimeä"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
@@ -36140,45 +36196,45 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "roskaa ilmaisun %<#pragma pack%> lopussa"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr ""
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -36188,27 +36244,27 @@
 msgid "expected %<(%> or end of line"
 msgstr "odotettiin %<(%> tai rivin loppu"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
@@ -36218,27 +36274,27 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%> vain parametrina ei ole oikeutettu"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<operator%>"
 msgid "expected %<for%> after %qs"
@@ -36245,47 +36301,47 @@
 msgstr "tiedostonimi puuttuu %qs:n jälkeen"
 
 # XXXXXXX
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -36300,7 +36356,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -36310,33 +36366,33 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "# Ei kohde:"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<decltype%>"
 msgid "expected %<declare%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -36394,22 +36450,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "%qs määrittää %<auto%>:n tiedostoalue-esittelyssä"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "parametrilla %u in vaillinainen tyyppi"
@@ -36425,55 +36481,55 @@
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 #| msgid "requested alignment is not a power of 2"
 msgid "vectorlength must be a power of 2"
 msgstr "kohdistuksen pitää olla kahden potenssi, ei %d"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 #| msgid "case label is not an integer constant expression"
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma%> is not allowed here"
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "%<#pragma%> ei ole sallittu täällä"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -36483,7 +36539,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr ""
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "odotettiin %<:%> tai %<...%>"
@@ -37220,7 +37276,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, fuzzy, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
@@ -37548,7 +37604,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "%<noreturn%>-esitellyllä funktiolla on %<return%>-lause"
@@ -37558,7 +37614,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -37584,7 +37640,7 @@
 msgid "function returns address of label"
 msgstr "funktio palauttaa osoitteen paikalliseen muuttujaan"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, fuzzy, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "yhteensopivuusvalitsin (jätetään huomiotta)"
@@ -37599,7 +37655,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, fuzzy, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -37619,17 +37675,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue-lause silmukan ulkopuolella"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, fuzzy, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
@@ -37640,7 +37696,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break-lause silmukan tai switch-rakenteen ulkopuolella"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 #| msgid "continue statement not within a loop"
 msgid "continue statement within %<#pragma simd%> loop body"
@@ -37747,12 +37803,12 @@
 msgid "used vector type where scalar is required"
 msgstr "käytetty unionityypin arvoa, vaikka vaaditaan skalaari"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -37763,27 +37819,27 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, fuzzy, gcc-internal-format
 #| msgid "bit-field %qs has invalid type"
 msgid "bit-field %qE in %qs clause"
 msgstr "bittikentän %qs leveys on nolla"
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member of %qD"
 msgid "%qE is a member of a union"
 msgstr "joustava taulukkojäsen unionissa"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qs määritelty parametrille %qE"
@@ -37795,72 +37851,72 @@
 msgstr "bittikentän %qs leveys on nolla"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr ""
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "zero length array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, fuzzy, gcc-internal-format
 #| msgid "variable length array is used"
 msgid "negative length in array section in %qs clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE:lla ei ole luokkatyyppiä"
@@ -37881,7 +37937,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "tyypillä %qE on käyttäjän määrittelemä muodostin"
@@ -37892,17 +37948,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "käytetään muuttuvapituista taulukkoa"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, fuzzy, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -37922,18 +37978,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -37945,32 +38001,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "automaattimuuttuja %qE ei voi olla %<threadprivate%>"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
@@ -37990,57 +38046,57 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "instanssimuuttuja %qE on esitelty yksityisenä"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not have class type"
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qE:lla ei ole luokkatyyppiä"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "halutaan rekisterimuuttujan %qD osoite"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "funktiolle %2$qE annettu argumentin %1$d tyyppi on yhteensopimaton"
@@ -38050,32 +38106,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qs määritelty parametrille %qE"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -38641,159 +38697,159 @@
 msgstr "%Hswitch-lauseesta puuttuu default-nimike"
 
 # Tämä esiintynee esim. const char* → char* -muunnoksessa.
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 #| msgid "conversion from %qT to %qT discards qualifiers"
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "muunnos tyypistä %qT tyyppiin %qT ei säilytä tyyppimääreitä"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr ""
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "%qT ei ole nimiavaruus"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 #| msgid "too many arguments to constructor %q#D"
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "liikaa argumentteja muodostimelle %q#D"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 #| msgid "constructors cannot be declared virtual"
 msgid "constructor delegates to itself"
 msgstr "Kopiomuodostin %qs"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, fuzzy, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr ""
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "päättämätön kutsu funktioon ”%s”: puuttuva ”%c”"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, fuzzy, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "%s: valitsin on moniselitteinen; vaihtoehdot:"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr ""
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a constructor"
 msgid "pure virtual %q#D called from constructor"
 msgstr "arvon palautus muodostimesta"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 #| msgid "returning a value from a destructor"
 msgid "pure virtual %q#D called from destructor"
 msgstr "arvon palautus hajottimesta"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, fuzzy, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, fuzzy, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr ""
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr " ehdokas 1: %q+#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr " ehdokas 2: %q+#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++:n mukaan nämä ovat moniselitteisiä siitä huolimatta, että ensimmäisen huonoin muunnos on parempi kuin toisen huonoin:"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "virheellinen %qT-tyyppisen ei-const-viittauksen alustus %qT-tyyppisestä väliaikaisesta muuttujasta"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "virheellinen %qT-tyyppisen viittauksen alustus %qT-tyyppisestä lausekkeesta"
@@ -38895,49 +38951,49 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr ""
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared here"
 msgid "%qD can be marked override"
 msgstr "%q+D esitelty täällä"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "funktion %q+D määrittely on merkitty dllimport-tyyppiseksi"
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%Jnimike %qD määritelty, mutta ei käytetty"
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "Näytä _piilotetut"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "        %qD"
 msgid "  by %qD"
@@ -38944,236 +39000,236 @@
 msgstr "nimellä %qD"
 
 # semi-fuzzy
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
 # semi-fuzzy
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "ei-staattista datajäsentä %q+D käytetty virheellisesti"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "private member %q#D in anonymous union"
 msgstr "jäsentä %q+D käytetty virheellisesti staattisessa jäsenfunktiossa"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, fuzzy, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "Varoita perittyjen metodien puuttuvista toteutuksista"
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "bittikenttä %+q#D ei ole kokonaislukutyyppinen"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "bittikentän %q+D leveys ei ole kokonaislukuvakio"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "bittikentän %q+D leveys negatiivinen"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "bittikentän %q+D leveys nolla"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "bittikentän %qs leveys ylittää tyyppinsä"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D on liian pieni sisältämään %q#T:n kaikkia arvoja"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D may not be static because it is a member of a union"
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D ei voi olla staattinen koska se on unionin jäsen"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "staattinen jäsenfunktio %q#D esitelty tyyppimääreillä"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "%Jparametri %qD esitelty tyhjällä tyypillä"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 #| msgid "member %qD cannot be declared both virtual and static"
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "jäsentä %qD ei voida esitellä sekä virtuaaliseksi että staattiseksi"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "%Jparametri %qD esitelty %<inline%>:ksi"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "useita kenttiä unionissa %qT alustettu"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "kentällä %q+#D on sama nimi kuin luokalla"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "  mutta ei ylikuormitusta %<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "  eikä %<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "  mutta ei ylikuormitusta %<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "%J%qD:n lohko on ristiriidassa edellisen esittelyn kanssa"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr ""
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "liikaa argumentteja metodille %qE"
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "%q+D-funktion paluuarvon tyyppi ei ole %<int%>"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "Java-luokalla %qT ei voi olla implisiittistä epätriviaalia hajotinta"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr ""
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 #| msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qE declared %<constexpr%>"
 msgid "non-static const member %q#D in class without a constructor"
@@ -39181,160 +39237,160 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "layout of classes derived from empty class %qT may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "tyhjästä luokasta %qT perittyjen luokkien rakenne saattaa muuttua GCC:n tulevissa versioissa"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "taulukon %qE koko on liian suuri"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "joustavan taulukkojäsenen sisältävän tietueen epäkelpo käyttö"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "joustava taulukkojäsen ei ole structin lopussa"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "joustava taulukkojäsen muuten tyhjässä structissa"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T uudelleenmääritelty"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "luokalla %q#T on virtuaalifunktioita ja käytettävissä oleva epävirtuaalinen hajotin"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr ""
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr ""
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "%qD ei ole %qD:n jäsen"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "liian vähän argumentteja"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
@@ -39344,12 +39400,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "esittelyssä %q+D"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -39379,341 +39435,341 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "epäkelpo tallennusluokka funktiolle %qs"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T ei ole luokka"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "alustamaton const %qD"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, fuzzy, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "internal function"
 msgid "call to internal function %qE"
 msgstr "lopetusalkio puuttuu funktiokutsusta"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "esittely ei esittele mitään"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "%qD:n esittely ei-funktiona"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "%qD käytössä ilman esittelyä ennen sen määrittelyä"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, fuzzy, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "protokollalla %qE on kehäriippuvuus"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, fuzzy, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 #| msgid "right shift count is negative"
 msgid "right operand of shift expression %q+E is negative"
 msgstr "oikealle siirron lukumäärä on negatiivinen"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 #| msgid "left-hand operand of comma expression has no effect"
 msgid "left operand of shift expression %q+E is negative"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr ""
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "accessing uninitialized array element"
 msgstr "taulukon tyypillä on vaillinainen alkiotyyppi"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 #| msgid "uninitialized const member %qD"
 msgid "accessing uninitialized member %qD"
 msgstr "jäsen %qD on alustamaton viittaus"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD käytössä ilman prototyyppiä ennen sen määrittelyä"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "luetellun tyypin jäsenen %qE arvo ei ole kokonaislukuvakio"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not a constant expression"
 msgid "statement is not a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, fuzzy, gcc-internal-format
 #| msgid "reinterpret_cast from type %qT to type %qT casts away qualifiers"
 msgid "reinterpret_cast from integer to pointer"
 msgstr "tyyppimuunnos osoittimesta erikokoiseen kokonaislukuun"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "ei-staattinen datajäsen %qE esitelty %<constexpr%>:ksi"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "tallennusluokka %<thread_local%> virheellinen funktiolle %qs"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "%qD:a käytetään alustamattomana tässä funktiossa"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "Jako nollalla kohdassa %L"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "ei-vakio alustuslauseke kohdassa %L"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Odottamaton %s-lause kohdassa %C"
@@ -40534,7 +40590,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "  ohittaa %q+#D:n alustuksen"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -40549,7 +40605,7 @@
 msgid "%qD is not a type"
 msgstr "%qD ei ole tyyppi"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr ""
@@ -42229,7 +42285,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "parametri esitelty %<auto%>:ksi"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
@@ -42689,13 +42745,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD:llä on sama nimi kuin luokalla, jossa se on esitelty"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT ei ole malli"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "%q+D:lla on edellinen esittely täällä"
@@ -42705,8 +42761,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "sijoitus kirjoitussuojattuun viitteeseen %qD"
@@ -42756,7 +42812,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "edellinen määrittely täällä"
@@ -42820,7 +42876,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "paluutyyppi %q#T on vaillinainen"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, fuzzy, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
@@ -42835,7 +42891,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "funktion paluuarvojen tyypit eivät ole yhteensopivia %<volatile%>:n takia"
@@ -42995,27 +43051,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "bittikentän %qs leveys ei ole kokonaislukuvakio"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%>:n on palautettava tyyppi %qT"
@@ -43024,67 +43080,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%>:n ensimmäisen parametrin tyypin on oltava %<size_t%> (%qT)"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%>:n on palautettava tyyppi %qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>:n ensimmäisen parametrin tyypin on oltava %qT"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
@@ -43093,47 +43149,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%J%qF käytetty, mutta ei määritelty"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%J%qD esitelty uudelleen ilman linkitystä"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr "sisäkkäinen funktio %qs esitelty %<extern%>:ksi"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
@@ -43140,12 +43196,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "poistettu funktio %q+D"
@@ -43455,18 +43511,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "alustamaton const-jäsen %qD"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D alustetaan jäljempänä kuin"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "jäsen %qD on alustamaton viittaus"
@@ -43568,7 +43624,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT ei ole luokkatyyppi"
@@ -43588,7 +43644,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
@@ -43785,22 +43841,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr "yhdysliteraalin koko on muuttuva"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "versioviitetaulukolle ei voi varata muistia"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "%2$qD:n parametrilla %1$P on vaillinainen tyyppi %3$qT"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "Lambda-funktio"
@@ -43855,112 +43911,112 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, fuzzy, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "typedef %qD on alustettu (käytä __typeof__ sen sijaan)"
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, fuzzy, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "Tyyppi"
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "kolmoismerkki ??%c muunnettu merkiksi %c"
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr ""
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, fuzzy, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "alustamaton const %qD"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, fuzzy, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "virheellinen alustin taulukon jäsenelle %q#D"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "hajotin ei voi olla staattinen jäsenfunktio"
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 #| msgid "non-static data member %qD has Java class type"
 msgid "copying non-static data member %q#D of rvalue reference type"
@@ -43967,76 +44023,76 @@
 msgstr "ei-staattisella datajäsenellä %qD on Java-luokkatyyppi"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "edellinen esittely %q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, fuzzy, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr "%qD:n tyyppi ei täsmää aiemman esittelyn kanssa"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "%qT ei ole malli"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD:lla ei voi olla oletusargumentteja"
 
 # XXX
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "oletusargumentti annettu %2$q#D:n parametrille %1$d"
@@ -44231,95 +44287,95 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, fuzzy, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "luokalla %q#T on datajäseninä osoittimia"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD:n esittely viitteiden taulukkona"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %D"
 msgstr "%qE on esittelemättä"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a friend"
 msgstr "%q+D esitelty ystävänä"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qs-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables"
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qE-attribuutti pätee vain muuttujiin"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "%<fast_interrupt%>-attribuuttidirektiivi jätetty huomiotta"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr ""
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "suggested alternative:"
 #| msgid_plural "suggested alternatives:"
@@ -44326,7 +44382,7 @@
 msgid "suggested alternative: %qs"
 msgstr "ehdotettu vaihtoehto:"
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -44333,27 +44389,27 @@
 msgstr[0] "ehdotettu vaihtoehto:"
 msgstr[1] "ehdotetut vaihtoehdot:"
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, fuzzy, gcc-internal-format
 msgid "  %qE"
 msgstr "%qE on vanhentunut"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -44373,7 +44429,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -44398,7 +44454,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "pyyntö jäsenen %qs käsittelyyn jossain, joka ei ole tietue tai unioni"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%> on esittelemättä"
@@ -44458,1214 +44514,1219 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(mahdollisesti %qT:n määrittelyn perästä puuttuu puolipiste)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE ei ole malli"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, fuzzy, gcc-internal-format
 msgid "invalid template-id"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "liukulukuylivuoto lausekkeessa"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, fuzzy, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, fuzzy, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, fuzzy, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "alustinalkio ei ole vakiolauseke"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, fuzzy, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "case-nimiö ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "ylivuoto vakiolausekkeessa"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr ""
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, fuzzy, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, fuzzy, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(ehkä tarkoitettiin %<typename %T::%E%>)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 #| msgid "%qE in namespace %qE does not name a type"
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE nimiavaruudessa %qE ei nimeä tyyppiä"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE nimiavaruudessa %qE ei nimeä tyyppiä"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%E%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "ja kohteella %qT:lla ei ole mallimuodostimia"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "luokalla %qT ei ole %qD-nimistä kenttää"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE ei nimeä tyyppiä"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, fuzzy, gcc-internal-format
 msgid "expected string-literal"
 msgstr "odotettiin merkkijonoliteraalia"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, fuzzy, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr "muotoilu on leveämerkkinen merkkijono"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr "liukulukuvakio ylittää %qT:n arvoalueen"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr "liukulukuvakio ylittää %qT:n arvoalueen"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, fuzzy, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr "liukulukuvakio katkaistu nollaksi"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr ""
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 msgid "expected binary operator"
 msgstr "%s: odotettiin binääristä operaattoria"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 msgid "expected ..."
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr "virheellinen lauseke kohdemuuttujana"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "ehtolausekkeessa ei-lvalue-taulukko"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr "virheellinen loogisen lausekkeen käyttö operandina %<operator--%>:lle"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "säiekohtaista muistia ei tueta tälle kohteelle"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ kieltää lohkot lausekkeiden sisällä"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr ""
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, fuzzy, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "odotettiin lauseketta"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "<this%>-sanaa ei voi käyttää tässä yhteydessä"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, fuzzy, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "paikallinen muuttuja %qD ei voi esiintyä tässä yhteydessä"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "odotettiin lauseketta"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, fuzzy, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%qT ei ole luokka tai nimiavaruus"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%<~%T%>:n esittely %qT:n jäsenenä"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "ID"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD ei ole malli"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "väärä määrä argumentteja funktiolle %<__builtin_next_arg%>"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ kieltää yhdysliteraalit"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 #| msgid "-client_name not allowed with -dynamiclib"
 msgid "braced list index is not allowed with array notation"
 msgstr "valitsimia -client_name ja -dynamiclib ei voi käyttää yhdessä"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "%qD:n virheellinen käyttö"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%> ei ole luokan jäsen"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, fuzzy, gcc-internal-format
 msgid "non-scalar type"
 msgstr "pyydetty muuntoa ei-skalaarityypiksi"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "vanhanmallisen tyyppimuunnoksen käyttö"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "suosittellaan sulkumerkkejä %<>>%>-lausekkeen ympärille"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, fuzzy, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "Odotettiin argumenttiluetteloa kohdassa %C"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "%qD ei ole muuttuja"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D esitelty täällä"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support complex types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C90 ei tue kompleksityyppejä"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "ylimääräinen %<volatile%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, fuzzy, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "nimike yhdyslauseen lopussa"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%> nimeää muodostimen, ei tyyppiä"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr "ei palautuslausetta funktiossa, joka palauttaa ei-voidin"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "odotettiin iteraatioesittelyä tai -alustusta"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr "break-lause ei ole silmukan tai switch-lauseen sisässä"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ kieltää lasketut goto-käskyt"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s-lausetta odotettiin kohdassa %L"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%> ei ole lohkon alussa"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "tyhjä indeksiväli alustimessa"
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, fuzzy, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "tyhjä esittely"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
 #, fuzzy, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr "puuttuva alustin jäsenelle %qD"
+
+#: cp/parser.c:13220
+#, fuzzy, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "virheellinen muunnostarkennin jälkiliitteessä: %c"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "muuttujan %q+D koko muistissa ei ole tunnettu"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "luokkamäärittelyä ei voi esitellä ystäväksi"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "mallit eivät voi olla virtuaalisia"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "%s: virheellinen kenttämääritys %s"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, fuzzy, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "epäkelpo %<restrict%>-avainsanan käyttö"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "ei voi laajentaa alustinta jäsenelle %<%D%>"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "%q+D esitelty staattisena, edellinen esittely ei-staattinen"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "leveä merkkijonovakio %<asm%>-lauseessa"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "epäkelvot operandit binääriselle %s-operaatiolle"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "odotettiin %<operator%>"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, fuzzy, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "Avainsana %s on tuntematon tai sillä ei vielä ole toteutusta"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "hajottimet eivät voi olla cv-määriteltyjä"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, fuzzy, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr "anonyymit variadiset makrot esiteltiin C99:ssä"
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "strftime-muotoilut eivät voi muotoilla argumentteja"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(G++ hyväksyy koodin -fpermissive-valitsimella)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "jäsennysvirhe malliargumenttien luettelossa"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "odotettiin %<template%>"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, fuzzy, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, fuzzy, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr ""
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr ""
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, fuzzy, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C forbids forward parameter declarations"
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C kieltää parametrien ennakkoesittelyn"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "Odotettu nimi"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "parametritaulukon esittelijän attribuutit jätetään huomiotta"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD ei ole malli"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%J%qD:n edellinen esittely oli täällä"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "esittely %qD ei esittele mitään"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "ylimääräinen %<;%>"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C++ forbids incrementing an enum"
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ kieltää enumin lisäyksen"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "odotettiin %<namespace%>"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot be inline"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "nested identifier required"
 msgstr "’$’ tunnisteessa tai lukuarvossa"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "parametriksi ei voida esitellä %<constexpr%>:ksi"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "%<namespace%>-määrittely ei ole sallittu täällä"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, fuzzy, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, fuzzy, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "Ristiriita funktioargumentin attribuuteissa kohdassa %C"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "%Jsisäänrakennettu funktio %qD esitelty ei-funktiona"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "taulukkoindeksi alustimessa ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%> ei ole tyyppi"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -45674,7 +45735,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "Varoita implisiittisistä funktioesittelyistä"
@@ -45681,343 +45742,343 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "id="
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD on nimiavaruus"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "parametrilla %P on vaillinainen tyyppi %qT"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "cv-määreen kaksoiskappale"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate cv-qualifier"
 msgid "multiple ref-qualifiers"
 msgstr "ristiriitaiset tyyppimääreet %q+D:lle"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "Kaksoiskappale pääsy-tarkenne kohdassa %C"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "Odotettiin käyttöoikeustarkennetta kohdassa %C"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "odotettiin %<,%> tai %<...%>"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "%<operator new%>:n ensimmäisellä parametrilla ei voi olla oletusargumenttia"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C ei salli ylimääräisiä %<;%>-merkkejä funktion ulkopuolella"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C90 ei tue joustavia taulukkojäseniä"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "odotettiin luokan nimeä"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "Odotettiin :: TYPE-määrittelyssä kohdassa %C"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "ei löydetä luokkaa %qE"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "virheellinen luokan nimi %qD:n esittelyssä"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "funktiomalli %qD esitelty uudelleen luokkamallina"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "%s: ei voida avata PCH-tiedostoa: %m\n"
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "edellinen %q+#T:n määrittely"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "tallennusluokka annettu typenamelle"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "ystäväesittely ei nimeä luokkaa tai funktiota"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "pure-tarkenne funktiomäärittelyssä"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "ylimääräinen %<,%> jäsenesittelyn lopussa"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "skalaarialustimen ympärillä on aaltosulkeet"
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, fuzzy, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:23700
-#, gcc-internal-format
-msgid "more than one access specifier in base-specified"
-msgstr ""
+#: cp/parser.c:23723
+#, fuzzy, gcc-internal-format
+msgid "more than one access specifier in base-specifier"
+msgstr "varoitus: lähdetiedosto %s annettu useammin kuin kerran"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "%qs esitelty funktion palauttavana funktiona"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "virheellinen %<auto%>:n käyttö muunnosoperaattorissa"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "hajotin ei voi olla %<constexpr%>"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "vakio tai tunniste odotettu"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute conflicts with attribute %s"
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "%qE-attribuutti on ristiriidassa attribuutin %s kanssa"
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "ENUM-määrittelylause odotettiin ennen kohdetta %C"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "attribuutti %qs pätee vain funktiotyyppeihin"
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "taulukon koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "virheellinen %<%T::%E%>:n esittely"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "%J%qD:n edellinen esittely oli täällä"
@@ -46026,429 +46087,429 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "nimetyt paluuarvot eivät ole enää tuettuja"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "[Tyhjä]"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr ""
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "malli C-linkityksellä"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "    Ei ilmaistuja epäjäseniä\n"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "malliesittelylle %q+D"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "esittely ei esittele mitään"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "%Hdatamäärittelyllä ei ole tyyppiä eikä tallennusluokkaa"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr ""
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, fuzzy, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, fuzzy, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "käytetty %<__thread%> ennen %<extern%>:a"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 ei tue %<long long%> -tyyppiä"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "sekä %<_Sat%> että %<char%> esittelymääritteissä"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "ylimääräinen %<const%>"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "kaksois-%qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "odotettiin %<new%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "odotettiin %<delete%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "odotettiin %<return%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "odotettiin %<extern%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "odotettiin %<static_assert%>"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "odotettiin %<decltype%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "odotettiin %<operator%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "odotettiin %<class%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "odotettiin %<template%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "odotettiin %<namespace%>"
 
 # XXXXXXX
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "odotettiin %<=%>, %<,%>, %<;%>, %<asm%> tai %<__attribute__%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, fuzzy, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "  siirtyy catch-lohkoon"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, fuzzy, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "nimiö "
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, fuzzy, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "Taso 2 ei ole synkronoitu"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, fuzzy, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "<throw-lauseke>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "odotettiin %<,%> tai %<;%>"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, fuzzy, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "”)” oli odotus"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "odotettiin %<:%> tai %<...%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr ""
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "%q+#D aiemmin esitelty täällä"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, fuzzy, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD esitelty uudelleen eri näkyvyydellä"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
 
 # XXX
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "useita tallennuspaikkoja esittelymääritteissä"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, fuzzy, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "%qE ei ole Objective-C-luokkanimi eikä -alias"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "Odotettiin toista ulottuvuutta taulukkoesittelyssä kohdassa %C"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "%Jlohkoattribuuttia ei voi määrittää paikalliselle muuttujalle"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "virheellinen tyyppi iterointimuuttujalle %qE"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qs-attribuuttia ei huomioida %qs:lle"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "virheellinen vastaanottajatyyppi %qs"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid reduction-identifier"
 msgstr "odotettiin tunnistetta tai %<(%>"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "Alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "sisäkkäisessä funktiossa käytetty rekisterimuuttujaa %qD"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "mahdollisia ikisilmukoita ei voi optimoida"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "%Jvanhanmallinen funktiomäärittely"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 #| msgid "invalid initializer"
 msgid "invalid initializer clause"
 msgstr "epäkelpo alustin"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "odotettiin kokonaislukulauseketta"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 #| msgid "new types may not be defined in a return type"
 msgid "types may not be defined in declare reduction type list"
 msgstr "uusia tyyppejä ei voi määritellä paluutyypissä"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%qD does not refer to a namespace scope function"
@@ -46455,71 +46516,71 @@
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, fuzzy, gcc-internal-format
 msgid "atomic_cancel"
 msgstr "_Peru"
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "roskaa ilmaisun %<#pragma GCC pch_preprocess%> lopussa"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "virheellinen määrittely"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC optimize is not allowed inside functions"
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize ei ole sallittu funktioiden sisällä"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "moduulienvälisiä optimointeja ei ole toteutettu C++:lle"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 #| msgid "Expected variable name at %C"
 msgid "expected variable-name"
 msgstr "Odotettiin muuttujanimeä kohdassa %C"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "odotettiin merkkijonoa ilmaisun %<#pragma message%> jälkeen"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, fuzzy, gcc-internal-format
 #| msgid "templates may not be %<virtual%>"
 msgid "implicit templates may not be %<virtual%>"
@@ -46612,7 +46673,7 @@
 msgid "candidate is: %#D"
 msgstr "ehdokas on: %#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s %d"
@@ -47193,123 +47254,138 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr ""
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
+
+#: cp/pt.c:6672
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr ""
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE ei ole kelvollinen malliargumentti tyypille %qT, koska se ei ole objekti ulkoisella linkityksellä"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "virheellinen hajottimen %qD käyttö tyyppinä"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "  odotettiin %qT-tyyppistä vakiota, saatiin %qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "  odotettiin luokkamallia, saatiin %qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "  odotettiin tyyppiä, saatiin %qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "  odotettiin tyyppiä, saatiin %qT"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
@@ -47317,104 +47393,104 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, fuzzy, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "ehtolausekkeessa on tyyppiristiriita"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "%qE:ta ei voi muuntaa tyypistä %qT tyyppiin %qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr ""
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "attribuutille %qs annettu väärä määrä argumentteja"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "prototype for %q+#D"
 msgid "provided for %qD"
 msgstr "nimellä %qD"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "tallennusluokka annettu parametrille %qs"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, fuzzy, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, fuzzy, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure"
 msgstr "%qT ei ole malli"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a variable"
 msgid "use of invalid variable template %qE"
 msgstr "%qD ei ole muuttuja"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr ""
@@ -47432,208 +47508,208 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "muuttujalla %qD on funktiotyyppi"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "virheellinen parametrityyppi %qT"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "esittelyssä %q+D"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "taulukon palauttava funktio"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "funktion palauttava funktio"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, fuzzy, gcc-internal-format
 msgid "forming reference to void"
 msgstr "tyhjää arvoa ei jätetä huomioimatta, vaikka kuuluisi"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "NULLin muunnos epäosoitintyypiksi %qT"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "tyyppitäsmäämättömyys taulukkoviitteessä"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "tyyppimuunnos lisää funktiotyyppiin uusia määreitä"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr ""
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr ""
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "%<void *%>-tyyppistä osoitinta käytetty laskutoimituksessa"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "luodaan void-taulukko"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%Jcase-arvo %qs ei ole luetellussa tyypissä"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, fuzzy, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT ei ole luokka-, struct- eikä unionityyppi"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, fuzzy, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "muodostimen virheellinen käyttö mallina"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, fuzzy, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "käytetään virheellistä kenttää %qD"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "void-lausekkeen epäkelpo käyttö"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, fuzzy, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "Käytä rekistereitä argumenttien välittämiseen"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "käytä #includea sen sijaan"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%J%qD esitelty avoimeksi määrittelyn jälkeen"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD ei ole luokka eikä nimiavaruus"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT on/käyttää anonyymiä tyyppiä"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD:n malliargumentti käyttää paikallista tyyppiä %qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, fuzzy, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "ohjelman alustusta yritettäessä"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "malliesittelylle %q+D"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 msgid "%s %#S"
 msgstr ""
@@ -47641,67 +47717,67 @@
 "%s, %s, %s, %s,\n"
 "%s, %s ja %s.\n"
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr ""
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr ""
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr ""
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "käyttämätön muuttuja %q+D"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "jäsenen %q+D kaksoiskappale"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ kieltää metodiosoittimen käytön vähennyslaskussa"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr ""
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr ""
@@ -47713,93 +47789,93 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "staattinen tai tyyppimääreitä ei-parametrisessa taulukkoesittelijässä"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "tyyppi %qT ei ole tyypin %qT kantatyyppi"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "%qD ei ole mallifunktio"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "liian paljon argumentteja funktiolle %qs"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Tiedostoa ”%s” on jo tarkasteltu.\n"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "ei voi emuloida %qs"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "%qE:n muunnos tyypistä %qT tyyppiin %qT ei ole yksiselitteinen"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "alustusalkio ei ole vakio"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "initializer element is not constant"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -47958,482 +48034,482 @@
 msgid "  since %q+#D declared in base class"
 msgstr ""
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, fuzzy, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "ehdotetaan aaltosulkeita tyhjän lohkon ympärille %<do%>-lauseessa"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of member %q+D in static member function"
 msgid "invalid use of member %qD in static member function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "ei argumentteja"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "%<this%> ei ole käytettävissä staattisissa jäsenfunktioissa"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "virheellinen ei-staattisen jäsenfunktion käyttö"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr ""
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, fuzzy, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "objektityyppi %qT ei täsmää hajottimen nimen ~%qT kanssa"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE ei ole tyyppiä %qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "ei-objektityyppinen yhdysliteraali %qT"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "mallinimen %qE virheellinen käyttö ilman argumenttiluetteloa"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "perustyypin %qT kaksoiskappale virheellinen"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "        %qD"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, fuzzy, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "oletusargumentti määritelty lambda-parametrille"
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "poistettu funktio %q+D"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "täsmäämättömät argumentit"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, fuzzy, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "%qD ei ole nimiavaruuden nimi"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "  odotettiin luokkamallia, saatiin %qT"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, fuzzy, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE ei ole tyyppi"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "odotettiin %qT, mutta argumentti on tyyppiä %qT"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "tarpeeton tyyppimääre tyhjässä esittelyssä"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "jäsenfunktiota %qD ei voi kutsua ilman oliota"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr ""
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "ISO C kieltää nollan kokoisen taulukon %qE"
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr "tyypillä %qE on virtuaalisia jäsenfunktioita"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%qs expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "etumerkillisen ja etumerkittömän kokonaislukulausekkeen vertailu"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "muuttuja %qD esitelty uudelleen funktiona"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "%qE ei ole malli"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<grainsize%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<priority%> expression must be integral"
 msgstr "taulukon %qD koko ei ole kokonaislukutyyppinen vakiolauseke"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<num_tasks%> expression must be integral"
 msgstr "%<num_threads%>-arvon on oltava positiivinen"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "indeksoitu arvo ei ole taulukko eikä osoitin"
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 #| msgid "%<num_threads%> value must be positive"
 msgid "%<tile%> argument needs integral type"
 msgstr "%s:n arvon on oltava kokonaisluku"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%Jparametrin %qD tyyppi on vaillinainen"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %s"
 msgid "static assertion failed"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "staattinen väite epäonnistui: %s"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "ei-vakio ehto staattiselle väitteelle"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "decltypen argumentin on oltava lauseke"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%J%qD on tavallisesti ei-staattinen funktio"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "pilkkulausekkeen vasemmalla operandilla ei ole vaikutusta"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported argument to %<__builtin_return_address%>"
 msgid "non-pointer argument to %<__builtin_launder%>"
@@ -48449,108 +48525,108 @@
 msgid "lambda-expression in a constant expression"
 msgstr "liukulukuvakio esikääntäjän lausekkeessa"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "%qE-attribuutti pätee vain funktiotyyppeihin"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, fuzzy, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "haluttu sijainti ei ole kokonaislukuvakio"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "Rinnakkaiset työt (-j) eivät ole tuettuja tällä alustalla."
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "%qs:n esittely taulukollisena tyhjiä alkioita"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE-attribuutti tarvitsee prototyyppejä, joilla nimettyjä argumentteja"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "näkyvyysargumentti ei ole merkkijono"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "universaali merkki %.*s ei ole kelvollinen tunniste"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "universaali merkki %.*s ei ole kelvollinen tunniste"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qs-attribuuttia ei huomioida ei-luokkatyypeille"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%J%qE-attribuutti soveltuu vain funktioihin"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "nolla nollaosoitinvakiona"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "verifiointi epäonnistui kohdassa PC=%d: %s"
@@ -49243,12 +49319,12 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "virheellinen muunnos tyypistä %qT tyyppiin %qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
@@ -49255,7 +49331,7 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
@@ -49262,7 +49338,7 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
@@ -49269,7 +49345,7 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "ei voi muuntaa tyypistä %1$qT tyyppiin %2$qT %4$qD:n argumentiksi %3$qP"
@@ -49276,7 +49352,7 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
@@ -49283,77 +49359,77 @@
 
 # XXX
 # %s on "initialization", jota EI VOI suomentaa tällä hetkellä.
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "ei voi muuntaa tyyppiä %qT tyypiksi %qT"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 #| msgid "return type %q#T is incomplete"
 msgid "class type %qT is incomplete"
 msgstr "nimellä %qT on vaillinainen tyyppi"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "funktiokutsun argumentti voi olla ehdokas muotoiluattribuutille"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "funktio on ehkä mahdollinen ehdokas %qs-muotoiluattribuutille"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 #| msgid "  initializing argument %P of %qD"
 msgid "in passing argument %P of %qD"
 msgstr "  alustettaessa funktion %2$qD argumenttia %1$P"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr ""
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, fuzzy, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "palautettu viittaus paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of label %qD returned"
 msgstr "nimiö %qD määritelty täällä"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "palautettu osoite paikalliseen muuttujaan %q+D"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "arvon palautus hajottimesta"
@@ -49360,55 +49436,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "arvon palautus muodostimesta"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "return-lause ilman arvoa funktiossa, jonka paluutyyppi on %qT"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "taulukon palauttava funktio"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "arvo return-lauseelle funktiossa, jonka paluutyyppi on ”void”"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%> ei saa palauttaa NULLia ellei esittely ole %<throw()%> (tai -fcheck-new ole voimassa)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -53522,87 +53598,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "vektoriylivuoto lausekkeessa"
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -53796,12 +53872,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -54602,515 +54678,530 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr ""
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr "Laajennus: Puuttuva positiivinen leveys L-määrittelijän jälkeen kohdassa %L"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr "Piste vaadittu muotomääritteessä kohdassa %L"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %L"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "Laajennus: Puuttuva positiivinen leveys L-määrittelijän jälkeen kohdassa %L"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %L"
 msgid "Missing positive width after L descriptor at %L"
 msgstr "Laajennus: Puuttuva positiivinen leveys L-määrittelijän jälkeen kohdassa %L"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "%s muotoilumerkkijonossa kohdassa %L"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr "Positiivinen leveys vaadittu muotomäärittelijässä %s kohdassa %L"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "Piste vaadittu muotomääritteessä %s kohdassa %L"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "Piste vaadittu muotomääritteessä kohdassa %L"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "PARAMETER kohdassa %L on ilman alustinta"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s muotoilumerkkijonossa kohdassa %L"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr "Piste vaadittu muotomääritteessä kohdassa %L"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr ""
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "PRINT statement at %C not allowed within PURE procedure"
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Puuttuva muotonimiö kohdassa %C"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "Virheellinen arvo %s-spesifikaatiolle kohdassa %C"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "Kaksoiskappale %s-spesifikaatio kohdassa %C"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "Kaksoiskappale %s-nimiöspesifikaatio kohdassa %C"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr ""
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr ""
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "tyhjä esittely"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, fuzzy, gcc-internal-format
 #| msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "Muuttuja %s ei voida liittää PURE-proseduuriin kohdassa %C"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr "epäkelpo osoitintila %qs"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "%s:n kohdassa %L täytyy olla INTEGER"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr ""
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "Lausekkeen CASE-lauseessa kohdassa %L on oltava skalaari"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr "<tunnistevirhe>"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr "%<__builtin_args_info%>-funktion argumentti puuttuu"
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr "Piste vaadittu muotomääritteessä kohdassa %L"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr "Ei voi muuntaa tyyppiä %s tyyppiin %s kohdassa %L"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "tyhjä esittely"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr ""
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "UNIT-numeron CLOSE-lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number missing in statement at %L"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "tyhjennä puskurit"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing format with default unit at %C"
 msgstr "Puuttuva muotonimiö kohdassa %C"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "Kaksoiskappale-NML-spesifikaatio kohdassa %C"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "Kaksoiskappalemuotospesifikaatio kohdassa %C"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "Kaksoiskappale-NML-spesifikaatio kohdassa %C"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "UNIT ei ole määritelty kohdassa %L"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "virheellinen muunnos tyypistä %qT tyypiksi %qT"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR-tunnistenimiötä %d kohdassa %L ei ole määritelty"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END-tunnistenimiötä %d kohdassa %L ei ole määritelty"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR-tunnistenimiötä %d kohdassa %L ei ole määritelty"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT-nimiö %d kohdassa %L ei ole määritelty"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "Syntaksivirhe siirräntäiteraattorissa kohdassa %C"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "Odotettiin muuttujaa READ-lauseessa kohdassa %C"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Odotettiin lauseketta %s-lauseessa kohdassa %C"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "Syntaksivirhe %s-lauseessa kohdassa %C"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "ASYNCHRONOUS= määrite kohdassa %L täytyy olla alustuslauseke"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT-lause kohdassa %C ei ole sallittu PURE-proseduurin sisällä"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "DATA-lause kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "UNIT number in statement at %L must be non-negative"
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "UNIT-numeron lauseessa kohdassa %L täytyy olla epänegatiivinen"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "CLOSE-lause ei ole sallittu PURE-proseduurissa kohdassa %C"
@@ -56021,264 +56112,264 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr ""
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr "kokonaislukuylivuoto lausekkeessa"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 #| msgid "Name '%s' at %C is already defined as a generic interface at %L"
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "Nimi ”%s” kohdassa %C on jo määritelty geneerisenä rajapintana kohdassa %L"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "%<%c%s%>:n aikasempi esittely"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr ""
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "Syntaksivirhe PROCEDURE-lauseessa kohdassa %C"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, fuzzy, gcc-internal-format
 #| msgid "Reading module %s at line %d column %d: %s"
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "Luetaan moduulia %s rivillä %d sarake %d: %s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, fuzzy, gcc-internal-format
 #| msgid "Writing module %s at line %d column %d: %s"
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "Kirjoitetaan moduuli %s rivillä %d sarake %d: %s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, fuzzy, gcc-internal-format
 #| msgid "Module %s at line %d column %d: %s"
 msgid "Module %qs at line %d column %d: %s"
 msgstr "Moduuli %s rivillä %d sarakkeessa %d: %s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "Virhe kirjoitettaessa moduulitiedostoa %s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, fuzzy, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr "virheellinen merkkijonovakio"
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for writing at %C: %s"
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "Ei voi avata moduulitiedostoa ”%s” kirjoittamista varten kohdassa %C: %s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "Virhe kirjoitettaessa moduulitiedostoa %s"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete module file '%s': %s"
 msgid "Can't delete module file %qs: %s"
 msgstr "Ei voida poistaa moduulitiedostoa ”%s”: %s"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 #| msgid "Can't rename module file '%s' to '%s': %s"
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "Ei voida nimetä uudelleen moduulitiedostoa ”%s” nimellä ”%s”: %s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 #| msgid "Can't delete temporary module file '%s': %s"
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "Ei voida poistaa tilapäistä moduulitiedostoa ”%s”: %s"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs at %C already declared"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 #| msgid "Symbol '%s' already declared"
 msgid "Symbol %qs already declared"
 msgstr "%qs alustettu ja esitelty %<extern%>-avainsanalla"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "tyhjä esittely"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "Odotettiin sitomisattribuuttia kohdassa %C"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "odotettiin ”::” moduuliluonteen jälkeen paikassa %C, mutta ei löytynyt"
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "odotettiin ”::” moduuliluonteen jälkeen paikassa %C, mutta ei löytynyt"
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "odotettiin ”::” moduuliluonteen jälkeen paikassa %C, mutta ei löytynyt"
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 #| msgid "Can't open module file '%s' for reading at %C: %s"
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "Ei voi avata moduulitiedostoa ”%s” lukemista varten kohdassa %C: %s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr ""
@@ -58734,7 +58825,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "%J%qD:lle ei ole aiempaa esittelyä"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -60271,456 +60362,446 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, fuzzy, gcc-internal-format
 #| msgid "Empty array constructor at %C is not allowed"
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "Tyhjä taulukkomuodostin kohdassa %C ei ole sallittu"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 #| msgid "PROCEDURE attribute conflicts with INTENT attribute in '%s' at %L"
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE-attribuutti on ristiriidassa INTENT-attribuutin kanssa kohteessa ”%s” kohdassa %L"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, fuzzy, gcc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the POINTER and BIND(C) attributes"
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä POINTER- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%qE-attribuutti soveltuu vain variadisiin funktioihin"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "SAVE-attribuuttia kohdassa %L ei voida määritellä PURE-proseduurissa"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "Sijoitus FORALL-indeksimuuttujaan kohdassa %L"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Variable '%s' at %L cannot have both the ALLOCATABLE and BIND(C) attributes"
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "Muuttujalla ”%s” kohdassa %L ei voi olla sekä ALLOCATABLE- että BIND(C)-attribuutit"
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, fuzzy, gcc-internal-format
 #| msgid "'%s' argument of '%s' intrinsic at %L cannot be INTENT(IN)"
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "kääntäjänsisäisen ”%2$s”-funktion argumentin ”%1$s” kohdassa %3$L ei voi olla INTENT(IN)"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, fuzzy, gcc-internal-format
 #| msgid "Initialization of variable at %C is not allowed in a PURE procedure"
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "Muuttujan alustus kohdassa %C ei ole sallittu PURE-proseduurissa"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 #| msgid "Unknown argument list function at %L"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "Tuntematon argumenttiluettelofunktio kohdassa %L"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "muuttuvakokoista objektia ei voi alustaa"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta ei käytetty"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "Nimiö %d kohdassa %L on määritelty, mutta sitä ei voida käyttää"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "Syntaksivirhe IMPORT-lauseessa kohdassa %C"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, fuzzy, gcc-internal-format
 #| msgid "Return type of BIND(C) function '%s' at %L cannot be a character string"
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "BIND(C)-funktion ”%s” paluutyyppi kohdassa %L ei voi olla merkkijono"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, fuzzy, gcc-internal-format
 #| msgid "Intrinsic '%s' at %L must have at least two arguments"
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "Kääntäjänsisäisellä ”%s”-funktiolla kohdassa %L on oltava vähintään kaksi argumenttia"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -61821,12 +61902,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "%<__builtin_args_info%>-funktion argumentin pitää olla vakio"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "%s: rivi %d: virheellinen komento ”%s”\n"
Index: gcc/po/el.po
===================================================================
--- gcc/po/el.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/el.po	(.../branches/gcc-7-branch)
@@ -6,7 +6,7 @@
 msgstr ""
 "Project-Id-Version: gcc 4.0-b20041128\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2004-12-15 18:53+0000\n"
 "Last-Translator: Simos Xenitellis <simos74@gmx.net>\n"
 "Language-Team: Greek <nls@tux.hellug.gr>\n"
@@ -190,13 +190,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr ""
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, fuzzy, c-format
 msgid "invalid expression as operand"
@@ -556,65 +556,65 @@
 " επιλογές σε αυτές τις διεργασίες, πρέπει να χρησιμοποιήσετε τις επιλογές\n"
 " -W<γράμμα>.\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, fuzzy, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "δημιουργία %s %s στο %s"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, fuzzy, c-format
 #| msgid "libraries: %s\n"
 msgid "Target: %s\n"
 msgstr "βιβλιοθήκες: %s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "Έχει ρυθμιστεί με: %s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "Μοντέλο νημάτων: %s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, fuzzy, c-format
 #| msgid "gcc version %s\n"
 msgid "gcc version %s %s\n"
 msgstr "έκδοση gcc %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, fuzzy, c-format
 #| msgid "gcc driver version %s executing gcc version %s\n"
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "έκδοση οδηγού gcc %s εκτελεί την έκδοση gcc %s\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr ""
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr ""
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "εγκατάσταση: %s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "προγράμματα: %s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "βιβλιοθήκες: %s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -624,17 +624,17 @@
 "Για οδηγίες για αναφορές σφαλμάτων. παρακαλώ δείτε:\n"
 
 # src/request.c:37
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, fuzzy, c-format
 msgid "%s %s%s\n"
 msgstr "%s: %s: "
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr ""
 
 # src/main.c:850
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 #, fuzzy
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
@@ -645,7 +645,7 @@
 "αντιγραφής. Δεν υπάρχει ΚΑΜΙΑ εγγύηση· ούτε ακόμα για ΛΕΙΤΟΥΡΓΙΚΟΤΗΤΑ ή \n"
 "ΚΑΤΑΛΛΗΛΟΤΗΤΑ ΓΙΑ ΕΝΑ ΣΥΓΚΕΚΡΙΜΕΝΟ ΣΚΟΠΟ.\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -654,7 +654,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -661,7 +661,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -669,7 +669,7 @@
 "\n"
 msgstr ""
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -681,18 +681,18 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, fuzzy, c-format
+#| msgid "  -o <file>                Place the output into <file>\n"
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "  -o <αρχείο>              Τοποθέτηση της εξόδου στο <αρχείο>\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, fuzzy, c-format
 #| msgid "  -v, --version                   Print version number, then exit\n"
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "  -v, --version                   Εμφάνιση αριθμού έκδοσης, μετά έξοδος\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, fuzzy, c-format
-#| msgid "  -o <file>                Place the output into <file>\n"
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "  -o <αρχείο>              Τοποθέτηση της εξόδου στο <αρχείο>\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -708,14 +708,14 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr ""
 
-#: gcov-tool.c:272
+#: gcov-tool.c:270
 #, c-format
-msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
 msgstr ""
 
-#: gcov-tool.c:273
+#: gcov-tool.c:272
 #, c-format
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr ""
 
 #: gcov-tool.c:290
@@ -743,31 +743,31 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr ""
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgid "    -f, --function                      Print function level info\n"
 msgstr "  -h, --help                      Εμφάνιση αυτής της βοήθειας, μετά έξοδος\n"
 
-#: gcov-tool.c:422
+#: gcov-tool.c:421
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -f, --function                      Print function level info\n"
+msgid "    -F, --fullname                      Print full filename\n"
 msgstr "  -h, --help                      Εμφάνιση αυτής της βοήθειας, μετά έξοδος\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:422
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
-msgid "    -F, --fullname                      Print full filename\n"
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
 msgstr "  -h, --help                      Εμφάνιση αυτής της βοήθειας, μετά έξοδος\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:423
 #, fuzzy, c-format
 #| msgid "  -h, --help                      Print this help, then exit\n"
 msgid "    -o, --object                        Print object level info\n"
 msgstr "  -h, --help                      Εμφάνιση αυτής της βοήθειας, μετά έξοδος\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr ""
@@ -858,20 +858,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      Εμφάνιση αυτής της βοήθειας, μετά έξοδος\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr ""
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr ""
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -878,17 +873,22 @@
 "                                    rather than percentages\n"
 msgstr ""
 
-#: gcov.c:663
+#: gcov.c:662
 #, fuzzy, c-format
 #| msgid "  --help                   Display this information\n"
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  --help                   Εμφάνιση αυτών των πληροφοριών\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr ""
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      Εμφάνιση αυτής της βοήθειας, μετά έξοδος\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1073,33 +1073,33 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr ""
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, fuzzy, c-format
 msgid "No executable lines\n"
 msgstr "δημιουργία αρχείου `%s'\n"
 
 # src/request.c:37
-#: gcov.c:2013
+#: gcov.c:2020
 #, fuzzy, c-format
 msgid "%s '%s'\n"
 msgstr "%s: %s"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, fuzzy, c-format
 msgid "No branches\n"
 msgstr ""
@@ -1106,52 +1106,52 @@
 "Δεν υπάρχει αρχείο `%s'.\n"
 "\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr ""
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, fuzzy, c-format
 msgid "No calls\n"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, fuzzy, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s πριν από `%s'"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, fuzzy, c-format
 msgid "call   %2d returned %s\n"
 msgstr "  αλλά %d απαιτούνται"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr ""
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, fuzzy, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "Άγνωστή επιλογή για το `s'"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr ""
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, fuzzy, c-format
 msgid "Cannot open source file %s\n"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
@@ -1264,89 +1264,89 @@
 msgid "Uses of this option are diagnosed."
 msgstr ""
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr ""
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr ""
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr ""
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr ""
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr ""
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr ""
 
-#: opts.c:1281
+#: opts.c:1288
 #, c-format
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr ""
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr ""
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr ""
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr ""
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr ""
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr ""
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr ""
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr ""
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr ""
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr ""
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr ""
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr ""
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr ""
 
@@ -2899,8 +2899,8 @@
 msgid "<command-line>"
 msgstr ""
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
@@ -2919,7 +2919,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, fuzzy, c-format
 msgid "missing operand"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
@@ -2939,8 +2939,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr ""
@@ -2956,18 +2956,18 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, fuzzy, c-format
 msgid "invalid %%R value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, fuzzy, c-format
 msgid "invalid %%N value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, fuzzy, c-format
 msgid "invalid %%P value"
 msgstr "μη έγκυρος χρήστης"
@@ -2977,7 +2977,7 @@
 msgid "invalid %%h value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, fuzzy, c-format
 msgid "invalid %%L value"
 msgstr "μη έγκυρος χρήστης"
@@ -2998,7 +2998,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, fuzzy, c-format
 msgid "invalid %%s value"
 msgstr "μη έγκυρος χρήστης"
@@ -3008,7 +3008,7 @@
 msgid "invalid %%C value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, fuzzy, c-format
 msgid "invalid %%E value"
 msgstr "μη έγκυρος χρήστης"
@@ -3019,7 +3019,7 @@
 msgstr "Δεν είναι δυνατόν να βρεθεί ο τύπος του επεξεργαστή."
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, fuzzy, c-format
 msgid "invalid %%xn code"
 msgstr "μη έγκυρο δικαίωμα"
@@ -3082,7 +3082,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, fuzzy, c-format
 msgid "invalid operand output code"
 msgstr "Μη έγκυρος κώδικας αίτησης"
@@ -3092,29 +3092,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, fuzzy, c-format
 msgid "invalid shift operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, fuzzy, c-format
 msgid "predicated Thumb instruction"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, fuzzy, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3122,110 +3122,110 @@
 msgid "invalid operand for code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, fuzzy, c-format
 msgid "instruction never executed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr ""
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr ""
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr ""
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 msgid "bad address, not an I/O address:"
 msgstr ""
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr ""
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr ""
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr ""
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr ""
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr ""
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 #, fuzzy
 msgid "invalid insn:"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 #, fuzzy
 msgid "incorrect insn:"
 msgstr "λάθος συνθηματικό"
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 #, fuzzy
 msgid "unknown move insn:"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr ""
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr ""
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 msgid "unsupported fixed-point conversion"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 msgid "variable"
 msgstr ""
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 msgid "function parameter"
 msgstr "κακό όρισμα"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 #| msgid "structure"
 msgid "structure field"
 msgstr "δομή"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 msgid "return type of function"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 msgid "pointer"
 msgstr ""
 
@@ -3247,7 +3247,7 @@
 msgstr "μη έγκυρος χρήστης"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3504,88 +3504,88 @@
 msgid "bad output_condmove_single operand"
 msgstr "αρχείο εξόδου"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, fuzzy, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr ""
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr ""
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr ""
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr ""
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, c-format
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr ""
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, fuzzy, c-format
 msgid "invalid operand code '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, fuzzy, c-format
 msgid "invalid constraints for operand"
 msgstr "μη έγκυρος χρήστης"
 
 # src/grep.c:1133
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 #, fuzzy
 msgid "unknown insn mode"
 msgstr "άγνωστη μέθοδος καταλόγων"
@@ -3626,7 +3626,7 @@
 msgid "invalid %%P operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, fuzzy, c-format
 msgid "invalid %%p value"
 msgstr "μη έγκυρος χρήστης"
@@ -3682,7 +3682,7 @@
 msgstr ""
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 #, fuzzy
 msgid "bad address"
 msgstr "Εσφαλμένη διεύθυνση"
@@ -3718,7 +3718,7 @@
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 #, fuzzy
 msgid "invalid address"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
@@ -3810,285 +3810,285 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 #, fuzzy
 msgid "-mvsx needs indexed addressing"
 msgstr "Ακατάλληλη χρήση του διαμορφωτή διεύθυνσης"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 #, fuzzy
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "Εσφαλμένος κώδικας αίτησης"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 msgid "-mquad-memory is not available in little endian mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 #, fuzzy
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "Εσφαλμένος κώδικας αίτησης"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 #, fuzzy
 msgid "bad move"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, fuzzy, c-format
 msgid "invalid %%e value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, fuzzy, c-format
 msgid "invalid %%f value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, fuzzy, c-format
 msgid "invalid %%F value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, fuzzy, c-format
 msgid "invalid %%G value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, fuzzy, c-format
 msgid "invalid %%j code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, fuzzy, c-format
 msgid "invalid %%J code"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, fuzzy, c-format
 msgid "invalid %%k value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, fuzzy, c-format
 msgid "invalid %%K value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, fuzzy, c-format
 msgid "invalid %%O value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, fuzzy, c-format
 msgid "invalid %%q value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, fuzzy, c-format
 msgid "invalid %%T value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, fuzzy, c-format
 msgid "invalid %%u value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, fuzzy, c-format
 msgid "invalid %%v value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, fuzzy, c-format
 msgid "invalid %%x value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, fuzzy, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 #, fuzzy
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "Αδύνατη η δημιουργία διεργασίας στον εξυπηρετητή"
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr ""
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, fuzzy, c-format
 msgid "cannot decompose address"
 msgstr "Δεν είναι δυνατή η εκχώρηση της ζητηθήσας διεύθυνσης"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr ""
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "Μη έγκυρος κώδικας αίτησης"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 msgid "vector argument passed to unprototyped function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 msgid "types differ in signedness"
 msgstr ""
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 msgid "binary operator does not support vector bool operand"
 msgstr ""
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4114,43 +4114,43 @@
 msgid "created and used with different endianness"
 msgstr ""
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, fuzzy, c-format
 msgid "invalid %%Y operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, fuzzy, c-format
 msgid "invalid %%A operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, fuzzy, c-format
 msgid "invalid %%B operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "μη έγκυρη μετατόπιση UTC"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, fuzzy, c-format
 msgid "invalid %%f operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, fuzzy, c-format
 msgid "invalid %%s operand"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, c-format
 msgid "floating-point constant not a valid immediate operand"
 msgstr ""
@@ -4316,32 +4316,32 @@
 msgid "bad test"
 msgstr "Εσφαλμένη διεύθυνση"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, fuzzy, c-format
 msgid "invalid %%D value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 #, fuzzy
 msgid "invalid mask"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, fuzzy, c-format
 msgid "invalid %%d value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, fuzzy, c-format
 msgid "invalid %%t/%%b value"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 #, fuzzy
 msgid "no register in address"
 msgstr "μη έγκυρος χρόνος έναρξης"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 #, fuzzy
 msgid "address offset not a constant"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -4364,8 +4364,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4387,14 +4387,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, fuzzy, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "Μη ορισμένο όνομα %s"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4425,7 +4425,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, fuzzy, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4433,7 +4433,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, fuzzy, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4443,7 +4443,7 @@
 msgstr ""
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, fuzzy, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4450,7 +4450,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, fuzzy, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4460,7 +4460,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4473,24 +4473,24 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr ""
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr ""
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr ""
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, fuzzy, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr ""
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr ""
 
@@ -4499,18 +4499,18 @@
 msgid "expected %<.%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, fuzzy, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, fuzzy, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr ""
@@ -4518,17 +4518,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, fuzzy, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr ""
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, fuzzy, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4538,7 +4538,7 @@
 msgid "(anonymous)"
 msgstr "((ανώνυμο))"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, fuzzy, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "Μη ορισμένο όνομα %s"
@@ -4548,11 +4548,11 @@
 msgid "expected label"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr ""
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr ""
 
@@ -4786,11 +4786,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr ""
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr ""
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] ""
@@ -4973,89 +4973,89 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr ""
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 #, fuzzy
 #| msgid "  but %d required"
 msgid "Positive width required"
 msgstr "  αλλά %d απαιτούνται"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 #, fuzzy
 msgid "Nonnegative width required"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 msgid "Unexpected element %qc in format string at %L"
 msgstr ""
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 #, fuzzy
 msgid "Unexpected end of format string"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 #, fuzzy
 msgid "Zero width in format descriptor"
 msgstr "σφάλμα εγγραφής %s"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 #, fuzzy
 msgid "Missing leading left parenthesis"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 msgid "Left parenthesis required after %<*%>"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr ""
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr ""
 
-#: fortran/io.c:726
-#, c-format
-msgid "Right parenthesis expected at %C"
-msgstr ""
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr ""
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr ""
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr ""
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 #, fuzzy
 msgid "Positive exponent width required"
 msgstr "Αδυναμία προσπέλασης του αρχείου της αλλαγής"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, c-format
+msgid "Right parenthesis expected at %C"
+msgstr ""
+
+#: fortran/io.c:1040
 #, fuzzy
 msgid "Period required in format specifier"
 msgstr "άγνωστο πρόθεμα: %s"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr ""
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 msgid "internal unit in WRITE"
 msgstr ""
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, c-format
 msgid "%s tag with INQUIRE"
 msgstr ""
@@ -5065,87 +5065,87 @@
 msgid "Syntax error in expression at %C"
 msgstr "συντακτικό σφάλμα στο ορισμό του %s: %s"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 #, fuzzy
 msgid "Unexpected EOF"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr ""
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr ""
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr ""
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 #, fuzzy
 msgid "Expected name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 #, fuzzy
 msgid "Expected left parenthesis"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr ""
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 #, fuzzy
 msgid "Expected integer"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 #, fuzzy
 msgid "Expected string"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 #, fuzzy
 msgid "find_enum(): Enum not found"
 msgstr "το αρχείο χάρτη χαρακτήρων `%s' δεν βρέθηκε"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 #, fuzzy
 msgid "Expected attribute bit name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 #, fuzzy
 msgid "Expected integer string"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr ""
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 #, fuzzy
 msgid "Expected real string"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 #, fuzzy
 msgid "Expected expression type"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 #, fuzzy
 msgid "Bad operator"
 msgstr "μη έγκυρος χρήστης"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 #, fuzzy
 msgid "Bad type in constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 #, fuzzy
 msgid "Unexpected end of module"
 msgstr "Μη ορισμένο όνομα %s"
@@ -5421,12 +5421,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr ""
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 #, fuzzy
 msgid "Assignment of scalar to unallocated array"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
@@ -5816,7 +5816,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 #, fuzzy
 msgid "may not use both -m32 and -m64"
 msgstr "δεν είναι δυνατό να παραληφθεί ο χρήστης και η ομάδα"
@@ -8808,7 +8808,7 @@
 msgstr ""
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 msgid "Schedule code for given CPU."
 msgstr ""
@@ -9037,7 +9037,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 msgid "Use LRA instead of reload."
 msgstr ""
 
@@ -9278,13 +9278,13 @@
 msgid "Use 80-bit long double."
 msgstr "Χρήση ABI 64-bit"
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 msgid "Use 64-bit long double."
 msgstr "Χρήση ABI 64-bit"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy
 msgid "Use 128-bit long double."
@@ -10339,90 +10339,90 @@
 msgid "64 bit ABI."
 msgstr "Χρήση ABI 64-bit"
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 msgid "Maintain backchain pointer."
 msgstr ""
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 msgid "Additional debug prints."
 msgstr ""
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 msgid "ESA/390 architecture."
 msgstr ""
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 msgid "Enable decimal floating point hardware support."
 msgstr ""
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 msgid "Enable hardware floating point."
 msgstr ""
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 msgid "Use hardware transactional execution instructions."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr ""
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 msgid "Use packed stack layout."
 msgstr ""
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 msgid "Use bras for executable < 64k."
 msgstr ""
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 msgid "Disable hardware floating point."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr ""
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr ""
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 msgid "Use the mvcle instruction for block moves."
 msgstr "Ακατάλληλη εντολή"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr ""
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr ""
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 msgid "z/Architecture."
 msgstr ""
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr ""
 
@@ -10474,11 +10474,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr ""
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr ""
 
@@ -10715,82 +10715,98 @@
 msgstr ""
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr ""
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr ""
+
+#: config/sparc/sparc.opt:102
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr ""
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 msgid "Pointers are 64-bit."
 msgstr ""
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 msgid "Pointers are 32-bit."
 msgstr ""
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "Χρήση ABI 64-bit"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "Χρήση ABI 32-bit"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 msgid "Use stack bias."
 msgstr ""
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr ""
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr ""
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr ""
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 msgid "Use features of and schedule code for given CPU."
 msgstr ""
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 msgid "Use given SPARC-V9 code model."
 msgstr ""
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 msgid "Enable debug output."
 msgstr ""
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr ""
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr ""
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr ""
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:250
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr ""
+
+#: config/sparc/sparc.opt:283
 msgid "Specify the memory model in effect for the program."
 msgstr ""
 
@@ -15367,7 +15383,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -15781,7 +15797,7 @@
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 msgid "expected integer"
 msgstr "Μη ορισμένο όνομα %s"
@@ -16106,137 +16122,137 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr ""
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 msgid "invalid comparison of non-ordered type"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 msgid "slice can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 msgid "map can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 msgid "func can only be compared to nil"
 msgstr ""
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 msgid "invalid operation (%s)"
 msgstr "μη έγκυρη επιλογή %s"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 msgid "invalid comparison of non-comparable type"
 msgstr "μη έγκυρος δεύτερος τελεστής σε κατάσταση συμβατότητας `%s'"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 msgid "invalid comparison of generated struct"
 msgstr "μη έγκυρη μέτρηση επανάληψης `%s' στη κατασκευή [c*n]"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 msgid "invalid comparison of non-comparable struct"
 msgstr ""
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 msgid "invalid comparison of generated array"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 #, fuzzy
 msgid "invalid comparison of non-comparable array"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 msgid "multiple-value function call in single-value context"
 msgstr ""
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr ""
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, fuzzy, c-format
 msgid "cannot use type %s as type %s"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 #, fuzzy
 msgid "different receiver types"
 msgstr "είδος μορφής"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 #, fuzzy
 msgid "different number of parameters"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 #, fuzzy
 msgid "different parameter types"
 msgstr "είδος μορφής"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 #, fuzzy
 msgid "different varargs"
 msgstr "είδος μορφής"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 msgid "different number of results"
 msgstr ""
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 #, fuzzy
 msgid "different result types"
 msgstr "είδος μορφής"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr ""
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 msgid "pointer to interface type has no methods"
 msgstr ""
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 #, fuzzy
 msgid "type has no methods"
 msgstr "σφάλμα κατά την ανάγνωση της εισόδου"
 
 # src/main.c:785
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, fuzzy, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "Ασαφής μορφή `%s'"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, fuzzy, c-format
 msgid "missing method %s%s%s"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr ""
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr ""
@@ -16412,7 +16428,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, fuzzy, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "πάρα πολλά ορίσματα"
@@ -16474,27 +16490,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr ""
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "μη έγκυρη κατάσταση για την dlopen()"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr ""
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr ""
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -16501,7 +16517,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, fuzzy, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "μη έγκυρος αριθμός από γραμμές"
@@ -16508,12 +16524,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr ""
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr ""
@@ -16520,62 +16536,62 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr ""
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr ""
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr ""
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr ""
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "πάρα πολλά ορίσματα"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr ""
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, gcc-internal-format
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr ""
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, fuzzy, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, fuzzy, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr ""
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr ""
@@ -17487,12 +17503,12 @@
 msgstr ""
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, fuzzy, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr ""
@@ -17587,13 +17603,13 @@
 msgid "cannot find '%s'"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
 # src/request.c:37
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, fuzzy, gcc-internal-format
 #| msgid "%s: %s"
 msgid "%s: %m"
@@ -17604,7 +17620,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr ""
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -17819,7 +17835,7 @@
 msgid "error writing %qs"
 msgstr "σφάλμα εγγραφής %s"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "αδυναμία ανοίγματος του `%s'"
@@ -17899,17 +17915,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr ""
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr ""
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -18019,12 +18035,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr ""
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr ""
@@ -18039,12 +18055,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
@@ -18059,7 +18075,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr ""
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr ""
@@ -18089,7 +18105,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr ""
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr ""
@@ -18099,7 +18115,7 @@
 msgid "total size of local objects too large"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr ""
@@ -18201,62 +18217,67 @@
 msgid "input file %qs is the same as output file"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: gcc.c:4498
+#: gcc.c:4476
+#, gcc-internal-format
+msgid "output filename may not be empty"
+msgstr ""
+
+#: gcc.c:4501
 #, fuzzy, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "Δεν υπάρχουν αρχεία εισόδου"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr ""
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr ""
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr ""
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr ""
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "ΣΦΑΛΜΑ: Αδυναμία δημιουργίας προσωρινού αρχείου για αλλαγή"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "Αδύνατη η δημιουργία αρχείου καταγραφών \"%s\""
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, fuzzy, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr ""
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr ""
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr ""
@@ -18264,233 +18285,233 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr ""
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, fuzzy, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "%s: μη αναγνωρίσιμη επιλογή `-%c'\n"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "πάρα πολλά ορίσματα"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr ""
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, fuzzy, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "πολύ λίγα ορίσματα"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr ""
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, fuzzy, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, fuzzy, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr ""
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "αδυναμία ανοίγματος αρχείου εξόδου `%s'"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr ""
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr ""
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr ""
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "δεν υπάρχουν αρχεία εισόδου"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr ""
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s: ο μεταγλωττιστής %s δεν έχει εγκατασταθεί στο σύστημα αυτό"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr ""
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr ""
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr ""
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "το αρχείο χάρτη χαρακτήρων `%s' δεν βρέθηκε"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr ""
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr ""
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
 # src/shred.c:1134
-#: gcc.c:9279
+#: gcc.c:9282
 #, fuzzy, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, fuzzy, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "μη έγκυρη διαμόρφωση συντόμευσης"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "πολύ λίγα ορίσματα"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to procedure"
 msgid "too many arguments to %%:version-compare"
 msgstr "πάρα πολλά ορίσματα στη ρουτίνα"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr ""
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to procedure"
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "πάρα πολλά ορίσματα στη ρουτίνα"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to procedure"
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "πάρα πολλά ορίσματα στη ρουτίνα"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "πολύ λίγα ορίσματα"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "too many arguments to procedure"
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "πάρα πολλά ορίσματα στη ρουτίνα"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr ""
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "πολύ λίγα ορίσματα"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "λάθος αριθμός ορισμάτων"
@@ -18635,9 +18656,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, fuzzy, gcc-internal-format
 msgid "declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -19053,229 +19074,229 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, fuzzy, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr ""
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr ""
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, gcc-internal-format
 msgid "enclosing target region"
 msgstr ""
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr ""
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, gcc-internal-format
 msgid "enclosing task"
 msgstr ""
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "σφάλμα ανάγνωσης %s"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr ""
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE δεν έχει διακυρηχθεί (πρώτη χρήση στη συνάρτηση αυτή)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, gcc-internal-format
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr ""
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
 # src/shred.c:1134
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr ""
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr ""
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr ""
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr ""
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr ""
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr ""
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr ""
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr ""
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr ""
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr ""
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 msgid "invalid private reduction on %qE"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, gcc-internal-format
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr ""
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr ""
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr ""
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr ""
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr ""
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr ""
@@ -19508,7 +19529,7 @@
 
 #: ipa-devirt.c:1229
 #, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr ""
 
 #: ipa-devirt.c:1235
@@ -19608,7 +19629,7 @@
 
 #: ipa-devirt.c:1576
 #, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr ""
 
 #: ipa-devirt.c:1599
@@ -19993,198 +20014,198 @@
 msgid "multiple loop axes specified for routine"
 msgstr ""
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr ""
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, gcc-internal-format
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr ""
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, fuzzy, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr ""
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr ""
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, gcc-internal-format
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, gcc-internal-format
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, gcc-internal-format
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, gcc-internal-format
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr ""
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, gcc-internal-format
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, gcc-internal-format
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr ""
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, gcc-internal-format
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr ""
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, gcc-internal-format
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr ""
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr ""
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr ""
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr ""
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr ""
@@ -20269,7 +20290,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, fuzzy, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "Λείπει παράμετρος για `%s'"
@@ -20427,129 +20448,139 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
 #, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr ""
+
+#: opts.c:1015
+#, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr ""
+
+#: opts.c:1417
+#, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr ""
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr ""
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr ""
 
-#: opts.c:1837
+#: opts.c:1844
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 msgid "HSA has not been enabled during configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr ""
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr ""
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "Μη έγκυρο διάστημα χρόνου `%s'"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 msgid "invalid --param name %qs"
 msgstr "Μη έγκυρο διάστημα χρόνου `%s'"
 
-#: opts.c:2382
+#: opts.c:2389
 #, fuzzy, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "Μη έγκυρο διάστημα χρόνου `%s'"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr ""
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "αυτός είναι ο πρώτος ορισμός"
 
 # src/request.c:806 src/request.c:912
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
 # src/request.c:806 src/request.c:912
-#: opts.c:2533
+#: opts.c:2540
 #, fuzzy, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "Μη αναγνωρίσημο όνομα επιφάνειας `%s'"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr ""
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr ""
 
-#: opts.c:2602
+#: opts.c:2609
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "μη αναγνωρίσημη επιλογή `-%c'"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr ""
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -20888,7 +20919,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr ""
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -21488,12 +21519,12 @@
 msgid "error closing %s: %m"
 msgstr "σφάλμα ανάγνωσης %s"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr ""
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -22404,47 +22435,47 @@
 msgid "in expansion of macro %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr ""
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr ""
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr ""
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr ""
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr ""
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr ""
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr ""
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr ""
@@ -22545,33 +22576,33 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "in a call to built-in function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "Στη συνάρτηση μέλος `%s':"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, gcc-internal-format
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr ""
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, gcc-internal-format
 msgid "within this loop"
 msgstr ""
@@ -22926,11 +22957,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -23897,7 +23928,7 @@
 msgid "type was previously declared %qE"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, gcc-internal-format
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
 msgstr ""
@@ -24180,7 +24211,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr ""
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr ""
@@ -24799,62 +24830,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr ""
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr ""
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr ""
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr ""
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, fuzzy, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr ""
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, fuzzy, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr ""
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr ""
@@ -24956,7 +24987,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr ""
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, fuzzy, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -24986,7 +25017,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr ""
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, fuzzy, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -25001,22 +25032,22 @@
 msgid "%qE is not initialized"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, fuzzy, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "Η λειτουργία δεν επιτρέπεται"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, fuzzy, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "μη έγκυρο όνομα μήνα"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, fuzzy, gcc-internal-format
 msgid "missing increment expression"
 msgstr "παράληψη ορίσματος αρχείου"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, fuzzy, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -25567,8 +25598,8 @@
 msgid "wrong type argument to %s"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr ""
@@ -26236,7 +26267,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
@@ -26397,7 +26428,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr ""
@@ -26724,7 +26755,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
@@ -26804,7 +26835,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr ""
@@ -26891,9 +26922,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
@@ -26979,7 +27010,7 @@
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -27155,234 +27186,234 @@
 msgid "insn addresses not freed"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, fuzzy, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, fuzzy, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr ""
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr ""
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr ""
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr ""
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, fuzzy, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "μη έγκυρη ώρα της μέρας"
@@ -27389,27 +27420,27 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, gcc-internal-format
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr ""
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr ""
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr ""
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr ""
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr ""
@@ -27416,116 +27447,116 @@
 
 # src/getopt1.c:155
 # src/getopt1.c:155
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 msgid "selected fp16 options are incompatible"
 msgstr "επιλογή α\n"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr ""
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr ""
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, fuzzy, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr ""
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, gcc-internal-format
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr ""
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr ""
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr ""
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr ""
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr ""
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr ""
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr ""
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, fuzzy, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, gcc-internal-format
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr ""
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr ""
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr ""
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -27533,72 +27564,77 @@
 msgid "%qE attribute only applies to functions"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, gcc-internal-format
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr ""
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, gcc-internal-format
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr ""
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr ""
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, gcc-internal-format
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr ""
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
 #, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
+#, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr ""
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr ""
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr ""
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr ""
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid fpu for attribute(target(\"%s\"))"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
@@ -27606,13 +27642,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr ""
@@ -27708,163 +27744,174 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr ""
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr ""
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
 #, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
+#, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr ""
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr ""
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr ""
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr ""
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr ""
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr ""
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables in static storage"
 msgstr ""
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr ""
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr ""
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr ""
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr ""
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr ""
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr ""
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr ""
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
+#, fuzzy, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "μη πλήρης εγγραφή"
+
+#: config/avr/avr.c:10160
 #, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr ""
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr ""
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr ""
@@ -28151,12 +28198,12 @@
 msgid "invalid IACC argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr ""
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, fuzzy, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
@@ -28334,7 +28381,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -28464,287 +28511,287 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr ""
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr ""
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr ""
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "το --no-dereference (-h) δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, gcc-internal-format
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, gcc-internal-format
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr ""
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr ""
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, gcc-internal-format
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, gcc-internal-format
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr ""
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, gcc-internal-format
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr ""
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, gcc-internal-format
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr ""
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr ""
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr ""
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr ""
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr ""
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr ""
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, fuzzy, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr ""
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr ""
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr ""
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr ""
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr ""
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr ""
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr ""
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr ""
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr ""
@@ -28751,297 +28798,297 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, fuzzy, gcc-internal-format
 msgid "unsupported size for integer register"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr ""
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr ""
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr ""
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, gcc-internal-format
 msgid "interrupt service routine can't be called directly"
 msgstr ""
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, fuzzy, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, fuzzy, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr ""
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr ""
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, fuzzy, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr ""
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "λάθος συνθηματικό"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr ""
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr ""
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, fuzzy, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "μη έγκυρο δικαίωμα"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, gcc-internal-format
 msgid "interrupt service routine can't have non-void return value"
 msgstr ""
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, gcc-internal-format
 msgid "alternatives not allowed in asm flag output"
 msgstr ""
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "άγνωστο σετ `%s'"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "Η παράμετρος κινητής υποδιαστολής δεν είναι έγκυρη: %s"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr ""
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "Εμφάνιση έκδοσης προγράμματος"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr ""
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -29163,7 +29210,7 @@
 msgid "argument %qd is not a constant"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr ""
@@ -29173,7 +29220,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr ""
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr ""
@@ -29276,7 +29323,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr ""
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, fuzzy, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
@@ -29779,8 +29826,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, fuzzy, gcc-internal-format
 msgid "bad builtin code"
 msgstr "μη έγκυρο μήκος γραμμής: %s"
@@ -30034,27 +30081,27 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -30079,7 +30126,7 @@
 msgid "-g option disabled"
 msgstr "Η λειτουργία NIS+ απέτυχε"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr ""
@@ -30214,157 +30261,157 @@
 msgid "junk at end of #pragma longcall"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, gcc-internal-format
 msgid "vec_mul only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, gcc-internal-format
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, gcc-internal-format
 msgid "vec_adde only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, gcc-internal-format
 msgid "vec_addec only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "η `%s' παίρνει είτε κανένα είτε δύο ορίσματα"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "%s μετατρέπει ακέραιο σε δείκτη χωρίς μετατροπέα"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr ""
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr "Δεν είναι δυνατή η καταχώρηση της υπηρεσίας"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, fuzzy, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, fuzzy, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, fuzzy, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, fuzzy, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
@@ -30371,67 +30418,67 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, gcc-internal-format
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, fuzzy, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr "Εσφαλμένος κώδικας αίτησης"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, fuzzy, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr "Εσφαλμένος κώδικας αίτησης"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, fuzzy, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr "Εσφαλμένος κώδικας αίτησης"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, fuzzy, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "Εσφαλμένος κώδικας αίτησης"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "Εσφαλμένος κώδικας αίτησης"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, gcc-internal-format
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr ""
@@ -30440,515 +30487,520 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, gcc-internal-format
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, gcc-internal-format
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, gcc-internal-format
 msgid "-mvsx-timode might need -mlra"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, gcc-internal-format
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr ""
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr ""
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr ""
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, gcc-internal-format, gfc-internal-format
 msgid "builtin %s only accepts a string argument"
 msgstr ""
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr ""
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, fuzzy, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, fuzzy, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "εσωτερικό σφάλμα στο %s, γραμμή %u"
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr ""
 
 # src/shred.c:1134
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, fuzzy, gcc-internal-format
 msgid "stack frame too large"
 msgstr "%s: το αρχείο είναι πολύ μεγάλο"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr ""
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, gcc-internal-format
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr ""
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr ""
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "μη έγκυρος χρήστης"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr ""
@@ -31136,6 +31188,7 @@
 msgstr ""
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr ""
@@ -31228,7 +31281,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr ""
@@ -31255,7 +31308,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -31276,7 +31329,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -31289,160 +31342,160 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "Ο αριθμός σύνδεσμου είναι έξω από το όριο"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, gcc-internal-format
 msgid "unresolved overloaded builtin"
 msgstr ""
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, gcc-internal-format
 msgid "bad builtin icode"
 msgstr ""
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 msgid "invalid argument %d for builtin %qF"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr ""
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr ""
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr ""
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr ""
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "Το όνομα `%s' είναι άγνωστο\n"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr ""
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "Το servname δεν υποστηρίζεται από το ai_socktype"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware vector support not available on %s"
 msgstr ""
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "Ακατάλληλη εντολή"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr ""
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr ""
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr ""
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, fuzzy, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "%s: ο αριθμός γραμμής πρέπει να είναι μεγαλύτερος από το μηδέν"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr ""
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "το πρώτο όρισμα της `%s' πρέπει να είναι `int'"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -31499,27 +31552,27 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr ""
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr ""
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr ""
 
-#: config/sparc/sparc.c:1425
+#: config/sparc/sparc.c:1541
 #, fuzzy, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -31807,22 +31860,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr ""
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "Η οικογένεια διευθύνσεων δεν υποστηρίζεται από την οικογένεια πρωτοκόλλου"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr ""
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr ""
@@ -31909,7 +31962,7 @@
 msgid "could not read the BRIG file"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -32313,9 +32366,9 @@
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -32448,7 +32501,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr ""
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -33497,7 +33550,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr ""
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr ""
@@ -33637,17 +33690,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr ""
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr ""
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -33697,7 +33750,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, fuzzy, gcc-internal-format
 msgid "expected end of line"
 msgstr "Μη ορισμένο όνομα %s"
@@ -33738,7 +33791,7 @@
 msgstr "άγνωστος χαρακτήρας `%s'"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, fuzzy, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "δημιουργία αρχείου `%s'\n"
@@ -33753,7 +33806,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr ""
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "το `%s' είναι πρόγονος του `%s'"
@@ -33768,8 +33821,8 @@
 msgid "unexpected attribute"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 msgid "%<fallthrough%> attribute not followed by %<;%>"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
@@ -33807,7 +33860,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr ""
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr ""
@@ -33835,7 +33888,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, fuzzy, gcc-internal-format
 msgid "expected string literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
@@ -33899,14 +33952,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, fuzzy, gcc-internal-format
 msgid "expected identifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, fuzzy, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "σκουπίδια στο τέλος του αριθμού"
@@ -34041,7 +34094,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr ""
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr ""
@@ -34066,12 +34119,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr ""
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -34085,17 +34138,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, fuzzy, gcc-internal-format
 msgid "expected statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr ""
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr ""
@@ -34105,7 +34158,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr ""
@@ -34125,7 +34178,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -34301,17 +34354,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr ""
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -34366,61 +34419,61 @@
 msgid "no type or storage class may be specified here,"
 msgstr "Εγγραφή ονομάτων των επιλεγμένων λέξεων-κλειδιών"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, gcc-internal-format
 msgid "unknown property attribute"
 msgstr ""
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr ""
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, gcc-internal-format
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr ""
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr ""
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr ""
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
@@ -34435,12 +34488,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, fuzzy, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "Μη έγκυρη κανονική έκφραση"
@@ -34455,53 +34508,53 @@
 msgid "%qD is not a variable"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 msgid "expected %<none%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr ""
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, gcc-internal-format
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr ""
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 msgid "too many %<if%> clauses"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, gcc-internal-format
 msgid "too many %<if%> clauses without modifier"
 msgstr ""
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -34529,22 +34582,22 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr ""
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, gcc-internal-format
 msgid "expected %<tofrom%>"
 msgstr ""
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr ""
@@ -34554,57 +34607,57 @@
 msgid "%<num_workers%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, fuzzy, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "πάρα πολλά ορίσματα"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, fuzzy, gcc-internal-format
 msgid "unexpected argument"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr ""
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, gcc-internal-format
 msgid "ordered argument needs positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr ""
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, fuzzy, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr ""
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, fuzzy, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "μη έγκυρο δικαίωμα"
@@ -34619,17 +34672,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr ""
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, fuzzy, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr "ειδικά αρχεία μπλοκ δεν υποστηρίζονται"
@@ -34649,17 +34702,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr ""
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "μη έγκυρος χρήστης"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
@@ -34669,67 +34722,67 @@
 msgid "invalid proc_bind kind"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, fuzzy, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr ""
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, gcc-internal-format
 msgid "invalid OpenACC clause at file scope"
 msgstr ""
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, gcc-internal-format
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr ""
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr ""
@@ -34744,7 +34797,7 @@
 msgid "expected function name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a function"
 msgstr "Το `%s' δεν είναι κατάλογος."
@@ -34754,42 +34807,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr ""
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr ""
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr ""
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr ""
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, fuzzy, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "κακοδιαμορφωμένη γραμμή αγνοήθηκε"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr ""
@@ -34799,27 +34852,27 @@
 msgid "expected %<(%> or end of line"
 msgstr ""
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, fuzzy, gcc-internal-format
 msgid "for statement expected"
 msgstr "αναμενόταν ')'\n"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "αναμενόταν ')'\n"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, fuzzy, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -34829,72 +34882,72 @@
 msgid "not enough perfectly nested loops"
 msgstr ""
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr ""
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr ""
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, gcc-internal-format
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr ""
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, gcc-internal-format
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr ""
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr ""
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr ""
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr ""
@@ -34909,7 +34962,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -34919,32 +34972,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr ""
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr ""
@@ -34999,22 +35052,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr ""
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr ""
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr ""
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, fuzzy, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "μη πλήρης εγγραφή"
@@ -35029,52 +35082,52 @@
 msgid "pragma simd must be inside a function"
 msgstr ""
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "%s: ο αριθμός γραμμής πρέπει να είναι μεγαλύτερος από το μηδέν"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr ""
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr ""
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr ""
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr ""
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr ""
@@ -35084,7 +35137,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "Μη ορισμένο όνομα %s"
@@ -35810,7 +35863,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr ""
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr ""
@@ -36138,7 +36191,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr ""
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr ""
@@ -36148,7 +36201,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr ""
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr ""
@@ -36173,7 +36226,7 @@
 msgid "function returns address of label"
 msgstr ""
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr ""
@@ -36188,7 +36241,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr ""
@@ -36208,17 +36261,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr ""
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr ""
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr ""
@@ -36228,7 +36281,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr ""
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr ""
@@ -36334,12 +36387,12 @@
 msgid "used vector type where scalar is required"
 msgstr ""
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr ""
@@ -36349,25 +36402,25 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 msgid "%qE is a member of a union"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -36378,70 +36431,70 @@
 msgstr ""
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr ""
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -36461,7 +36514,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr ""
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "Οι ορισμοί πηγή βρίσκονται στο ΑΡΧΕΙΟ"
@@ -36471,17 +36524,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr ""
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -36501,18 +36554,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr ""
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr ""
@@ -36524,32 +36577,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr ""
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
@@ -36569,55 +36622,55 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr ""
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr ""
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, gcc-internal-format
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr ""
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr ""
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr ""
@@ -36627,32 +36680,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr ""
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, fuzzy, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -37201,69 +37254,69 @@
 msgid "use of multiversioned function without a default"
 msgstr ""
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, fuzzy, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, fuzzy, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr ""
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr ""
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr ""
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr ""
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr ""
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "δεν ταιριάζει συνάρτηση για την κλήση στο %<%T::%s(%A)%#V%>"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%s(%A)%>"
@@ -37271,87 +37324,87 @@
 
 # src/getopt.c:813
 # src/getopt.c:813
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "η κλήση της υπερφορτωμένης %<%s(%A)%> είναι διφορούμενη"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr ""
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr ""
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr ""
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr ""
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr ""
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, fuzzy, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr ""
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, fuzzy, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, gcc-internal-format
 msgid " candidate 1: %q#F"
 msgstr ""
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, gcc-internal-format
 msgid " candidate 2: %q#F"
 msgstr ""
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr ""
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr ""
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, fuzzy, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr ""
@@ -37452,272 +37505,272 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr ""
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr ""
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr ""
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr ""
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr ""
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr ""
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, gcc-internal-format
 msgid "%qD was hidden"
 msgstr ""
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 msgid "  by %qD"
 msgstr "  κατά `%D'"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, gcc-internal-format
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr ""
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, gcc-internal-format
 msgid "private member %q#D in anonymous union"
 msgstr ""
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, gcc-internal-format
 msgid "private member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous union"
 msgstr ""
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, gcc-internal-format
 msgid "protected member %q#D in anonymous struct"
 msgstr ""
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr ""
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, fuzzy, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, fuzzy, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, fuzzy, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "Αρνητικό πλάτος στην αποτίμηση"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, gcc-internal-format
 msgid "width of %qD exceeds its type"
 msgstr ""
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, gcc-internal-format
 msgid "%qD is too small to hold all values of %q#T"
 msgstr ""
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr ""
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, fuzzy, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr ""
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr ""
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr ""
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, fuzzy, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, gcc-internal-format
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr ""
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr ""
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 msgid "field %q#D with same name as class"
 msgstr "Υπάρχει αντικείμενο με το ίδιο όνομα"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr ""
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr ""
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr ""
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, fuzzy, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr ""
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr ""
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr ""
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, gcc-internal-format
 msgid "non-static reference %q#D in class without a constructor"
 msgstr ""
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, gcc-internal-format
 msgid "non-static const member %q#D in class without a constructor"
 msgstr ""
@@ -37724,152 +37777,152 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr ""
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr ""
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, gcc-internal-format
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr ""
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, gcc-internal-format
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr ""
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, gcc-internal-format
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr ""
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 msgid "in the definition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "μη έγκυρη ώρα της μέρας"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, fuzzy, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr ""
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr ""
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr ""
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr ""
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr ""
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, fuzzy, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, fuzzy, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "η μετατροπή από `%s' σε `%s' δεν υποστηρίζετε"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, fuzzy, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr ""
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, fuzzy, gcc-internal-format
 msgid "not enough type information"
 msgstr "εμφάνιση πληροφοριών προόδου"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
@@ -37879,12 +37932,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, fuzzy, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, gcc-internal-format
 msgid "changes meaning of %qD from %q#D"
 msgstr ""
@@ -37914,334 +37967,334 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr ""
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr ""
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr ""
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr ""
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr ""
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr ""
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, fuzzy, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to internal function %qE"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 #| msgid "call to non-function %qD"
 msgid "call to non-constexpr function %qD"
 msgstr "κλήση σε μη-συνάρτηση %qD"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "αυτή είναι η θέση του πρώτου ορισμού"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr ""
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr ""
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr ""
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr ""
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer in %qE"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr ""
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 msgid "dereferencing a null pointer"
 msgstr "Δεν μπορεί να καθοριστεί το όνομα του συστήματος"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, fuzzy, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, fuzzy, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "το `%s' είναι μη-προσπελάσιμο"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr ""
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr ""
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr ""
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr ""
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr ""
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr ""
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr ""
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr ""
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "μη έγκυρο είδος αλφαριθμητικού `%s'"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> is not a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "Μη ορισμένο όνομα %s"
@@ -39042,7 +39095,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr ""
@@ -39057,7 +39110,7 @@
 msgid "%qD is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, fuzzy, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -40696,7 +40749,7 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, fuzzy, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
@@ -41147,13 +41200,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr ""
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
@@ -41165,8 +41218,8 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, fuzzy, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
@@ -41216,7 +41269,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr ""
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, fuzzy, gcc-internal-format
 msgid "previous definition here"
 msgstr "κανένας ορισμός του `UNDEFINED'"
@@ -41280,7 +41333,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr ""
@@ -41295,7 +41348,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr ""
@@ -41453,27 +41506,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "Ο κατάλογος `%s' δεν είναι προσιτός."
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr ""
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr ""
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr ""
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr ""
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr ""
@@ -41482,67 +41535,67 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr ""
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr ""
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr ""
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr ""
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr ""
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr ""
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr ""
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr ""
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr ""
@@ -41551,47 +41604,47 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr ""
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr ""
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, gcc-internal-format
 msgid "inline function %qD used but never defined"
 msgstr ""
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, fuzzy, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "έχουν παραληφθεί ορίσματα"
@@ -41598,12 +41651,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr ""
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, fuzzy, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
@@ -41914,18 +41967,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "Μη έγκυρη ακέραια παράμετρος `%s'"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "η κλάση χαρακτήρων `%s' ορίστηκε ήδη"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, fuzzy, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "δεν είναι δυνατόν να γίνει `stat' το locale αρχείο `%s'"
@@ -42027,7 +42080,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr ""
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
@@ -42047,7 +42100,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, fuzzy, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
@@ -42244,22 +42297,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr ""
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, fuzzy, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "αδυναμία αλλαγής στο κατάλογο %s"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr ""
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, fuzzy, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
@@ -42314,181 +42367,181 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr ""
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr ""
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr ""
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr ""
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr ""
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr ""
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr ""
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr ""
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr ""
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr ""
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr ""
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr ""
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr ""
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr ""
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "μη έγκυρο byte ή λίστα πεδίων"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr ""
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr ""
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr ""
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr ""
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr ""
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr ""
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, fuzzy, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr ""
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr ""
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -42495,7 +42548,7 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, fuzzy, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
@@ -42688,97 +42741,97 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, fuzzy, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, fuzzy, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 msgid "%qD has not been declared within %D"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, gcc-internal-format
 msgid "only here as a friend"
 msgstr ""
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr ""
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr ""
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr ""
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, fuzzy, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr ""
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr ""
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr ""
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr ""
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, fuzzy, gcc-internal-format
 msgid "suggested alternative: %qs"
 msgstr "άγνωστος χαρακτήρας `%s'"
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
@@ -42785,27 +42838,27 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr ""
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr ""
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr ""
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr ""
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr ""
@@ -42825,7 +42878,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -42850,7 +42903,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
@@ -42910,725 +42963,730 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr ""
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, fuzzy, gcc-internal-format
 msgid "invalid template-id"
 msgstr "Μη έγκυρη ημερομηνία `%s'."
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr ""
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, fuzzy, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, fuzzy, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, fuzzy, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, fuzzy, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, fuzzy, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, fuzzy, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr ""
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr ""
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, fuzzy, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, fuzzy, gcc-internal-format
 msgid "expected string-literal"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr ""
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr ""
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr ""
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr "%s: το %s είναι τόσο μεγάλο που δε μπορεί να αναπαρασταθεί"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr "σχετική θέση αρχείου είναι εκτός ορίων"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr ""
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr ""
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr ""
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, fuzzy, gcc-internal-format
 msgid "expected declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 msgid "expected binary operator"
 msgstr "Αγνωστος δυαδικός χειριστής."
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 msgid "expected ..."
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 msgid "binary expression in operand of fold-expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "Λάθος έκφραση στην αποτίμηση (λάθος είσοδος): %s"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, fuzzy, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "Η λειτουργία δεν υποστηρίζεται"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr ""
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr ""
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, fuzzy, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr ""
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, fuzzy, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr ""
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, fuzzy, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, fuzzy, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr ""
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr ""
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr ""
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr ""
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr ""
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr ""
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr ""
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr ""
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr ""
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr ""
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr ""
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr ""
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr ""
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr ""
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, gcc-internal-format
 msgid "expected expression-list or type-id"
 msgstr ""
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr ""
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr ""
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, fuzzy, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "παλαιού είδους θέση"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr ""
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr ""
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr ""
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr ""
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr ""
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "Μη αναγνωρίσιμη μεταβλητή `%s'"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr ""
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr ""
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr ""
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not support lambda templates"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, fuzzy, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 msgid "duplicate %<mutable%>"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr ""
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, fuzzy, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr ""
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr ""
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr ""
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, fuzzy, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr ""
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr ""
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr ""
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr ""
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, fuzzy, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr ""
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr ""
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr ""
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr ""
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, fuzzy, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr ""
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr ""
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, fuzzy, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr ""
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, gcc-internal-format
 msgid "types may not be defined in a for-range-declaration"
 msgstr ""
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, fuzzy, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr "πολλαπλός αριθμός επιλογών την εντολή `s'"
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 msgid "empty decomposition declaration"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+msgid "invalid initializer for structured binding declaration"
+msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr ""
@@ -43635,220 +43693,220 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr ""
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr ""
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 msgid "%qD invalid in lambda"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr ""
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr ""
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr ""
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr ""
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr ""
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr ""
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, fuzzy, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr ""
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr ""
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr ""
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr ""
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr ""
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, fuzzy, gcc-internal-format
 msgid "expected operator"
 msgstr "Μη ορισμένο όνομα %s"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr ""
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, fuzzy, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, fuzzy, gcc-internal-format
 msgid "expected template-id"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, fuzzy, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr ""
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr ""
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, fuzzy, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, fuzzy, gcc-internal-format
 msgid "expected template-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr ""
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr ""
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr ""
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, fuzzy, gcc-internal-format
 msgid "expected template-argument"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr ""
@@ -43855,258 +43913,258 @@
 
 # src/dfa.c:962
 # src/dfa.c:970
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "Δεν ορίστηκε συντακτικό"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr ""
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, fuzzy, gcc-internal-format
 msgid "expected type-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr ""
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, fuzzy, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, fuzzy, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr ""
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, fuzzy, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 msgid "unnamed scoped enum is not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr ""
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr ""
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, fuzzy, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr ""
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, fuzzy, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, fuzzy, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr ""
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr ""
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr ""
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, fuzzy, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, gcc-internal-format
 msgid "a nested namespace definition cannot have attributes"
 msgstr ""
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, gcc-internal-format
 msgid "a nested namespace definition cannot be inline"
 msgstr ""
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, gcc-internal-format
 msgid "nested identifier required"
 msgstr ""
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 msgid "namespace %qD entered"
 msgstr "άγνωστο σετ `%s'"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, fuzzy, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr ""
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr ""
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr ""
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr ""
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, fuzzy, gcc-internal-format
 msgid "expected initializer"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, fuzzy, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "Δεν ήταν δυνατή η εύρεση ετικέττας για μεταγωγή στο `%s'"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr ""
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, fuzzy, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, fuzzy, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, fuzzy, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, fuzzy, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr ""
@@ -44115,7 +44173,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, fuzzy, gcc-internal-format
 msgid "invalid declarator"
 msgstr "μη έγκυρος χρήστης"
@@ -44122,337 +44180,337 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "Μη έγκυρη ανταλλαγή"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, fuzzy, gcc-internal-format
 msgid "expected declarator"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, fuzzy, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, fuzzy, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, gcc-internal-format
 msgid "%E requires %<-fgnu-tm%>"
 msgstr ""
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "διπλός αριθμός μηνύματος"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, fuzzy, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr ""
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr ""
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr ""
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, fuzzy, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "ο διαχωριστής δε μπορεί να είναι κενός"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "Δεν μπορεί να τεθεί η ημερομηνία."
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr ""
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr ""
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, fuzzy, gcc-internal-format
 msgid "expected class-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr ""
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, fuzzy, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "δε βρέθηκε ο προεπεξεργαστής C: %s \n"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr ""
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, fuzzy, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr ""
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, fuzzy, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr ""
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 msgid "previous definition of %q#T"
 msgstr "κανένας ορισμός του `UNDEFINED'"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr ""
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, fuzzy, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "συντακτικό σφάλμα στον ορισμό κλάσης χαρακτήρων"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr ""
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "αδυναμία εισαγωγής στοιχείο παραβολής `%.*s'"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr ""
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr ""
 
-#: cp/parser.c:23680
+#: cp/parser.c:23703
 #, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr ""
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr ""
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr ""
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr ""
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr ""
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr ""
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr ""
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr ""
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr ""
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 msgid "expected attribute before %<...%>"
 msgstr "Κακή αίτηση παραμέτρων"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr ""
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr ""
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr ""
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, fuzzy, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, fuzzy, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
@@ -44461,262 +44519,262 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr ""
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, fuzzy, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr ""
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr ""
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 msgid "empty introduction-list"
 msgstr "κενό αλφαριθμητικό"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, fuzzy, gcc-internal-format
 msgid "no matching concept for template-introduction"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr ""
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr ""
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, fuzzy, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, gcc-internal-format
 msgid "a class template declaration must not declare anything else"
 msgstr ""
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, fuzzy, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "προηγούμενη αυτονόητη διακύρηξη του `%s'"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr ""
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr ""
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "αρχεία fifo δεν υποστηρίζονται"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "μη έγκυρος δηλωτής πεδίου: `%s'"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "διπλό κλειδί"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, fuzzy, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, fuzzy, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, fuzzy, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, fuzzy, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr ""
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, fuzzy, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, fuzzy, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr ""
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, fuzzy, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, fuzzy, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, fuzzy, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, fuzzy, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, fuzzy, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr ""
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, fuzzy, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr ""
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, fuzzy, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr ""
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr ""
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr ""
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr ""
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, fuzzy, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr ""
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, fuzzy, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, fuzzy, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "Μη ορισμένο όνομα %s"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr ""
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr ""
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, fuzzy, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "Μη έγκυρη επιλογή `%s'"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr ""
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr ""
@@ -44723,229 +44781,229 @@
 
 # src/grep.c:785 src/grep.c:792
 # src/grep.c:1060 src/grep.c:1067 src/grep.c:1076
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, fuzzy, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "μη έγκυρο όρισμα μήκους περιεχομένου"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr ""
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr ""
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr ""
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr ""
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr ""
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr ""
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "συμβολικοί σύνδεσμοι δεν υποστηρίζονται στο σύστημα αυτό"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr ""
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "Ακατάλληλη τιμή στο ai_flags"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, fuzzy, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "Προσδιοριστής αφαιρέθηκε"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr ""
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "Μη έγκυρη παράμετρος"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr ""
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, fuzzy, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr ""
 
 # src/request.c:263
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "Το βήμα αρχικοποίησης απέτυχε"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr ""
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr ""
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "μη έγκυρο μέγεθος οριζόντιου στηλοθέτη: %s"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "Μη έγκυρη προπορευόμενη κανονική έκφραση"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr ""
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr ""
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, fuzzy, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "μη τερματιζόμενo αλφαριθμητικό"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr ""
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, fuzzy, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 msgid "expected variable-name"
 msgstr "%s: αναμενόταν αριθμητική τιμή."
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr ""
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr ""
@@ -45037,7 +45095,7 @@
 msgid "candidate is: %#D"
 msgstr "αδυναμία ανοίγματος του `%s'"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, gcc-internal-format
 msgid "%s %#D"
 msgstr ""
@@ -45613,122 +45671,137 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
 #, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6634
+#, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr ""
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
+
+#: cp/pt.c:6672
+#, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr ""
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr ""
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr ""
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr ""
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "μη έγκυρος αριθμός από γραμμές"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr ""
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr ""
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, fuzzy, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, fuzzy, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, fuzzy, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, fuzzy, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 msgid "  expected %qD but got %qD"
 msgstr "%s: αναμενόταν ακέραιος μετά το `%c'"
@@ -45735,102 +45808,102 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr ""
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "λάθος αριθμός ορισμάτων"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, gcc-internal-format
 msgid "provided for %qD"
 msgstr ""
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr ""
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr ""
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr ""
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, fuzzy, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "μη έγκυρος αριθμός από κενές γραμμές: `%s'"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 msgid "template constraint failure"
 msgstr "εσωτερικό σφάλμα gcc"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr ""
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr ""
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
@@ -45848,271 +45921,271 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, fuzzy, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "μη πλήρης εγγραφή"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, fuzzy, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "Μη έγκυρη προτεραιότητα `%s'"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, fuzzy, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr ""
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr ""
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr ""
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, fuzzy, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, fuzzy, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, fuzzy, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr ""
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr ""
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr ""
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr ""
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr ""
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, fuzzy, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "έχει παραληφθεί η λίστα με τα πεδία"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, fuzzy, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr ""
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr ""
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr ""
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr ""
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "Το επώνυμο αντικείμενο δεν είναι αναζητήσιμο"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, fuzzy, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 msgid "%qT is/uses unnamed type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, fuzzy, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "Η παράμετρος `%s' δεν είναι έγκυρη."
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr ""
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, fuzzy, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, fuzzy, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 msgid "%s %#S"
 msgstr ""
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, fuzzy, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "Ο έλεγχος μονοπατιού για το `%s' βρήκε `%s'"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, fuzzy, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr ""
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "αδυναμία ανοίγματος αρχείου ορισμού locale `%s'"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr ""
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr ""
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, fuzzy, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "διπλός ορισμός συνόλου"
@@ -46124,92 +46197,92 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr ""
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr ""
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "Μη έγκυρος χαρακτήρας παραβολής"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr ""
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 msgid "non-class template %qT used without template arguments"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "έχουν παραληφθεί ορίσματα"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "Η λειτουργία δεν έχει υλοποιηθεί"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "Δεν μπόρεσα να ανοίξω το αρχείο %s"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, gcc-internal-format
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr ""
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, gcc-internal-format
 msgid "deduced expression type does not satisfy placeholder constraints"
 msgstr ""
@@ -46368,201 +46441,201 @@
 msgid "  since %q+#D declared in base class"
 msgstr "Δεν υπάρχει προηγούμενη κανονική έκφραση"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr ""
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr ""
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr ""
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, fuzzy, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "%s: οι τιμές του πεδίου `%s' δεν πρέπει να είναι μεγαλύτερες από %d"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, fuzzy, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "η `%s' είναι συνήθως μη-στατική συνάρτηση"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "μη έγκυρος αριθμός πεδίου: `%s'"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "μη έγκυρος χρήστης"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr ""
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr ""
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, fuzzy, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr ""
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr ""
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr ""
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, fuzzy, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr ""
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, fuzzy, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "μη έγκυρος αριθμός αρχείου στη δήλωση πεδίου: `%s'"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, fuzzy, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr ""
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, fuzzy, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr ""
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr ""
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr ""
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr ""
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr ""
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, fuzzy, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, fuzzy, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr ""
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, fuzzy, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr ""
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr ""
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr ""
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, fuzzy, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "μη έγκυρος αριθμός από στήλες: `%s'"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
@@ -46569,267 +46642,267 @@
 
 # src/getopt.c:628
 # src/getopt.c:628
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "%s: η επιλογή `%s' είναι ασαφής\n"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr ""
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, gcc-internal-format
 msgid "%qE has const type for %<reduction%>"
 msgstr ""
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr ""
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr ""
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "Λάθος έκφραση στην αποτίμηση: %s"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr ""
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr ""
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%s' δεν είναι ισχύων θετικός ακέραιος."
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 msgid "template %qE in clause %qs"
 msgstr "αποτυχία κατά την εγγραφή δεδομένων για την κατηγορία `%s'"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr ""
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr ""
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr ""
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr ""
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr ""
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr ""
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr ""
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, gcc-internal-format
 msgid "static assertion failed"
 msgstr ""
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr ""
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr ""
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, fuzzy, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "Η παράμετρος στο <%s> πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr ""
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, gcc-internal-format
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr ""
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "Λείπει παράμετρος για `%s'"
@@ -46844,107 +46917,107 @@
 msgid "lambda-expression in a constant expression"
 msgstr "%s: μη έγκυρη κανονική έκφραση: %s"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr ""
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, gcc-internal-format
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr ""
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr ""
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr ""
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr ""
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr ""
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "προειδοποίηση: το --pid=PID δεν υποστηρίζεται σε αυτό το σύστημα"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "μη τερματιζμένο αλφαριθμητικό σταθεράς"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "Η παράμετρος στο `%s' πρέπει να είναι ένας απλός χαρακτήρας"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "Το `%s' δεν είναι κατάλογος."
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "το `%s' είναι πρόγονος του `%s'"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "%s: διπλός ορισμός έκδοσης κατηγορίας"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "διπλός ορισμός συνόλου"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr ""
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr ""
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "αδυναμία ανάγνωσης κεφαλίδας από το `%s'"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "η τιμή για το %s πρέπει να είναι ακέραιος"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr ""
@@ -47627,102 +47700,102 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "μη έγκυρος χαρακτήρας `%c' στο τύπο αλφαριθμητικού `%s'"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, fuzzy, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "δεν είναι δυνατό να δημιουργηθεί το %s `%s' στο `%s'"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "η επιστρεφόμενη τιμή της `%s' δεν είναι `int'"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr ""
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 msgid "in passing argument %P of %qD"
 msgstr "Λείπει παράμετρος για `%s'"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, fuzzy, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "xdr_reference: η μνήμη εξαντλήθηκε\n"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr ""
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, gcc-internal-format
 msgid "reference to local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, gcc-internal-format
 msgid "address of local variable %qD returned"
 msgstr ""
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr ""
@@ -47729,55 +47802,55 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr ""
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr ""
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, fuzzy, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "έχει παραληφθεί το αρχείο προορισμού"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr ""
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, gcc-internal-format
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr ""
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, fuzzy, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "`return' χωρίς τιμή, σε συνάρτηση που επιστρέφει μη-κενό"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr ""
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr ""
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr ""
@@ -51741,87 +51814,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr ""
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr ""
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr ""
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr ""
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr ""
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr ""
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr ""
@@ -52009,12 +52082,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr ""
@@ -52792,509 +52865,524 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr ""
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr ""
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr "(χωρίς περιγραφή)"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr ""
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, gcc-internal-format, gfc-internal-format
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing positive width after L descriptor at %L"
 msgstr ""
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "repeated leap second moment"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr ""
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "άγνωστο πρόθεμα: %s"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "άγνωστο πρόθεμα: %s"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr ""
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "Έχει παραληφθεί εντολή"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "Η αλυσίδα μορφής δεν είναι έγκυρη: `%s'"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr ""
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr ""
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr ""
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "Ελλιπής ή κακοσχηματισμένη ιδιότητα"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "Μη έγκυρη ρύθμιση θύρας (port)"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr ""
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr ""
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr ""
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr ""
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "δεν είστε μέλος της ομάδας `%s'"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr ""
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr ""
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr ""
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr ""
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr ""
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr ""
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr ""
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr ""
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr ""
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr ""
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr ""
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr ""
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr ""
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr ""
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr ""
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format with default unit at %C"
 msgstr ""
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr ""
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "διπλό όνομα χαρακτήρα `%s'"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr ""
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr ""
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "μη ορισμένο"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr ""
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr ""
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr ""
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr ""
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr ""
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr ""
+
+#: fortran/io.c:3317
+#, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr ""
+
+#: fortran/io.c:3328
 #, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr ""
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "συντακτικό σφάλμα στον καθορισμό σειράς"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr ""
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "Μη έγκυρη κανονική έκφραση"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "syntax error at %qs token"
 msgid "Syntax error in %s statement at %C"
 msgstr "συντακτικό σφάλμα στο σύμβολο %qs"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr ""
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr ""
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr ""
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr ""
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr ""
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr ""
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr ""
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr ""
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr ""
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr ""
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr ""
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr ""
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr ""
@@ -54193,252 +54281,252 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr ""
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr ""
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr ""
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "δημιουργία αρχείου `%s'\n"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr ""
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr ""
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr ""
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "%s: Σφάλμα κατά την εγγραφή του %s\n"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr ""
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr ""
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr ""
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr ""
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "%s: Σφάλμα εγγραφής "
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "%s: Σφάλμα κατά την εγγραφή του %s\n"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s: Δεν είναι δυνατόν να δημιουργηθεί %s: %s\n"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "%s: Προειδοποίηση: η uname απέτυχε: %s\n"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "%s: Δε μπορεί να διαγραφεί το %s: %s\n"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr ""
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr ""
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr ""
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr ""
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr ""
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr ""
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr ""
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr ""
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr ""
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr ""
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr ""
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr ""
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr ""
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr ""
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "%s: Δεν είναι δυνατόν να ανοιχτεί το %s: %s\n"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr ""
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr ""
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, gcc-internal-format, gfc-internal-format
 msgid "Can't USE the same %smodule we're building!"
 msgstr ""
@@ -56816,7 +56904,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr ""
@@ -58306,447 +58394,437 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr ""
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr ""
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr ""
-
-#: fortran/resolve.c:13924
-#, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr ""
-
-#: fortran/resolve.c:13942
-#, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr ""
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr ""
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr ""
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr ""
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr ""
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr ""
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr ""
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr ""
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr ""
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr ""
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr ""
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr ""
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr ""
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr ""
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr ""
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr ""
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr ""
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr ""
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr ""
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr ""
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr ""
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, gcc-internal-format
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr ""
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr ""
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr ""
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr ""
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr ""
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr ""
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr ""
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr ""
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "το `%s' δεν είναι κανονικό αρχείο"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr ""
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr ""
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr ""
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr ""
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr ""
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr ""
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr ""
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr ""
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr ""
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr ""
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr ""
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr ""
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr ""
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr ""
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr ""
@@ -59832,12 +59910,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr ""
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr ""
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr ""
Index: gcc/po/zh_CN.po
===================================================================
--- gcc/po/zh_CN.po	(.../tags/gcc_7_2_0_release)
+++ gcc/po/zh_CN.po	(.../branches/gcc-7-branch)
@@ -32,7 +32,7 @@
 msgstr ""
 "Project-Id-Version: gcc 6.1.0\n"
 "Report-Msgid-Bugs-To: https://gcc.gnu.org/bugs/\n"
-"POT-Creation-Date: 2017-05-01 22:24+0000\n"
+"POT-Creation-Date: 2017-08-04 22:17+0000\n"
 "PO-Revision-Date: 2016-04-30 17:13-0400\n"
 "Last-Translator: Mingye Wang (Arthur2e5) <arthur200126@gmail.com>\n"
 "Language-Team: Chinese (simplified) <i18n-zh@googlegroups.com>\n"
@@ -218,13 +218,13 @@
 #. TARGET_PRINT_OPERAND must handle them.
 #. We can't handle floating point constants;
 #. PRINT_OPERAND must handle them.
-#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17057
+#: final.c:3988 config/arc/arc.c:5068 config/i386/i386.c:17063
 #: config/pdp11/pdp11.c:1698
 #, c-format
 msgid "floating constant misused"
 msgstr "错误地使用了浮点常量"
 
-#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17155
+#: final.c:4046 config/arc/arc.c:5165 config/i386/i386.c:17161
 #: config/pdp11/pdp11.c:1739
 #, c-format
 msgid "invalid expression as operand"
@@ -502,62 +502,62 @@
 "以 -g、-f、-m、-O、-W 或 --param 开头的选项将由 %s 自动传递给其调用的\n"
 " 不同子进程。若要向这些进程传递其他选项，必须使用 -W<字母> 选项。\n"
 
-#: gcc.c:5934
+#: gcc.c:5937
 #, c-format
 msgid "Processing spec (%s), which is '%s'\n"
 msgstr "处理 spec (%s)，即‘%s’\n"
 
-#: gcc.c:6638
+#: gcc.c:6641
 #, c-format
 msgid "Target: %s\n"
 msgstr "目标：%s\n"
 
-#: gcc.c:6639
+#: gcc.c:6642
 #, c-format
 msgid "Configured with: %s\n"
 msgstr "配置为：%s\n"
 
-#: gcc.c:6653
+#: gcc.c:6656
 #, c-format
 msgid "Thread model: %s\n"
 msgstr "线程模型：%s\n"
 
-#: gcc.c:6664
+#: gcc.c:6667
 #, c-format
 msgid "gcc version %s %s\n"
 msgstr "gcc 版本 %s %s\n"
 
-#: gcc.c:6667
+#: gcc.c:6670
 #, c-format
 msgid "gcc driver version %s %sexecuting gcc version %s\n"
 msgstr "版本为 %s %s的 gcc 驱动程序，执行版本为 %s 的 gcc\n"
 
-#: gcc.c:6740 gcc.c:6952
+#: gcc.c:6743 gcc.c:6955
 #, c-format
 msgid "The bug is not reproducible, so it is likely a hardware or OS problem.\n"
 msgstr "此 bug 不可重现，可能是硬件或操作系统问题。\n"
 
-#: gcc.c:6876
+#: gcc.c:6879
 #, c-format
 msgid "Preprocessed source stored into %s file, please attach this to your bugreport.\n"
 msgstr "预处理后的源码储存于文件 %s，请将其附在错误报告内。\n"
 
-#: gcc.c:7829
+#: gcc.c:7832
 #, c-format
 msgid "install: %s%s\n"
 msgstr "安装：%s%s\n"
 
-#: gcc.c:7832
+#: gcc.c:7835
 #, c-format
 msgid "programs: %s\n"
 msgstr "程序：%s\n"
 
-#: gcc.c:7834
+#: gcc.c:7837
 #, c-format
 msgid "libraries: %s\n"
 msgstr "库：%s\n"
 
-#: gcc.c:7951
+#: gcc.c:7954
 #, c-format
 msgid ""
 "\n"
@@ -566,16 +566,16 @@
 "\n"
 "报告程序缺陷的步骤请参见：\n"
 
-#: gcc.c:7967 gcov-tool.c:528
+#: gcc.c:7970 gcov-tool.c:528
 #, c-format
 msgid "%s %s%s\n"
 msgstr "%s %s%s\n"
 
-#: gcc.c:7970 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
+#: gcc.c:7973 gcov-tool.c:530 gcov.c:689 fortran/gfortranspec.c:280
 msgid "(C)"
 msgstr "©"
 
-#: gcc.c:7971 fortran/gfortranspec.c:281
+#: gcc.c:7974 fortran/gfortranspec.c:281
 msgid ""
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
@@ -584,7 +584,7 @@
 "本程序是自由软件；请参看源代码的版权声明。本软件没有任何担保；\n"
 "包括没有适销性和某一专用目的下的适用性担保。\n"
 
-#: gcc.c:8276
+#: gcc.c:8279
 #, c-format
 msgid ""
 "\n"
@@ -597,7 +597,7 @@
 "=========\n"
 "\n"
 
-#: gcc.c:8277
+#: gcc.c:8280
 #, c-format
 msgid ""
 "Use \"-Wl,OPTION\" to pass \"OPTION\" to the linker.\n"
@@ -606,7 +606,7 @@
 "使用“-Wl,选项”将“选项”传递给链接器。\n"
 "\n"
 
-#: gcc.c:9580
+#: gcc.c:9583
 #, c-format
 msgid ""
 "Assembler options\n"
@@ -617,7 +617,7 @@
 "=========\n"
 "\n"
 
-#: gcc.c:9581
+#: gcc.c:9584
 #, c-format
 msgid ""
 "Use \"-Wa,OPTION\" to pass \"OPTION\" to the assembler.\n"
@@ -631,16 +631,16 @@
 msgid "  merge [options] <dir1> <dir2>         Merge coverage file contents\n"
 msgstr "  merge [选项] <目录1> <目录2>           合并测试覆盖率文件内容\n"
 
-#: gcov-tool.c:176 gcov-tool.c:270 gcov-tool.c:420
+#: gcov-tool.c:176 gcov-tool.c:271
 #, c-format
+msgid "    -o, --output <dir>                  Output directory\n"
+msgstr "    -o, --output <dir>                  输出目录\n"
+
+#: gcov-tool.c:177 gcov-tool.c:273 gcov-tool.c:425
+#, c-format
 msgid "    -v, --verbose                       Verbose mode\n"
 msgstr "    -v, --verbo      se                 输出更多信息\n"
 
-#: gcov-tool.c:177 gcov-tool.c:271
-#, c-format
-msgid "    -o, --output <dir>                  Output directory\n"
-msgstr "    -o, --output <dir>                  输出目录\n"
-
 #: gcov-tool.c:178
 #, c-format
 msgid "    -w, --weight <w1,w2>                Set weights (float point values)\n"
@@ -656,17 +656,17 @@
 msgid "  rewrite [options] <dir>               Rewrite coverage file contents\n"
 msgstr "  rewrite [选项] <目录>                  覆写测试覆盖率文件内容\n"
 
+#: gcov-tool.c:270
+#, fuzzy, c-format
+#| msgid "    -n, --normalize <long long>         Normalize the profile\n"
+msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
+msgstr "    -n, --normalize <long long>         归一化配置\n"
+
 #: gcov-tool.c:272
 #, c-format
 msgid "    -s, --scale <float or simple-frac>  Scale the profile counters\n"
 msgstr "    -s, --scale <浮点数或分数>            按比例缩放配置计数器\n"
 
-#: gcov-tool.c:273
-#, fuzzy, c-format
-#| msgid "    -n, --normalize <long long>         Normalize the profile\n"
-msgid "    -n, --normalize <int64_t>           Normalize the profile\n"
-msgstr "    -n, --normalize <long long>         归一化配置\n"
-
 #: gcov-tool.c:290
 #, c-format
 msgid "Rewrite subcommand usage:"
@@ -692,27 +692,27 @@
 msgid "  overlap [options] <dir1> <dir2>       Compute the overlap of two profiles\n"
 msgstr " overlap [选项] <目录1> <目录2>          计算两个配置文件的重叠\n"
 
-#: gcov-tool.c:421
+#: gcov-tool.c:420
 #, c-format
-msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
-msgstr "    -h, --hotonly                       只打印热对象/函数的信息\n"
-
-#: gcov-tool.c:422
-#, c-format
 msgid "    -f, --function                      Print function level info\n"
 msgstr "    -f, --function                      打印函数级信息\n"
 
-#: gcov-tool.c:423
+#: gcov-tool.c:421
 #, c-format
 msgid "    -F, --fullname                      Print full filename\n"
 msgstr "    -F, --fullname                      打印全名\n"
 
-#: gcov-tool.c:424
+#: gcov-tool.c:422
 #, c-format
+msgid "    -h, --hotonly                       Only print info for hot objects/functions\n"
+msgstr "    -h, --hotonly                       只打印热对象/函数的信息\n"
+
+#: gcov-tool.c:423
+#, c-format
 msgid "    -o, --object                        Print object level info\n"
 msgstr "    -o, --object                        打印对象级信息\n"
 
-#: gcov-tool.c:425
+#: gcov-tool.c:424
 #, fuzzy, c-format
 msgid "    -t <float>, --hot_threshold <float> Set the threshold for hotness\n"
 msgstr "-t <浮点数>, --hot_threshold <浮点数> 设置热阈值"
@@ -802,20 +802,15 @@
 
 #: gcov.c:658
 #, c-format
-msgid "  -h, --help                      Print this help, then exit\n"
-msgstr "  -h, --help                      打印此帮助并退出\n"
-
-#: gcov.c:659
-#, c-format
 msgid "  -a, --all-blocks                Show information for every basic block\n"
 msgstr "  -a, --all-blocks                显示每个基本块的信息\n"
 
-#: gcov.c:660
+#: gcov.c:659
 #, c-format
 msgid "  -b, --branch-probabilities      Include branch probabilities in output\n"
 msgstr "  -b, --branch-probabilities      输出包含分支概率\n"
 
-#: gcov.c:661
+#: gcov.c:660
 #, c-format
 msgid ""
 "  -c, --branch-counts             Output counts of branches taken\n"
@@ -822,16 +817,21 @@
 "                                    rather than percentages\n"
 msgstr "  -c, --branch-counts             给出跳转的分支数，而不是百分比\n"
 
-#: gcov.c:663
+#: gcov.c:662
 #, c-format
 msgid "  -d, --display-progress          Display progress information\n"
 msgstr "  -d, --display-progress          显示进度信息\n"
 
-#: gcov.c:664
+#: gcov.c:663
 #, c-format
 msgid "  -f, --function-summaries        Output summaries for each function\n"
 msgstr "  -f, --function-summaries        输出每个函数的小结信息\n"
 
+#: gcov.c:664
+#, c-format
+msgid "  -h, --help                      Print this help, then exit\n"
+msgstr "  -h, --help                      打印此帮助并退出\n"
+
 #: gcov.c:665
 #, c-format
 msgid "  -i, --intermediate-format       Output .gcov file in intermediate text format\n"
@@ -1015,82 +1015,82 @@
 msgid "%s:graph is unsolvable for '%s'\n"
 msgstr "%s：图为‘%s’不可解\n"
 
-#: gcov.c:2002
+#: gcov.c:2009
 #, c-format
 msgid "Lines executed:%s of %d\n"
 msgstr "已执行的行数：%s (共 %d 行)\n"
 
-#: gcov.c:2005
+#: gcov.c:2012
 #, c-format
 msgid "No executable lines\n"
 msgstr "没有可执行行\n"
 
-#: gcov.c:2013
+#: gcov.c:2020
 #, c-format
 msgid "%s '%s'\n"
 msgstr "%s‘%s’\n"
 
-#: gcov.c:2020
+#: gcov.c:2027
 #, c-format
 msgid "Branches executed:%s of %d\n"
 msgstr "执行的分支：%s (共有 %d 个)\n"
 
-#: gcov.c:2024
+#: gcov.c:2031
 #, c-format
 msgid "Taken at least once:%s of %d\n"
 msgstr "至少执行一次的跳转：%s(总数为 %d)\n"
 
-#: gcov.c:2030
+#: gcov.c:2037
 #, c-format
 msgid "No branches\n"
 msgstr "没有跳转\n"
 
-#: gcov.c:2032
+#: gcov.c:2039
 #, c-format
 msgid "Calls executed:%s of %d\n"
 msgstr "执行的调用：%s (共 %d)\n"
 
-#: gcov.c:2036
+#: gcov.c:2043
 #, c-format
 msgid "No calls\n"
 msgstr "没有调用\n"
 
-#: gcov.c:2317
+#: gcov.c:2324
 #, c-format
 msgid "%s:no lines for '%s'\n"
 msgstr "%s：‘%s’没有行\n"
 
-#: gcov.c:2419
+#: gcov.c:2426
 #, c-format
 msgid "call   %2d returned %s\n"
 msgstr "call   %2d 返回了 %s\n"
 
-#: gcov.c:2424
+#: gcov.c:2431
 #, c-format
 msgid "call   %2d never executed\n"
 msgstr "call   %2d 从未被执行\n"
 
-#: gcov.c:2429
+#: gcov.c:2436
 #, c-format
 msgid "branch %2d taken %s%s\n"
 msgstr "branch %2d 被执行 %s%s\n"
 
-#: gcov.c:2434
+#: gcov.c:2441
 #, c-format
 msgid "branch %2d never executed\n"
 msgstr "branch %2d 从未被执行\n"
 
-#: gcov.c:2439
+#: gcov.c:2446
 #, c-format
 msgid "unconditional %2d taken %s\n"
 msgstr "unconditional %2d 被执行 %s\n"
 
-#: gcov.c:2442
+#: gcov.c:2449
 #, c-format
 msgid "unconditional %2d never executed\n"
 msgstr "无条件 %2d 从未执行\n"
 
-#: gcov.c:2512
+#: gcov.c:2519
 #, c-format
 msgid "Cannot open source file %s\n"
 msgstr "无法打开源文件 %s\n"
@@ -1197,90 +1197,90 @@
 msgid "Uses of this option are diagnosed."
 msgstr "对此选项的使用将被诊断。"
 
-#: opts.c:1096
+#: opts.c:1103
 #, c-format
 msgid "default %d minimum %d maximum %d"
 msgstr "默认 %d 最小 %d 最大 %d"
 
-#: opts.c:1163
+#: opts.c:1170
 #, c-format
 msgid "Same as %s.  Use the latter option instead."
 msgstr "与 %s相同。请用后者替代。"
 
-#: opts.c:1171
+#: opts.c:1178
 #, c-format
 msgid "%s  Same as %s."
 msgstr "%s  与 %s 相同。"
 
-#: opts.c:1242
+#: opts.c:1249
 msgid "[default]"
 msgstr "[默认]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[enabled]"
 msgstr "[启用]"
 
-#: opts.c:1253
+#: opts.c:1260
 msgid "[disabled]"
 msgstr "[禁用]"
 
-#: opts.c:1272
+#: opts.c:1279
 #, c-format
 msgid " No options with the desired characteristics were found\n"
 msgstr " 找不到具有指定特性的选项\n"
 
-#: opts.c:1281
+#: opts.c:1288
 #, fuzzy, c-format
 #| msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end\n"
 msgid " None found.  Use --help=%s to show *all* the options supported by the %s front-end.\n"
 msgstr " 找不到对应的选项。使用 --help=%s 显示 %s 前端所支持的所有选项\n"
 
-#: opts.c:1287
+#: opts.c:1294
 #, c-format
 msgid " All options with the desired characteristics have already been displayed\n"
 msgstr " 所有具有指定特性的选项已被显示\n"
 
-#: opts.c:1372
+#: opts.c:1379
 msgid "The following options are target specific"
 msgstr "下列选项与特定目标机相关"
 
-#: opts.c:1375
+#: opts.c:1382
 msgid "The following options control compiler warning messages"
 msgstr "下列选项控制编译器警告信息"
 
-#: opts.c:1378
+#: opts.c:1385
 msgid "The following options control optimizations"
 msgstr "下列选项控制优化"
 
-#: opts.c:1381 opts.c:1420
+#: opts.c:1388 opts.c:1427
 msgid "The following options are language-independent"
 msgstr "下列选项与具体语言无关"
 
-#: opts.c:1384
+#: opts.c:1391
 msgid "The --param option recognizes the following as parameters"
 msgstr "--param 选项可接受以下参数"
 
-#: opts.c:1390
+#: opts.c:1397
 msgid "The following options are specific to just the language "
 msgstr "下列选项只与特定语言相关 "
 
-#: opts.c:1392
+#: opts.c:1399
 msgid "The following options are supported by the language "
 msgstr "下列选项被语言支持"
 
-#: opts.c:1403
+#: opts.c:1410
 msgid "The following options are not documented"
 msgstr "下列选项未列入文档"
 
-#: opts.c:1405
+#: opts.c:1412
 msgid "The following options take separate arguments"
 msgstr "下列选项带分立的参数"
 
-#: opts.c:1407
+#: opts.c:1414
 msgid "The following options take joined arguments"
 msgstr "下列选项带联合的参数"
 
-#: opts.c:1418
+#: opts.c:1425
 msgid "The following options are language-related"
 msgstr "下列选项与语言相关"
 
@@ -2928,8 +2928,8 @@
 msgid "<command-line>"
 msgstr "<命令行>"
 
-#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21832 config/arm/arm.c:21845
-#: config/arm/arm.c:21870 config/nios2/nios2.c:2653
+#: config/aarch64/aarch64.c:4927 config/arm/arm.c:21821 config/arm/arm.c:21834
+#: config/arm/arm.c:21859 config/nios2/nios2.c:2653
 #, fuzzy, c-format
 msgid "Unsupported operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
@@ -2948,7 +2948,7 @@
 msgid "incompatible floating point / vector register operand for '%%%c'"
 msgstr ""
 
-#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22377
+#: config/aarch64/aarch64.c:5103 config/arm/arm.c:22366
 #, c-format
 msgid "missing operand"
 msgstr "缺少操作数"
@@ -2968,8 +2968,8 @@
 msgid "invalid operand prefix '%%%c'"
 msgstr "‘%%%c’不是一个有效的操作数前缀"
 
-#: config/alpha/alpha.c:5092 config/i386/i386.c:18279
-#: config/rs6000/rs6000.c:23938 config/sparc/sparc.c:8854
+#: config/alpha/alpha.c:5092 config/i386/i386.c:18285
+#: config/rs6000/rs6000.c:23985 config/sparc/sparc.c:8995
 #, c-format
 msgid "'%%&' used without any local dynamic TLS references"
 msgstr "使用‘%%&’ 时没有指定任何动态 TLS 引用"
@@ -2985,18 +2985,18 @@
 msgstr "无效 %%r 值"
 
 #: config/alpha/alpha.c:5190 config/ia64/ia64.c:5442
-#: config/rs6000/rs6000.c:23618 config/xtensa/xtensa.c:2363
+#: config/rs6000/rs6000.c:23665 config/xtensa/xtensa.c:2364
 #, c-format
 msgid "invalid %%R value"
 msgstr "无效 %%R 值"
 
-#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23538
-#: config/xtensa/xtensa.c:2330
+#: config/alpha/alpha.c:5196 config/rs6000/rs6000.c:23585
+#: config/xtensa/xtensa.c:2331
 #, c-format
 msgid "invalid %%N value"
 msgstr "无效 %%N 值"
 
-#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23566
+#: config/alpha/alpha.c:5204 config/rs6000/rs6000.c:23613
 #, c-format
 msgid "invalid %%P value"
 msgstr "无效 %%P 值"
@@ -3006,7 +3006,7 @@
 msgid "invalid %%h value"
 msgstr "无效 %%h 值"
 
-#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2356
+#: config/alpha/alpha.c:5220 config/xtensa/xtensa.c:2357
 #, c-format
 msgid "invalid %%L value"
 msgstr "无效 %%L 值"
@@ -3027,7 +3027,7 @@
 msgstr "无效 %%U 值"
 
 #: config/alpha/alpha.c:5290 config/alpha/alpha.c:5301
-#: config/rs6000/rs6000.c:23626
+#: config/rs6000/rs6000.c:23673
 #, c-format
 msgid "invalid %%s value"
 msgstr "无效 %%s 值"
@@ -3037,7 +3037,7 @@
 msgid "invalid %%C value"
 msgstr "无效 %%C 值"
 
-#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23402
+#: config/alpha/alpha.c:5349 config/rs6000/rs6000.c:23449
 #, c-format
 msgid "invalid %%E value"
 msgstr "无效 %%E 值"
@@ -3048,7 +3048,7 @@
 msgstr "未指定未知的重定位方式"
 
 #: config/alpha/alpha.c:5383 config/cr16/cr16.c:1534
-#: config/rs6000/rs6000.c:23943 config/spu/spu.c:1447
+#: config/rs6000/rs6000.c:23990 config/spu/spu.c:1447
 #, c-format
 msgid "invalid %%xn code"
 msgstr "无效的 %%xn 代码"
@@ -3111,7 +3111,7 @@
 #. Unknown flag.
 #. Undocumented flag.
 #: config/arc/arc.c:3467 config/epiphany/epiphany.c:1289
-#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9133
+#: config/m32r/m32r.c:2230 config/nds32/nds32.c:2292 config/sparc/sparc.c:9274
 #, c-format
 msgid "invalid operand output code"
 msgstr "无效的操作数输出代码"
@@ -3121,29 +3121,29 @@
 msgid "invalid UNSPEC as operand: %d"
 msgstr "无效的 UNSPEC 用作操作数"
 
-#: config/arm/arm.c:18841 config/arm/arm.c:18866 config/arm/arm.c:18876
-#: config/arm/arm.c:18885 config/arm/arm.c:18894
+#: config/arm/arm.c:18830 config/arm/arm.c:18855 config/arm/arm.c:18865
+#: config/arm/arm.c:18874 config/arm/arm.c:18883
 #, c-format
 msgid "invalid shift operand"
 msgstr "无效的移位操作数"
 
-#: config/arm/arm.c:21708 config/arm/arm.c:21726
+#: config/arm/arm.c:21697 config/arm/arm.c:21715
 #, c-format
 msgid "predicated Thumb instruction"
 msgstr "预测到的 Thumb 指令"
 
-#: config/arm/arm.c:21714
+#: config/arm/arm.c:21703
 #, c-format
 msgid "predicated instruction in conditional sequence"
 msgstr "在条件序列中预测到的指令"
 
-#: config/arm/arm.c:21947 config/arm/arm.c:21969 config/arm/arm.c:21979
-#: config/arm/arm.c:21989 config/arm/arm.c:21999 config/arm/arm.c:22038
-#: config/arm/arm.c:22056 config/arm/arm.c:22081 config/arm/arm.c:22096
-#: config/arm/arm.c:22123 config/arm/arm.c:22130 config/arm/arm.c:22148
-#: config/arm/arm.c:22155 config/arm/arm.c:22163 config/arm/arm.c:22184
-#: config/arm/arm.c:22191 config/arm/arm.c:22324 config/arm/arm.c:22331
-#: config/arm/arm.c:22358 config/arm/arm.c:22365 config/bfin/bfin.c:1437
+#: config/arm/arm.c:21936 config/arm/arm.c:21958 config/arm/arm.c:21968
+#: config/arm/arm.c:21978 config/arm/arm.c:21988 config/arm/arm.c:22027
+#: config/arm/arm.c:22045 config/arm/arm.c:22070 config/arm/arm.c:22085
+#: config/arm/arm.c:22112 config/arm/arm.c:22119 config/arm/arm.c:22137
+#: config/arm/arm.c:22144 config/arm/arm.c:22152 config/arm/arm.c:22173
+#: config/arm/arm.c:22180 config/arm/arm.c:22313 config/arm/arm.c:22320
+#: config/arm/arm.c:22347 config/arm/arm.c:22354 config/bfin/bfin.c:1437
 #: config/bfin/bfin.c:1444 config/bfin/bfin.c:1451 config/bfin/bfin.c:1458
 #: config/bfin/bfin.c:1467 config/bfin/bfin.c:1474 config/bfin/bfin.c:1481
 #: config/bfin/bfin.c:1488
@@ -3151,28 +3151,28 @@
 msgid "invalid operand for code '%c'"
 msgstr "代码‘%c’的操作数无效"
 
-#: config/arm/arm.c:22051
+#: config/arm/arm.c:22040
 #, c-format
 msgid "instruction never executed"
 msgstr "指令从不被执行"
 
 #. Former Maverick support, removed after GCC-4.7.
-#: config/arm/arm.c:22072
+#: config/arm/arm.c:22061
 #, fuzzy, c-format
 msgid "obsolete Maverick format code '%c'"
 msgstr "不受支持的算符用于编码‘%c’"
 
-#: config/avr/avr.c:2439
+#: config/avr/avr.c:2455
 #, c-format
 msgid "address operand requires constraint for X, Y, or Z register"
 msgstr "地址操作数需要 X、Y 或 Z 寄存器约束"
 
-#: config/avr/avr.c:2620
+#: config/avr/avr.c:2636
 #, fuzzy
 msgid "operands to %T/%t must be reg + const_int:"
 msgstr "输出操作数 %d 必须使用%<&%>约束"
 
-#: config/avr/avr.c:2670 config/avr/avr.c:2737
+#: config/avr/avr.c:2686 config/avr/avr.c:2753
 #, fuzzy
 msgid "bad address, not an I/O address:"
 msgstr ""
@@ -3179,87 +3179,87 @@
 "\n"
 "错误：不当的地址在 From: 标头内。\n"
 
-#: config/avr/avr.c:2679
+#: config/avr/avr.c:2695
 #, fuzzy
 msgid "bad address, not a constant:"
 msgstr "地址偏移量不是一个常量"
 
-#: config/avr/avr.c:2697 config/avr/avr.c:2704
+#: config/avr/avr.c:2713 config/avr/avr.c:2720
 msgid "bad address, not (reg+disp):"
 msgstr "地址错误，不是(reg+disp)："
 
-#: config/avr/avr.c:2711
+#: config/avr/avr.c:2727
 msgid "bad address, not post_inc or pre_dec:"
 msgstr "错误的地址，不是 post_inc 或 pre_dec："
 
-#: config/avr/avr.c:2723
+#: config/avr/avr.c:2739
 msgid "internal compiler error.  Bad address:"
 msgstr "编译器内部错误。错误的地址："
 
-#: config/avr/avr.c:2756
+#: config/avr/avr.c:2772
 #, fuzzy, c-format
 msgid "Unsupported code '%c' for fixed-point:"
 msgstr "C++ 不支持定点类型"
 
-#: config/avr/avr.c:2764
+#: config/avr/avr.c:2780
 msgid "internal compiler error.  Unknown mode:"
 msgstr "编译器内部错误。未知的模式："
 
-#: config/avr/avr.c:3788 config/avr/avr.c:4732 config/avr/avr.c:5179
+#: config/avr/avr.c:3804 config/avr/avr.c:4748 config/avr/avr.c:5195
 msgid "invalid insn:"
 msgstr "无效指令："
 
-#: config/avr/avr.c:3842 config/avr/avr.c:3954 config/avr/avr.c:4012
-#: config/avr/avr.c:4064 config/avr/avr.c:4083 config/avr/avr.c:4275
-#: config/avr/avr.c:4583 config/avr/avr.c:4868 config/avr/avr.c:5072
-#: config/avr/avr.c:5236 config/avr/avr.c:5330 config/avr/avr.c:5529
+#: config/avr/avr.c:3858 config/avr/avr.c:3970 config/avr/avr.c:4028
+#: config/avr/avr.c:4080 config/avr/avr.c:4099 config/avr/avr.c:4291
+#: config/avr/avr.c:4599 config/avr/avr.c:4884 config/avr/avr.c:5088
+#: config/avr/avr.c:5252 config/avr/avr.c:5345 config/avr/avr.c:5544
 msgid "incorrect insn:"
 msgstr "错误指令："
 
-#: config/avr/avr.c:4099 config/avr/avr.c:4374 config/avr/avr.c:4654
-#: config/avr/avr.c:4940 config/avr/avr.c:5118 config/avr/avr.c:5386
-#: config/avr/avr.c:5587
+#: config/avr/avr.c:4115 config/avr/avr.c:4390 config/avr/avr.c:4670
+#: config/avr/avr.c:4956 config/avr/avr.c:5134 config/avr/avr.c:5401
+#: config/avr/avr.c:5602
 msgid "unknown move insn:"
 msgstr "无效的 move 指令："
 
-#: config/avr/avr.c:6046
+#: config/avr/avr.c:6061
 msgid "bad shift insn:"
 msgstr "错误的 shift 指令"
 
-#: config/avr/avr.c:6154 config/avr/avr.c:6635 config/avr/avr.c:7050
+#: config/avr/avr.c:6169 config/avr/avr.c:6650 config/avr/avr.c:7065
 msgid "internal compiler error.  Incorrect shift:"
 msgstr "编译器内部错误。不正确的移位量："
 
-#: config/avr/avr.c:8456
+#: config/avr/avr.c:8471
 #, fuzzy
 msgid "unsupported fixed-point conversion"
 msgstr "整点转换中类型无效"
 
-#: config/avr/avr.c:9803
+#: config/avr/avr.c:9818
 #, fuzzy
 #| msgid "Loop variable"
 msgid "variable"
 msgstr "循环变量"
 
-#: config/avr/avr.c:9808
+#: config/avr/avr.c:9823
 #, fuzzy
 #| msgid "redefinition of parameter %q+D"
 msgid "function parameter"
 msgstr "形参%q+D重定义"
 
-#: config/avr/avr.c:9813
+#: config/avr/avr.c:9828
 #, fuzzy
 #| msgid "struct defined here"
 msgid "structure field"
 msgstr "结构在此定义"
 
-#: config/avr/avr.c:9819
+#: config/avr/avr.c:9834
 #, fuzzy
 #| msgid "creating array of functions"
 msgid "return type of function"
 msgstr "创建函数的数组"
 
-#: config/avr/avr.c:9824
+#: config/avr/avr.c:9839
 #, fuzzy
 #| msgid "null pointer"
 msgid "pointer"
@@ -3283,7 +3283,7 @@
 msgstr "无效的双精度常量操作数"
 
 #: config/cris/cris.c:604 config/ft32/ft32.c:106 config/moxie/moxie.c:104
-#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5268 gcc.c:5282
+#: final.c:3455 final.c:3457 fold-const.c:268 gcc.c:5271 gcc.c:5285
 #: rtl-error.c:101 toplev.c:337 tree-vrp.c:7849 cp/typeck.c:6167
 #: lto/lto-object.c:184 lto/lto-object.c:281 lto/lto-object.c:338
 #: lto/lto-object.c:362
@@ -3505,91 +3505,91 @@
 msgid "bad output_condmove_single operand"
 msgstr "错误的 output_condmove_single 操作数"
 
-#: config/i386/i386.c:17149
+#: config/i386/i386.c:17155
 #, c-format
 msgid "invalid UNSPEC as operand"
 msgstr "无效的 UNSPEC 用作操作数"
 
-#: config/i386/i386.c:17660
+#: config/i386/i386.c:17666
 #, fuzzy, c-format
 msgid "invalid use of asm flag output"
 msgstr "向函数类型%qT的转换无效"
 
-#: config/i386/i386.c:17882
+#: config/i386/i386.c:17888
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'O'"
 msgstr "fr30_print_operand：%%A 代码操作数无效"
 
-#: config/i386/i386.c:17917
+#: config/i386/i386.c:17923
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'z'"
 msgstr "‘z’修饰符的操作数无效"
 
-#: config/i386/i386.c:17986
+#: config/i386/i386.c:17992
 #, fuzzy, c-format
 msgid "invalid operand type used with operand code 'Z'"
 msgstr "操作数代码‘%c’的操作数类型无效"
 
-#: config/i386/i386.c:17991
+#: config/i386/i386.c:17997
 #, fuzzy, c-format
 msgid "invalid operand size for operand code 'Z'"
 msgstr "‘z’修饰符的操作数无效"
 
-#: config/i386/i386.c:18067
+#: config/i386/i386.c:18073
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'Y'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18146
+#: config/i386/i386.c:18152
 #, c-format
 msgid "operand is not a condition code, invalid operand code 'D'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:18164
+#: config/i386/i386.c:18170
 #, fuzzy, c-format
 msgid "operand is not a condition code, invalid operand code '%c'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:18177
+#: config/i386/i386.c:18183
 #, fuzzy, c-format
 msgid "operand is not an offsettable memory reference, invalid operand code 'H'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘D’"
 
-#: config/i386/i386.c:18192
+#: config/i386/i386.c:18198
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'K'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18220
+#: config/i386/i386.c:18226
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'r'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18238
+#: config/i386/i386.c:18244
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not an integer, invalid operand code 'R'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18261
+#: config/i386/i386.c:18267
 #, fuzzy, c-format
 #| msgid "operand is not a condition code, invalid operand code 'Y'"
 msgid "operand is not a specific integer, invalid operand code 'R'"
 msgstr "操作数不是一个条件码，无效的操作数代码‘Y’"
 
-#: config/i386/i386.c:18357
+#: config/i386/i386.c:18363
 #, c-format
 msgid "invalid operand code '%c'"
 msgstr "无效的操作数代码‘%c’"
 
-#: config/i386/i386.c:18419
+#: config/i386/i386.c:18425
 #, c-format
 msgid "invalid constraints for operand"
 msgstr "操作数的约束无效"
 
-#: config/i386/i386.c:28920
+#: config/i386/i386.c:28926
 msgid "unknown insn mode"
 msgstr "未知的指令模式"
 
@@ -3627,7 +3627,7 @@
 msgid "invalid %%P operand"
 msgstr "无效的 %%P 操作数"
 
-#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23556
+#: config/iq2000/iq2000.c:3153 config/rs6000/rs6000.c:23603
 #, c-format
 msgid "invalid %%p value"
 msgstr "无效的 %%p 值"
@@ -3681,7 +3681,7 @@
 msgstr "后自增地址不是一个寄存器"
 
 #: config/m32r/m32r.c:2333 config/m32r/m32r.c:2348
-#: config/rs6000/rs6000.c:35600
+#: config/rs6000/rs6000.c:35649
 msgid "bad address"
 msgstr "错误地址"
 
@@ -3714,7 +3714,7 @@
 msgstr "指令包含无效地址！"
 
 #: config/microblaze/microblaze.c:2309 config/microblaze/microblaze.c:2528
-#: config/xtensa/xtensa.c:2460
+#: config/xtensa/xtensa.c:2461
 msgid "invalid address"
 msgstr "无效地址"
 
@@ -3805,288 +3805,288 @@
 msgid "Try running '%s' in the shell to raise its limit.\n"
 msgstr "尝试在命令解释器中运行‘%s’以提升它的极限。\n"
 
-#: config/rs6000/rs6000.c:4223
+#: config/rs6000/rs6000.c:4225
 msgid "-maltivec=le not allowed for big-endian targets"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4235
+#: config/rs6000/rs6000.c:4237
 msgid "-mvsx requires hardware floating point"
 msgstr "-mvsx 需要硬件浮点"
 
-#: config/rs6000/rs6000.c:4243
+#: config/rs6000/rs6000.c:4245
 msgid "-mvsx and -mpaired are incompatible"
 msgstr "-mvsx 与 -mpaired 互不兼容"
 
-#: config/rs6000/rs6000.c:4245
+#: config/rs6000/rs6000.c:4247
 msgid "-mvsx needs indexed addressing"
 msgstr "-mvsx 需要变址寻址"
 
-#: config/rs6000/rs6000.c:4250
+#: config/rs6000/rs6000.c:4252
 msgid "-mvsx and -mno-altivec are incompatible"
 msgstr "-mvsx 与 -mno-altivec 互不兼容"
 
-#: config/rs6000/rs6000.c:4252
+#: config/rs6000/rs6000.c:4254
 msgid "-mno-altivec disables vsx"
 msgstr "-mno-altivec 禁用了 VSX"
 
-#: config/rs6000/rs6000.c:4460
+#: config/rs6000/rs6000.c:4462
 msgid "-mquad-memory requires 64-bit mode"
 msgstr "-mquad-memory 需要 64 位模式"
 
-#: config/rs6000/rs6000.c:4463
+#: config/rs6000/rs6000.c:4465
 msgid "-mquad-memory-atomic requires 64-bit mode"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4475
+#: config/rs6000/rs6000.c:4477
 #, fuzzy
 msgid "-mquad-memory is not available in little endian mode"
 msgstr "生成小端在前的代码"
 
-#: config/rs6000/rs6000.c:4547
+#: config/rs6000/rs6000.c:4549
 #, fuzzy
 #| msgid "-mquad-memory requires 64-bit mode"
 msgid "-mtoc-fusion requires 64-bit"
 msgstr "-mquad-memory 需要 64 位模式"
 
-#: config/rs6000/rs6000.c:4554
+#: config/rs6000/rs6000.c:4556
 msgid "-mtoc-fusion requires medium/large code model"
 msgstr ""
 
-#: config/rs6000/rs6000.c:11245
+#: config/rs6000/rs6000.c:11276
 msgid "bad move"
 msgstr "错误的移动"
 
-#: config/rs6000/rs6000.c:23199
+#: config/rs6000/rs6000.c:23246
 msgid "Bad 128-bit move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:23390
+#: config/rs6000/rs6000.c:23437
 #, c-format
 msgid "invalid %%e value"
 msgstr "无效 %%e 值"
 
-#: config/rs6000/rs6000.c:23411
+#: config/rs6000/rs6000.c:23458
 #, c-format
 msgid "invalid %%f value"
 msgstr "无效 %%f 值"
 
-#: config/rs6000/rs6000.c:23420
+#: config/rs6000/rs6000.c:23467
 #, c-format
 msgid "invalid %%F value"
 msgstr "无效 %%F 值"
 
-#: config/rs6000/rs6000.c:23429
+#: config/rs6000/rs6000.c:23476
 #, c-format
 msgid "invalid %%G value"
 msgstr "无效 %%G 值"
 
-#: config/rs6000/rs6000.c:23464
+#: config/rs6000/rs6000.c:23511
 #, c-format
 msgid "invalid %%j code"
 msgstr "无效 %%j 代码"
 
-#: config/rs6000/rs6000.c:23474
+#: config/rs6000/rs6000.c:23521
 #, c-format
 msgid "invalid %%J code"
 msgstr "无效 %%J 代码"
 
-#: config/rs6000/rs6000.c:23484
+#: config/rs6000/rs6000.c:23531
 #, c-format
 msgid "invalid %%k value"
 msgstr "无效 %%k 值"
 
-#: config/rs6000/rs6000.c:23499 config/xtensa/xtensa.c:2349
+#: config/rs6000/rs6000.c:23546 config/xtensa/xtensa.c:2350
 #, c-format
 msgid "invalid %%K value"
 msgstr "无效 %%K 值"
 
-#: config/rs6000/rs6000.c:23546
+#: config/rs6000/rs6000.c:23593
 #, c-format
 msgid "invalid %%O value"
 msgstr "无效 %%O 值"
 
-#: config/rs6000/rs6000.c:23593
+#: config/rs6000/rs6000.c:23640
 #, c-format
 msgid "invalid %%q value"
 msgstr "无效 %%q 值"
 
-#: config/rs6000/rs6000.c:23646
+#: config/rs6000/rs6000.c:23693
 #, c-format
 msgid "invalid %%T value"
 msgstr "无效 %%T 值"
 
-#: config/rs6000/rs6000.c:23658
+#: config/rs6000/rs6000.c:23705
 #, c-format
 msgid "invalid %%u value"
 msgstr "无效 %%u 值"
 
-#: config/rs6000/rs6000.c:23672 config/xtensa/xtensa.c:2319
+#: config/rs6000/rs6000.c:23719 config/xtensa/xtensa.c:2320
 #, c-format
 msgid "invalid %%v value"
 msgstr "无效 %%v 值"
 
-#: config/rs6000/rs6000.c:23739 config/xtensa/xtensa.c:2370
+#: config/rs6000/rs6000.c:23786 config/xtensa/xtensa.c:2371
 #, c-format
 msgid "invalid %%x value"
 msgstr "无效的 %%x 值"
 
-#: config/rs6000/rs6000.c:23887
+#: config/rs6000/rs6000.c:23934
 #, c-format
 msgid "invalid %%y value, try using the 'Z' constraint"
 msgstr "无效 %%y 值，请试用“Z”约束"
 
-#: config/rs6000/rs6000.c:24603
+#: config/rs6000/rs6000.c:24650
 msgid "__float128 and __ibm128 cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:24609
+#: config/rs6000/rs6000.c:24656
 #, fuzzy
 msgid "__ibm128 and long double cannot be used in the same expression"
 msgstr "对声明中的过时用法给出警告"
 
-#: config/rs6000/rs6000.c:24615
+#: config/rs6000/rs6000.c:24662
 msgid "__float128 and long double cannot be used in the same expression"
 msgstr ""
 
-#: config/rs6000/rs6000.c:38903
+#: config/rs6000/rs6000.c:38952
 msgid "AltiVec argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/rs6000/rs6000.c:40709
+#: config/rs6000/rs6000.c:40758
 #, fuzzy
 msgid "Could not generate addis value for fusion"
 msgstr "不为每个函数生成单一的退出点"
 
-#: config/rs6000/rs6000.c:40781
+#: config/rs6000/rs6000.c:40830
 #, fuzzy
 msgid "Unable to generate load/store offset for fusion"
 msgstr "无法生成重新载入，为："
 
-#: config/rs6000/rs6000.c:40885
+#: config/rs6000/rs6000.c:40934
 msgid "Bad GPR fusion"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41103
+#: config/rs6000/rs6000.c:41152
 msgid "emit_fusion_p9_load, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41149
+#: config/rs6000/rs6000.c:41198
 msgid "emit_fusion_p9_load, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41152
+#: config/rs6000/rs6000.c:41201
 msgid "emit_fusion_p9_load not MEM"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41190
+#: config/rs6000/rs6000.c:41239
 msgid "emit_fusion_p9_store, bad reg #1"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41236
+#: config/rs6000/rs6000.c:41285
 msgid "emit_fusion_p9_store, bad reg #2"
 msgstr ""
 
-#: config/rs6000/rs6000.c:41239
+#: config/rs6000/rs6000.c:41288
 msgid "emit_fusion_p9_store not MEM"
 msgstr ""
 
-#: config/s390/s390.c:7482
+#: config/s390/s390.c:7489
 #, fuzzy, c-format
 msgid "symbolic memory references are only supported on z10 or later"
 msgstr "符号内存参考是只有支持的于 z10 或稍后"
 
-#: config/s390/s390.c:7493
+#: config/s390/s390.c:7500
 #, c-format
 msgid "cannot decompose address"
 msgstr "无法分解地址"
 
-#: config/s390/s390.c:7562
+#: config/s390/s390.c:7569
 #, fuzzy, c-format
 msgid "invalid comparison operator for 'E' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.c:7585
+#: config/s390/s390.c:7592
 #, fuzzy, c-format
 msgid "invalid reference for 'J' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.c:7603
+#: config/s390/s390.c:7610
 #, fuzzy, c-format
 msgid "invalid address for 'O' output modifier"
 msgstr "‘o’修饰符的操作数无效"
 
-#: config/s390/s390.c:7625
+#: config/s390/s390.c:7632
 #, fuzzy, c-format
 msgid "invalid address for 'R' output modifier"
 msgstr "‘b’修饰符的操作数无效"
 
-#: config/s390/s390.c:7643
+#: config/s390/s390.c:7650
 #, fuzzy, c-format
 msgid "memory reference expected for 'S' output modifier"
 msgstr "内存参考预期的用于‘S’输出修饰键"
 
-#: config/s390/s390.c:7653
+#: config/s390/s390.c:7660
 #, fuzzy, c-format
 msgid "invalid address for 'S' output modifier"
 msgstr "%s：无效的输出格式"
 
-#: config/s390/s390.c:7674
+#: config/s390/s390.c:7681
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'N' output modifier"
 msgstr "暂存器或内存运算式预期的用于‘N’输出修饰键"
 
-#: config/s390/s390.c:7685
+#: config/s390/s390.c:7692
 #, fuzzy, c-format
 msgid "register or memory expression expected for 'M' output modifier"
 msgstr "暂存器或内存运算式预期的用于‘公尺’输出修饰键"
 
-#: config/s390/s390.c:7771 config/s390/s390.c:7792
+#: config/s390/s390.c:7778 config/s390/s390.c:7799
 #, fuzzy, c-format
 msgid "invalid constant for output modifier '%c'"
 msgstr "CHARACTER 常量的种别 %d 无效，在%C处"
 
-#: config/s390/s390.c:7789
+#: config/s390/s390.c:7796
 #, fuzzy, c-format
 msgid "invalid constant - try using an output modifier"
 msgstr "无效的操作数输出代码"
 
-#: config/s390/s390.c:7826
+#: config/s390/s390.c:7833
 #, fuzzy, c-format
 msgid "invalid constant vector for output modifier '%c'"
 msgstr "CHARACTER 常量的种别 %d 无效，在%C处"
 
-#: config/s390/s390.c:7833
+#: config/s390/s390.c:7840
 #, fuzzy, c-format
 msgid "invalid expression - try using an output modifier"
 msgstr "无效的最小左值表达式"
 
-#: config/s390/s390.c:7836
+#: config/s390/s390.c:7843
 #, fuzzy, c-format
 msgid "invalid expression for output modifier '%c'"
 msgstr "C++ 不允许在%qs表达式中定义类型"
 
-#: config/s390/s390.c:11703
+#: config/s390/s390.c:11710
 #, fuzzy
 #| msgid "AltiVec argument passed to unprototyped function"
 msgid "vector argument passed to unprototyped function"
 msgstr "传递 AltiVec 参数给无原型的函数"
 
-#: config/s390/s390.c:15522
+#: config/s390/s390.c:15529
 #, fuzzy
 #| msgid "pointer targets in return differ in signedness"
 msgid "types differ in signedness"
 msgstr "返回指针时目标与指针符号不一致"
 
-#: config/s390/s390.c:15532
+#: config/s390/s390.c:15539
 msgid "binary operator does not support two vector bool operands"
 msgstr ""
 
-#: config/s390/s390.c:15535
+#: config/s390/s390.c:15542
 #, fuzzy
 msgid "binary operator does not support vector bool operand"
 msgstr "目标格式不支持无限大浮点数"
 
-#: config/s390/s390.c:15543
+#: config/s390/s390.c:15550
 msgid "binary operator does not support mixing vector bool with floating point vector operands"
 msgstr ""
 
@@ -4112,43 +4112,43 @@
 msgid "created and used with different endianness"
 msgstr "创建和使用时使用了不同的大小端设定"
 
-#: config/sparc/sparc.c:8863 config/sparc/sparc.c:8869
+#: config/sparc/sparc.c:9004 config/sparc/sparc.c:9010
 #, c-format
 msgid "invalid %%Y operand"
 msgstr "无效的 %%Y 操作数"
 
-#: config/sparc/sparc.c:8956
+#: config/sparc/sparc.c:9097
 #, c-format
 msgid "invalid %%A operand"
 msgstr "无效的 %%A 操作数"
 
-#: config/sparc/sparc.c:8976
+#: config/sparc/sparc.c:9117
 #, c-format
 msgid "invalid %%B operand"
 msgstr "无效的 %%B 操作数"
 
-#: config/sparc/sparc.c:9056 config/tilegx/tilegx.c:5103
+#: config/sparc/sparc.c:9197 config/tilegx/tilegx.c:5103
 #: config/tilepro/tilepro.c:4512
 #, fuzzy, c-format
 msgid "invalid %%C operand"
 msgstr "无效的 %%c 操作数"
 
-#: config/sparc/sparc.c:9088 config/tilegx/tilegx.c:5136
+#: config/sparc/sparc.c:9229 config/tilegx/tilegx.c:5136
 #, fuzzy, c-format
 msgid "invalid %%D operand"
 msgstr "无效的 %%d 操作数"
 
-#: config/sparc/sparc.c:9107
+#: config/sparc/sparc.c:9248
 #, c-format
 msgid "invalid %%f operand"
 msgstr "无效的 %%f 操作数"
 
-#: config/sparc/sparc.c:9119
+#: config/sparc/sparc.c:9260
 #, c-format
 msgid "invalid %%s operand"
 msgstr "无效的 %%s 操作数"
 
-#: config/sparc/sparc.c:9164
+#: config/sparc/sparc.c:9305
 #, fuzzy, c-format
 #| msgid "floating point constant not a valid immediate operand"
 msgid "floating-point constant not a valid immediate operand"
@@ -4316,30 +4316,30 @@
 msgid "bad test"
 msgstr "错误的测试"
 
-#: config/xtensa/xtensa.c:2307
+#: config/xtensa/xtensa.c:2308
 #, c-format
 msgid "invalid %%D value"
 msgstr "无效的 %%D 值"
 
-#: config/xtensa/xtensa.c:2344
+#: config/xtensa/xtensa.c:2345
 msgid "invalid mask"
 msgstr "无效掩码"
 
-#: config/xtensa/xtensa.c:2377
+#: config/xtensa/xtensa.c:2378
 #, c-format
 msgid "invalid %%d value"
 msgstr "无效的 %%d 值"
 
-#: config/xtensa/xtensa.c:2396 config/xtensa/xtensa.c:2406
+#: config/xtensa/xtensa.c:2397 config/xtensa/xtensa.c:2407
 #, c-format
 msgid "invalid %%t/%%b value"
 msgstr "无效的 %%t/%%b 值"
 
-#: config/xtensa/xtensa.c:2485
+#: config/xtensa/xtensa.c:2486
 msgid "no register in address"
 msgstr "地址中无寄存器"
 
-#: config/xtensa/xtensa.c:2493
+#: config/xtensa/xtensa.c:2494
 msgid "address offset not a constant"
 msgstr "地址偏移量不是一个常量"
 
@@ -4360,8 +4360,8 @@
 #: c/gimple-parser.c:189 c/gimple-parser.c:198 c/gimple-parser.c:227
 #: c/gimple-parser.c:1320 c/gimple-parser.c:1344 c/gimple-parser.c:1424
 #: c/gimple-parser.c:1451 c/c-parser.c:2985 c/c-parser.c:9257
-#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27236
-#: cp/parser.c:27809
+#: c/gimple-parser.c:1228 c/gimple-parser.c:1267 cp/parser.c:27259
+#: cp/parser.c:27832
 #, gcc-internal-format
 msgid "expected %<;%>"
 msgstr "需要%<;%>"
@@ -4383,14 +4383,14 @@
 #: c/c-parser.c:17131 c/c-parser.c:17573 c/c-parser.c:17631 c/c-parser.c:18057
 #: c/gimple-parser.c:364 c/gimple-parser.c:783 c/gimple-parser.c:835
 #: c/gimple-parser.c:861 c/gimple-parser.c:1148 c/gimple-parser.c:1289
-#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24946
-#: cp/parser.c:27812
+#: c/gimple-parser.c:1378 c/c-parser.c:11143 cp/parser.c:24969
+#: cp/parser.c:27835
 #, gcc-internal-format
 msgid "expected %<(%>"
 msgstr "需要%<(%>"
 
 #: c/c-parser.c:2217 c/c-parser.c:7364 c/c-parser.c:7769 c/c-parser.c:7810
-#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27234 cp/parser.c:27827
+#: c/c-parser.c:7948 c/c-parser.c:11932 cp/parser.c:27257 cp/parser.c:27850
 #, gcc-internal-format
 msgid "expected %<,%>"
 msgstr "需要 %<,%>"
@@ -4421,7 +4421,7 @@
 #: c/gimple-parser.c:793 c/gimple-parser.c:815 c/gimple-parser.c:842
 #: c/gimple-parser.c:865 c/gimple-parser.c:988 c/gimple-parser.c:1159
 #: c/gimple-parser.c:1170 c/gimple-parser.c:1292 c/gimple-parser.c:1381
-#: cp/parser.c:24979 cp/parser.c:27857
+#: cp/parser.c:25002 cp/parser.c:27880
 #, gcc-internal-format
 msgid "expected %<)%>"
 msgstr "需要%<)%>"
@@ -4429,7 +4429,7 @@
 #: c/c-parser.c:3619 c/c-parser.c:4573 c/c-parser.c:4609 c/c-parser.c:6267
 #: c/c-parser.c:7879 c/c-parser.c:8237 c/c-parser.c:8390 c/c-parser.c:10829
 #: c/c-parser.c:17969 c/c-parser.c:17971 c/c-parser.c:18310
-#: c/gimple-parser.c:965 cp/parser.c:7115 cp/parser.c:27821
+#: c/gimple-parser.c:965 cp/parser.c:7120 cp/parser.c:27844
 #, gcc-internal-format
 msgid "expected %<]%>"
 msgstr "需要%<]%>"
@@ -4439,7 +4439,7 @@
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
 #: c/c-parser.c:4429 c/c-parser.c:14776 c/gimple-parser.c:1493
-#: cp/parser.c:27815 cp/parser.c:29742
+#: cp/parser.c:27838 cp/parser.c:29765
 #, gcc-internal-format
 msgid "expected %<}%>"
 msgstr "需要 %<}%>"
@@ -4446,7 +4446,7 @@
 
 #: c/c-parser.c:4743 c/c-parser.c:9598 c/c-parser.c:15502 c/c-parser.c:18336
 #: c/gimple-parser.c:142 c/gimple-parser.c:1384 c/c-parser.c:2803
-#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17788 cp/parser.c:27818
+#: c/c-parser.c:3006 c/c-parser.c:9152 cp/parser.c:17811 cp/parser.c:27841
 #, gcc-internal-format
 msgid "expected %<{%>"
 msgstr "需要%<{%>"
@@ -4456,7 +4456,7 @@
 #: c/c-parser.c:11621 c/c-parser.c:11756 c/c-parser.c:12125 c/c-parser.c:12217
 #: c/c-parser.c:12870 c/c-parser.c:16975 c/c-parser.c:17034
 #: c/gimple-parser.c:1432 c/gimple-parser.c:1459 c/c-parser.c:6174
-#: c/c-parser.c:11237 cp/parser.c:27851 cp/parser.c:28953 cp/parser.c:31615
+#: c/c-parser.c:11237 cp/parser.c:27874 cp/parser.c:28976 cp/parser.c:31638
 #, gcc-internal-format
 msgid "expected %<:%>"
 msgstr "需要 %<:%>"
@@ -4471,27 +4471,27 @@
 msgid "Cilk array notation cannot be used for a throw expression"
 msgstr "对声明中的过时用法给出警告"
 
-#: c/c-parser.c:5715 cp/semantics.c:1144
+#: c/c-parser.c:5715 cp/semantics.c:1147
 #, fuzzy
 msgid "Cilk array notation cannot be used as a condition for switch statement"
 msgstr "new 不能用于函数类型"
 
-#: c/c-parser.c:5766 cp/semantics.c:799
+#: c/c-parser.c:5766 cp/semantics.c:802
 #, fuzzy
 msgid "Cilk array notation cannot be used as a condition for while statement"
 msgstr "new 不能用于函数类型"
 
-#: c/c-parser.c:5818 cp/parser.c:27745
+#: c/c-parser.c:5818 cp/parser.c:27768
 #, gcc-internal-format
 msgid "expected %<while%>"
 msgstr "需要 %<while%>"
 
-#: c/c-parser.c:5825 cp/semantics.c:858
+#: c/c-parser.c:5825 cp/semantics.c:861
 #, fuzzy
 msgid "Cilk array notation cannot be used as a condition for a do-while statement"
 msgstr "new 不能用于函数类型"
 
-#: c/c-parser.c:6028 cp/semantics.c:977
+#: c/c-parser.c:6028 cp/semantics.c:980
 #, fuzzy
 msgid "Cilk array notation cannot be used in a condition for a for-loop"
 msgstr "对声明中的过时用法给出警告"
@@ -4500,18 +4500,18 @@
 msgid "expected %<.%>"
 msgstr "需要%<.%>"
 
-#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29527
-#: cp/parser.c:29601
+#: c/c-parser.c:8823 c/c-parser.c:8855 c/c-parser.c:9095 cp/parser.c:29550
+#: cp/parser.c:29624
 #, gcc-internal-format
 msgid "expected %<@end%>"
 msgstr "需要 %<@end%>"
 
-#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27836
+#: c/c-parser.c:9512 c/gimple-parser.c:778 cp/parser.c:27859
 #, gcc-internal-format
 msgid "expected %<>%>"
 msgstr "需要 %<>%>"
 
-#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27860
+#: c/c-parser.c:12309 c/c-parser.c:13088 cp/parser.c:27883
 #, gcc-internal-format
 msgid "expected %<,%> or %<)%>"
 msgstr "需要 %<,%> 或 %<)%>"
@@ -4519,17 +4519,17 @@
 #. All following cases are statements with LHS.
 #: c/c-parser.c:14488 c/c-parser.c:14532 c/c-parser.c:14760 c/c-parser.c:15001
 #: c/c-parser.c:17172 c/c-parser.c:17795 c/gimple-parser.c:287
-#: c/c-parser.c:4632 cp/parser.c:27839
+#: c/c-parser.c:4632 cp/parser.c:27862
 #, gcc-internal-format
 msgid "expected %<=%>"
 msgstr "需要%<=%>"
 
-#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35022
+#: c/c-parser.c:15545 c/c-parser.c:15535 cp/parser.c:35045
 #, gcc-internal-format
 msgid "expected %<#pragma omp section%> or %<}%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27824 cp/parser.c:30884
+#: c/c-parser.c:17957 c/c-parser.c:10764 cp/parser.c:27847 cp/parser.c:30907
 #, gcc-internal-format
 msgid "expected %<[%>"
 msgstr "需要%<[%>"
@@ -4538,7 +4538,7 @@
 msgid "(anonymous)"
 msgstr "(匿名)"
 
-#: c/gimple-parser.c:767 cp/parser.c:15443 cp/parser.c:27833
+#: c/gimple-parser.c:767 cp/parser.c:15462 cp/parser.c:27856
 #, gcc-internal-format
 msgid "expected %<<%>"
 msgstr "需要%<<%>"
@@ -4549,11 +4549,11 @@
 msgid "expected label"
 msgstr "需要通道"
 
-#: cp/call.c:9927
+#: cp/call.c:9932
 msgid "candidate 1:"
 msgstr "备选 1："
 
-#: cp/call.c:9928
+#: cp/call.c:9933
 msgid "candidate 2:"
 msgstr "备选 2："
 
@@ -4785,11 +4785,11 @@
 msgid "%r%s:%d:%R   in constexpr expansion of %qs"
 msgstr "%s:%d：在%qs的广义常表达式扩展中"
 
-#: cp/pt.c:1950 cp/semantics.c:5250
+#: cp/pt.c:1950 cp/semantics.c:5263
 msgid "candidates are:"
 msgstr "备选为："
 
-#: cp/pt.c:21895
+#: cp/pt.c:21984
 msgid "candidate is:"
 msgid_plural "candidates are:"
 msgstr[0] "备选是："
@@ -4965,77 +4965,77 @@
 msgid "actual argument to INTENT = OUT/INOUT"
 msgstr "实际参数到含义=出/INOUT"
 
-#: fortran/io.c:585
+#: fortran/io.c:595
 msgid "Positive width required"
 msgstr "需要正的宽度"
 
-#: fortran/io.c:586
+#: fortran/io.c:596
 msgid "Nonnegative width required"
 msgstr "需要非负的宽度"
 
-#: fortran/io.c:587
+#: fortran/io.c:597
 #, fuzzy
 msgid "Unexpected element %qc in format string at %L"
 msgstr "%2$L处格式字符串中非预期的元素‘%1$c’"
 
-#: fortran/io.c:589
+#: fortran/io.c:599
 msgid "Unexpected end of format string"
 msgstr "非预期的格式字符串结尾"
 
-#: fortran/io.c:590
+#: fortran/io.c:600
 msgid "Zero width in format descriptor"
 msgstr "格式描述中域宽为 0"
 
-#: fortran/io.c:610
+#: fortran/io.c:620
 msgid "Missing leading left parenthesis"
 msgstr "缺少前导左括号"
 
-#: fortran/io.c:639
+#: fortran/io.c:649
 #, fuzzy
 msgid "Left parenthesis required after %<*%>"
 msgstr "缺少前导左括号"
 
-#: fortran/io.c:670
+#: fortran/io.c:680
 msgid "Expected P edit descriptor"
 msgstr "需要 P 编辑描述符"
 
 #. P requires a prior number.
-#: fortran/io.c:678
+#: fortran/io.c:688
 msgid "P descriptor requires leading scale factor"
 msgstr "P 描述符需要前导因子"
 
-#: fortran/io.c:726
-#, fuzzy, c-format
-#| msgid "Missing right parenthesis at %C"
-msgid "Right parenthesis expected at %C"
-msgstr "%C处缺少右括号"
-
-#: fortran/io.c:819 fortran/io.c:833
+#: fortran/io.c:782 fortran/io.c:796
 msgid "Comma required after P descriptor"
 msgstr "P 描述符后需要逗号"
 
-#: fortran/io.c:847
+#: fortran/io.c:810
 msgid "Positive width required with T descriptor"
 msgstr "T 描述符需要正的宽度"
 
-#: fortran/io.c:930
+#: fortran/io.c:893
 msgid "E specifier not allowed with g0 descriptor"
 msgstr "g0 描述符不允许有 E 限定符"
 
-#: fortran/io.c:1000
+#: fortran/io.c:963
 msgid "Positive exponent width required"
 msgstr "需要正的指数宽度"
 
-#: fortran/io.c:1030
+#: fortran/io.c:1006
+#, fuzzy, c-format
+#| msgid "Missing right parenthesis at %C"
+msgid "Right parenthesis expected at %C"
+msgstr "%C处缺少右括号"
+
+#: fortran/io.c:1040
 msgid "Period required in format specifier"
 msgstr "格式限定符中需要句号"
 
-#: fortran/io.c:1748
+#: fortran/io.c:1758
 #, c-format
 msgid "%s tag"
 msgstr "%s 标记"
 
-#: fortran/io.c:3217
+#: fortran/io.c:3251
 #, fuzzy
 msgid "internal unit in WRITE"
 msgstr "%L处内部单位带向量下标"
@@ -5042,7 +5042,7 @@
 
 #. For INQUIRE, all tags except FILE, ID and UNIT are variable definition
 #. contexts.  Thus, use an extended RESOLVE_TAG macro for that.
-#: fortran/io.c:4484
+#: fortran/io.c:4551
 #, fuzzy, c-format
 msgid "%s tag with INQUIRE"
 msgstr "%s 标记"
@@ -5052,75 +5052,75 @@
 msgid "Syntax error in expression at %C"
 msgstr "%C 表达式语法错误"
 
-#: fortran/module.c:1211
+#: fortran/module.c:1212
 msgid "Unexpected EOF"
 msgstr "非预期的文件结束"
 
-#: fortran/module.c:1295
+#: fortran/module.c:1296
 msgid "Integer overflow"
 msgstr "整数溢出"
 
-#: fortran/module.c:1325
+#: fortran/module.c:1326
 msgid "Name too long"
 msgstr "名字太长"
 
-#: fortran/module.c:1427 fortran/module.c:1530
+#: fortran/module.c:1428 fortran/module.c:1531
 msgid "Bad name"
 msgstr "错误的名字"
 
-#: fortran/module.c:1554
+#: fortran/module.c:1555
 msgid "Expected name"
 msgstr "需要名字"
 
-#: fortran/module.c:1557
+#: fortran/module.c:1558
 msgid "Expected left parenthesis"
 msgstr "需要左圆括号"
 
-#: fortran/module.c:1560
+#: fortran/module.c:1561
 msgid "Expected right parenthesis"
 msgstr "需要右圆括号"
 
-#: fortran/module.c:1563
+#: fortran/module.c:1564
 msgid "Expected integer"
 msgstr "需要整数"
 
-#: fortran/module.c:1566 fortran/module.c:2559
+#: fortran/module.c:1567 fortran/module.c:2560
 msgid "Expected string"
 msgstr "需要字符串"
 
-#: fortran/module.c:1591
+#: fortran/module.c:1592
 msgid "find_enum(): Enum not found"
 msgstr "find_enum()：找不到枚举"
 
-#: fortran/module.c:2274
+#: fortran/module.c:2275
 msgid "Expected attribute bit name"
 msgstr "需要属性位名"
 
-#: fortran/module.c:3163
+#: fortran/module.c:3164
 msgid "Expected integer string"
 msgstr "需要整数字符串"
 
-#: fortran/module.c:3167
+#: fortran/module.c:3168
 msgid "Error converting integer"
 msgstr "转换整数时出错"
 
-#: fortran/module.c:3189
+#: fortran/module.c:3190
 msgid "Expected real string"
 msgstr "需要实数字符串"
 
-#: fortran/module.c:3413
+#: fortran/module.c:3414
 msgid "Expected expression type"
 msgstr "需要表达式类型"
 
-#: fortran/module.c:3493
+#: fortran/module.c:3494
 msgid "Bad operator"
 msgstr "错误的运算符"
 
-#: fortran/module.c:3608
+#: fortran/module.c:3609
 msgid "Bad type in constant expression"
 msgstr "常量表达式中类型错误"
 
-#: fortran/module.c:6950
+#: fortran/module.c:6951
 msgid "Unexpected end of module"
 msgstr "非预期的模块结束"
 
@@ -5395,12 +5395,12 @@
 msgid "Actual string length is shorter than the declared one for dummy argument '%s' (%ld/%ld)"
 msgstr "字符串的实际长度短于其虚参声明‘%s’(%ld/%ld)"
 
-#: fortran/trans-expr.c:8617
+#: fortran/trans-expr.c:8627
 #, fuzzy, c-format
 msgid "Target of rank remapping is too small (%ld < %ld)"
 msgstr "目标的分级重新映射太小 (%ld<%ld)"
 
-#: fortran/trans-expr.c:9983
+#: fortran/trans-expr.c:9993
 msgid "Assignment of scalar to unallocated array"
 msgstr ""
 
@@ -5768,7 +5768,7 @@
 
 #: config/sparc/linux64.h:149 config/sparc/linux64.h:156
 #: config/sparc/netbsd-elf.h:108 config/sparc/netbsd-elf.h:117
-#: config/sparc/sol2.h:228 config/sparc/sol2.h:234
+#: config/sparc/sol2.h:237 config/sparc/sol2.h:243
 msgid "may not use both -m32 and -m64"
 msgstr "不能同时使用 -m32 和 -m64"
 
@@ -9664,7 +9664,7 @@
 msgstr "指定线程局部存储偏移量立即数的位大小"
 
 #: config/ia64/ia64.opt:122 config/spu/spu.opt:84 config/i386/i386.opt:510
-#: config/s390/s390.opt:197 config/sparc/sparc.opt:138
+#: config/s390/s390.opt:200 config/sparc/sparc.opt:146
 #: config/visium/visium.opt:49
 #, fuzzy
 #| msgid "Schedule code for given CPU"
@@ -9940,7 +9940,7 @@
 msgid "target the software simulator."
 msgstr ""
 
-#: config/ft32/ft32.opt:27 config/s390/s390.opt:228 config/mips/mips.opt:389
+#: config/ft32/ft32.opt:27 config/s390/s390.opt:231 config/mips/mips.opt:389
 #, fuzzy
 msgid "Use LRA instead of reload."
 msgstr "请使用 %.100s 作为替代"
@@ -10234,7 +10234,7 @@
 msgid "Use 80-bit long double."
 msgstr "使用 64 位 long double"
 
-#: config/i386/i386.opt:204 config/s390/s390.opt:157
+#: config/i386/i386.opt:204 config/s390/s390.opt:160
 #: config/sparc/long-double-switch.opt:27 config/alpha/alpha.opt:102
 #, fuzzy
 #| msgid "Use 64-bit long double"
@@ -10241,7 +10241,7 @@
 msgid "Use 64-bit long double."
 msgstr "使用 64 位 long double"
 
-#: config/i386/i386.opt:208 config/s390/s390.opt:153
+#: config/i386/i386.opt:208 config/s390/s390.opt:156
 #: config/sparc/long-double-switch.opt:23 config/alpha/alpha.opt:98
 #, fuzzy
 #| msgid "Use 128-bit long double"
@@ -11468,118 +11468,118 @@
 msgid "64 bit ABI."
 msgstr "64 位 ABI"
 
-#: config/s390/s390.opt:123
+#: config/s390/s390.opt:126
 #, fuzzy
 #| msgid "Maintain backchain pointer"
 msgid "Maintain backchain pointer."
 msgstr "维护链回上层栈帧的指针"
 
-#: config/s390/s390.opt:127
+#: config/s390/s390.opt:130
 #, fuzzy
 #| msgid "Additional debug prints"
 msgid "Additional debug prints."
 msgstr "附加的调试输出"
 
-#: config/s390/s390.opt:131
+#: config/s390/s390.opt:134
 #, fuzzy
 #| msgid "ESA/390 architecture"
 msgid "ESA/390 architecture."
 msgstr "ESA/390 结构"
 
-#: config/s390/s390.opt:135
+#: config/s390/s390.opt:138
 #, fuzzy
 #| msgid "Enable decimal floating point hardware support"
 msgid "Enable decimal floating point hardware support."
 msgstr "启用硬件十进制浮点支持"
 
-#: config/s390/s390.opt:139
+#: config/s390/s390.opt:142
 #, fuzzy
 #| msgid "Enable hardware floating point"
 msgid "Enable hardware floating point."
 msgstr "启用硬件浮点单元"
 
-#: config/s390/s390.opt:143
+#: config/s390/s390.opt:146
 msgid "Takes two non-negative integer numbers separated by a comma. Prepend the function label with the number of two-byte Nop instructions indicated by the first.  Append Nop instructions covering the number of halfwords indicated by the second after the label.  Nop instructions of the largest possible size are used (six, four or two bytes), beginning with the largest possible size.  Using 0 for both values disables hotpatching."
 msgstr ""
 
-#: config/s390/s390.opt:161
+#: config/s390/s390.opt:164
 #, fuzzy
 msgid "Use hardware transactional execution instructions."
 msgstr "使用 ColdFire 上的硬件除法指令"
 
-#: config/s390/s390.opt:165
+#: config/s390/s390.opt:168
 #, fuzzy
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "Use hardware vector facility instructions and enable the vector ABI."
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.opt:169
+#: config/s390/s390.opt:172
 #, fuzzy
 #| msgid "Use packed stack layout"
 msgid "Use packed stack layout."
 msgstr "使用紧实的堆栈布局"
 
-#: config/s390/s390.opt:173
+#: config/s390/s390.opt:176
 #, fuzzy
 #| msgid "Use bras for executable < 64k"
 msgid "Use bras for executable < 64k."
 msgstr "为小于 64k 的可执行文件使用 bras 指令"
 
-#: config/s390/s390.opt:177
+#: config/s390/s390.opt:180
 #, fuzzy
 #| msgid "Disable hardware floating point"
 msgid "Disable hardware floating point."
 msgstr "禁用硬件浮点单元"
 
-#: config/s390/s390.opt:181
+#: config/s390/s390.opt:184
 #, fuzzy
 #| msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered"
 msgid "Set the max. number of bytes which has to be left to stack size before a trap instruction is triggered."
 msgstr "设置在陷阱指令被触发前留在堆栈中最大字节数"
 
-#: config/s390/s390.opt:185
+#: config/s390/s390.opt:188
 msgid "Switches off the -mstack-guard= option."
 msgstr ""
 
-#: config/s390/s390.opt:189
+#: config/s390/s390.opt:192
 #, fuzzy
 #| msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit"
 msgid "Emit extra code in the function prologue in order to trap if the stack size exceeds the given limit."
 msgstr "在函数前言中生成额外代码以捕获堆栈大小越限"
 
-#: config/s390/s390.opt:193
+#: config/s390/s390.opt:196
 msgid "Switches off the -mstack-size= option."
 msgstr ""
 
-#: config/s390/s390.opt:201
+#: config/s390/s390.opt:204
 #, fuzzy
 #| msgid "Generate string instructions for block moves"
 msgid "Use the mvcle instruction for block moves."
 msgstr "为块移动使用字符串指令"
 
-#: config/s390/s390.opt:205
+#: config/s390/s390.opt:208
 msgid "Enable the z vector language extension providing the context-sensitive vector macro and enable the Altivec-style builtins in vecintrin.h."
 msgstr ""
 
-#: config/s390/s390.opt:210
+#: config/s390/s390.opt:213
 #, fuzzy
 #| msgid "Warn if a function uses alloca or creates an array with dynamic size"
 msgid "Warn if a function uses alloca or creates an array with dynamic size."
 msgstr "当函数使用 alloca 来创建变长数组时给出警告"
 
-#: config/s390/s390.opt:214
+#: config/s390/s390.opt:217
 #, fuzzy
 #| msgid "Warn if a single function's framesize exceeds the given framesize"
 msgid "Warn if a single function's framesize exceeds the given framesize."
 msgstr "当单个函数的帧大小超过给定值时给出警告"
 
-#: config/s390/s390.opt:218
+#: config/s390/s390.opt:221
 #, fuzzy
 #| msgid "z/Architecture"
 msgid "z/Architecture."
 msgstr "z/Architecture"
 
-#: config/s390/s390.opt:222
+#: config/s390/s390.opt:225
 #, fuzzy
 msgid "Set the branch costs for conditional branch instructions.  Reasonable values are small, non-negative integers.  The default branch cost is 1."
 msgstr "设置分支成本用于条件分支指令。 Reasonable 值是小，non-negative 整数。 缺省分支成本是 0。"
@@ -11642,11 +11642,11 @@
 msgid "Known ARM CPUs (for use with the -mcpu= and -mtune= options):"
 msgstr "已知 ARM 处理器 (用于 -mcpu= 和 -mtune= 选项)："
 
-#: config/arm/arm-tables.opt:359
+#: config/arm/arm-tables.opt:353
 msgid "Known ARM architectures (for use with the -march= option):"
 msgstr "已知 ARM 架构 (用于 -march= 选项)："
 
-#: config/arm/arm-tables.opt:471
+#: config/arm/arm-tables.opt:465
 msgid "Known ARM FPUs (for use with the -mfpu= option):"
 msgstr "已知 ARM 浮点处理器 (用于 -mfpu= 选项)："
 
@@ -11949,107 +11949,125 @@
 msgstr "使用 UltraSPARC 可视化指令集"
 
 #: config/sparc/sparc.opt:86
+msgid "Use additional VIS instructions introduced in OSA2017."
+msgstr ""
+
+#: config/sparc/sparc.opt:90
 #, fuzzy
 msgid "Use UltraSPARC Compare-and-Branch extensions."
 msgstr "使用 UltraSPARC 可视化指令集"
 
-#: config/sparc/sparc.opt:90
+#: config/sparc/sparc.opt:94
 #, fuzzy
 msgid "Use UltraSPARC Fused Multiply-Add extensions."
 msgstr "使用 UltraSPARC 可视化指令集"
 
-#: config/sparc/sparc.opt:94
+#: config/sparc/sparc.opt:98
+msgid "Use Floating-point Multiply Single to Double (FsMULd) instruction."
+msgstr ""
+
+#: config/sparc/sparc.opt:102
 #, fuzzy
 msgid "Use UltraSPARC Population-Count instruction."
 msgstr "使用硬件浮点指令"
 
-#: config/sparc/sparc.opt:98
+#: config/sparc/sparc.opt:106
 #, fuzzy
 msgid "Use UltraSPARC Subtract-Extended-with-Carry instruction."
 msgstr "使用硬件浮点指令"
 
-#: config/sparc/sparc.opt:102
+#: config/sparc/sparc.opt:110
 #, fuzzy
 #| msgid "Pointers are 64-bit"
 msgid "Pointers are 64-bit."
 msgstr "指针是 64 位"
 
-#: config/sparc/sparc.opt:106
+#: config/sparc/sparc.opt:114
 #, fuzzy
 #| msgid "Pointers are 32-bit"
 msgid "Pointers are 32-bit."
 msgstr "指针是 32 位"
 
-#: config/sparc/sparc.opt:110
+#: config/sparc/sparc.opt:118
 #, fuzzy
 #| msgid "Use 64-bit ABI"
 msgid "Use 64-bit ABI."
 msgstr "使用 64 位 ABI"
 
-#: config/sparc/sparc.opt:114
+#: config/sparc/sparc.opt:122
 #, fuzzy
 #| msgid "Use 32-bit ABI"
 msgid "Use 32-bit ABI."
 msgstr "使用 32 位 ABI"
 
-#: config/sparc/sparc.opt:118
+#: config/sparc/sparc.opt:126
 #, fuzzy
 #| msgid "Use stack bias"
 msgid "Use stack bias."
 msgstr "使用堆栈偏移"
 
-#: config/sparc/sparc.opt:122
+#: config/sparc/sparc.opt:130
 #, fuzzy
 #| msgid "Use structs on stronger alignment for double-word copies"
 msgid "Use structs on stronger alignment for double-word copies."
 msgstr "为结构使用更强的对齐以使用双字复制"
 
-#: config/sparc/sparc.opt:126
+#: config/sparc/sparc.opt:134
 #, fuzzy
 #| msgid "Optimize tail call instructions in assembler and linker"
 msgid "Optimize tail call instructions in assembler and linker."
 msgstr "在汇编器和链接器中优化尾调用指令"
 
-#: config/sparc/sparc.opt:130
+#: config/sparc/sparc.opt:138
 #, fuzzy
 #| msgid "Generate code for the supervisor mode (default)"
 msgid "Do not generate code that can only run in supervisor mode (default)."
 msgstr "生成监视者 (supervisor) 模式的代码"
 
-#: config/sparc/sparc.opt:134 config/visium/visium.opt:45
+#: config/sparc/sparc.opt:142 config/visium/visium.opt:45
 #, fuzzy
 #| msgid "Use features of and schedule code for given CPU"
 msgid "Use features of and schedule code for given CPU."
 msgstr "使用指定 CPU 的特性和调度代码"
 
-#: config/sparc/sparc.opt:214
+#: config/sparc/sparc.opt:225
 #, fuzzy
 #| msgid "Use given SPARC-V9 code model"
 msgid "Use given SPARC-V9 code model."
 msgstr "使用给定的 SPARC-V9 代码模型"
 
-#: config/sparc/sparc.opt:218
+#: config/sparc/sparc.opt:229
 #, fuzzy
 #| msgid "Enable debug output"
 msgid "Enable debug output."
 msgstr "开启调试输出"
 
-#: config/sparc/sparc.opt:222
+#: config/sparc/sparc.opt:233
 msgid "Enable strict 32-bit psABI struct return checking."
 msgstr "启用严格的 32 位 psABI 结构返回检查"
 
-#: config/sparc/sparc.opt:226
+#: config/sparc/sparc.opt:237
 #, fuzzy
 msgid "Enable workaround for single erratum of AT697F processor (corresponding to erratum #13 of AT697E processor)."
 msgstr "启用变通方法用於单一 erratum 的 AT697F 处理器"
 
-#: config/sparc/sparc.opt:231
+#: config/sparc/sparc.opt:242
 #, fuzzy
 msgid "Enable workarounds for the errata of the UT699 processor."
 msgstr "启用变通方法用於单一 erratum 的 AT697F 处理器"
 
-#: config/sparc/sparc.opt:260
+#: config/sparc/sparc.opt:246
 #, fuzzy
+msgid "Enable workarounds for the errata of the UT699E/UT700 processor."
+msgstr "启用变通方法用於单一 erratum 的 AT697F 处理器"
+
+#: config/sparc/sparc.opt:250
+#, fuzzy
+msgid "Enable workarounds for the errata of the GR712RC processor."
+msgstr "启用变通方法用於单一 erratum 的 AT697F 处理器"
+
+#: config/sparc/sparc.opt:283
+#, fuzzy
 msgid "Specify the memory model in effect for the program."
 msgstr "指定内存式样在中效果用于程序。"
 
@@ -17932,7 +17950,7 @@
 msgstr ""
 
 #: common.opt:2495
-msgid "Detect paths that trigger erroneous or undefined behavior due a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
+msgid "Detect paths that trigger erroneous or undefined behavior due to a null value being used in a way forbidden by a returns_nonnull or nonnull attribute.  Isolate those paths from the main control flow and turn the statement with erroneous or undefined behavior into a trap."
 msgstr ""
 
 #: common.opt:2502
@@ -18465,7 +18483,7 @@
 msgstr "需要整数或布尔类型"
 
 #: go/gofrontend/expressions.cc:4204 c/c-parser.c:12782 c/c-parser.c:12789
-#: cp/parser.c:32592 cp/parser.c:32599
+#: cp/parser.c:32615 cp/parser.c:32622
 #, fuzzy, gcc-internal-format
 #| msgid "Expected integer"
 msgid "expected integer"
@@ -18787,138 +18805,138 @@
 msgid "range clause must have array, slice, string, map, or channel type"
 msgstr "右实参必须是一个切片或字符串"
 
-#: go/gofrontend/types.cc:513
+#: go/gofrontend/types.cc:525
 #, fuzzy
 msgid "invalid comparison of non-ordered type"
 msgstr "非成员函数类型上的限定符无效"
 
-#: go/gofrontend/types.cc:529
+#: go/gofrontend/types.cc:541
 #, fuzzy
 msgid "slice can only be compared to nil"
 msgstr "重复的类只会被编译一次"
 
-#: go/gofrontend/types.cc:531
+#: go/gofrontend/types.cc:543
 #, fuzzy
 msgid "map can only be compared to nil"
 msgstr "重复的类只会被编译一次"
 
-#: go/gofrontend/types.cc:533
+#: go/gofrontend/types.cc:545
 #, fuzzy
 msgid "func can only be compared to nil"
 msgstr "重复的类只会被编译一次"
 
-#: go/gofrontend/types.cc:539
+#: go/gofrontend/types.cc:551
 #, fuzzy, c-format
 msgid "invalid operation (%s)"
 msgstr "操作无效的对象"
 
-#: go/gofrontend/types.cc:562
+#: go/gofrontend/types.cc:574
 #, fuzzy
 msgid "invalid comparison of non-comparable type"
 msgstr "非成员函数类型上的限定符无效"
 
-#: go/gofrontend/types.cc:575
+#: go/gofrontend/types.cc:587
 #, fuzzy
 msgid "invalid comparison of generated struct"
 msgstr "gimple 条件中比较代码无效"
 
-#: go/gofrontend/types.cc:586
+#: go/gofrontend/types.cc:598
 #, fuzzy
 msgid "invalid comparison of non-comparable struct"
 msgstr "gimple 条件中比较代码无效"
 
-#: go/gofrontend/types.cc:596
+#: go/gofrontend/types.cc:608
 #, fuzzy
 msgid "invalid comparison of generated array"
 msgstr "对非左值数组的使用无效"
 
-#: go/gofrontend/types.cc:603
+#: go/gofrontend/types.cc:615
 #, fuzzy
 msgid "invalid comparison of non-comparable array"
 msgstr "对非左值数组的使用无效"
 
-#: go/gofrontend/types.cc:631
+#: go/gofrontend/types.cc:643
 #, fuzzy
 msgid "multiple-value function call in single-value context"
 msgstr "%qD的声明中类名无效"
 
-#: go/gofrontend/types.cc:708
+#: go/gofrontend/types.cc:720
 msgid "need explicit conversion"
 msgstr "需要显式转换"
 
-#: go/gofrontend/types.cc:715
+#: go/gofrontend/types.cc:727
 #, c-format
 msgid "cannot use type %s as type %s"
 msgstr "不能将类型 %s 用作 %s"
 
-#: go/gofrontend/types.cc:3849
+#: go/gofrontend/types.cc:3864
 msgid "different receiver types"
 msgstr "不同的接收器类型"
 
-#: go/gofrontend/types.cc:3869 go/gofrontend/types.cc:3882
-#: go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3884 go/gofrontend/types.cc:3897
+#: go/gofrontend/types.cc:3912
 msgid "different number of parameters"
 msgstr "形参数量不同"
 
-#: go/gofrontend/types.cc:3890
+#: go/gofrontend/types.cc:3905
 msgid "different parameter types"
 msgstr "形参类型不同"
 
-#: go/gofrontend/types.cc:3905
+#: go/gofrontend/types.cc:3920
 msgid "different varargs"
 msgstr "不同的可变参数"
 
-#: go/gofrontend/types.cc:3914 go/gofrontend/types.cc:3927
-#: go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3929 go/gofrontend/types.cc:3942
+#: go/gofrontend/types.cc:3958
 #, fuzzy
 msgid "different number of results"
 msgstr "形参数量不同"
 
-#: go/gofrontend/types.cc:3935
+#: go/gofrontend/types.cc:3951
 #, fuzzy
 msgid "different result types"
 msgstr "不同的接收器类型"
 
-#: go/gofrontend/types.cc:8423
+#: go/gofrontend/types.cc:8445
 #, c-format
 msgid "need explicit conversion; missing method %s%s%s"
 msgstr "需要显式转换；缺少方法%s%s%s"
 
-#: go/gofrontend/types.cc:8440 go/gofrontend/types.cc:8582
+#: go/gofrontend/types.cc:8462 go/gofrontend/types.cc:8605
 #, c-format
 msgid "incompatible type for method %s%s%s"
 msgstr "方法%s%s%s类型不兼容"
 
-#: go/gofrontend/types.cc:8444 go/gofrontend/types.cc:8586
+#: go/gofrontend/types.cc:8466 go/gofrontend/types.cc:8609
 #, fuzzy, c-format
 msgid "incompatible type for method %s%s%s (%s)"
 msgstr "方法%s%s%s类型不兼容"
 
-#: go/gofrontend/types.cc:8523 go/gofrontend/types.cc:8536
+#: go/gofrontend/types.cc:8545 go/gofrontend/types.cc:8558
 #, fuzzy
 msgid "pointer to interface type has no methods"
 msgstr "类型没有方法"
 
-#: go/gofrontend/types.cc:8525 go/gofrontend/types.cc:8538
+#: go/gofrontend/types.cc:8547 go/gofrontend/types.cc:8560
 msgid "type has no methods"
 msgstr "类型没有方法"
 
-#: go/gofrontend/types.cc:8559
+#: go/gofrontend/types.cc:8581
 #, c-format
 msgid "ambiguous method %s%s%s"
 msgstr "有歧义的方法%s%s%s"
 
-#: go/gofrontend/types.cc:8562
+#: go/gofrontend/types.cc:8584
 #, c-format
 msgid "missing method %s%s%s"
 msgstr "缺少方法%s%s%s"
 
-#: go/gofrontend/types.cc:8603
+#: go/gofrontend/types.cc:8626
 #, fuzzy, c-format
 msgid "method %s%s%s requires a pointer receiver"
 msgstr "方法%s%s%s需要一个指针"
 
-#: go/gofrontend/types.cc:8621
+#: go/gofrontend/types.cc:8644
 #, fuzzy, c-format
 msgid "method %s%s%s is marked go:nointerface"
 msgstr "方法%s%s%s需要一个指针"
@@ -19094,7 +19112,7 @@
 msgid "specified bound %wu equals the size of the destination"
 msgstr ""
 
-#: builtins.c:4640 gimplify.c:3149
+#: builtins.c:4640 gimplify.c:3150
 #, gcc-internal-format
 msgid "too few arguments to function %<va_start%>"
 msgstr "给函数%<va_start%>的参数太少"
@@ -19156,27 +19174,27 @@
 msgid "invalid memory model for %<__atomic_load%>"
 msgstr "错误地使用了%<auto%>"
 
-#: builtins.c:5881 builtins.c:6068
+#: builtins.c:5881 builtins.c:6074
 #, fuzzy, gcc-internal-format
 msgid "invalid memory model for %<__atomic_store%>"
 msgstr "gimple 内存存储中右操作数无效"
 
-#: builtins.c:6186
+#: builtins.c:6192
 #, fuzzy, gcc-internal-format
 msgid "non-constant argument 1 to __atomic_always_lock_free"
 msgstr "non-constant 参数 1 到 __atomic_always_lock_free"
 
-#: builtins.c:6228
+#: builtins.c:6234
 #, fuzzy, gcc-internal-format
 msgid "non-integer argument 1 to __atomic_is_lock_free"
 msgstr "non-integer 参数 1 到 __atomic_is_lock_free"
 
-#: builtins.c:6292
+#: builtins.c:6298
 #, fuzzy, gcc-internal-format
 msgid "__builtin_thread_pointer is not supported on this target"
 msgstr "__builtin_saveregs 不为此目标所支持"
 
-#: builtins.c:6312
+#: builtins.c:6318
 #, fuzzy, gcc-internal-format
 msgid "__builtin_set_thread_pointer is not supported on this target"
 msgstr "__builtin_eh_return 在此目标机上不受支持"
@@ -19183,7 +19201,7 @@
 
 #. All valid uses of __builtin_va_arg_pack () are removed during
 #. inlining.
-#: builtins.c:6572 expr.c:10797
+#: builtins.c:6578 expr.c:10795
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack ()%>"
 msgstr "%K对%<__builtin_va_arg_pack ()%>的使用无效"
@@ -19190,12 +19208,12 @@
 
 #. All valid uses of __builtin_va_arg_pack_len () are removed during
 #. inlining.
-#: builtins.c:6578
+#: builtins.c:6584
 #, gcc-internal-format
 msgid "%Kinvalid use of %<__builtin_va_arg_pack_len ()%>"
 msgstr "%K对%<__builtin_va_arg_pack_len ()%>的使用无效"
 
-#: builtins.c:6815
+#: builtins.c:6821
 #, gcc-internal-format
 msgid "%<__builtin_longjmp%> second argument must be 1"
 msgstr "%<__builtin_longjmp%>的第二个实参必须是 1"
@@ -19202,63 +19220,63 @@
 
 #. Software implementation of Pointer Bounds Checker is NYI.
 #. Target support is required.
-#: builtins.c:7457
+#: builtins.c:7463
 #, gcc-internal-format
 msgid "Your target platform does not support -fcheck-pointer-bounds"
 msgstr "目标平台不支持 -fcheck-pointer-bounds"
 
-#: builtins.c:7776
+#: builtins.c:7782
 #, gcc-internal-format
 msgid "target format does not support infinity"
 msgstr "目标格式不支持无限大浮点数"
 
-#: builtins.c:9394
+#: builtins.c:9400
 #, gcc-internal-format
 msgid "%<va_start%> used in function with fixed args"
 msgstr "在定参数的函数中使用了%<va_start%>"
 
-#: builtins.c:9402
+#: builtins.c:9408
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<va_start%>"
 msgstr "给函数%<va_start%>的参数数目不对"
 
-#: builtins.c:9417
+#: builtins.c:9423
 #, gcc-internal-format
 msgid "%<__builtin_next_arg%> called without an argument"
 msgstr "调用%<__builtin_next_arg%>时没有给定实参"
 
-#: builtins.c:9422
+#: builtins.c:9428
 #, gcc-internal-format
 msgid "wrong number of arguments to function %<__builtin_next_arg%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: builtins.c:9454
+#: builtins.c:9460
 #, gcc-internal-format
 msgid "second parameter of %<va_start%> not last named argument"
 msgstr "%<va_start%>的第二个参数不是最后一个有名参数"
 
-#: builtins.c:9467
+#: builtins.c:9473
 #, fuzzy, gcc-internal-format
 #| msgid "undefined behaviour when second parameter of %<va_start%> is declared with %<register%> storage"
 msgid "undefined behavior when second parameter of %<va_start%> is declared with %<register%> storage"
 msgstr "当%<va_start%>的第二个参数有%<register%>存储时行为未经定义"
 
-#: builtins.c:9496
+#: builtins.c:9502
 #, gcc-internal-format
 msgid "%Kfirst argument of %D must be a pointer, second integer constant"
 msgstr "%K%D 的第一个实参必须是一个指针，第二个必须是整常量"
 
-#: builtins.c:9509
+#: builtins.c:9515
 #, gcc-internal-format
 msgid "%Klast argument of %D is not integer constant between 0 and 3"
 msgstr "%K%D 的最后一个实参不是一个 0 到 3 之间的整常量"
 
-#: builtins.c:9783
+#: builtins.c:9789
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object %qD"
 msgstr "%K试图 free 不在堆上的对象%qD"
 
-#: builtins.c:9786
+#: builtins.c:9792
 #, gcc-internal-format
 msgid "%Kattempt to free a non-heap object"
 msgstr "%K试图 free 一个不在堆上的对象"
@@ -20171,12 +20189,12 @@
 msgstr "%qE属性被忽略，因为%qT已被定义"
 
 #. include_self=
-#: cgraphunit.c:968 c/c-decl.c:11128
+#: cgraphunit.c:968 c/c-decl.c:11131
 #, gcc-internal-format
 msgid "%q+F used but never defined"
 msgstr "%q+F使用过但从未定义"
 
-#: cgraphunit.c:970 c/c-decl.c:11137
+#: cgraphunit.c:970 c/c-decl.c:11140
 #, gcc-internal-format
 msgid "%q+F declared %<static%> but never defined"
 msgstr "%q+F声明为%<static%>却从未定义过"
@@ -20272,12 +20290,12 @@
 msgid "cannot find '%s'"
 msgstr "找不到‘%s’"
 
-#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6787
+#: collect-utils.c:183 collect2.c:2361 collect2.c:2560 gcc.c:3080 gcc.c:6790
 #, fuzzy, gcc-internal-format
 msgid "pex_init failed: %m"
 msgstr "cap_init 失败"
 
-#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8428
+#: collect-utils.c:192 collect2.c:2370 collect2.c:2568 gcc.c:8431
 #, gcc-internal-format
 msgid "%s: %m"
 msgstr "%s：%m"
@@ -20287,7 +20305,7 @@
 msgid "COLLECT_LTO_WRAPPER must be set"
 msgstr "环境变量 COLLECT_GCC 必须被设置"
 
-#: collect2.c:966 gcc.c:7313 lto-wrapper.c:1479
+#: collect2.c:966 gcc.c:7316 lto-wrapper.c:1479
 #: config/i386/intelmic-mkoffload.c:554 config/nvptx/mkoffload.c:403
 #, gcc-internal-format
 msgid "atexit failed"
@@ -20499,7 +20517,7 @@
 msgid "error writing %qs"
 msgstr "写入%qs时错误"
 
-#: coverage.c:1245
+#: coverage.c:1257
 #, gcc-internal-format, gfc-internal-format
 msgid "cannot open %s"
 msgstr "不能打开 %s"
@@ -20579,17 +20597,17 @@
 msgid "ignoring possibly conflicting option %<-fopt-info-%s%>"
 msgstr ""
 
-#: dwarf2out.c:1093
+#: dwarf2out.c:1097
 #, fuzzy, gcc-internal-format
 msgid "multiple EH personalities are supported only with assemblers supporting .cfi_personality directive"
 msgstr "多个 EH 个性需要汇编器支持 .cfi.personality 指示。"
 
-#: dwarf2out.c:13685
+#: dwarf2out.c:13689
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "non-delegitimized UNSPEC %s (%d) found in variable location"
 msgstr "变量位置处发现未被非法化的 UNSPEC %d"
 
-#: dwarf2out.c:27308
+#: dwarf2out.c:27319
 #, gcc-internal-format
 msgid "-feliminate-dwarf2-dups is broken for C++, ignoring"
 msgstr ""
@@ -20700,12 +20718,12 @@
 msgid "write of %wu-bit data outside the bound of destination object, data truncated into %wu-bit"
 msgstr ""
 
-#: expr.c:10804
+#: expr.c:10802
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute error: %s"
 msgstr "%K调用%qs，声明有错误属性：%s"
 
-#: expr.c:10811
+#: expr.c:10809
 #, gcc-internal-format
 msgid "%Kcall to %qs declared with attribute warning: %s"
 msgstr "%K调用%qs，声明有警告属性：%s"
@@ -20720,12 +20738,12 @@
 msgid "the frame size of %wd bytes is larger than %wd bytes"
 msgstr "栈帧有 %wd 字节，超过了 %wd 字节"
 
-#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1148
+#: final.c:4635 toplev.c:1404 tree-cfgcleanup.c:1211
 #, fuzzy, gcc-internal-format
 msgid "could not open final insn dump file %qs: %m"
 msgstr "无法打开最终指令转储文件%qs：%s"
 
-#: final.c:4688 tree-cfgcleanup.c:1164
+#: final.c:4688 tree-cfgcleanup.c:1227
 #, fuzzy, gcc-internal-format
 msgid "could not close final insn dump file %qs: %m"
 msgstr "无法关闭最终指令转储文件%qs：%s"
@@ -20740,7 +20758,7 @@
 msgid "comparison is always %d due to width of bit-field"
 msgstr "由于位段宽度所限，比较结果永远为 %d"
 
-#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2974
+#: fold-const.c:5340 tree-ssa-reassoc.c:2343 tree-ssa-reassoc.c:2983
 #, gcc-internal-format
 msgid "assuming signed overflow does not occur when simplifying range test"
 msgstr "简化范围检查时假定有符号数从不溢出"
@@ -20770,7 +20788,7 @@
 msgid "assuming signed overflow does not occur when combining constants around a comparison"
 msgstr "在比较周围组合变量时假定有符号数从不溢出"
 
-#: fold-const.c:12048
+#: fold-const.c:12049
 #, gcc-internal-format
 msgid "fold check: original tree changed by fold"
 msgstr "折叠检查: 原始树因折叠而改变 "
@@ -20780,7 +20798,7 @@
 msgid "total size of local objects too large"
 msgstr "局部对象的总大小太大"
 
-#: function.c:1765 gimplify.c:6111
+#: function.c:1765 gimplify.c:6112
 #, gcc-internal-format
 msgid "impossible constraint in %<asm%>"
 msgstr "%<asm%>中不可能的约束"
@@ -20880,62 +20898,67 @@
 msgid "input file %qs is the same as output file"
 msgstr "用法：%s [选项] [输入文件] [输出文件]\n"
 
-#: gcc.c:4498
+#: gcc.c:4476
 #, fuzzy, gcc-internal-format
+msgid "output filename may not be empty"
+msgstr "输出文件"
+
+#: gcc.c:4501
+#, fuzzy, gcc-internal-format
 msgid "-pipe ignored because -save-temps specified"
 msgstr "警告：忽略 -pipe，因为指定了 -save-temps"
 
-#: gcc.c:4586
+#: gcc.c:4589
 #, fuzzy, gcc-internal-format
 msgid "%<-x %s%> after last input file has no effect"
 msgstr "警告：出现在最后一个输入文件后的‘-x %s’不起作用"
 
-#: gcc.c:4768
+#: gcc.c:4771
 #, fuzzy, gcc-internal-format
 msgid "unable to locate default linker script %qs in the library search paths"
 msgstr "无法在库搜索路径中定位默认链接器脚本‘%s’"
 
-#: gcc.c:4973
+#: gcc.c:4976
 #, fuzzy, gcc-internal-format
 msgid "switch %qs does not start with %<-%>"
 msgstr "开关%qs不再被支持"
 
-#: gcc.c:4977
+#: gcc.c:4980
 #, fuzzy, gcc-internal-format
 msgid "spec-generated switch is just %<-%>"
 msgstr "spec-generated 切换就 %<-%>"
 
-#: gcc.c:5070
+#: gcc.c:5073
 #, gcc-internal-format, gfc-internal-format
 msgid "could not open temporary response file %s"
 msgstr "无法打开临时响应文件 %s"
 
-#: gcc.c:5077
+#: gcc.c:5080
 #, gcc-internal-format, gfc-internal-format
 msgid "could not write to temporary response file %s"
 msgstr "无法写入临时响应文件 %s"
 
-#: gcc.c:5083
+#: gcc.c:5086
 #, gcc-internal-format, gfc-internal-format
 msgid "could not close temporary response file %s"
 msgstr "无法关闭临时响应文件 %s"
 
-#: gcc.c:5206
+#: gcc.c:5209
 #, fuzzy, gcc-internal-format
 msgid "spec %qs invalid"
 msgstr "%C处类型指定无效"
 
-#: gcc.c:5356
+#: gcc.c:5359
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%0%c%>"
 msgstr "位段%qs类型无效"
 
-#: gcc.c:5677
+#: gcc.c:5680
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%W%c%>"
 msgstr "位段%qs类型无效"
 
-#: gcc.c:5700
+#: gcc.c:5703
 #, fuzzy, gcc-internal-format
 msgid "spec %qs has invalid %<%%x%c%>"
 msgstr "位段%qs类型无效"
@@ -20943,228 +20966,228 @@
 #. Catch the case where a spec string contains something like
 #. '%{foo:%*}'.  i.e. there is no * in the pattern on the left
 #. hand side of the :.
-#: gcc.c:5911
+#: gcc.c:5914
 #, fuzzy, gcc-internal-format
 msgid "spec failure: %<%%*%> has not been initialized by pattern match"
 msgstr "spec 失败：‘%%*’未经模式匹配初始化"
 
-#: gcc.c:5954
+#: gcc.c:5957
 #, fuzzy, gcc-internal-format
 msgid "spec failure: unrecognized spec option %qc"
 msgstr "spec 错误：无法识别的 spec 选项‘%c’"
 
-#: gcc.c:6016
+#: gcc.c:6019
 #, fuzzy, gcc-internal-format
 msgid "unknown spec function %qs"
 msgstr "spec 函数名格式错误"
 
-#: gcc.c:6046
+#: gcc.c:6049
 #, fuzzy, gcc-internal-format
 msgid "error in args to spec function %qs"
 msgstr "给 spec 函数‘%s’的参数有错"
 
-#: gcc.c:6100
+#: gcc.c:6103
 #, gcc-internal-format
 msgid "malformed spec function name"
 msgstr "spec 函数名格式错误"
 
 #. )
-#: gcc.c:6103
+#: gcc.c:6106
 #, gcc-internal-format
 msgid "no arguments for spec function"
 msgstr "spec 函数没有参数"
 
-#: gcc.c:6122
+#: gcc.c:6125
 #, gcc-internal-format
 msgid "malformed spec function arguments"
 msgstr "spec 函数参数格式错误"
 
-#: gcc.c:6396
+#: gcc.c:6399
 #, fuzzy, gcc-internal-format
 msgid "braced spec %qs is invalid at %qc"
 msgstr "花括号中的 spec‘%s’在‘%c’中无效"
 
-#: gcc.c:6491
+#: gcc.c:6494
 #, fuzzy, gcc-internal-format
 msgid "braced spec body %qs is invalid"
 msgstr "花括号中的 spec 体‘%s’无效"
 
-#: gcc.c:7097
+#: gcc.c:7100
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not determine length of compare-debug file %s"
 msgstr "%s：无法确定比较调试文件 %s 的长度"
 
-#: gcc.c:7108
+#: gcc.c:7111
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure (length)"
 msgstr "%s：-fcompare-debug 失败(长度)"
 
-#: gcc.c:7118 gcc.c:7159
+#: gcc.c:7121 gcc.c:7162
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: could not open compare-debug file %s"
 msgstr "%s：无法打开比较调试文件 %s"
 
-#: gcc.c:7138 gcc.c:7175
+#: gcc.c:7141 gcc.c:7178
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: -fcompare-debug failure"
 msgstr "%s：-fcompare-debug 失败"
 
-#: gcc.c:7483
+#: gcc.c:7486
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_SUFFIX_SPEC"
 msgstr "spec 失败：SYSROOT_SUFFIX_SPEC 参数多于一个"
 
-#: gcc.c:7507
+#: gcc.c:7510
 #, gcc-internal-format
 msgid "spec failure: more than one arg to SYSROOT_HEADERS_SUFFIX_SPEC"
 msgstr "spec 失败：SYSROOT_HEADERS_SUFFIX_SPEC 参数多于一个"
 
-#: gcc.c:7812
+#: gcc.c:7815
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>; did you mean %<-%s%>?"
 msgstr "命令行选项文件“%s”不存在"
 
-#: gcc.c:7816
+#: gcc.c:7819
 #, fuzzy, gcc-internal-format
 msgid "unrecognized command line option %<-%s%>"
 msgstr "%P：无法识别的选项‘%s’\n"
 
-#: gcc.c:7942
+#: gcc.c:7945
 #, gcc-internal-format
 msgid "not configured with sysroot headers suffix"
 msgstr "没有配置 sysroot 头文件后缀"
 
-#: gcc.c:8003
+#: gcc.c:8006
 #, gcc-internal-format
 msgid "no input files"
 msgstr "没有输入文件"
 
-#: gcc.c:8054
+#: gcc.c:8057
 #, gcc-internal-format
 msgid "cannot specify -o with -c, -S or -E with multiple files"
 msgstr "当有多个文件时不能在已指定 -c 或 -S 的情况下指定 -o"
 
-#: gcc.c:8095
+#: gcc.c:8098
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: %s compiler not installed on this system"
 msgstr "%s：此系统未安装 %s 编译器"
 
-#: gcc.c:8119
+#: gcc.c:8122
 #, fuzzy, gcc-internal-format
 msgid "recompiling with -fcompare-debug"
 msgstr "在 -fcompare-debug 重新编译时"
 
-#: gcc.c:8135
+#: gcc.c:8138
 #, gcc-internal-format
 msgid "during -fcompare-debug recompilation"
 msgstr "在 -fcompare-debug 重新编译时"
 
-#: gcc.c:8144
+#: gcc.c:8147
 #, fuzzy, gcc-internal-format
 msgid "comparing final insns dumps"
 msgstr "比较最终指令转储"
 
-#: gcc.c:8261
+#: gcc.c:8264
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "-fuse-linker-plugin, but %s not found"
 msgstr "使用了 -fuse-linker-plugin，但"
 
-#: gcc.c:8294
+#: gcc.c:8297
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: linker input file unused because linking not done"
 msgstr "%s：未使用链接器输入文件，因为链接尚未完成"
 
-#: gcc.c:8350 c-family/c-opts.c:749
+#: gcc.c:8353 c-family/c-opts.c:749
 #, gcc-internal-format
 msgid "cannot use %<-%> as input filename for a precompiled header"
 msgstr ""
 
-#: gcc.c:8356
+#: gcc.c:8359
 #, gcc-internal-format, gfc-internal-format
 msgid "language %s not recognized"
 msgstr "语言 %s 未能被识别"
 
-#: gcc.c:8596
+#: gcc.c:8599
 #, fuzzy, gcc-internal-format
 msgid "multilib spec %qs is invalid"
 msgstr "%C处类型指定无效"
 
-#: gcc.c:8798
+#: gcc.c:8801
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusions %qs is invalid"
 msgstr "属性%qs的参数无效"
 
-#: gcc.c:8862
+#: gcc.c:8865
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs %qs is invalid"
 msgstr "属性%qs的参数无效"
 
-#: gcc.c:9024
+#: gcc.c:9027
 #, fuzzy, gcc-internal-format
 msgid "multilib select %qs is invalid"
 msgstr "%<long long%>对%qs无效"
 
-#: gcc.c:9064
+#: gcc.c:9067
 #, fuzzy, gcc-internal-format
 msgid "multilib exclusion %qs is invalid"
 msgstr "属性%qs的参数无效"
 
-#: gcc.c:9279
+#: gcc.c:9282
 #, gcc-internal-format
 msgid "environment variable %qs not defined"
 msgstr "环境变量%qs未定义"
 
-#: gcc.c:9418 gcc.c:9423
+#: gcc.c:9421 gcc.c:9426
 #, gcc-internal-format
 msgid "invalid version number %qs"
 msgstr "无效的版本号%qs"
 
-#: gcc.c:9466
+#: gcc.c:9469
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:version-compare"
 msgstr "%%：version-compare 的参数太少"
 
-#: gcc.c:9472
+#: gcc.c:9475
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:version-compare"
 msgstr "%%：version-compare 的参数太多"
 
-#: gcc.c:9514
+#: gcc.c:9517
 #, fuzzy, gcc-internal-format
 msgid "unknown operator %qs in %%:version-compare"
 msgstr "%%:version-compare 中有未知的运算符‘%s’"
 
-#: gcc.c:9638
+#: gcc.c:9641
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-dump-opt"
 msgstr "%%:compare-debug-dump-opt 的参数太多"
 
-#: gcc.c:9711
+#: gcc.c:9714
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-self-opt"
 msgstr "%%:compare-debug-self-opt 的参数太多"
 
-#: gcc.c:9747
+#: gcc.c:9750
 #, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:compare-debug-auxbase-opt"
 msgstr "%%:compare-debug-auxbase-opt 的参数太少"
 
-#: gcc.c:9751
+#: gcc.c:9754
 #, gcc-internal-format, gfc-internal-format
 msgid "too many arguments to %%:compare-debug-auxbase-opt"
 msgstr "%%:compare-debug-auxbase-opt 的参数太多"
 
-#: gcc.c:9758
+#: gcc.c:9761
 #, gcc-internal-format, gfc-internal-format
 msgid "argument to %%:compare-debug-auxbase-opt does not end in .gk"
 msgstr "%%:compare-debug-auxbase-opt 的参数未以 .gk 结尾"
 
-#: gcc.c:9832
+#: gcc.c:9835
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "too few arguments to %%:replace-extension"
 msgstr "%%：version-compare 的参数太少"
 
-#: gcc.c:9885
+#: gcc.c:9888
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of arguments to %%:debug-level-gt"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -21313,9 +21336,9 @@
 #: gimple-ssa-isolate-paths.c:413 gimple-ssa-isolate-paths.c:531 tree.c:12880
 #: tree.c:12917 c/c-typeck.c:2906 c/c-typeck.c:2990 c/c-typeck.c:9913
 #: c/c-typeck.c:9930 c/gimple-parser.c:1556 c/gimple-parser.c:1564
-#: cp/call.c:6454 cp/call.c:7933 cp/constexpr.c:777 cp/constexpr.c:2174
-#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5072 cp/pt.c:7993
-#: cp/semantics.c:1764 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
+#: cp/call.c:6454 cp/call.c:7936 cp/constexpr.c:778 cp/constexpr.c:2190
+#: cp/cvt.c:992 cp/cvt.c:1019 cp/decl.c:7224 cp/decl2.c:5073 cp/pt.c:8075
+#: cp/semantics.c:1767 cp/typeck.c:1648 cp/typeck.c:1843 cp/typeck.c:3718
 #, gcc-internal-format
 msgid "declared here"
 msgstr "在此声明"
@@ -21741,232 +21764,232 @@
 msgid "attribute %<fallthrough%> not preceding a case label or default label"
 msgstr ""
 
-#: gimplify.c:3289
+#: gimplify.c:3290
 #, gcc-internal-format
 msgid "using result of function returning %<void%>"
 msgstr "使用返回%<void%>的函数的结果"
 
-#: gimplify.c:5969
+#: gimplify.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "invalid lvalue in asm output %d"
 msgstr "汇编输出 %d 中左值无效"
 
-#: gimplify.c:6112
+#: gimplify.c:6113
 #, gcc-internal-format, gfc-internal-format
 msgid "non-memory input %d must stay in memory"
 msgstr "非内存输入 %d 必须在内存中"
 
-#: gimplify.c:6152 gimplify.c:6161
+#: gimplify.c:6153 gimplify.c:6162
 #, gcc-internal-format, gfc-internal-format
 msgid "memory input %d is not directly addressable"
 msgstr "内存输入 %d 不可直接寻址"
 
-#: gimplify.c:6764
+#: gimplify.c:6767
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in target region"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: gimplify.c:6766
+#: gimplify.c:6769
 #, fuzzy, gcc-internal-format
 msgid "enclosing target region"
 msgstr "括入并行"
 
-#: gimplify.c:6778
+#: gimplify.c:6781
 #, fuzzy, gcc-internal-format
 msgid "threadprivate variable %qE used in untied task"
 msgstr "嵌套函数中使用了寄存器变量%qD"
 
-#: gimplify.c:6780
+#: gimplify.c:6783
 #, fuzzy, gcc-internal-format
 msgid "enclosing task"
 msgstr "括入并行"
 
-#: gimplify.c:6852
+#: gimplify.c:6855
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing %qs"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:6854
+#: gimplify.c:6857
 #, fuzzy, gcc-internal-format
 msgid "enclosing %qs"
 msgstr "括入并行"
 
-#: gimplify.c:6965
+#: gimplify.c:6968
 #, fuzzy, gcc-internal-format
 msgid "%qE not specified in enclosing OpenACC %qs construct"
 msgstr "%qE未为在括入的并行中指定"
 
-#: gimplify.c:6967
+#: gimplify.c:6970
 #, fuzzy, gcc-internal-format
 msgid "enclosing OpenACC %qs construct"
 msgstr "括入并行"
 
-#: gimplify.c:7018
+#: gimplify.c:7021
 #, gcc-internal-format
 msgid "%qE with %<link%> clause used in %<routine%> function"
 msgstr ""
 
-#: gimplify.c:7026
+#: gimplify.c:7029
 #, fuzzy, gcc-internal-format
 #| msgid "%qE undeclared (first use in this function)"
 msgid "%qE requires a %<declare%> directive for use in a %<routine%> function"
 msgstr "%qE未声明(在此函数内第一次使用)"
 
-#: gimplify.c:7092 gimplify.c:7692
+#: gimplify.c:7095 gimplify.c:7695
 #, fuzzy, gcc-internal-format
 #| msgid "variable %q+D declared %<inline%>"
 msgid "variable %qE declared in enclosing %<host_data%> region"
 msgstr "变量%q+D声明为%<inline%>"
 
-#: gimplify.c:7113
+#: gimplify.c:7116
 #, gcc-internal-format
 msgid "%qD referenced in target region does not have a mappable type"
 msgstr ""
 
-#: gimplify.c:7231 gimplify.c:7263
+#: gimplify.c:7234 gimplify.c:7266
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE is predetermined linear"
 msgstr "迭代变量%qE不应当是 reduction"
 
-#: gimplify.c:7234
+#: gimplify.c:7237
 #, gcc-internal-format
 msgid "iteration variable %qE should be private"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:7248
+#: gimplify.c:7251
 #, gcc-internal-format
 msgid "iteration variable %qE should not be firstprivate"
 msgstr "迭代变量%qE不应当是 firstprivate"
 
-#: gimplify.c:7251
+#: gimplify.c:7254
 #, gcc-internal-format
 msgid "iteration variable %qE should not be reduction"
 msgstr "迭代变量%qE不应当是 reduction"
 
-#: gimplify.c:7254
+#: gimplify.c:7257
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be linear"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:7257
+#: gimplify.c:7260
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be lastprivate"
 msgstr "迭代变量%qE不应当是 firstprivate"
 
-#: gimplify.c:7260
+#: gimplify.c:7263
 #, fuzzy, gcc-internal-format
 msgid "iteration variable %qE should not be private"
 msgstr "迭代变量%qE应当是私有的"
 
-#: gimplify.c:7562
+#: gimplify.c:7565
 #, gcc-internal-format
 msgid "%<linear%> clause for variable other than loop iterator specified on construct combined with %<distribute%>"
 msgstr ""
 
-#: gimplify.c:7769
+#: gimplify.c:7772
 #, gcc-internal-format
 msgid "mapping field %qE of variable length structure"
 msgstr ""
 
-#: gimplify.c:7980
+#: gimplify.c:7983
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: gimplify.c:8284
+#: gimplify.c:8287
 #, fuzzy, gcc-internal-format
 msgid "copyprivate variable %qE is not threadprivate or private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:8304
+#: gimplify.c:8307
 #, gcc-internal-format
 msgid "%s variable %qE is private in outer context"
 msgstr "%s 变量%qE在外层上下文中是私有的"
 
-#: gimplify.c:8330
+#: gimplify.c:8333
 #, fuzzy, gcc-internal-format
 msgid "expected %qs %<if%> clause modifier rather than %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: gimplify.c:8596
+#: gimplify.c:8599
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<map%> clause"
 msgstr ""
 
-#: gimplify.c:8629
+#: gimplify.c:8632
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in implicit %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8802
+#: gimplify.c:8805
 #, gcc-internal-format
 msgid "%<_Atomic%> %qD in %<firstprivate%> clause on %<target%> construct"
 msgstr ""
 
-#: gimplify.c:8853
+#: gimplify.c:8856
 #, gcc-internal-format
 msgid "same variable used in %<firstprivate%> and %<lastprivate%> clauses on %<distribute%> construct"
 msgstr ""
 
-#: gimplify.c:8935
+#: gimplify.c:8938
 #, gcc-internal-format
 msgid "incompatible data clause with reduction on %qE; promoting to present_or_copy"
 msgstr ""
 
-#: gimplify.c:9080
+#: gimplify.c:9083
 #, fuzzy, gcc-internal-format
 #| msgid "invalid template declaration of %qD"
 msgid "invalid private reduction on %qE"
 msgstr "%qD模板声明无效"
 
-#: gimplify.c:10904 omp-low.c:2814
+#: gimplify.c:10907 omp-low.c:2842
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside a loop with %<ordered%> clause with a parameter"
 msgstr "有序区域必须紧密嵌套在一个有次序分句的循环内"
 
-#: gimplify.c:10922
+#: gimplify.c:10925
 #, gcc-internal-format
 msgid "variable %qE is not an iteration of outermost loop %d, expected %qE"
 msgstr ""
 
-#: gimplify.c:10935
+#: gimplify.c:10938
 #, fuzzy, gcc-internal-format
 #| msgid "number of results does not match number of values"
 msgid "number of variables in %<depend(sink)%> clause does not match number of iteration variables"
 msgstr "返回值的数量不匹配值的数量"
 
-#: gimplify.c:10948
+#: gimplify.c:10951
 #, gcc-internal-format
 msgid "more than one %<depend(source)%> clause on an %<ordered%> construct"
 msgstr ""
 
-#: gimplify.c:10959
+#: gimplify.c:10962
 #, gcc-internal-format
 msgid "%<depend(source)%> clause specified together with %<depend(sink:)%> clauses on the same construct"
 msgstr ""
 
-#: gimplify.c:11902
+#: gimplify.c:11905
 #, fuzzy, gcc-internal-format
 msgid "expected %<_Cilk_spawn%> before %<_Cilk_sync%>"
 msgstr "%<else%>前需要%<}%>"
 
-#: gimplify.c:12201
+#: gimplify.c:12204
 #, gcc-internal-format
 msgid "gimplification failed"
 msgstr "gimplification 失败"
 
-#: gimplify.c:12729
+#: gimplify.c:12732
 #, gcc-internal-format
 msgid "%qT is promoted to %qT when passed through %<...%>"
 msgstr "通过%<...%>传递时%qT被提升为%qT"
 
-#: gimplify.c:12734
+#: gimplify.c:12737
 #, gcc-internal-format
 msgid "(so you should pass %qT not %qT to %<va_arg%>)"
 msgstr "(因此您应该向%<va_arg%>传递%qT而不是%qT)"
 
-#: gimplify.c:12741
+#: gimplify.c:12744
 #, gcc-internal-format
 msgid "if this code is reached, the program will abort"
 msgstr "如果执行到这段代码，程序将中止"
@@ -22202,7 +22225,7 @@
 
 #: ipa-devirt.c:1229
 #, fuzzy, gcc-internal-format
-msgid "type %qT itself violate the C++ One Definition Rule"
+msgid "type %qT itself violates the C++ One Definition Rule"
 msgstr "先前的定义在这里"
 
 #: ipa-devirt.c:1235
@@ -22302,7 +22325,7 @@
 
 #: ipa-devirt.c:1576
 #, fuzzy, gcc-internal-format
-msgid "fields has different layout in another translation unit"
+msgid "fields have different layout in another translation unit"
 msgstr "%qE未声明(不在函数内)"
 
 #: ipa-devirt.c:1599
@@ -22686,207 +22709,207 @@
 msgid "multiple loop axes specified for routine"
 msgstr "为类型名指定了存储类"
 
-#: omp-low.c:2120 omp-offload.c:1124
+#: omp-low.c:2148 omp-offload.c:1124
 #, gcc-internal-format
 msgid "%<seq%> overrides other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2123 omp-offload.c:1125
+#: omp-low.c:2151 omp-offload.c:1125
 #, gcc-internal-format
 msgid "%<auto%> conflicts with other OpenACC loop specifiers"
 msgstr ""
 
-#: omp-low.c:2127 omp-offload.c:1159
+#: omp-low.c:2155 omp-offload.c:1159
 #, gcc-internal-format
 msgid "inner loop uses same OpenACC parallelism as containing loop"
 msgstr ""
 
-#: omp-low.c:2174
+#: omp-low.c:2202
 #, gcc-internal-format
 msgid "argument not permitted on %qs clause in OpenACC %<parallel%>"
 msgstr ""
 
-#: omp-low.c:2443
+#: omp-low.c:2471
 #, fuzzy, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC routine"
 msgstr "%P: 找不到 %s 于 %s 内部\n"
 
-#: omp-low.c:2452
+#: omp-low.c:2480
 #, gcc-internal-format
 msgid "non-OpenACC construct inside of OpenACC region"
 msgstr ""
 
-#: omp-low.c:2477
+#: omp-low.c:2505
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region may not be closely nested inside of critical or explicit task region"
 msgid "%<ordered simd threads%> must be closely nested inside of %<for simd%> region"
 msgstr "有序区域不可以紧密嵌套在临界或显式的任务区域内"
 
-#: omp-low.c:2485
+#: omp-low.c:2513
 #, gcc-internal-format
 msgid "OpenMP constructs other than %<#pragma omp ordered simd%> may not be nested inside %<simd%> region"
 msgstr ""
 
-#: omp-low.c:2497
+#: omp-low.c:2525
 #, gcc-internal-format
 msgid "only %<distribute%> or %<parallel%> regions are allowed to be strictly nested inside %<teams%> region"
 msgstr ""
 
-#: omp-low.c:2514
+#: omp-low.c:2542
 #, gcc-internal-format
 msgid "%<distribute%> region must be strictly nested inside %<teams%> construct"
 msgstr ""
 
-#: omp-low.c:2555
+#: omp-low.c:2583
 #, gcc-internal-format
 msgid "OpenACC loop directive must be associated with an OpenACC compute region"
 msgstr ""
 
-#: omp-low.c:2577
+#: omp-low.c:2605
 #, fuzzy, gcc-internal-format
 msgid "orphaned %qs construct"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: omp-low.c:2606
+#: omp-low.c:2634
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<nowait%> for construct"
 msgstr ""
 
-#: omp-low.c:2611
+#: omp-low.c:2639
 #, gcc-internal-format
 msgid "%<#pragma omp cancel for%> inside %<ordered%> for construct"
 msgstr ""
 
-#: omp-low.c:2631 omp-low.c:2644
+#: omp-low.c:2659 omp-low.c:2672
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel sections%> inside %<nowait%> sections construct"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 
-#: omp-low.c:2670
+#: omp-low.c:2698
 #, fuzzy, gcc-internal-format
 msgid "%<%s taskgroup%> construct not closely nested inside of %<taskgroup%> region"
 msgstr "主要区域不可以紧密嵌套在工作共享或显式的任务区域内"
 
-#: omp-low.c:2684
+#: omp-low.c:2712
 #, fuzzy, gcc-internal-format
 msgid "invalid arguments"
 msgstr "%<...%>作为实参。)"
 
-#: omp-low.c:2690
+#: omp-low.c:2718
 #, gcc-internal-format
 msgid "%<%s %s%> construct not closely nested inside of %qs"
 msgstr ""
 
-#: omp-low.c:2718
+#: omp-low.c:2746
 #, fuzzy, gcc-internal-format
 #| msgid "barrier region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
 msgid "barrier region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "屏障区域不可以紧密嵌套在工作共享、临界、有序、主要的或显式的任务区域内"
 
-#: omp-low.c:2725
+#: omp-low.c:2753
 #, fuzzy, gcc-internal-format
 #| msgid "work-sharing region may not be closely nested inside of work-sharing, critical, ordered, master or explicit task region"
 msgid "work-sharing region may not be closely nested inside of work-sharing, %<critical%>, %<ordered%>, %<master%>, explicit %<task%> or %<taskloop%> region"
 msgstr "工作共享区域不可以紧密嵌套在工作共享、临界、有序、主要的或显式的任务区域内"
 
-#: omp-low.c:2754
+#: omp-low.c:2782
 #, fuzzy, gcc-internal-format
 #| msgid "master region may not be closely nested inside of work-sharing or explicit task region"
 msgid "%<master%> region may not be closely nested inside of work-sharing, explicit %<task%> or %<taskloop%> region"
 msgstr "主要区域不可以紧密嵌套在工作共享或显式的任务区域内"
 
-#: omp-low.c:2778 omp-low.c:2917
+#: omp-low.c:2806 omp-low.c:2945
 #, gcc-internal-format
 msgid "%<depend(%s)%> is only allowed in %<omp ordered%>"
 msgstr ""
 
-#: omp-low.c:2806
+#: omp-low.c:2834
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> construct with %<depend%> clause must be closely nested inside an %<ordered%> loop"
 msgstr "有序区域必须紧密嵌套在一个有次序分句的循环内"
 
-#: omp-low.c:2823
+#: omp-low.c:2851
 #, gcc-internal-format
 msgid "invalid depend kind in omp %<ordered%> %<depend%>"
 msgstr ""
 
-#: omp-low.c:2838
+#: omp-low.c:2866
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> %<simd%> must be closely nested inside %<simd%> region"
 msgstr "有序区域必须紧密嵌套在一个有次序分句的循环内"
 
-#: omp-low.c:2851
+#: omp-low.c:2879
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region may not be closely nested inside of critical or explicit task region"
 msgid "%<ordered%> region may not be closely nested inside of %<critical%>, %<ordered%>, explicit %<task%> or %<taskloop%> region"
 msgstr "有序区域不可以紧密嵌套在临界或显式的任务区域内"
 
-#: omp-low.c:2862 omp-low.c:2875
+#: omp-low.c:2890 omp-low.c:2903
 #, fuzzy, gcc-internal-format
 #| msgid "ordered region must be closely nested inside a loop region with an ordered clause"
 msgid "%<ordered%> region must be closely nested inside a loop region with an %<ordered%> clause"
 msgstr "有序区域必须紧密嵌套在一个有次序分句的循环内"
 
-#: omp-low.c:2892
+#: omp-low.c:2920
 #, fuzzy, gcc-internal-format
 #| msgid "critical region may not be nested inside a critical region with the same name"
 msgid "%<critical%> region may not be nested inside a %<critical%> region with the same name"
 msgstr "临界区域不可以被嵌套在同名的临界区域内"
 
-#: omp-low.c:2904
+#: omp-low.c:2932
 #, fuzzy, gcc-internal-format
 msgid "%<teams%> construct not closely nested inside of %<target%> construct"
 msgstr "主要区域不可以紧密嵌套在工作共享或显式的任务区域内"
 
-#: omp-low.c:2925
+#: omp-low.c:2953
 #, gcc-internal-format
 msgid "OpenACC region inside of OpenACC routine, nested parallelism not supported yet"
 msgstr ""
 
-#: omp-low.c:2938
+#: omp-low.c:2966
 #, gcc-internal-format
 msgid "OpenACC construct inside of non-OpenACC region"
 msgstr ""
 
-#: omp-low.c:2983
+#: omp-low.c:3011
 #, fuzzy, gcc-internal-format
 msgid "%s %qs construct inside of %s %qs region"
 msgstr "%P: 找不到 %s 于 %s 内部\n"
 
-#: omp-low.c:2996 omp-low.c:3003
+#: omp-low.c:3024 omp-low.c:3031
 #, fuzzy, gcc-internal-format
 msgid "%qs construct inside of %qs region"
 msgstr "%P: 找不到 %s 于 %s 内部\n"
 
-#: omp-low.c:3115
+#: omp-low.c:3143
 #, gcc-internal-format
 msgid "setjmp/longjmp inside simd construct"
 msgstr ""
 
-#: omp-low.c:6341
+#: omp-low.c:6379
 #, gcc-internal-format
 msgid "ignoring sink clause with offset that is not a multiple of the loop step"
 msgstr ""
 
-#: omp-low.c:6364
+#: omp-low.c:6402
 #, gcc-internal-format
 msgid "first offset must be in opposite direction of loop iterations"
 msgstr ""
 
-#: omp-low.c:9087
+#: omp-low.c:9125
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid exit from %s structured block"
 msgstr "OpenMP 结构块出口无效"
 
-#: omp-low.c:9089 omp-low.c:9094
+#: omp-low.c:9127 omp-low.c:9132
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid entry to %s structured block"
 msgstr "OpenMP 结构块出口无效"
 
 #. Otherwise, be vague and lazy, but efficient.
-#: omp-low.c:9098
+#: omp-low.c:9136
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid branch to/from %s structured block"
 msgstr "OpenMP 结构块出口无效"
@@ -22972,7 +22995,7 @@
 msgid "command line option %qs is not supported by this configuration"
 msgstr "此配置不支持命令行选项%qs"
 
-#: opts-common.c:1129 opts.c:1773
+#: opts-common.c:1129 opts.c:1780
 #, gcc-internal-format
 msgid "missing argument to %qs"
 msgstr "%qs缺少参数"
@@ -23129,130 +23152,140 @@
 msgid "-fsanitize-address-use-after-scope requires -fstack-reuse=none option"
 msgstr ""
 
-#: opts.c:1410
+#: opts.c:1012
+#, fuzzy, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=address%>"
+msgstr "-static-libgfortran 在此配置下不受支持"
+
+#: opts.c:1015
+#, fuzzy, gcc-internal-format
+msgid "transactional memory is not supported with %<-fsanitize=kernel-address%>"
+msgstr "-static-libgfortran 在此配置下不受支持"
+
+#: opts.c:1417
 #, gcc-internal-format
 msgid "unrecognized include_flags 0x%x passed to print_specific_help"
 msgstr "传递给 print_specific_help 的 include_flags 0x%x 不可识别"
 
-#: opts.c:1610
+#: opts.c:1617
 #, gcc-internal-format
 msgid "-fsanitize=all option is not valid"
 msgstr ""
 
-#: opts.c:1642
+#: opts.c:1649
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s; did you mean %qs?"
 msgstr "警告：--help= 选项的参数不可识别：%.*s\n"
 
-#: opts.c:1649
+#: opts.c:1656
 #, fuzzy, gcc-internal-format
 msgid "unrecognized argument to -f%ssanitize%s= option: %q.*s"
 msgstr "警告：--help= 选项的参数不可识别：%.*s\n"
 
-#: opts.c:1828
+#: opts.c:1835
 #, gcc-internal-format
 msgid "--help argument %q.*s is ambiguous, please be more specific"
 msgstr "--help 的参数%q.*s有歧义，请改用更加明确的参数"
 
-#: opts.c:1837
+#: opts.c:1844
 #, gcc-internal-format
 msgid "unrecognized argument to --help= option: %q.*s"
 msgstr "--help= 选项的参数未知：%q.*s"
 
-#: opts.c:2078
+#: opts.c:2085
 #, fuzzy, gcc-internal-format
 #| msgid "LTO support has not been enabled in this configuration"
 msgid "HSA has not been enabled during configuration"
 msgstr "LTO 支持在此配置下未被启用"
 
-#: opts.c:2090
+#: opts.c:2097
 #, gcc-internal-format
 msgid "-foffload-abi option can be specified only for offload compiler"
 msgstr ""
 
-#: opts.c:2098
+#: opts.c:2105
 #, gcc-internal-format, gfc-internal-format
 msgid "structure alignment must be a small power of two, not %d"
 msgstr "结构的对齐必须是 2 的较小次方，而不是 %d"
 
-#: opts.c:2217
+#: opts.c:2224
 #, fuzzy, gcc-internal-format
 msgid "unknown stack check parameter %qs"
 msgstr "未知的堆栈检查参数“%s”"
 
-#: opts.c:2249
+#: opts.c:2256
 #, gcc-internal-format
 msgid "%<-gdwarf%s%> is ambiguous; use %<-gdwarf-%s%> for DWARF version or %<-gdwarf -g%s%> for debug level"
 msgstr ""
 
-#: opts.c:2260
+#: opts.c:2267
 #, gcc-internal-format, gfc-internal-format
 msgid "dwarf version %d is not supported"
 msgstr "不支持 dwarf 版本 %d"
 
-#: opts.c:2360
+#: opts.c:2367
 #, gcc-internal-format, gfc-internal-format
 msgid "%s: --param arguments should be of the form NAME=VALUE"
 msgstr "%s：--param 实参的形式应该为“名字=值”"
 
-#: opts.c:2371
+#: opts.c:2378
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs; did you mean %qs?"
 msgstr "无效的 --param 值%qs"
 
-#: opts.c:2374
+#: opts.c:2381
 #, fuzzy, gcc-internal-format
 #| msgid "invalid --param value %qs"
 msgid "invalid --param name %qs"
 msgstr "无效的 --param 值%qs"
 
-#: opts.c:2382
+#: opts.c:2389
 #, gcc-internal-format
 msgid "invalid --param value %qs"
 msgstr "无效的 --param 值%qs"
 
-#: opts.c:2504
+#: opts.c:2511
 #, gcc-internal-format
 msgid "target system does not support debug output"
 msgstr "目标系统不支持调试输出"
 
-#: opts.c:2513
+#: opts.c:2520
 #, fuzzy, gcc-internal-format
 msgid "debug format %qs conflicts with prior selection"
 msgstr "调试格式“%s”与先前的选择冲突"
 
-#: opts.c:2531
+#: opts.c:2538
 #, fuzzy, gcc-internal-format
 msgid "unrecognized debug output level %qs"
 msgstr "无法识别的调试输出级别“%s”"
 
-#: opts.c:2533
+#: opts.c:2540
 #, fuzzy, gcc-internal-format
 msgid "debug output level %qs is too high"
 msgstr "调试输出级别 %s 太高"
 
-#: opts.c:2553
+#: opts.c:2560
 #, gcc-internal-format
 msgid "getting core file size maximum limit: %m"
 msgstr "获取核心文件大小上限：%m"
 
-#: opts.c:2557
+#: opts.c:2564
 #, gcc-internal-format
 msgid "setting core file size limit to maximum: %m"
 msgstr "将核心文件大小上限设为最大值：%m"
 
-#: opts.c:2602
+#: opts.c:2609
 #, gcc-internal-format, gfc-internal-format
 msgid "unrecognized gcc debugging option: %c"
 msgstr "无法识别的 gcc 调试选项：%c"
 
-#: opts.c:2627
+#: opts.c:2634
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: no option -%s"
 msgstr "-Werror=%s：没有选项 -%s"
 
-#: opts.c:2629
+#: opts.c:2636
 #, gcc-internal-format, gfc-internal-format
 msgid "-Werror=%s: -%s is not an option that controls warnings"
 msgstr ""
@@ -23604,7 +23637,7 @@
 msgid "register of %qD used for multiple global register variables"
 msgstr "嵌套函数中使用了全局寄存器变量%qD"
 
-#: reginfo.c:789 config/rs6000/rs6000.c:31768
+#: reginfo.c:789 config/rs6000/rs6000.c:31817
 #, fuzzy, gcc-internal-format
 msgid "conflicts with %qD"
 msgstr "%qD与已用的函数冲突"
@@ -24205,12 +24238,12 @@
 msgid "error closing %s: %m"
 msgstr "关闭 %s 时出错：%m"
 
-#: toplev.c:2054
+#: toplev.c:2057
 #, fuzzy, gcc-internal-format
 msgid "self-tests incompatible with -E"
 msgstr "%qs必须与%qs一起使用"
 
-#: toplev.c:2069
+#: toplev.c:2072
 #, gcc-internal-format
 msgid "self-tests are not enabled in this build"
 msgstr ""
@@ -25125,47 +25158,47 @@
 msgid "in expansion of macro %qs"
 msgstr "印出 EXPR 的宏展开"
 
-#: tree-eh.c:4669
+#: tree-eh.c:4684
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has multiple EH edges"
 msgstr "基本块 %i 有多个 EH 边"
 
-#: tree-eh.c:4681
+#: tree-eh.c:4696
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i can not throw but has an EH edge"
 msgstr "基本块 %i 不能抛出异常但却有 EH 边"
 
-#: tree-eh.c:4689
+#: tree-eh.c:4704
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i last statement has incorrectly set lp"
 msgstr "基本块 %i 最后一条语句设置了不正确的 lp"
 
-#: tree-eh.c:4695
+#: tree-eh.c:4710
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an EH edge"
 msgstr "基本块 %i 缺少一条 EH 边"
 
-#: tree-eh.c:4701
+#: tree-eh.c:4716
 #, gcc-internal-format, gfc-internal-format
 msgid "Incorrect EH edge %i->%i"
 msgstr "不正确的 EH 边 %i->%i"
 
-#: tree-eh.c:4735 tree-eh.c:4754
+#: tree-eh.c:4750 tree-eh.c:4769
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i is missing an edge"
 msgstr "基本块 %i 缺少一条边"
 
-#: tree-eh.c:4771
+#: tree-eh.c:4786
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i too many fallthru edges"
 msgstr "基本块 %i 下落边太多"
 
-#: tree-eh.c:4780
+#: tree-eh.c:4795
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect edge"
 msgstr "基本块 %i 有不正确的边"
 
-#: tree-eh.c:4786
+#: tree-eh.c:4801
 #, gcc-internal-format, gfc-internal-format
 msgid "BB %i has incorrect fallthru edge"
 msgstr "基本块 %i 有不正确的下落边"
@@ -25266,33 +25299,33 @@
 msgid "target does not support atomic profile update, single mode is selected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3422
+#: tree-ssa-ccp.c:3420
 #, gcc-internal-format, gfc-internal-format
 msgid "argument %u null where non-null expected"
 msgstr ""
 
-#: tree-ssa-ccp.c:3427
+#: tree-ssa-ccp.c:3425
 #, fuzzy, gcc-internal-format
 msgid "in a call to built-in function %qD"
 msgstr "内建函数实参无效"
 
-#: tree-ssa-ccp.c:3431
+#: tree-ssa-ccp.c:3429
 #, fuzzy, gcc-internal-format
 msgid "in a call to function %qD declared here"
 msgstr "内联函数%q+D声明过但从未定义"
 
-#: tree-ssa-loop-niter.c:2367
+#: tree-ssa-loop-niter.c:2416
 #, fuzzy, gcc-internal-format
 #| msgid "cannot optimize loop, the loop counter may overflow"
 msgid "missed loop optimization, the loop counter may overflow"
 msgstr "无法优化循环，循环变量可能溢出"
 
-#: tree-ssa-loop-niter.c:2964
+#: tree-ssa-loop-niter.c:3013
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "iteration %s invokes undefined behavior"
 msgstr "%qE上的运算结果可能是未定义的"
 
-#: tree-ssa-loop-niter.c:2965
+#: tree-ssa-loop-niter.c:3014
 #, fuzzy, gcc-internal-format
 #| msgid "within this context"
 msgid "within this loop"
@@ -25648,11 +25681,11 @@
 #: c-family/c-attribs.c:2898 c-family/c-attribs.c:2937
 #: c-family/c-attribs.c:3019 c-family/c-attribs.c:3062
 #: c-family/c-attribs.c:3078 c-family/c-attribs.c:3172
-#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6741
-#: config/arm/arm.c:6769 config/arm/arm.c:6786 config/avr/avr.c:9460
-#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7715
-#: config/i386/i386.c:41425 config/ia64/ia64.c:762
-#: config/rs6000/rs6000.c:35369 config/spu/spu.c:3741
+#: c-family/c-common.c:5631 config/darwin.c:2062 config/arm/arm.c:6719
+#: config/arm/arm.c:6747 config/arm/arm.c:6764 config/avr/avr.c:9475
+#: config/h8300/h8300.c:5480 config/h8300/h8300.c:5504 config/i386/i386.c:7721
+#: config/i386/i386.c:41466 config/ia64/ia64.c:762
+#: config/rs6000/rs6000.c:35418 config/spu/spu.c:3741
 #: ada/gcc-interface/utils.c:6124 ada/gcc-interface/utils.c:6141
 #: ada/gcc-interface/utils.c:6157 ada/gcc-interface/utils.c:6183
 #: lto/lto-lang.c:241
@@ -26629,7 +26662,7 @@
 msgid "type was previously declared %qE"
 msgstr "以前在此声明过"
 
-#: c-family/c-attribs.c:2524 cp/class.c:4715
+#: c-family/c-attribs.c:2524 cp/class.c:4717
 #, fuzzy, gcc-internal-format
 #| msgid "%qs can only be specified for functions"
 msgid "%<transaction_safe_dynamic%> may only be specified for a virtual function"
@@ -26908,7 +26941,7 @@
 msgid "the compiler can assume that the address of %qD will always evaluate to %<true%>"
 msgstr "%qD的地址总是等价为%<true%>"
 
-#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8608
+#: c-family/c-common.c:3427 cp/semantics.c:660 cp/typeck.c:8609
 #, gcc-internal-format
 msgid "suggest parentheses around assignment used as truth value"
 msgstr "建议在用作真值的赋值语句前后加上括号"
@@ -27534,62 +27567,62 @@
 msgid "extra type qualifiers in format argument (argument %d)"
 msgstr "格式字符串实参 %d 有多余的类型限定"
 
-#: c-family/c-format.c:3469
+#: c-family/c-format.c:3475
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%s%s%>, but argument %d has type %qT"
 msgstr "格式%q.*s需要类型%<%s%s%>，但实参 %d 的类型为%qT"
 
-#: c-family/c-format.c:3479
+#: c-family/c-format.c:3485
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%s%s%> argument"
 msgstr "%s: “%s” 而不需吻合中 “ifdef” 或 “ifndef” "
 
-#: c-family/c-format.c:3490
+#: c-family/c-format.c:3496
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects argument of type %<%T%s%>, but argument %d has type %qT"
 msgstr "格式%q.*s需要类型%<%s%s%>，但实参 %d 的类型为%qT"
 
-#: c-family/c-format.c:3500
+#: c-family/c-format.c:3506
 #, fuzzy, gcc-internal-format
 msgid "%s %<%s%.*s%> expects a matching %<%T%s%> argument"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: c-family/c-format.c:3562 c-family/c-format.c:3568 c-family/c-format.c:3719
+#: c-family/c-format.c:3568 c-family/c-format.c:3574 c-family/c-format.c:3725
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as a type"
 msgstr "%<__gcc_host_wide_int__%>未被定义为一个类型"
 
-#: c-family/c-format.c:3575 c-family/c-format.c:3729
+#: c-family/c-format.c:3581 c-family/c-format.c:3735
 #, gcc-internal-format
 msgid "%<__gcc_host_wide_int__%> is not defined as %<long%> or %<long long%>"
 msgstr "%<__gcc_host_wide_int__%>未被定义为%<long%>或%<long long%>"
 
-#: c-family/c-format.c:3625
+#: c-family/c-format.c:3631
 #, gcc-internal-format
 msgid "%<locus%> is not defined as a type"
 msgstr "%<locus%>未被定义为一个类型"
 
-#: c-family/c-format.c:3678
+#: c-family/c-format.c:3684
 #, gcc-internal-format
 msgid "%<location_t%> is not defined as a type"
 msgstr "%<location_t%>未被定义为一个类型"
 
-#: c-family/c-format.c:3695
+#: c-family/c-format.c:3701
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a type"
 msgstr "%<tree%>未被定义为一个类型"
 
-#: c-family/c-format.c:3700
+#: c-family/c-format.c:3706
 #, gcc-internal-format
 msgid "%<tree%> is not defined as a pointer type"
 msgstr "%<tree%>未被定义为一个指针类型"
 
-#: c-family/c-format.c:3973
+#: c-family/c-format.c:3979
 #, gcc-internal-format
 msgid "args to be formatted is not %<...%>"
 msgstr "待格式化的实参不是%<...%>"
 
-#: c-family/c-format.c:3985
+#: c-family/c-format.c:3991
 #, gcc-internal-format
 msgid "strftime formats cannot format arguments"
 msgstr "strftime 格式字符串无法格式化实参"
@@ -27690,7 +27723,7 @@
 msgid "repeated %<@%> before Objective-C string"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: c-family/c-lex.c:1191 cp/parser.c:3974
+#: c-family/c-lex.c:1191 cp/parser.c:3976
 #, gcc-internal-format
 msgid "unsupported non-standard concatenation of string literals"
 msgstr "不受支持的非标准字面字符串毗连"
@@ -27721,7 +27754,7 @@
 msgid "%<#pragma omp atomic capture%> uses two different variables for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
 
-#: c-family/c-omp.c:485 cp/semantics.c:8196
+#: c-family/c-omp.c:485 cp/semantics.c:8209
 #, gcc-internal-format
 msgid "invalid type for iteration variable %qE"
 msgstr "迭代变量%qE类型无效"
@@ -27737,22 +27770,22 @@
 msgid "%qE is not initialized"
 msgstr "%qE未经初始化"
 
-#: c-family/c-omp.c:527 cp/semantics.c:8084
+#: c-family/c-omp.c:527 cp/semantics.c:8097
 #, gcc-internal-format
 msgid "missing controlling predicate"
 msgstr "缺少控制谓词"
 
-#: c-family/c-omp.c:612 cp/semantics.c:7740
+#: c-family/c-omp.c:612 cp/semantics.c:7753
 #, gcc-internal-format
 msgid "invalid controlling predicate"
 msgstr "无效的控制谓词"
 
-#: c-family/c-omp.c:619 cp/semantics.c:8090
+#: c-family/c-omp.c:619 cp/semantics.c:8103
 #, gcc-internal-format
 msgid "missing increment expression"
 msgstr "缺少自增语句"
 
-#: c-family/c-omp.c:683 cp/semantics.c:7855
+#: c-family/c-omp.c:683 cp/semantics.c:7868
 #, gcc-internal-format
 msgid "invalid increment expression"
 msgstr "无效的自增语句"
@@ -28301,8 +28334,8 @@
 msgid "wrong type argument to %s"
 msgstr "不能对该类型的参数求绝对值"
 
-#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1757
-#: cp/constexpr.c:3911
+#: c-family/c-warn.c:49 c-family/c-warn.c:62 cp/constexpr.c:1773
+#: cp/constexpr.c:3935
 #, gcc-internal-format
 msgid "overflow in constant expression"
 msgstr "常量表达式溢出"
@@ -28977,7 +29010,7 @@
 msgid "this condition has identical branches"
 msgstr ""
 
-#: c-family/cilk.c:93 cp/parser.c:6570
+#: c-family/cilk.c:93 cp/parser.c:6575
 #, fuzzy, gcc-internal-format
 msgid "%<_Cilk_spawn%> may only be used inside a function"
 msgstr "%<friend%>只能在类中指定"
@@ -29138,7 +29171,7 @@
 msgid "-march=%s: unsupported ISA substring %qs"
 msgstr ""
 
-#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1371
+#: common/config/rs6000/rs6000-common.c:174 config/sparc/sparc.c:1482
 #, gcc-internal-format, gfc-internal-format
 msgid "unknown -mdebug-%s switch"
 msgstr "未知的 -mdebug-%s 开关"
@@ -29465,7 +29498,7 @@
 msgid "%Kargument %d must be a constant immediate"
 msgstr "实参必须是常数"
 
-#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2471
+#: config/aarch64/aarch64-builtins.c:1160 config/arm/arm-builtins.c:2476
 #, fuzzy, gcc-internal-format
 msgid "%Klane index must be a constant immediate"
 msgstr "掩码必须是一个立即数"
@@ -29545,7 +29578,7 @@
 msgid "unknown value %qs for -mtune"
 msgstr "-mtune 参数的值 %qs 未知"
 
-#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3094
+#: config/aarch64/aarch64.c:8929 config/arm/arm.c:3072
 #, gcc-internal-format, gfc-internal-format
 msgid "switch -mcpu=%s conflicts with -march=%s switch"
 msgstr "开关 -mcpu=%s 与 -march=%s 冲突"
@@ -29633,9 +29666,9 @@
 msgid "target %s %s=%s is not valid"
 msgstr "无效的 %s 字组：%s\n"
 
-#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30411
-#: config/i386/i386.c:6772 config/rs6000/rs6000.c:39283
-#: config/s390/s390.c:15017
+#: config/aarch64/aarch64.c:9544 config/arm/arm.c:30400
+#: config/i386/i386.c:6778 config/rs6000/rs6000.c:39332
+#: config/s390/s390.c:15024
 #, fuzzy, gcc-internal-format
 msgid "attribute %<target%> argument not a string"
 msgstr "%qE属性需要一个字符串常量作为实参"
@@ -29721,7 +29754,7 @@
 msgstr "-mmemory-latency 开关的值%qs错误"
 
 #: config/alpha/alpha.c:6663 config/alpha/alpha.c:6666 config/arc/arc.c:5816
-#: config/arc/arc.c:6095 config/s390/s390.c:873 config/tilegx/tilegx.c:3542
+#: config/arc/arc.c:6095 config/s390/s390.c:876 config/tilegx/tilegx.c:3542
 #: config/tilepro/tilepro.c:3106
 #, gcc-internal-format
 msgid "bad builtin fcode"
@@ -29900,234 +29933,234 @@
 msgid "insn addresses not freed"
 msgstr "在 %2$s 缓存中 %1$zu 字节可用"
 
-#: config/arm/arm-builtins.c:2349
+#: config/arm/arm-builtins.c:2354
 #, fuzzy, gcc-internal-format
 msgid "this builtin is not supported for this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: config/arm/arm-builtins.c:2454
+#: config/arm/arm-builtins.c:2459
 #, gcc-internal-format
 msgid "You must enable NEON instructions (e.g. -mfloat-abi=softfp -mfpu=neon) to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2492
+#: config/arm/arm-builtins.c:2497
 #, gcc-internal-format
 msgid "You must enable VFP instructions to use these intrinsics."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2552
+#: config/arm/arm-builtins.c:2557
 #, gcc-internal-format
 msgid "You must enable crypto instructions (e.g. include -mfloat-abi=softfp -mfpu=crypto-neon...) to use these intrinsics."
 msgstr ""
 
 #. @@@ better error message
-#: config/arm/arm-builtins.c:2610 config/arm/arm-builtins.c:2714
+#: config/arm/arm-builtins.c:2615 config/arm/arm-builtins.c:2719
 #, gcc-internal-format
 msgid "selector must be an immediate"
 msgstr "选择子必须是立即数"
 
-#: config/arm/arm-builtins.c:2618 config/arm/arm-builtins.c:2663
-#: config/arm/arm-builtins.c:2721 config/arm/arm-builtins.c:2730
+#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2668
+#: config/arm/arm-builtins.c:2726 config/arm/arm-builtins.c:2735
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 7"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:2623 config/arm/arm-builtins.c:2732
+#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2737
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 3"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:2628 config/arm/arm-builtins.c:2734
+#: config/arm/arm-builtins.c:2633 config/arm/arm-builtins.c:2739
 #, fuzzy, gcc-internal-format
 msgid "the range of selector should be in 0 to 1"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/arm/arm-builtins.c:2800
+#: config/arm/arm-builtins.c:2805
 #, gcc-internal-format
 msgid "mask must be an immediate"
 msgstr "掩码必须是一个立即数"
 
-#: config/arm/arm-builtins.c:2805
+#: config/arm/arm-builtins.c:2810
 #, fuzzy, gcc-internal-format
 msgid "the range of mask should be in 0 to 255"
 msgstr "%qE属性的参数应当在 0 和 255 之间"
 
-#: config/arm/arm-builtins.c:2993
+#: config/arm/arm-builtins.c:2998
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2995
+#: config/arm/arm-builtins.c:3000
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_rori_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2997
+#: config/arm/arm-builtins.c:3002
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:2999
+#: config/arm/arm-builtins.c:3004
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 32.  please check the intrinsic _mm_ror_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3005
+#: config/arm/arm-builtins.c:3010
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_rori_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3007
+#: config/arm/arm-builtins.c:3012
 #, gcc-internal-format
 msgid "the range of count should be in 0 to 64.  please check the intrinsic _mm_ror_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3012
+#: config/arm/arm-builtins.c:3017
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3014
+#: config/arm/arm-builtins.c:3019
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3016
+#: config/arm/arm-builtins.c:3021
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3018
+#: config/arm/arm-builtins.c:3023
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3020
+#: config/arm/arm-builtins.c:3025
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3022
+#: config/arm/arm-builtins.c:3027
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_slli_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3024
+#: config/arm/arm-builtins.c:3029
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3026
+#: config/arm/arm-builtins.c:3031
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3028
+#: config/arm/arm-builtins.c:3033
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srai_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3030
+#: config/arm/arm-builtins.c:3035
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3032
+#: config/arm/arm-builtins.c:3037
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3034
+#: config/arm/arm-builtins.c:3039
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_srl_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3036
+#: config/arm/arm-builtins.c:3041
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3038
+#: config/arm/arm-builtins.c:3043
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3040
+#: config/arm/arm-builtins.c:3045
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sll_si64 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3042
+#: config/arm/arm-builtins.c:3047
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi16 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3044
+#: config/arm/arm-builtins.c:3049
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_pi32 in code."
 msgstr ""
 
-#: config/arm/arm-builtins.c:3046
+#: config/arm/arm-builtins.c:3051
 #, gcc-internal-format
 msgid "the count should be no less than 0.  please check the intrinsic _mm_sra_si64 in code."
 msgstr ""
 
-#: config/arm/arm.c:2800
+#: config/arm/arm.c:2778
 #, gcc-internal-format
 msgid "iWMMXt and NEON are incompatible"
 msgstr "iWMMXt 与 NEON 互不兼容"
 
-#: config/arm/arm.c:2806
+#: config/arm/arm.c:2784
 #, gcc-internal-format
 msgid "target CPU does not support ARM mode"
 msgstr "目标 CPU 不支持 ARM 模式"
 
-#: config/arm/arm.c:2810
+#: config/arm/arm.c:2788
 #, gcc-internal-format
 msgid "enabling backtrace support is only meaningful when compiling for the Thumb"
 msgstr "函数调用回溯支持只在为 Thumb 编译时有意义"
 
-#: config/arm/arm.c:2813
+#: config/arm/arm.c:2791
 #, gcc-internal-format
 msgid "enabling callee interworking support is only meaningful when compiling for the Thumb"
 msgstr "被调用者协作只在为 Thumb 编译时有意义"
 
-#: config/arm/arm.c:2821
+#: config/arm/arm.c:2799
 #, gcc-internal-format
 msgid "-g with -mno-apcs-frame may not give sensible debugging"
 msgstr "-g 与 -mno-apcs-frame 并用可能不能给出有意义的调试信息"
 
-#: config/arm/arm.c:2825
+#: config/arm/arm.c:2803
 #, gcc-internal-format
 msgid "iWMMXt unsupported under Thumb mode"
 msgstr ""
 
-#: config/arm/arm.c:2828
+#: config/arm/arm.c:2806
 #, gcc-internal-format
 msgid "can not use -mtp=cp15 with 16-bit Thumb"
 msgstr "-mtp=cp15 和 16 位 Thumb 不能并用"
 
-#: config/arm/arm.c:2832
+#: config/arm/arm.c:2810
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with Thumb"
 msgstr "RTP PIC 与 Thumb 不兼容"
 
-#: config/arm/arm.c:2840
+#: config/arm/arm.c:2818
 #, gcc-internal-format
 msgid "-mslow-flash-data only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2845
+#: config/arm/arm.c:2823
 #, gcc-internal-format
 msgid "-mpure-code only supports non-pic code on armv7-m targets"
 msgstr ""
 
-#: config/arm/arm.c:2948
+#: config/arm/arm.c:2926
 #, gcc-internal-format
 msgid "target CPU does not support THUMB instructions"
 msgstr "目标 CPU 不支持 THUMB 指令"
 
-#: config/arm/arm.c:2993
+#: config/arm/arm.c:2971
 #, gcc-internal-format
 msgid "target CPU does not support unaligned accesses"
 msgstr "目标 CPU 不支持未对齐的访问"
@@ -30134,145 +30167,145 @@
 
 #. To support this we need to be able to parse FPU feature options
 #. from the architecture string.
-#: config/arm/arm.c:3247
+#: config/arm/arm.c:3225
 #, fuzzy, gcc-internal-format
 #| msgid "-mpcrel -fPIC is not currently supported on selected cpu"
 msgid "-mfpu=auto not currently supported without an explicit CPU."
 msgstr "-mpcrel -fPIC 目前在所选的 CPU 上不受支持"
 
-#: config/arm/arm.c:3322
+#: config/arm/arm.c:3300
 #, gcc-internal-format
 msgid "target CPU does not support interworking"
 msgstr "目标 CPU 不支持交互工作"
 
-#: config/arm/arm.c:3328
+#: config/arm/arm.c:3306
 #, gcc-internal-format
 msgid "-mapcs-stack-check incompatible with -mno-apcs-frame"
 msgstr "-mapcs-stack-check 和 -mno-apcs-frame 互不兼容"
 
-#: config/arm/arm.c:3336
+#: config/arm/arm.c:3314
 #, gcc-internal-format
 msgid "-fpic and -mapcs-reent are incompatible"
 msgstr "-fpic 和 -mapcs-reent 互不兼容"
 
-#: config/arm/arm.c:3339
+#: config/arm/arm.c:3317
 #, gcc-internal-format
 msgid "APCS reentrant code not supported.  Ignored"
 msgstr "不支持 APCS 重入代码。已忽略"
 
-#: config/arm/arm.c:3373
+#: config/arm/arm.c:3351
 #, fuzzy, gcc-internal-format
 #| msgid "-mrelocatable and -msdata=%s are incompatible"
 msgid "selected fp16 options are incompatible"
 msgstr "-mrelocatable 与 -msdata=%s 互不兼容"
 
-#: config/arm/arm.c:3404
+#: config/arm/arm.c:3382
 #, gcc-internal-format
 msgid "iwmmxt requires an AAPCS compatible ABI for proper operation"
 msgstr "iwmmxt 需要与 AAPCS 兼容的 ABI 方能正确操作"
 
-#: config/arm/arm.c:3407
+#: config/arm/arm.c:3385
 #, gcc-internal-format
 msgid "iwmmxt abi requires an iwmmxt capable cpu"
 msgstr "iwmmxt abi 需要相应 CPU 的支持"
 
-#: config/arm/arm.c:3418
+#: config/arm/arm.c:3396
 #, gcc-internal-format
 msgid "AAPCS does not support -mcaller-super-interworking"
 msgstr "AAPCS 不支持 -mcaller-super-interworking"
 
-#: config/arm/arm.c:3421
+#: config/arm/arm.c:3399
 #, gcc-internal-format
 msgid "AAPCS does not support -mcallee-super-interworking"
 msgstr "AAPCS 不支持 -mcallee-super-interworking"
 
-#: config/arm/arm.c:3426
+#: config/arm/arm.c:3404
 #, gcc-internal-format
 msgid "__fp16 and no ldrh"
 msgstr "__fp16 而无 ldrh"
 
-#: config/arm/arm.c:3437
+#: config/arm/arm.c:3415
 #, fuzzy, gcc-internal-format
 #| msgid "-mfloat-abi=hard and VFP"
 msgid "-mfloat-abi=hard: selected processor lacks an FPU"
 msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:3445
+#: config/arm/arm.c:3423
 #, gcc-internal-format
 msgid "-mfloat-abi=hard and VFP"
 msgstr "-mfloat-abi=hard 和 VFP"
 
-#: config/arm/arm.c:3481
+#: config/arm/arm.c:3459
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8, 32 or 64"
 msgstr "结构大小边界只能被设定为 %s"
 
-#: config/arm/arm.c:3483
+#: config/arm/arm.c:3461
 #, fuzzy, gcc-internal-format
 msgid "structure size boundary can only be set to 8 or 32"
 msgstr "结构大小边界只能被设定为 %s"
 
-#: config/arm/arm.c:3508
+#: config/arm/arm.c:3486
 #, gcc-internal-format
 msgid "RTP PIC is incompatible with -msingle-pic-base"
 msgstr "RTP PIC 与 -msingle-pic-base 不兼容"
 
-#: config/arm/arm.c:3520
+#: config/arm/arm.c:3498
 #, gcc-internal-format
 msgid "-mpic-register= is useless without -fpic"
 msgstr "-mpic-register= 不与 -fpic 并用时不起作用"
 
-#: config/arm/arm.c:3529
+#: config/arm/arm.c:3507
 #, gcc-internal-format, gfc-internal-format
 msgid "unable to use '%s' for PIC register"
 msgstr "‘%s’不能被用作 PIC 寄存器"
 
-#: config/arm/arm.c:3548
+#: config/arm/arm.c:3526
 #, gcc-internal-format
 msgid "-freorder-blocks-and-partition not supported on this architecture"
 msgstr "-freorder-blocks-and-partition 不能在此架构下工作"
 
-#: config/arm/arm.c:3639
+#: config/arm/arm.c:3617
 #, fuzzy, gcc-internal-format
 #| msgid "target CPU does not support THUMB instructions"
 msgid "target CPU does not support ARMv8-M Security Extensions"
 msgstr "目标 CPU 不支持 THUMB 指令"
 
-#: config/arm/arm.c:5707
+#: config/arm/arm.c:5685
 #, fuzzy, gcc-internal-format
 msgid "non-AAPCS derived PCS variant"
 msgstr "不是从 AAPCS 派生出的 PCS 变种"
 
-#: config/arm/arm.c:5709
+#: config/arm/arm.c:5687
 #, fuzzy, gcc-internal-format
 msgid "variadic functions must use the base AAPCS variant"
 msgstr "可变参数函数必须使用基础的 AAPCS 变种"
 
-#: config/arm/arm.c:5728
+#: config/arm/arm.c:5706
 #, gcc-internal-format
 msgid "PCS variant"
 msgstr "PCS 变动"
 
-#: config/arm/arm.c:5923
+#: config/arm/arm.c:5901
 #, gcc-internal-format
 msgid "Thumb-1 hard-float VFP ABI"
 msgstr "Thumb-1 硬件浮点 VFP ABI"
 
-#: config/arm/arm.c:6362 config/arm/arm.c:6565 config/arm/arm.c:6593
-#: config/arm/arm.c:26560
+#: config/arm/arm.c:6340 config/arm/arm.c:6543 config/arm/arm.c:6571
+#: config/arm/arm.c:26549
 #, gcc-internal-format
 msgid "parameter passing for argument of type %qT changed in GCC 7.1"
 msgstr ""
 
-#: config/arm/arm.c:6709 config/arm/arm.c:6727 config/arm/arm.c:6902
-#: config/avr/avr.c:9480 config/avr/avr.c:9496 config/bfin/bfin.c:4673
+#: config/arm/arm.c:6687 config/arm/arm.c:6705 config/arm/arm.c:6880
+#: config/avr/avr.c:9495 config/avr/avr.c:9511 config/bfin/bfin.c:4673
 #: config/bfin/bfin.c:4734 config/bfin/bfin.c:4763
 #: config/epiphany/epiphany.c:475 config/h8300/h8300.c:5456
-#: config/i386/i386.c:7670 config/i386/i386.c:13041 config/i386/i386.c:41329
-#: config/i386/i386.c:41379 config/i386/i386.c:41449 config/m68k/m68k.c:760
-#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4278 config/rl78/rl78.c:781
-#: config/rs6000/rs6000.c:35295 config/rx/rx.c:2696 config/rx/rx.c:2722
-#: config/s390/s390.c:1082 config/sh/sh.c:8394 config/sh/sh.c:8412
+#: config/i386/i386.c:7676 config/i386/i386.c:13047 config/i386/i386.c:41370
+#: config/i386/i386.c:41420 config/i386/i386.c:41490 config/m68k/m68k.c:760
+#: config/mcore/mcore.c:3056 config/nvptx/nvptx.c:4294 config/rl78/rl78.c:781
+#: config/rs6000/rs6000.c:35344 config/rx/rx.c:2696 config/rx/rx.c:2722
+#: config/s390/s390.c:1085 config/sh/sh.c:8394 config/sh/sh.c:8412
 #: config/sh/sh.c:8436 config/sh/sh.c:8507 config/sh/sh.c:8530
 #: config/spu/spu.c:3683 config/stormy16/stormy16.c:2212
 #: config/v850/v850.c:2083 config/visium/visium.c:705
@@ -30280,77 +30313,82 @@
 msgid "%qE attribute only applies to functions"
 msgstr "%qE属性只能用于函数"
 
-#: config/arm/arm.c:6851
+#: config/arm/arm.c:6829
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions with arguments passed on the stack"
 msgstr "%qE属性只能用于函数而非 %s"
 
-#: config/arm/arm.c:6863
+#: config/arm/arm.c:6841
 #, fuzzy, gcc-internal-format
 #| msgid "%qD must not have variable number of arguments"
 msgid "%qE attribute not available to functions with variable number of arguments"
 msgstr "%qD不能带可变数量的实参"
 
-#: config/arm/arm.c:6872
+#: config/arm/arm.c:6850
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to functions, not %s"
 msgid "%qE attribute not available to functions that return value on the stack"
 msgstr "%qE属性只能用于函数而非 %s"
 
-#: config/arm/arm.c:6894 config/arm/arm.c:6946
+#: config/arm/arm.c:6872 config/arm/arm.c:6924
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute ignored on non-class types"
 msgid "%qE attribute ignored without -mcmse option."
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/arm/arm.c:6913
+#: config/arm/arm.c:6891
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute has no effect on functions with static linkage"
 msgstr "%qE属性只能用于函数"
 
-#: config/arm/arm.c:6962
+#: config/arm/arm.c:6940
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to function types"
 msgid "%qE attribute only applies to base type of a function pointer"
 msgstr "%qE属性只能用于函数类型"
 
-#: config/arm/arm.c:12245
+#: config/arm/arm.c:8656
+#, gcc-internal-format
+msgid "accessing thread-local storage is not currently supported with -mpure-code or -mslow-flash-data"
+msgstr ""
+
+#: config/arm/arm.c:12232
 #, fuzzy, gcc-internal-format
 msgid "%K%s %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/arm/arm.c:12248
+#: config/arm/arm.c:12235
 #, fuzzy, gcc-internal-format
 msgid "%s %wd out of range %wd - %wd"
 msgstr "操作数号超出范围"
 
-#: config/arm/arm.c:23495
+#: config/arm/arm.c:23484
 #, gcc-internal-format
 msgid "unable to compute real location of stacked parameter"
 msgstr "无法计算出栈中参数的真实地址"
 
-#: config/arm/arm.c:24148
+#: config/arm/arm.c:24137
 #, fuzzy, gcc-internal-format
 msgid "Unexpected thumb1 far jump"
 msgstr "非预期的模块结束"
 
-#: config/arm/arm.c:24412
+#: config/arm/arm.c:24401
 #, gcc-internal-format
 msgid "no low registers available for popping high registers"
 msgstr "高寄存器弹栈时没有可用的低寄存器"
 
-#: config/arm/arm.c:24661
+#: config/arm/arm.c:24650
 #, gcc-internal-format
 msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/arm/arm.c:24890
+#: config/arm/arm.c:24879
 #, gcc-internal-format
 msgid "-fstack-check=specific for Thumb-1"
 msgstr ""
 
-#: config/arm/arm.c:30435
+#: config/arm/arm.c:30424
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid element type for attribute %qs"
 msgid "invalid fpu for attribute(target(\"%s\"))"
@@ -30359,13 +30397,13 @@
 #. This doesn't really make sense until we support
 #. general dynamic selection of the architecture and all
 #. sub-features.
-#: config/arm/arm.c:30443
+#: config/arm/arm.c:30432
 #, gcc-internal-format
 msgid "auto fpu selection not currently permitted here"
 msgstr ""
 
-#: config/arm/arm.c:30450 config/i386/i386.c:6838 config/i386/i386.c:6885
-#: config/s390/s390.c:15083 config/s390/s390.c:15133 config/s390/s390.c:15150
+#: config/arm/arm.c:30439 config/i386/i386.c:6844 config/i386/i386.c:6891
+#: config/s390/s390.c:15090 config/s390/s390.c:15140 config/s390/s390.c:15157
 #, gcc-internal-format, gfc-internal-format
 msgid "attribute(target(\"%s\")) is unknown"
 msgstr "attribute(target(\"%s\"))未知"
@@ -30459,166 +30497,177 @@
 msgid "function attributes %qs and %qs have no effect on %qs function"
 msgstr "%qE属性只能用于函数"
 
-#: config/avr/avr.c:1074
+#: config/avr/avr.c:1068
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot have arguments"
 msgstr "%qD不能有默认参数"
 
-#: config/avr/avr.c:1077
+#: config/avr/avr.c:1071
 #, fuzzy, gcc-internal-format
 msgid "%qs function cannot return a value"
 msgstr "不正确的函数返回值"
 
-#: config/avr/avr.c:1084
+#: config/avr/avr.c:1085
 #, fuzzy, gcc-internal-format
-msgid "%qs appears to be a misspelled %s handler, missing __vector prefix"
+msgid "%qs appears to be a misspelled %qs handler, missing %<__vector%> prefix"
 msgstr "%qs似乎是一个拼写错的信号处理者"
 
-#: config/avr/avr.c:1311
+#: config/avr/avr.c:1098
+#, gcc-internal-format
+msgid "%qs is a reserved indentifier in AVR-LibC.  Consider %<#include <avr/interrupt.h>%> before using the %qs macro"
+msgstr ""
+
+#: config/avr/avr.c:1327
 #, fuzzy, gcc-internal-format
 msgid "%<builtin_return_address%> contains only 2 bytes of address"
 msgstr "‘builtin_return_address’只包含两字节地址"
 
-#: config/avr/avr.c:2543
+#: config/avr/avr.c:2559
 #, fuzzy, gcc-internal-format
 msgid "pointer offset from symbol maybe incorrect"
 msgstr "相对符号的指针偏移量可能不正确。"
 
-#: config/avr/avr.c:2682
+#: config/avr/avr.c:2698
 #, gcc-internal-format
 msgid "accessing data memory with program memory address"
 msgstr "用程序内存地址访问数据内存"
 
-#: config/avr/avr.c:2743
+#: config/avr/avr.c:2759
 #, fuzzy, gcc-internal-format
 msgid "accessing program memory with data memory address"
 msgstr "用程序内存地址访问数据内存"
 
-#: config/avr/avr.c:3222
+#: config/avr/avr.c:3238
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "fixed register %s used to pass parameter to function"
 msgstr "用以传递整数参数的寄存器个数"
 
-#: config/avr/avr.c:3492
+#: config/avr/avr.c:3508
 #, fuzzy, gcc-internal-format
 msgid "writing to address space %qs not supported"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: config/avr/avr.c:9515
+#: config/avr/avr.c:9530
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute only applies to variables and functions"
 msgid "%qE attribute only applies to variables in static storage"
 msgstr "%qE属性只能为变量或函数所使用"
 
-#: config/avr/avr.c:9522
+#: config/avr/avr.c:9537
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute is not supported for R8C target"
 msgid "%qE attribute only supported for reduced Tiny cores"
 msgstr "%qE属性在 R8C 目标机上不受支持"
 
-#: config/avr/avr.c:9539 config/bfin/bfin.c:4795 config/i386/winnt.c:59
-#: config/nvptx/nvptx.c:4301
+#: config/avr/avr.c:9554 config/bfin/bfin.c:4795 config/i386/winnt.c:59
+#: config/nvptx/nvptx.c:4317
 #, gcc-internal-format
 msgid "%qE attribute only applies to variables"
 msgstr "属性%qE只能用于变量"
 
-#: config/avr/avr.c:9550
+#: config/avr/avr.c:9565
 #, gcc-internal-format
 msgid "%qE attribute allows only an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/avr/avr.c:9560
+#: config/avr/avr.c:9575
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute address out of range"
 msgstr "已弃用。此开关不起作用。"
 
-#: config/avr/avr.c:9573
+#: config/avr/avr.c:9588
 #, gcc-internal-format
 msgid "both %s and %qE attribute provide address"
 msgstr ""
 
-#: config/avr/avr.c:9583
+#: config/avr/avr.c:9598
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute on non-volatile variable"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/avr/avr.c:9653
+#: config/avr/avr.c:9668
 #, fuzzy, gcc-internal-format
 msgid "address spaces are not supported for reduced Tiny devices"
 msgstr "嵌套函数蹦床在此目标机上不受支持"
 
-#: config/avr/avr.c:9660
+#: config/avr/avr.c:9675
 #, fuzzy, gcc-internal-format
 msgid "address space %qs not supported for devices with flash size up to %d KiB"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/avr/avr.c:9831
+#: config/avr/avr.c:9846
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %qT"
 msgstr "条件表达式中使用了指向不相交地址空间的指针"
 
-#: config/avr/avr.c:9834
+#: config/avr/avr.c:9849
 #, fuzzy, gcc-internal-format
 msgid "pointer targeting address space %qs must be const in %s %q+D"
 msgstr "条件表达式中使用了指向不相交地址空间的指针"
 
-#: config/avr/avr.c:9880
+#: config/avr/avr.c:9895
 #, fuzzy, gcc-internal-format
 msgid "variable %q+D must be const in order to be put into read-only section by means of %qs"
 msgstr "变量 %q+D 必须是常数以便是置放进入只读区段依靠 %qs"
 
-#: config/avr/avr.c:9919
+#: config/avr/avr.c:9934
 #, fuzzy, gcc-internal-format
 msgid "static IO declaration for %q+D needs an address"
 msgstr "%q+D的声明隐藏了一个形参"
 
-#: config/avr/avr.c:9951
+#: config/avr/avr.c:9966
 #, fuzzy, gcc-internal-format
 msgid "IO definition for %q+D needs an address"
 msgstr "%q+D的上一个定义在此"
 
-#: config/avr/avr.c:10058
+#: config/avr/avr.c:10073
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in the .noinit section"
 msgstr "只有未初始化的变量才能放在 .noinit 节中"
 
-#: config/avr/avr.c:10138
+#. This might happen with C++ if stuff needs constructing.
+#: config/avr/avr.c:10149
 #, fuzzy, gcc-internal-format
+msgid "variable %q+D with dynamic initialization put into program memory area"
+msgstr "只有初始化的变量才能放入程序内存区"
+
+#: config/avr/avr.c:10160
+#, fuzzy, gcc-internal-format
 msgid "uninitialized variable %q+D put into program memory area"
 msgstr "只有初始化的变量才能放入程序内存区"
 
-#: config/avr/avr.c:10224
+#: config/avr/avr.c:10247
 #, fuzzy, gcc-internal-format
 #| msgid "%qE incompatible attribute ignored"
 msgid "%q+D has incompatible attributes %qs and %qs"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/avr/avr.c:10287
+#: config/avr/avr.c:10310
 #, fuzzy, gcc-internal-format
 msgid "architecture %qs supported for assembler only"
 msgstr "MCU%qs只支持汇编器"
 
-#: config/avr/avr.c:12823
+#: config/avr/avr.c:12872
 #, fuzzy, gcc-internal-format
 msgid "conversion from address space %qs to address space %qs"
 msgstr "不兼容的地址空间限定符%qs和%qs"
 
-#: config/avr/avr.c:13916 config/avr/avr.c:13929
+#: config/avr/avr.c:13965 config/avr/avr.c:13978
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time integer constant"
 msgstr "字符串常量中出现非预期的模块结束"
 
-#: config/avr/avr.c:13943
+#: config/avr/avr.c:13992
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s expects a compile time long integer constant as first argument"
 msgstr "%qs需要一个常量实参"
 
-#: config/avr/avr.c:13971
+#: config/avr/avr.c:14020
 #, gcc-internal-format, gfc-internal-format
 msgid "rounding to %d bits has no effect for fixed-point value with %d fractional bits"
 msgstr ""
 
-#: config/avr/avr.c:13980
+#: config/avr/avr.c:14029
 #, fuzzy, gcc-internal-format
 msgid "rounding result will always be 0"
 msgstr "对两个互斥的相等比较取%<and%>的结果永远是 0"
@@ -30901,12 +30950,12 @@
 msgid "invalid IACC argument"
 msgstr "无效的 IACC 实参"
 
-#: config/frv/frv.c:8708
+#: config/frv/frv.c:8708 config/sparc/sparc.c:10545
 #, gcc-internal-format
 msgid "%qs expects a constant argument"
 msgstr "%qs需要一个常量实参"
 
-#: config/frv/frv.c:8713
+#: config/frv/frv.c:8713 config/sparc/sparc.c:10551
 #, gcc-internal-format
 msgid "constant argument out of range for %qs"
 msgstr "常量实参超过%qs的范围"
@@ -31089,7 +31138,7 @@
 msgid "code model %qs not supported in x32 mode"
 msgstr "代码模式%qs在 %s 位模式下不受支持"
 
-#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6556
+#: config/i386/i386.c:5372 config/i386/i386.c:5381 config/i386/i386.c:6562
 #, gcc-internal-format, gfc-internal-format
 msgid "code model %s does not support PIC mode"
 msgstr "代码模式 %s 在 PIC 模式下不受支持"
@@ -31227,294 +31276,294 @@
 msgid "%<target(\"rtd\")%> is ignored in 64bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/i386/i386.c:5938
+#: config/i386/i386.c:5944
 #, fuzzy, gcc-internal-format
 msgid "-mpreferred-stack-boundary is not supported for this target"
 msgstr "堆栈限制在此目标机上不受支持"
 
-#: config/i386/i386.c:5941
+#: config/i386/i386.c:5947
 #, gcc-internal-format, gfc-internal-format
 msgid "-mpreferred-stack-boundary=%d is not between %d and %d"
 msgstr "-mpreferred-stack-boundary=%d 的值不在 %d 和 %d 之间"
 
-#: config/i386/i386.c:5964
+#: config/i386/i386.c:5970
 #, gcc-internal-format, gfc-internal-format
 msgid "-mincoming-stack-boundary=%d is not between %d and 12"
 msgstr "-mincoming-stack-boundary=%d 不在 %d 和 12 之间"
 
-#: config/i386/i386.c:5977
+#: config/i386/i386.c:5983
 #, gcc-internal-format
 msgid "-mnop-mcount is not compatible with this target"
 msgstr "-mnop-mcount 与此目标不兼容"
 
-#: config/i386/i386.c:5980
+#: config/i386/i386.c:5986
 #, fuzzy, gcc-internal-format
 msgid "-mnop-mcount is not implemented for -fPIC"
 msgstr "模块间优化未为 C++ 实现"
 
-#: config/i386/i386.c:5986
+#: config/i386/i386.c:5992
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<-msseregparm%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386.c:5987
+#: config/i386/i386.c:5993
 #, fuzzy, gcc-internal-format
 #| msgid "%ssseregparm%s used without SSE enabled"
 msgid "%<target(\"sseregparm\")%> used without SSE enabled"
 msgstr "使用了 %ssseregparm%s 却没有启用 SEE"
 
-#: config/i386/i386.c:5997
+#: config/i386/i386.c:6003
 #, gcc-internal-format
 msgid "SSE instruction set disabled, using 387 arithmetics"
 msgstr "SSE 指令集已禁用，使用 387 指令"
 
-#: config/i386/i386.c:6004
+#: config/i386/i386.c:6010
 #, gcc-internal-format
 msgid "387 instruction set disabled, using SSE arithmetics"
 msgstr "387 指令集已禁用，使用 SSE 指令"
 
-#: config/i386/i386.c:6054
+#: config/i386/i386.c:6060
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<-maccumulate-outgoing-args%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:6056
+#: config/i386/i386.c:6062
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "stack probing requires %<target(\"accumulate-outgoing-args\")%> for correctness"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:6070
+#: config/i386/i386.c:6076
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<-maccumulate-outgoing-args%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:6072
+#: config/i386/i386.c:6078
 #, fuzzy, gcc-internal-format
 #| msgid "stack probing requires %saccumulate-outgoing-args%s for correctness"
 msgid "fixed ebp register requires %<target(\"accumulate-outgoing-args\")%>"
 msgstr "堆栈探针目前需要框架指针或 %saccumulate-outgoing-args%s 来保证正确性"
 
-#: config/i386/i386.c:6178
+#: config/i386/i386.c:6184
 #, gcc-internal-format
 msgid "-mfentry isn%'t supported for 32-bit in combination with -fpic"
 msgstr "-mfentry 在 32 位下不能和 -fpic 同时使用"
 
-#: config/i386/i386.c:6185
+#: config/i386/i386.c:6191
 #, gcc-internal-format
 msgid "-mno-fentry isn%'t compatible with SEH"
 msgstr "-mno-fentry 与 SEH 不兼容"
 
-#: config/i386/i386.c:6252 config/rs6000/rs6000.c:5475
+#: config/i386/i386.c:6258 config/rs6000/rs6000.c:5477
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown option for -mrecip=%s"
 msgstr "未知的选项：%s %s %s"
 
-#: config/i386/i386.c:6866
+#: config/i386/i386.c:6872
 #, gcc-internal-format, gfc-internal-format
 msgid "option(\"%s\") was already specified"
 msgstr "option(\"%s\")已经被指定"
 
-#: config/i386/i386.c:7168
+#: config/i386/i386.c:7174
 #, gcc-internal-format
 msgid "Only DWARF debug format is supported for interrupt service routine."
 msgstr ""
 
-#: config/i386/i386.c:7267
+#: config/i386/i386.c:7273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "2 byte cop instructions are not allowed in 64-bit VLIW mode"
 msgid "%s instructions aren't allowed in %s service routine"
 msgstr "2 字节 cop 指针不允许被用在 VLIW 模式中"
 
-#: config/i386/i386.c:7271
+#: config/i386/i386.c:7277
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s instructions aren't allowed in function with no_caller_saved_registers attribute"
 msgstr "为每个函数使用堆栈保护机制"
 
-#: config/i386/i386.c:7683 config/i386/i386.c:7734
+#: config/i386/i386.c:7689 config/i386/i386.c:7740
 #, gcc-internal-format
 msgid "fastcall and regparm attributes are not compatible"
 msgstr "fastcall 和 regparm 属性互不兼容"
 
-#: config/i386/i386.c:7688
+#: config/i386/i386.c:7694
 #, fuzzy, gcc-internal-format
 msgid "regparam and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:7695 config/i386/i386.c:41349
+#: config/i386/i386.c:7701 config/i386/i386.c:41390
 #, gcc-internal-format
 msgid "%qE attribute requires an integer constant argument"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: config/i386/i386.c:7701
+#: config/i386/i386.c:7707
 #, gcc-internal-format
 msgid "argument to %qE attribute larger than %d"
 msgstr "%qE属性的实参大于 %d"
 
-#: config/i386/i386.c:7726 config/i386/i386.c:7769
+#: config/i386/i386.c:7732 config/i386/i386.c:7775
 #, gcc-internal-format
 msgid "fastcall and cdecl attributes are not compatible"
 msgstr "fastcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:7730
+#: config/i386/i386.c:7736
 #, gcc-internal-format
 msgid "fastcall and stdcall attributes are not compatible"
 msgstr "fastcall 和 stdcall 属性互不兼容"
 
-#: config/i386/i386.c:7738 config/i386/i386.c:7787
+#: config/i386/i386.c:7744 config/i386/i386.c:7793
 #, gcc-internal-format
 msgid "fastcall and thiscall attributes are not compatible"
 msgstr "fastcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:7748 config/i386/i386.c:7765
+#: config/i386/i386.c:7754 config/i386/i386.c:7771
 #, gcc-internal-format
 msgid "stdcall and cdecl attributes are not compatible"
 msgstr "stdcall 和 cdecl 属性互不兼容"
 
-#: config/i386/i386.c:7752
+#: config/i386/i386.c:7758
 #, gcc-internal-format
 msgid "stdcall and fastcall attributes are not compatible"
 msgstr "stdcall 和 fastcall 属性互不兼容"
 
-#: config/i386/i386.c:7756 config/i386/i386.c:7783
+#: config/i386/i386.c:7762 config/i386/i386.c:7789
 #, gcc-internal-format
 msgid "stdcall and thiscall attributes are not compatible"
 msgstr "stdcall 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:7773 config/i386/i386.c:7791
+#: config/i386/i386.c:7779 config/i386/i386.c:7797
 #, gcc-internal-format
 msgid "cdecl and thiscall attributes are not compatible"
 msgstr "cdecl 和 thiscall 属性互不兼容"
 
-#: config/i386/i386.c:7779
+#: config/i386/i386.c:7785
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute is used for non-class method"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: config/i386/i386.c:8023
+#: config/i386/i386.c:8029
 #, gcc-internal-format
 msgid "calling %qD with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:8026
+#: config/i386/i386.c:8032
 #, gcc-internal-format
 msgid "calling %qT with attribute sseregparm without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qT却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:8342
+#: config/i386/i386.c:8348
 #, gcc-internal-format
 msgid "X32 does not support ms_abi attribute"
 msgstr "X32 不支持 ms_abi 属性"
 
-#: config/i386/i386.c:8374
+#: config/i386/i386.c:8380
 #, gcc-internal-format
 msgid "ms_hook_prologue is not compatible with nested function"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.c:8687
+#: config/i386/i386.c:8693
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector argument without AVX512F enabled changes the ABI"
 msgstr "没有启用 MMX，却出现了 MMX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:8693
+#: config/i386/i386.c:8699
 #, fuzzy, gcc-internal-format
 msgid "AVX512F vector return without AVX512F enabled changes the ABI"
 msgstr "没有启用 SSE，却有 SSE 向量返回值，这改变了 ABI"
 
-#: config/i386/i386.c:8707
+#: config/i386/i386.c:8713
 #, gcc-internal-format
 msgid "AVX vector argument without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:8713
+#: config/i386/i386.c:8719
 #, fuzzy, gcc-internal-format
 msgid "AVX vector return without AVX enabled changes the ABI"
 msgstr "没有启用 AVX，却出现了 AVX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:8729
+#: config/i386/i386.c:8735
 #, gcc-internal-format
 msgid "SSE vector argument without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却出现了 SSE 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:8735
+#: config/i386/i386.c:8741
 #, gcc-internal-format
 msgid "SSE vector return without SSE enabled changes the ABI"
 msgstr "没有启用 SSE，却有 SSE 向量返回值，这改变了 ABI"
 
-#: config/i386/i386.c:8751
+#: config/i386/i386.c:8757
 #, gcc-internal-format
 msgid "MMX vector argument without MMX enabled changes the ABI"
 msgstr "没有启用 MMX，却出现了 MMX 向量实参，这改变了 ABI"
 
-#: config/i386/i386.c:8757
+#: config/i386/i386.c:8763
 #, gcc-internal-format
 msgid "MMX vector return without MMX enabled changes the ABI"
 msgstr "没有启用 MMX却返回 MMX 向量，这改变了 ABI"
 
-#: config/i386/i386.c:8939
+#: config/i386/i386.c:8945
 #, gcc-internal-format
 msgid "the ABI of passing struct with a flexible array member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有一个可变数组成员的结构的 ABI 有了改变"
 
-#: config/i386/i386.c:9056
+#: config/i386/i386.c:9062
 #, gcc-internal-format
 msgid "the ABI of passing union with long double has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.c:9174
+#: config/i386/i386.c:9180
 #, gcc-internal-format
 msgid "the ABI of passing structure with complex float member has changed in GCC 4.4"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/i386/i386.c:9337
+#: config/i386/i386.c:9343
 #, gcc-internal-format
 msgid "SSE register return with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中返回"
 
-#: config/i386/i386.c:9343
+#: config/i386/i386.c:9349
 #, gcc-internal-format
 msgid "SSE register argument with SSE disabled"
 msgstr "已禁用 SSE 却在 SSE 寄存器中传递参数"
 
-#: config/i386/i386.c:9359
+#: config/i386/i386.c:9365
 #, gcc-internal-format
 msgid "x87 register return with x87 disabled"
 msgstr "已禁用 x87 却在 x87 寄存器中返回"
 
-#: config/i386/i386.c:9655 config/i386/i386.c:9926 config/i386/i386.c:10449
+#: config/i386/i386.c:9661 config/i386/i386.c:9932 config/i386/i386.c:10455
 #, fuzzy, gcc-internal-format
 msgid "calling %qD with SSE calling convention without SSE/SSE2 enabled"
 msgstr "带属性 sseregparm 调用%qD却没有启用 SSE/SSE2"
 
-#: config/i386/i386.c:9657 config/i386/i386.c:9928 config/i386/i386.c:10451
+#: config/i386/i386.c:9663 config/i386/i386.c:9934 config/i386/i386.c:10457
 #, gcc-internal-format
 msgid "this is a GCC bug that can be worked around by adding attribute used to function called"
 msgstr ""
 
-#: config/i386/i386.c:10351
+#: config/i386/i386.c:10357
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "The ABI for passing parameters with %d-byte alignment has changed in GCC 4.6"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/i386/i386.c:13734
+#: config/i386/i386.c:13740
 #, fuzzy, gcc-internal-format
 msgid "ms_hook_prologue attribute isn%'t compatible with -mfentry for 32-bit"
 msgstr "ms_hook_prologue 与嵌套函数不兼容"
 
-#: config/i386/i386.c:13824
+#: config/i386/i386.c:13830
 #, gcc-internal-format
 msgid "Dynamic Realign Argument Pointer (DRAP) not supported in interrupt service routine.  This may be worked around by avoiding functions with aggregate return."
 msgstr ""
 
-#: config/i386/i386.c:14836
+#: config/i386/i386.c:14842
 #, gcc-internal-format
 msgid "-fsplit-stack does not support fastcall with nested function"
 msgstr "-fsplit-stack 不支持对嵌套函数使用 fastcall"
 
-#: config/i386/i386.c:14856
+#: config/i386/i386.c:14862
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 2 register parameters for a nested function"
 msgstr "-fsplit-stack 不支持在嵌套函数中使用 2 个寄存器参数"
@@ -31521,84 +31570,84 @@
 
 #. FIXME: We could make this work by pushing a register
 #. around the addition and comparison.
-#: config/i386/i386.c:14867
+#: config/i386/i386.c:14873
 #, gcc-internal-format
 msgid "-fsplit-stack does not support 3 register parameters"
 msgstr "-fsplit-stack 不支持 3 个寄存器参数"
 
-#: config/i386/i386.c:17672 config/i386/i386.c:17686
+#: config/i386/i386.c:17678 config/i386/i386.c:17692
 #, fuzzy, gcc-internal-format
 #| msgid "unsupported operand size for extended register"
 msgid "unsupported size for integer register"
 msgstr "扩展的寄存器不支持的操作数大小"
 
-#: config/i386/i386.c:17718
+#: config/i386/i386.c:17724
 #, gcc-internal-format
 msgid "extended registers have no high halves"
 msgstr "扩展的寄存器没有高半部分"
 
-#: config/i386/i386.c:17733
+#: config/i386/i386.c:17739
 #, gcc-internal-format
 msgid "unsupported operand size for extended register"
 msgstr "扩展的寄存器不支持的操作数大小"
 
-#: config/i386/i386.c:17924
+#: config/i386/i386.c:17930
 #, fuzzy, gcc-internal-format
 msgid "non-integer operand used with operand code 'z'"
 msgstr "非整数操作数使用了操作数代码‘%c’"
 
-#: config/i386/i386.c:28283
+#: config/i386/i386.c:28289
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't be called directly"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/i386/i386.c:32550
+#: config/i386/i386.c:32591
 #, gcc-internal-format
 msgid "No dispatcher found for the versioning attributes"
 msgstr ""
 
-#: config/i386/i386.c:32600
+#: config/i386/i386.c:32641
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for %s"
 msgstr "找不到任何查看器用于 %s/%s\n"
 
-#: config/i386/i386.c:32610
+#: config/i386/i386.c:32651
 #, gcc-internal-format, gfc-internal-format
 msgid "No dispatcher found for the versioning attributes : %s"
 msgstr ""
 
-#: config/i386/i386.c:32858
+#: config/i386/i386.c:32899
 #, gcc-internal-format
 msgid "Function versions cannot be marked as gnu_inline, bodies have to be generated"
 msgstr ""
 
-#: config/i386/i386.c:32863 config/i386/i386.c:33291
+#: config/i386/i386.c:32904 config/i386/i386.c:33332
 #, fuzzy, gcc-internal-format
 msgid "Virtual function multiversioning not supported"
 msgstr "联合成员函数%qD被声明为虚函数"
 
-#: config/i386/i386.c:32926
+#: config/i386/i386.c:32967
 #, gcc-internal-format
 msgid "missing %<target%> attribute for multi-versioned %D"
 msgstr ""
 
-#: config/i386/i386.c:32929
+#: config/i386/i386.c:32970
 #, fuzzy, gcc-internal-format
 msgid "previous declaration of %D"
 msgstr "先前的声明%q+D"
 
-#: config/i386/i386.c:33148
+#: config/i386/i386.c:33189
 #, fuzzy, gcc-internal-format
 msgid "multiversioning needs ifunc which is not supported on this target"
 msgstr "嵌套函数在此目标机上不受支持"
 
-#: config/i386/i386.c:33540
+#: config/i386/i386.c:33581
 #, fuzzy, gcc-internal-format
 msgid "Parameter to builtin must be a string constant or literal"
 msgstr "%qs的实参必须是一个 2 位无符号字面常量"
 
-#: config/i386/i386.c:33565 config/i386/i386.c:33615
+#: config/i386/i386.c:33606 config/i386/i386.c:33656
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Parameter to builtin not valid: %s"
 msgstr ""
@@ -31605,219 +31654,219 @@
 "\n"
 "错误：“%s”并非有效新闻群组！\n"
 
-#: config/i386/i386.c:34294 config/i386/i386.c:35692
+#: config/i386/i386.c:34335 config/i386/i386.c:35733
 #, gcc-internal-format
 msgid "the last argument must be a 2-bit immediate"
 msgstr "最后一个实参必须是一个 2 位立即数"
 
-#: config/i386/i386.c:34689
+#: config/i386/i386.c:34730
 #, fuzzy, gcc-internal-format
 msgid "the fifth argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:34784
+#: config/i386/i386.c:34825
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:35623
+#: config/i386/i386.c:35664
 #, gcc-internal-format
 msgid "the last argument must be an 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386.c:35638
+#: config/i386/i386.c:35679
 #, gcc-internal-format
 msgid "the last argument must be a 3-bit immediate"
 msgstr "最后一个实参必须是一个 3 位立即数"
 
-#: config/i386/i386.c:35671
+#: config/i386/i386.c:35712
 #, gcc-internal-format
 msgid "the last argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:35711
+#: config/i386/i386.c:35752
 #, gcc-internal-format
 msgid "the last argument must be a 1-bit immediate"
 msgstr "最后一个实参必须是一个 1 位立即数"
 
-#: config/i386/i386.c:35724
+#: config/i386/i386.c:35765
 #, gcc-internal-format
 msgid "the last argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386.c:35734
+#: config/i386/i386.c:35775
 #, gcc-internal-format
 msgid "the next to last argument must be an 8-bit immediate"
 msgstr "倒数第二个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:35739 config/i386/i386.c:36529
+#: config/i386/i386.c:35780 config/i386/i386.c:36570
 #, gcc-internal-format
 msgid "the last argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:35907
+#: config/i386/i386.c:35948
 #, fuzzy, gcc-internal-format
 msgid "the third argument must be comparison constant"
 msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 
-#: config/i386/i386.c:35912
+#: config/i386/i386.c:35953
 #, fuzzy, gcc-internal-format
 msgid "incorrect comparison mode"
 msgstr "不正确的格式：%s\n"
 
-#: config/i386/i386.c:35918 config/i386/i386.c:36119
+#: config/i386/i386.c:35959 config/i386/i386.c:36160
 #, fuzzy, gcc-internal-format
 msgid "incorrect rounding operand"
 msgstr "控制生成的浮点舍入模式"
 
-#: config/i386/i386.c:36101
+#: config/i386/i386.c:36142
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 4-bit immediate"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:36107
+#: config/i386/i386.c:36148
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be a 5-bit immediate"
 msgstr "最后一个实参必须是一个 5 位立即数"
 
-#: config/i386/i386.c:36110
+#: config/i386/i386.c:36151
 #, fuzzy, gcc-internal-format
 msgid "the immediate argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:36527
+#: config/i386/i386.c:36568
 #, gcc-internal-format
 msgid "the last argument must be a 32-bit immediate"
 msgstr "最后一个参数必须是一个 32 位立即数"
 
-#: config/i386/i386.c:36609 config/rs6000/rs6000.c:15973
+#: config/i386/i386.c:36650 config/rs6000/rs6000.c:16009
 #, gcc-internal-format
 msgid "selector must be an integer constant in the range 0..%wi"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: config/i386/i386.c:36814
+#: config/i386/i386.c:36855
 #, gcc-internal-format
 msgid "%qE needs unknown isa option"
 msgstr "%qE需要未知的 ISA 选项"
 
-#: config/i386/i386.c:36818
+#: config/i386/i386.c:36859
 #, gcc-internal-format
 msgid "%qE needs isa option %s"
 msgstr "%qE需要 ISA 选项 %s"
 
-#: config/i386/i386.c:37566
+#: config/i386/i386.c:37607
 #, gcc-internal-format
 msgid "last argument must be an immediate"
 msgstr "最后一个实参必须是一个立即数"
 
-#: config/i386/i386.c:38270 config/i386/i386.c:38452
+#: config/i386/i386.c:38311 config/i386/i386.c:38493
 #, fuzzy, gcc-internal-format
 msgid "the last argument must be scale 1, 2, 4, 8"
 msgstr "最后一个实参必须是一个 4 位立即数"
 
-#: config/i386/i386.c:38505
+#: config/i386/i386.c:38546
 #, fuzzy, gcc-internal-format
 msgid "the forth argument must be scale 1, 2, 4, 8"
 msgstr "左实参必须是一个切片"
 
-#: config/i386/i386.c:38511
+#: config/i386/i386.c:38552
 #, fuzzy, gcc-internal-format
 msgid "incorrect hint operand"
 msgstr "(提示略过)"
 
-#: config/i386/i386.c:38530
+#: config/i386/i386.c:38571
 #, fuzzy, gcc-internal-format
 msgid "the xabort's argument must be an 8-bit immediate"
 msgstr "最后一个实参必须是一个 8 位立即数"
 
-#: config/i386/i386.c:41336
+#: config/i386/i386.c:41377
 #, gcc-internal-format
 msgid "%qE attribute only available for 32-bit"
 msgstr "%qE属性只能在 32 位下使用"
 
-#: config/i386/i386.c:41357
+#: config/i386/i386.c:41398
 #, fuzzy, gcc-internal-format
 msgid "argument to %qE attribute is neither zero, nor one"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/i386/i386.c:41390 config/i386/i386.c:41399
+#: config/i386/i386.c:41431 config/i386/i386.c:41440
 #, gcc-internal-format
 msgid "ms_abi and sysv_abi attributes are not compatible"
 msgstr "ms_abi 和 sysv_abi 属性互不兼容"
 
-#: config/i386/i386.c:41435 config/rs6000/rs6000.c:35378
+#: config/i386/i386.c:41476 config/rs6000/rs6000.c:35427
 #, gcc-internal-format
 msgid "%qE incompatible attribute ignored"
 msgstr "%qE不兼容的属性已被忽略"
 
-#: config/i386/i386.c:41479
+#: config/i386/i386.c:41520
 #, gcc-internal-format
 msgid "interrupt service routine should have a pointer as the first argument"
 msgstr ""
 
-#: config/i386/i386.c:41486
+#: config/i386/i386.c:41527
 #, gcc-internal-format, gfc-internal-format
 msgid "interrupt service routine should have unsigned %sint as the second argument"
 msgstr ""
 
-#: config/i386/i386.c:41496
+#: config/i386/i386.c:41537
 #, gcc-internal-format
 msgid "interrupt service routine can only have a pointer argument and an optional integer argument"
 msgstr ""
 
-#: config/i386/i386.c:41499
+#: config/i386/i386.c:41540
 #, fuzzy, gcc-internal-format
 #| msgid "interrupt Service Routines cannot be coded in Thumb mode"
 msgid "interrupt service routine can't have non-void return value"
 msgstr "Thumb 模式中不能编码中断服务进程"
 
-#: config/i386/i386.c:44401
+#: config/i386/i386.c:44442
 #, fuzzy, gcc-internal-format
 #| msgid "By-value argument at %L is not allowed in this context"
 msgid "alternatives not allowed in asm flag output"
 msgstr "%L处上下文中不允许使用按值传递的实参"
 
-#: config/i386/i386.c:44465
+#: config/i386/i386.c:44506
 #, fuzzy, gcc-internal-format
 msgid "unknown asm flag output %qs"
 msgstr "未知的 TLS 模型%qs"
 
-#: config/i386/i386.c:44494
+#: config/i386/i386.c:44535
 #, fuzzy, gcc-internal-format
 msgid "invalid type for asm flag output"
 msgstr "向函数类型%qT的转换无效"
 
-#: config/i386/i386.c:50765
+#: config/i386/i386.c:50806
 #, fuzzy, gcc-internal-format
 msgid "Unknown architecture specific memory model"
 msgstr "未知的架构‘%s’"
 
-#: config/i386/i386.c:50772
+#: config/i386/i386.c:50813
 #, gcc-internal-format
 msgid "HLE_ACQUIRE not used with ACQUIRE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50778
+#: config/i386/i386.c:50819
 #, gcc-internal-format
 msgid "HLE_RELEASE not used with RELEASE or stronger memory model"
 msgstr ""
 
-#: config/i386/i386.c:50802 config/i386/i386.c:50923
+#: config/i386/i386.c:50843 config/i386/i386.c:50964
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unsupported simdlen %d"
 msgstr "不支持的真理哈希类型 %d。\n"
 
-#: config/i386/i386.c:50821
+#: config/i386/i386.c:50862
 #, fuzzy, gcc-internal-format
 msgid "unsupported return type %qT for simd\n"
 msgstr "%<operator new%>必须返回%qT"
 
-#: config/i386/i386.c:50843
+#: config/i386/i386.c:50884
 #, fuzzy, gcc-internal-format
 msgid "unsupported argument type %qT for simd\n"
 msgstr "需要类型%qT，但实参的类型为%qT"
 
-#: config/i386/i386.c:51169
+#: config/i386/i386.c:51210
 #, gcc-internal-format
 msgid "Pointer Checker requires MPX support on this target. Use -mmpx options to enable MPX."
 msgstr ""
@@ -31940,7 +31989,7 @@
 msgid "argument %qd is not a constant"
 msgstr "实参%qd不是一个常数"
 
-#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2455
+#: config/iq2000/iq2000.c:2912 config/xtensa/xtensa.c:2456
 #, gcc-internal-format
 msgid "PRINT_OPERAND_ADDRESS, null pointer"
 msgstr "PRINT_OPERAND_ADDRESS，空指针"
@@ -31950,7 +31999,7 @@
 msgid "PRINT_OPERAND: Unknown punctuation '%c'"
 msgstr "PRINT_OPERAND：未知的标点‘%c’"
 
-#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2299
+#: config/iq2000/iq2000.c:3076 config/xtensa/xtensa.c:2300
 #, gcc-internal-format
 msgid "PRINT_OPERAND null pointer"
 msgstr "PRINT_OPERAND 空指针"
@@ -32051,7 +32100,7 @@
 msgid "interrupt_thread is available only on fido"
 msgstr "interrupt_thread 只在 fido 中可用"
 
-#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28119
+#: config/m68k/m68k.c:1108 config/rs6000/rs6000.c:28168
 #, gcc-internal-format
 msgid "stack limit expression is not supported"
 msgstr "不支持堆栈限制表达式"
@@ -32560,8 +32609,8 @@
 msgid "MSP430 builtin functions only work inside interrupt handlers"
 msgstr ""
 
-#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3375
-#: config/xtensa/xtensa.c:3401
+#: config/msp430/msp430.c:2606 config/rx/rx.c:2635 config/xtensa/xtensa.c:3376
+#: config/xtensa/xtensa.c:3402
 #, gcc-internal-format
 msgid "bad builtin code"
 msgstr "错误的内建代码"
@@ -32814,28 +32863,28 @@
 msgid "PTX does not support weak declarations (only weak definitions)"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4283
+#: config/nvptx/nvptx.c:4299
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute requires a void return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: config/nvptx/nvptx.c:4306
+#: config/nvptx/nvptx.c:4322
 #, fuzzy, gcc-internal-format
 #| msgid "__BELOW100__ attribute not allowed with auto storage class"
 msgid "%qE attribute not allowed with auto storage class"
 msgstr "__BELOW100__ 属性不允许用于自动存储类"
 
-#: config/nvptx/nvptx.c:4674
+#: config/nvptx/nvptx.c:4690
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring %d"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4675
+#: config/nvptx/nvptx.c:4691
 #, gcc-internal-format, gfc-internal-format
 msgid "using vector_length (%d), ignoring runtime setting"
 msgstr ""
 
-#: config/nvptx/nvptx.c:4685
+#: config/nvptx/nvptx.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "using num_workers (%d), ignoring %d"
 msgstr ""
@@ -32860,7 +32909,7 @@
 msgid "-g option disabled"
 msgstr "-g 选项已被禁用"
 
-#: config/pa/pa.c:8769
+#: config/pa/pa.c:8793
 #, gcc-internal-format, gfc-internal-format
 msgid "alignment (%u) for %s exceeds maximum alignment for global common data.  Using %u"
 msgstr "对齐边界(%u) 对 %s 来说超过了全局共同数据的最大对齐边界。使用 %u"
@@ -33000,163 +33049,163 @@
 msgid "junk at end of #pragma longcall"
 msgstr "#pragma longcall 末尾有垃圾字符"
 
-#: config/rs6000/rs6000-c.c:5575
+#: config/rs6000/rs6000-c.c:5578
 #, gcc-internal-format
 msgid "vec_lvsl is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5579
+#: config/rs6000/rs6000-c.c:5582
 #, gcc-internal-format
 msgid "vec_lvsr is deprecated for little endian; use assignment for unaligned loads and stores"
 msgstr ""
 
-#: config/rs6000/rs6000-c.c:5589
+#: config/rs6000/rs6000-c.c:5592
 #, fuzzy, gcc-internal-format
 #| msgid "vec_extract only accepts 2 arguments"
 msgid "vec_mul only accepts 2 arguments"
 msgstr "vec_extract 只接受两个参数"
 
-#: config/rs6000/rs6000-c.c:5640
+#: config/rs6000/rs6000-c.c:5643
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_cmpne only accepts 2 arguments"
 msgstr "vec_insert 只接受三个参数"
 
-#: config/rs6000/rs6000-c.c:5710
+#: config/rs6000/rs6000-c.c:5713
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_adde only accepts 3 arguments"
 msgstr "vec_insert 只接受三个参数"
 
-#: config/rs6000/rs6000-c.c:5774
+#: config/rs6000/rs6000-c.c:5777
 #, fuzzy, gcc-internal-format
 #| msgid "vec_insert only accepts 3 arguments"
 msgid "vec_addec only accepts 3 arguments"
 msgstr "vec_insert 只接受三个参数"
 
-#: config/rs6000/rs6000-c.c:5862
+#: config/rs6000/rs6000-c.c:5865
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts %d arguments"
 msgstr "%s 只接受 %d 个参数"
 
-#: config/rs6000/rs6000-c.c:5867
+#: config/rs6000/rs6000-c.c:5870
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 1 argument"
 msgstr "%s 只接受 1 个参数"
 
-#: config/rs6000/rs6000-c.c:5872
+#: config/rs6000/rs6000-c.c:5875
 #, gcc-internal-format, gfc-internal-format
 msgid "%s only accepts 2 arguments"
 msgstr "%s 只接受 2 个参数"
 
-#: config/rs6000/rs6000-c.c:5938
+#: config/rs6000/rs6000-c.c:5941
 #, gcc-internal-format
 msgid "vec_extract only accepts 2 arguments"
 msgstr "vec_extract 只接受两个参数"
 
-#: config/rs6000/rs6000-c.c:6107
+#: config/rs6000/rs6000-c.c:6110
 #, gcc-internal-format
 msgid "vec_insert only accepts 3 arguments"
 msgstr "vec_insert 只接受三个参数"
 
-#: config/rs6000/rs6000-c.c:6381
+#: config/rs6000/rs6000-c.c:6388
 #, fuzzy, gcc-internal-format
 #| msgid "passing arg %d of %qE discards qualifiers frompointer target type"
 msgid "passing arg %d of %qE discards qualifiers from pointer target type"
 msgstr "传递%2$qE的第 %1$d 个参数时丢弃了指针目标类型的类型限定"
 
-#: config/rs6000/rs6000-c.c:6435
+#: config/rs6000/rs6000-c.c:6442
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s not supported in this compiler configuration"
 msgstr "弱引用在此配置下不受支持"
 
-#: config/rs6000/rs6000-c.c:6443
+#: config/rs6000/rs6000-c.c:6450
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "invalid parameter combination for AltiVec intrinsic"
 msgid "invalid parameter combination for AltiVec intrinsic %s"
 msgstr "对 AltiVec 内建函数来说无效的参数组合"
 
-#: config/rs6000/rs6000.c:3642
+#: config/rs6000/rs6000.c:3644
 #, gcc-internal-format
 msgid "-mrecip requires -ffinite-math or -ffast-math"
 msgstr "-mrecip 需要 -ffinite-math 或 -ffast-math"
 
-#: config/rs6000/rs6000.c:3644
+#: config/rs6000/rs6000.c:3646
 #, gcc-internal-format
 msgid "-mrecip requires -fno-trapping-math or -ffast-math"
 msgstr "-mrecip 需要 -fno-trapping-math 或 -ffast-math"
 
-#: config/rs6000/rs6000.c:3646
+#: config/rs6000/rs6000.c:3648
 #, gcc-internal-format
 msgid "-mrecip requires -freciprocal-math or -ffast-math"
 msgstr "-mrecip 需要 -freciprocal-math 或 -ffast-math"
 
-#: config/rs6000/rs6000.c:3746
+#: config/rs6000/rs6000.c:3748
 #, gcc-internal-format
 msgid "-m64 requires PowerPC64 architecture, enabling"
 msgstr "-m64 需要 PowerPC64 架构，正在启用"
 
-#: config/rs6000/rs6000.c:3929
+#: config/rs6000/rs6000.c:3931
 #, gcc-internal-format
 msgid "-malign-power is not supported for 64-bit Darwin; it is incompatible with the installed C and C++ libraries"
 msgstr "-malign-power 在 64 位 Darwin 下不受支持；它与已安装的 C 和 C++ 库不兼容"
 
-#: config/rs6000/rs6000.c:4021
+#: config/rs6000/rs6000.c:4023
 #, gcc-internal-format
 msgid "will not generate power9 instructions because assembler lacks power9 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4030
+#: config/rs6000/rs6000.c:4032
 #, gcc-internal-format
 msgid "will not generate power8 instructions because assembler lacks power8 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4039
+#: config/rs6000/rs6000.c:4041
 #, gcc-internal-format
 msgid "will not generate power7 instructions because assembler lacks power7 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4048
+#: config/rs6000/rs6000.c:4050
 #, gcc-internal-format
 msgid "will not generate power6 instructions because assembler lacks power6 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4057
+#: config/rs6000/rs6000.c:4059
 #, gcc-internal-format
 msgid "will not generate power5 instructions because assembler lacks power5 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4145
+#: config/rs6000/rs6000.c:4147
 #, fuzzy, gcc-internal-format
 msgid "not configured for SPE ABI"
 msgstr "没有为此 ABI 配置：‘%s’"
 
-#: config/rs6000/rs6000.c:4150
+#: config/rs6000/rs6000.c:4152
 #, fuzzy, gcc-internal-format
 msgid "not configured for SPE instruction set"
 msgstr "使用 PowerPC-64 指令集"
 
-#: config/rs6000/rs6000.c:4156
+#: config/rs6000/rs6000.c:4158
 #, gcc-internal-format
 msgid "target attribute or pragma changes SPE ABI"
 msgstr "目标属性或 pragma 改变了 SPE ABI"
 
-#: config/rs6000/rs6000.c:4163
+#: config/rs6000/rs6000.c:4165
 #, gcc-internal-format
 msgid "AltiVec not supported in this target"
 msgstr "AltiVec 在此目标机上不受支持"
 
-#: config/rs6000/rs6000.c:4165 config/rs6000/rs6000.c:4170
+#: config/rs6000/rs6000.c:4167 config/rs6000/rs6000.c:4172
 #, gcc-internal-format
 msgid "SPE not supported in this target"
 msgstr "SPE 在此目标机上不受支持"
 
-#: config/rs6000/rs6000.c:4198
+#: config/rs6000/rs6000.c:4200
 #, gcc-internal-format
 msgid "-mmultiple is not supported on little endian systems"
 msgstr "-mmultiple 在小端在前的系统上不受支持"
 
-#: config/rs6000/rs6000.c:4205
+#: config/rs6000/rs6000.c:4207
 #, gcc-internal-format
 msgid "-mstring is not supported on little endian systems"
 msgstr "-mstring 在小端在前的系统上不受支持"
@@ -33163,70 +33212,70 @@
 
 #. Enforce that none of the ISA_3_0_MASKS_SERVER flags
 #. were explicitly cleared.
-#: config/rs6000/rs6000.c:4301 config/rs6000/rs6000.c:4312
+#: config/rs6000/rs6000.c:4303 config/rs6000/rs6000.c:4314
 #, fuzzy, gcc-internal-format
 #| msgid "-mcmodel incompatible with other toc options"
 msgid "-mpower9-minmax incompatible with explicitly disabled options"
 msgstr "-mcmodel incompatible 与其他 toc 选项不兼容"
 
-#: config/rs6000/rs6000.c:4304
+#: config/rs6000/rs6000.c:4306
 #, gcc-internal-format
 msgid "Power9 target option is incompatible with -mcpu=<xxx> for <xxx> less than power9"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4336
+#: config/rs6000/rs6000.c:4338
 #, fuzzy, gcc-internal-format
 msgid "-mcrypto requires -maltivec"
 msgstr "停用自动需求：截取"
 
-#: config/rs6000/rs6000.c:4343
+#: config/rs6000/rs6000.c:4345
 #, gcc-internal-format
 msgid "-mdirect-move requires -mvsx"
 msgstr "-mdirect-move 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4350
+#: config/rs6000/rs6000.c:4352
 #, fuzzy, gcc-internal-format
 msgid "-mpower8-vector requires -maltivec"
 msgstr "停用自动需求：截取"
 
-#: config/rs6000/rs6000.c:4358
+#: config/rs6000/rs6000.c:4360
 #, gcc-internal-format
 msgid "-mpower8-vector requires -mvsx"
 msgstr "-mpower8-vector 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4377
+#: config/rs6000/rs6000.c:4379
 #, gcc-internal-format
 msgid "-mvsx-timode requires -mvsx"
 msgstr "-mvsx-timode 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4384
+#: config/rs6000/rs6000.c:4386
 #, fuzzy, gcc-internal-format
 msgid "-mhard-dfp requires -mhard-float"
 msgstr "不支持 -mhard-float"
 
-#: config/rs6000/rs6000.c:4437
+#: config/rs6000/rs6000.c:4439
 #, gcc-internal-format
 msgid "-mupper-regs-df requires -mvsx"
 msgstr "-mupper-regs-df 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4444
+#: config/rs6000/rs6000.c:4446
 #, fuzzy, gcc-internal-format
 #| msgid "-mupper-regs-df requires -mvsx"
 msgid "-mupper-regs-di requires -mvsx"
 msgstr "-mupper-regs-df 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4451
+#: config/rs6000/rs6000.c:4453
 #, gcc-internal-format
 msgid "-mupper-regs-sf requires -mpower8-vector"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4500
+#: config/rs6000/rs6000.c:4502
 #, fuzzy, gcc-internal-format
 #| msgid "-mpower8-vector requires -mvsx"
 msgid "-mpower8-fusion-sign requires -mpower8-fusion"
 msgstr "-mpower8-vector 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4503
+#: config/rs6000/rs6000.c:4505
 #, fuzzy, gcc-internal-format
 msgid "-mtoc-fusion requires -mpower8-fusion"
 msgstr "内建函数%q+D未被声明为函数"
@@ -33235,239 +33284,239 @@
 #. error messages.  However, if users have managed to select
 #. power9-fusion without selecting power8-fusion, they
 #. already know about undocumented flags.
-#: config/rs6000/rs6000.c:4520
+#: config/rs6000/rs6000.c:4522
 #, fuzzy, gcc-internal-format
 #| msgid "-mpower8-vector requires -mvsx"
 msgid "-mpower9-fusion requires -mpower8-fusion"
 msgstr "-mpower8-vector 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4573
+#: config/rs6000/rs6000.c:4575
 #, fuzzy, gcc-internal-format
 msgid "-mpower9-vector requires -mpower8-vector"
 msgstr "停用自动需求：截取"
 
-#: config/rs6000/rs6000.c:4618
+#: config/rs6000/rs6000.c:4620
 #, fuzzy, gcc-internal-format
 msgid "-mpower9-dform requires -mpower9-vector"
 msgstr "停用自动需求：截取"
 
-#: config/rs6000/rs6000.c:4647
+#: config/rs6000/rs6000.c:4649
 #, gcc-internal-format
 msgid "-mpower9-dform, -mpower9-dform-vector, -mpower9-dform-scalar require -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4670
+#: config/rs6000/rs6000.c:4672
 #, fuzzy, gcc-internal-format
 #| msgid "-mpower8-vector requires -mvsx"
 msgid "-mpower9-dform requires -mupper-regs-df"
 msgstr "-mpower8-vector 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4677
+#: config/rs6000/rs6000.c:4679
 #, fuzzy, gcc-internal-format
 #| msgid "-mpower8-vector requires -mvsx"
 msgid "-mpower9-dform requires -mupper-regs-sf"
 msgstr "-mpower8-vector 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4697
+#: config/rs6000/rs6000.c:4699
 #, fuzzy, gcc-internal-format
 #| msgid "-mvsx-timode requires -mvsx"
 msgid "-mvsx-timode might need -mlra"
 msgstr "-mvsx-timode 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4722
+#: config/rs6000/rs6000.c:4724
 #, fuzzy, gcc-internal-format
 #| msgid "-mdirect-move requires -mvsx"
 msgid "-mallow-movmisalign requires -mvsx"
 msgstr "-mdirect-move 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4737
+#: config/rs6000/rs6000.c:4739
 #, fuzzy, gcc-internal-format
 #| msgid "-mdirect-move requires -mvsx"
 msgid "-mefficient-unaligned-vsx requires -mvsx"
 msgstr "-mdirect-move 需要 -mvsx"
 
-#: config/rs6000/rs6000.c:4745
+#: config/rs6000/rs6000.c:4747
 #, gcc-internal-format
 msgid "-mefficient-unaligned-vsx requires -mallow-movmisalign"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4759
+#: config/rs6000/rs6000.c:4761
 #, gcc-internal-format
 msgid "-mvsx-small-integer requires -mpower8-vector, -mupper-regs-di, and -mdirect-move"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4771
+#: config/rs6000/rs6000.c:4773
 #, gcc-internal-format
 msgid "target attribute or pragma changes long double size"
 msgstr "目标属性或 pragma 改变了 long double 的大小"
 
-#: config/rs6000/rs6000.c:4797
+#: config/rs6000/rs6000.c:4799
 #, gcc-internal-format
 msgid "-mfloat128 requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4807
+#: config/rs6000/rs6000.c:4809
 #, gcc-internal-format
 msgid "-mfloat128-type requires VSX support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4823
+#: config/rs6000/rs6000.c:4825
 #, gcc-internal-format
 msgid "-mfloat128 requires -mfloat128-type"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4836
+#: config/rs6000/rs6000.c:4838
 #, fuzzy, gcc-internal-format
 msgid "-mfloat128-hardware requires -mfloat128-type"
 msgstr "不支持 -mhard-float"
 
-#: config/rs6000/rs6000.c:4859
+#: config/rs6000/rs6000.c:4861
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires full ISA 3.0 support"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4867
+#: config/rs6000/rs6000.c:4869
 #, gcc-internal-format
 msgid "-mfloat128-hardware requires -m64"
 msgstr ""
 
-#: config/rs6000/rs6000.c:4931
+#: config/rs6000/rs6000.c:4933
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unknown vectorization library ABI type (%s) for -mveclibabi= switch"
 msgstr "%2$sveclibabi=%3$s %4$s向量库 ABI 类型(%1$s)未知"
 
-#: config/rs6000/rs6000.c:4952 config/rs6000/rs6000.c:4967
+#: config/rs6000/rs6000.c:4954 config/rs6000/rs6000.c:4969
 #, gcc-internal-format
 msgid "target attribute or pragma changes AltiVec ABI"
 msgstr "目标属性或 pragma 改变了 AltiVec ABI"
 
-#: config/rs6000/rs6000.c:4980
+#: config/rs6000/rs6000.c:4982
 #, gcc-internal-format
 msgid "target attribute or pragma changes darwin64 ABI"
 msgstr "目标属性或 pragma 改变了 darwin64 ABI"
 
-#: config/rs6000/rs6000.c:5046
+#: config/rs6000/rs6000.c:5048
 #, gcc-internal-format
 msgid "target attribute or pragma changes single precision floating point"
 msgstr "目标属性或 pragma 改变了单精度浮点数"
 
-#: config/rs6000/rs6000.c:5049
+#: config/rs6000/rs6000.c:5051
 #, gcc-internal-format
 msgid "target attribute or pragma changes double precision floating point"
 msgstr "目标属性或 pragma 改变了双精度浮点数"
 
-#: config/rs6000/rs6000.c:5151
+#: config/rs6000/rs6000.c:5153
 #, gcc-internal-format
 msgid "%qs is not a valid number in -mstack-protector-guard-offset="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5156
+#: config/rs6000/rs6000.c:5158
 #, fuzzy, gcc-internal-format
 msgid "%qs is not a valid offset in -mstack-protector-guard-offset="
 msgstr "%qs对%qs而言无效"
 
-#: config/rs6000/rs6000.c:5168
+#: config/rs6000/rs6000.c:5170
 #, gcc-internal-format
 msgid "%qs is not a valid base register in -mstack-protector-guard-reg="
 msgstr ""
 
-#: config/rs6000/rs6000.c:5176
+#: config/rs6000/rs6000.c:5178
 #, gcc-internal-format
 msgid "-mstack-protector-guard=tls needs a valid base register"
 msgstr ""
 
-#: config/rs6000/rs6000.c:8171
+#: config/rs6000/rs6000.c:8202
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the layout of aggregates containing vectors with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/rs6000/rs6000.c:11584
+#: config/rs6000/rs6000.c:11615
 #, gcc-internal-format
 msgid "GCC vector returned by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 返回向量引用：非标准的 ABI 扩展，不保证兼容性"
 
-#: config/rs6000/rs6000.c:11746
+#: config/rs6000/rs6000.c:11777
 #, gcc-internal-format
 msgid "cannot return value in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量寄存器中返回值，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000.c:11946
+#: config/rs6000/rs6000.c:11977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "the ABI of passing aggregates with %d-byte alignment has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递有 long double 的联合的 ABI 有改变"
 
-#: config/rs6000/rs6000.c:12215
+#: config/rs6000/rs6000.c:12246
 #, gcc-internal-format
 msgid "cannot pass argument in vector register because altivec instructions are disabled, use -maltivec to enable them"
 msgstr "不能在向量寄存器中传递参数，因为 altivec 指令集已被禁用，使用 -maltivec 启用"
 
-#: config/rs6000/rs6000.c:13067
+#: config/rs6000/rs6000.c:13098
 #, fuzzy, gcc-internal-format
 msgid "the ABI of passing homogeneous float aggregates has changed in GCC 5"
 msgstr "在 GCC 4.4 中传递带有复数浮点成员结构的 ABI 有了改变"
 
-#: config/rs6000/rs6000.c:13242
+#: config/rs6000/rs6000.c:13273
 #, gcc-internal-format
 msgid "GCC vector passed by reference: non-standard ABI extension with no compatibility guarantee"
 msgstr "GCC 传递向量引用：非标准的 ABI 扩展，不保证兼容性"
 
-#: config/rs6000/rs6000.c:14036
+#: config/rs6000/rs6000.c:14067
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s already processed"
 msgstr "内部错误：内建函数 %s 没有类型"
 
-#: config/rs6000/rs6000.c:14540
+#: config/rs6000/rs6000.c:14571
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be an 8-bit field value"
 msgstr "实参 1 必须是一个 5 位有符号字面量"
 
-#: config/rs6000/rs6000.c:14586
+#: config/rs6000/rs6000.c:14617
 #, gcc-internal-format
 msgid "argument 1 must be a 5-bit signed literal"
 msgstr "实参 1 必须是一个 5 位有符号字面量"
 
-#: config/rs6000/rs6000.c:14689 config/rs6000/rs6000.c:16557
+#: config/rs6000/rs6000.c:14720 config/rs6000/rs6000.c:16593
 #, gcc-internal-format
 msgid "argument 2 must be a 5-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000.c:14707
+#: config/rs6000/rs6000.c:14738
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 6-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/rs6000/rs6000.c:14721
+#: config/rs6000/rs6000.c:14752
 #, fuzzy, gcc-internal-format
 #| msgid "argument 2 must be a 5-bit unsigned literal"
 msgid "argument 2 must be a 7-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000.c:14760
+#: config/rs6000/rs6000.c:14791
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate must be a constant"
 msgstr "__builtin_altivec_predicate 的第 1 个实参必须是常量"
 
-#: config/rs6000/rs6000.c:14817
+#: config/rs6000/rs6000.c:14848
 #, gcc-internal-format
 msgid "argument 1 of __builtin_altivec_predicate is out of range"
 msgstr "__builtin_altivec_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000.c:15305
+#: config/rs6000/rs6000.c:15336
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "builtin %s is only valid in 64-bit mode"
 msgstr "%srtd%s 在 64 位模式下被忽略"
 
-#: config/rs6000/rs6000.c:15354
+#: config/rs6000/rs6000.c:15385
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d must be an unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000.c:15356
+#: config/rs6000/rs6000.c:15387
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "argument %d is an unsigned literal that is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000.c:15494
+#: config/rs6000/rs6000.c:15525
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "%s only accepts 1 argument"
 msgid "builtin %s only accepts a string argument"
@@ -33474,285 +33523,290 @@
 msgstr "%s 只接受 1 个参数"
 
 #. Invalid CPU argument.
-#: config/rs6000/rs6000.c:15513
+#: config/rs6000/rs6000.c:15544
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "cpu %s is an invalid argument to builtin %s"
 msgstr "属性%qs的参数无效"
 
 #. Invalid HWCAP argument.
-#: config/rs6000/rs6000.c:15541
+#: config/rs6000/rs6000.c:15572
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "hwcap %s is an invalid argument to builtin %s"
 msgstr "属性%qs的参数无效"
 
-#: config/rs6000/rs6000.c:15615
+#: config/rs6000/rs6000.c:15598
+#, gcc-internal-format, gfc-internal-format
+msgid "%s needs GLIBC (2.23 and newer) that exports hardware capability bits"
+msgstr ""
+
+#: config/rs6000/rs6000.c:15651
 #, gcc-internal-format
 msgid "argument 3 must be a 4-bit unsigned literal"
 msgstr "实参 3 必须是一个 4 位无符号字面量"
 
-#: config/rs6000/rs6000.c:15640
+#: config/rs6000/rs6000.c:15676
 #, gcc-internal-format
 msgid "argument 3 must be a 2-bit unsigned literal"
 msgstr "实参 2 必须是一个 2 位无符号字面量"
 
-#: config/rs6000/rs6000.c:15660
+#: config/rs6000/rs6000.c:15696
 #, gcc-internal-format
 msgid "argument 3 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/rs6000/rs6000.c:15672
+#: config/rs6000/rs6000.c:15708
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be 0 or 2"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000.c:15684
+#: config/rs6000/rs6000.c:15720
 #, fuzzy, gcc-internal-format
 msgid "argument 1 must be a 1-bit unsigned literal"
 msgstr "实参 2 必须是一个 1 位无符号字面量"
 
-#: config/rs6000/rs6000.c:15698
+#: config/rs6000/rs6000.c:15734
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be a 6-bit unsigned literal"
 msgstr "实参 2 必须是一个 5 位无符号字面量"
 
-#: config/rs6000/rs6000.c:15710
+#: config/rs6000/rs6000.c:15746
 #, fuzzy, gcc-internal-format
 msgid "argument 2 must be 0 or 1"
 msgstr "数字必须是 0 或 1"
 
-#: config/rs6000/rs6000.c:15717
+#: config/rs6000/rs6000.c:15753
 #, fuzzy, gcc-internal-format
 msgid "argument 3 must be in the range 0..15"
 msgstr "%2$qE的第 %1$d 个参数必须是在 %3$d 和 %4$d 之间"
 
-#: config/rs6000/rs6000.c:15906
+#: config/rs6000/rs6000.c:15942
 #, gcc-internal-format
 msgid "argument to %qs must be a 2-bit unsigned literal"
 msgstr "%qs的实参必须是一个 2 位无符号字面常量"
 
-#: config/rs6000/rs6000.c:16063
+#: config/rs6000/rs6000.c:16099
 #, gcc-internal-format
 msgid "unresolved overload for Altivec builtin %qF"
 msgstr "无法解析的重载 Altivec 内建函数%qF"
 
-#: config/rs6000/rs6000.c:16237
+#: config/rs6000/rs6000.c:16273
 #, gcc-internal-format
 msgid "argument to dss must be a 2-bit unsigned literal"
 msgstr "dss 的实参必须是一个 2 位无符号字面常量"
 
-#: config/rs6000/rs6000.c:16285
+#: config/rs6000/rs6000.c:16321
 #, gcc-internal-format
 msgid "second argument to vec_vextract4b must be 0..12"
 msgstr ""
 
-#: config/rs6000/rs6000.c:16302
+#: config/rs6000/rs6000.c:16338
 #, fuzzy, gcc-internal-format
 #| msgid "third argument to %<__builtin_prefetch%> must be a constant"
 msgid "third argument to vec_vinsert4b must be 0..12"
 msgstr "%<__builtin_prefetch%>的第三个实参必须是一个常量"
 
-#: config/rs6000/rs6000.c:16677
+#: config/rs6000/rs6000.c:16713
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate must be a constant"
 msgstr "__builtin_paired_predicate 的第一个实参必须是常量"
 
-#: config/rs6000/rs6000.c:16724
+#: config/rs6000/rs6000.c:16760
 #, gcc-internal-format
 msgid "argument 1 of __builtin_paired_predicate is out of range"
 msgstr "__builtin_paired_predicate 的第一个实参越界"
 
-#: config/rs6000/rs6000.c:16749
+#: config/rs6000/rs6000.c:16785
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate must be a constant"
 msgstr "__builtin_spe_predicate 的第一个实参必须是常量"
 
-#: config/rs6000/rs6000.c:16821
+#: config/rs6000/rs6000.c:16857
 #, gcc-internal-format
 msgid "argument 1 of __builtin_spe_predicate is out of range"
 msgstr "__builtin_spe_predicate 的第 1 个实参越界"
 
-#: config/rs6000/rs6000.c:16903
+#: config/rs6000/rs6000.c:16939
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is only valid for the cell processor"
 msgstr "此内建函数只在 fr450 上可用"
 
-#: config/rs6000/rs6000.c:16905
+#: config/rs6000/rs6000.c:16941
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mvsx option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16907
+#: config/rs6000/rs6000.c:16943
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhtm option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16909
+#: config/rs6000/rs6000.c:16945
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -maltivec option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16911
+#: config/rs6000/rs6000.c:16947
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpaired option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16913
+#: config/rs6000/rs6000.c:16949
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mspe option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16916
+#: config/rs6000/rs6000.c:16952
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp and -mpower8-vector options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16919
+#: config/rs6000/rs6000.c:16955
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-dfp option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16921
+#: config/rs6000/rs6000.c:16957
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mpower8-vector option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16924 config/rs6000/rs6000.c:16930
+#: config/rs6000/rs6000.c:16960 config/rs6000/rs6000.c:16966
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 and -m64 options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16927 config/rs6000/rs6000.c:16933
+#: config/rs6000/rs6000.c:16963 config/rs6000/rs6000.c:16969
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mcpu=power9 option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16936
+#: config/rs6000/rs6000.c:16972
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float and -mlong-double-128 options"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16939
+#: config/rs6000/rs6000.c:16975
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mhard-float option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16941
+#: config/rs6000/rs6000.c:16977
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s requires the -mfloat128 option"
 msgstr "内建函数%q+D未被声明为函数"
 
-#: config/rs6000/rs6000.c:16943
+#: config/rs6000/rs6000.c:16979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Builtin function %s is not supported with the current options"
 msgstr "弱引用在此配置下不受支持"
 
-#: config/rs6000/rs6000.c:18786
+#: config/rs6000/rs6000.c:18833
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s had an unexpected return type %s"
 msgstr "内部错误：内建函数 %s 有非预期的返回类型 %s"
 
-#: config/rs6000/rs6000.c:18803
+#: config/rs6000/rs6000.c:18850
 #, gcc-internal-format, gfc-internal-format
 msgid "internal error: builtin function %s, argument %d had unexpected argument type %s"
 msgstr "内部错误：内建函数 %s 的第 %d 个参数有非预期的参数类型 %s"
 
-#: config/rs6000/rs6000.c:28088
+#: config/rs6000/rs6000.c:28135
 #, gcc-internal-format
 msgid "stack frame too large"
 msgstr "栈帧太大"
 
-#: config/rs6000/rs6000.c:31766
+#: config/rs6000/rs6000.c:31815
 #, fuzzy, gcc-internal-format
 msgid "-fsplit-stack uses register r29"
 msgstr "ISO C90 不允许可变数组成员"
 
-#: config/rs6000/rs6000.c:31774
+#: config/rs6000/rs6000.c:31823
 #, fuzzy, gcc-internal-format
 #| msgid "#pragma GCC target is not supported for this machine"
 msgid "Stack frame larger than 2G is not supported for -fsplit-stack"
 msgstr "#pragma GCC target 在此目标机上不受支持"
 
-#: config/rs6000/rs6000.c:32762
+#: config/rs6000/rs6000.c:32811
 #, gcc-internal-format
 msgid "no profiling of 64-bit code for this ABI"
 msgstr "此 ABI 不支持取样 64 位代码"
 
-#: config/rs6000/rs6000.c:35065
+#: config/rs6000/rs6000.c:35114
 #, fuzzy, gcc-internal-format
 msgid "You cannot take the address of a nested function if you use the -mno-pointers-to-nested-functions option."
 msgstr "您无法需地址的嵌套的函数如果您使用 -mno-pointers-to-nested-functions 选项。"
 
-#: config/rs6000/rs6000.c:35147
+#: config/rs6000/rs6000.c:35196
 #, gcc-internal-format
 msgid "use of %<long double%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<long double%>无效"
 
-#: config/rs6000/rs6000.c:35149
+#: config/rs6000/rs6000.c:35198
 #, gcc-internal-format
 msgid "use of boolean types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用布尔类型无效"
 
-#: config/rs6000/rs6000.c:35151
+#: config/rs6000/rs6000.c:35200
 #, gcc-internal-format
 msgid "use of %<complex%> in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用%<complex%>无效"
 
-#: config/rs6000/rs6000.c:35153
+#: config/rs6000/rs6000.c:35202
 #, gcc-internal-format
 msgid "use of decimal floating point types in AltiVec types is invalid"
 msgstr "在 AltiVec 类型中使用十进制浮点类型无效"
 
-#: config/rs6000/rs6000.c:35159
+#: config/rs6000/rs6000.c:35208
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is invalid for 64-bit code without -mvsx"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long%>对 64 位代码无效"
 
-#: config/rs6000/rs6000.c:35162
+#: config/rs6000/rs6000.c:35211
 #, gcc-internal-format
 msgid "use of %<long%> in AltiVec types is deprecated; use %<int%>"
 msgstr "已弃用在 AltiVec 类型中使用%<long%>；请改用%<int%>"
 
-#: config/rs6000/rs6000.c:35167
+#: config/rs6000/rs6000.c:35216
 #, gcc-internal-format
 msgid "use of %<long long%> in AltiVec types is invalid without -mvsx"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<long long%>无效"
 
-#: config/rs6000/rs6000.c:35170
+#: config/rs6000/rs6000.c:35219
 #, gcc-internal-format
 msgid "use of %<double%> in AltiVec types is invalid without -mvsx"
 msgstr "不使用 -mvsx 时，在 AltiVec 类型中使用%<double%>无效"
 
-#: config/rs6000/rs6000.c:38943
+#: config/rs6000/rs6000.c:38992
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting microcode insn %s\t[%s] #%d"
 msgstr "生成微代码指令 %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:38947
+#: config/rs6000/rs6000.c:38996
 #, gcc-internal-format, gfc-internal-format
 msgid "emitting conditional microcode insn %s\t[%s] #%d"
 msgstr "生成条件微代码指令 %s\t[%s] #%d"
 
-#: config/rs6000/rs6000.c:39255
+#: config/rs6000/rs6000.c:39304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "invalid cpu \"%s\" for %s\"%s\"%s"
 msgstr "%s：无效的目的：%s\n"
 
-#: config/rs6000/rs6000.c:39258
+#: config/rs6000/rs6000.c:39307
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is not allowed"
 msgstr "%s：不允许空权字符串"
 
-#: config/rs6000/rs6000.c:39260
+#: config/rs6000/rs6000.c:39309
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s\"%s\"%s is invalid"
 msgstr "无效的 %s 字组：%s\n"
 
-#: config/rs6000/rs6000.c:39777
+#: config/rs6000/rs6000.c:39826
 #, gcc-internal-format, gfc-internal-format
 msgid "-mno-%s turns off -m%s"
 msgstr ""
 
-#: config/rs6000/rs6000.c:39794
+#: config/rs6000/rs6000.c:39843
 #, fuzzy, gcc-internal-format
 msgid "-mno-power9-vector turns off -mpower9-dform"
 msgstr "停用自动需求：截取"
@@ -33939,6 +33993,7 @@
 msgstr "-mcall-aixdesc 与 -mabi=elfv2 不兼容"
 
 #: config/rs6000/freebsd64.h:113 config/rs6000/linux64.h:135
+#: config/rs6000/rtems.h:96
 #, gcc-internal-format
 msgid "-m64 requires a PowerPC64 cpu"
 msgstr "-m64 需要 PowerPC64 CPU"
@@ -34030,7 +34085,7 @@
 msgid "builtin vec_step can only be used on vector types."
 msgstr ""
 
-#: config/s390/s390-c.c:685 config/s390/s390.c:913
+#: config/s390/s390-c.c:685 config/s390/s390.c:916
 #, fuzzy, gcc-internal-format
 msgid "constant value required for builtin %qF argument %d"
 msgstr "%<__builtin_frame_address%>的实参无效"
@@ -34058,7 +34113,7 @@
 
 #: config/s390/s390-c.c:889
 #, gcc-internal-format
-msgid "%qF requires -march=arch12 or higher"
+msgid "%qF requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:903
@@ -34079,7 +34134,7 @@
 
 #: config/s390/s390-c.c:966
 #, gcc-internal-format
-msgid "%qs matching variant requires -march=arch12 or higher"
+msgid "%qs matching variant requires z14 or higher"
 msgstr ""
 
 #: config/s390/s390-c.c:972
@@ -34093,165 +34148,165 @@
 msgid "constant argument %d for builtin %qF is out of range for target type"
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.c:769
+#: config/s390/s390.c:772
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range (0.."
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.c:786
+#: config/s390/s390.c:789
 #, fuzzy, gcc-internal-format
 #| msgid "constant argument out of range for %qs"
 msgid "constant argument %d for builtin %qF is out of range ("
 msgstr "常量实参超过%qs的范围"
 
-#: config/s390/s390.c:837
+#: config/s390/s390.c:840
 #, gcc-internal-format
 msgid "builtin %qF is not supported without -mhtm (default with -march=zEC12 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:843
+#: config/s390/s390.c:846
 #, gcc-internal-format
 msgid "builtin %qF requires -mvx (default with -march=z13 and higher)."
 msgstr ""
 
-#: config/s390/s390.c:850
+#: config/s390/s390.c:853
 #, gcc-internal-format
-msgid "Builtin %qF requires arch12 or higher."
+msgid "Builtin %qF requires z14 or higher."
 msgstr ""
 
-#: config/s390/s390.c:869
+#: config/s390/s390.c:872
 #, fuzzy, gcc-internal-format
 #| msgid "<unresolved overloaded function type>"
 msgid "unresolved overloaded builtin"
 msgstr "<未解决的重载函数类型>"
 
-#: config/s390/s390.c:876 config/tilegx/tilegx.c:3545
+#: config/s390/s390.c:879 config/tilegx/tilegx.c:3545
 #: config/tilepro/tilepro.c:3109
 #, fuzzy, gcc-internal-format
 msgid "bad builtin icode"
 msgstr "错误的内建 fcode"
 
-#: config/s390/s390.c:1004
+#: config/s390/s390.c:1007
 #, fuzzy, gcc-internal-format
 #| msgid "invalid argument to built-in function"
 msgid "invalid argument %d for builtin %qF"
 msgstr "内建函数实参无效"
 
-#: config/s390/s390.c:1105
+#: config/s390/s390.c:1108
 #, fuzzy, gcc-internal-format
 msgid "requested %qE attribute is not a comma separated pair of non-negative integer constants or too large (max. %d)"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: config/s390/s390.c:9980
+#: config/s390/s390.c:9987
 #, gcc-internal-format
 msgid "total size of local variables exceeds architecture limit"
 msgstr "局部变量大小总和超过架构极限。"
 
-#: config/s390/s390.c:11094
+#: config/s390/s390.c:11101
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes exceeding user provided stack limit of %d bytes.  An unconditional trap is added."
 msgstr "影格大小的函数 %qs 是 %wd 字节超出用户提供的堆叠限制的 %d 字节。 unconditional 陷阱被已加入。"
 
-#: config/s390/s390.c:11110
+#: config/s390/s390.c:11117
 #, fuzzy, gcc-internal-format
 msgid "frame size of function %qs is %wd bytes which is more than half the stack size. The dynamic check would not be reliable. No check emitted for this function."
 msgstr "影格大小的函数 %qs 是 %wd 字节该项是超过半堆叠大小。动态检查会无法是 reliable。没有检查发出用于这个函数。"
 
-#: config/s390/s390.c:11138
+#: config/s390/s390.c:11145
 #, fuzzy, gcc-internal-format
 msgid "frame size of %qs is %wd bytes"
 msgstr "栈帧大小不是 8 字节的倍数：%wd"
 
-#: config/s390/s390.c:11142
+#: config/s390/s390.c:11149
 #, gcc-internal-format
 msgid "%qs uses dynamic stack allocation"
 msgstr "%qs使用动态栈分配"
 
-#: config/s390/s390.c:11520
+#: config/s390/s390.c:11527
 #, gcc-internal-format
 msgid "CPUs older than z900 are not supported for -fsplit-stack"
 msgstr ""
 
-#: config/s390/s390.c:14666
+#: config/s390/s390.c:14673
 #, gcc-internal-format, gfc-internal-format
 msgid "%sarch=%s%s is deprecated and will be removed in future releases; use at least %sarch=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14678
+#: config/s390/s390.c:14685
 #, gcc-internal-format, gfc-internal-format
 msgid "%stune=%s%s is deprecated and will be removed in future releases; use at least %stune=z900%s"
 msgstr ""
 
-#: config/s390/s390.c:14690
+#: config/s390/s390.c:14697
 #, gcc-internal-format, gfc-internal-format
 msgid "z/Architecture mode not supported on %s"
 msgstr "z/Architecture 模式在 %s 上不受支持"
 
-#: config/s390/s390.c:14693
+#: config/s390/s390.c:14700
 #, gcc-internal-format
 msgid "64-bit ABI not supported in ESA/390 mode"
 msgstr "64-bit ABI 在 ESA/390 模式下不受支持"
 
-#: config/s390/s390.c:14710
+#: config/s390/s390.c:14717
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "hardware decimal floating point instructions not available on %s"
 msgid "hardware vector support not available on %s"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.c:14713
+#: config/s390/s390.c:14720
 #, gcc-internal-format
 msgid "hardware vector support not available with -msoft-float"
 msgstr ""
 
-#: config/s390/s390.c:14741
+#: config/s390/s390.c:14748
 #, gcc-internal-format, gfc-internal-format
 msgid "hardware decimal floating point instructions not available on %s"
 msgstr "硬件十进制浮点指令在 %s 上不可用"
 
-#: config/s390/s390.c:14745
+#: config/s390/s390.c:14752
 #, gcc-internal-format
 msgid "hardware decimal floating point instructions not available in ESA/390 mode"
 msgstr "硬件十进制浮点指令在 ESA/390 模式下不可用"
 
-#: config/s390/s390.c:14757
+#: config/s390/s390.c:14764
 #, gcc-internal-format
 msgid "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 msgstr "-mhard-dfp can%'t be used in conjunction with -msoft-float"
 
-#: config/s390/s390.c:14765
+#: config/s390/s390.c:14772
 #, gcc-internal-format
 msgid "-mbackchain -mpacked-stack -mhard-float are not supported in combination"
 msgstr "-mbackchain -mpacked-stack -mhard-float 一起使用不受支持"
 
-#: config/s390/s390.c:14771
+#: config/s390/s390.c:14778
 #, gcc-internal-format
 msgid "stack size must be greater than the stack guard value"
 msgstr "栈大小必须大于栈防护值"
 
-#: config/s390/s390.c:14773
+#: config/s390/s390.c:14780
 #, gcc-internal-format
 msgid "stack size must not be greater than 64k"
 msgstr "栈大小不能大于 64K"
 
-#: config/s390/s390.c:14776
+#: config/s390/s390.c:14783
 #, gcc-internal-format
 msgid "-mstack-guard implies use of -mstack-size"
 msgstr "-mstack-guard 意味着使用 -mstack-size"
 
 #. argument is not a plain number
-#: config/s390/s390.c:14874
+#: config/s390/s390.c:14881
 #, fuzzy, gcc-internal-format
 msgid "arguments to %qs should be non-negative integers"
 msgstr "“%s”的实参应该是一个非负整数"
 
-#: config/s390/s390.c:14881
+#: config/s390/s390.c:14888
 #, fuzzy, gcc-internal-format
 msgid "argument to %qs is too large (max. %d)"
 msgstr "%qE属性的实参大于 %d"
 
 #. Value is not allowed for the target attribute.
-#: config/s390/s390.c:15089
+#: config/s390/s390.c:15096
 #, fuzzy, gcc-internal-format
 msgid "value %qs is not supported by attribute %<target%>"
 msgstr "嵌套函数在此目标机上不受支持"
@@ -34308,27 +34363,28 @@
 msgid "-mrelax is only supported for RTP PIC"
 msgstr "-mrelax 只在 RTP PIC 上受支持"
 
-#: config/sparc/sparc.c:1393
+#: config/sparc/sparc.c:1509
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is not supported by this configuration"
 msgstr "%s 不为这个配置所支持"
 
-#: config/sparc/sparc.c:1400
+#: config/sparc/sparc.c:1516
 #, gcc-internal-format
 msgid "-mlong-double-64 not allowed with -m64"
 msgstr "-mlong-double-64 不允许与 -m64 一起使用"
 
-#: config/sparc/sparc.c:1420
+#: config/sparc/sparc.c:1536
 #, gcc-internal-format, gfc-internal-format
 msgid "bad value (%s) for -mcmodel= switch"
 msgstr "-mcmodel= 值(%s)不正确"
 
-#: config/sparc/sparc.c:1425
-#, gcc-internal-format
-msgid "-mcmodel= is not supported on 32 bit systems"
+#: config/sparc/sparc.c:1541
+#, fuzzy, gcc-internal-format
+#| msgid "-mcmodel= is not supported on 32 bit systems"
+msgid "-mcmodel= is not supported on 32-bit systems"
 msgstr "32 位系统不支持 -mcmodel="
 
-#: config/sparc/sparc.c:1432
+#: config/sparc/sparc.c:1548
 #, fuzzy, gcc-internal-format
 msgid "-fcall-saved-REG is not supported for out registers"
 msgstr "-fdata-sections 在此目标机上不受支持"
@@ -34613,22 +34669,22 @@
 msgid "invalid constant in %<#pragma %s%>"
 msgstr "%<#pragma pack%>中有无效常量 - 已忽略"
 
-#: config/xtensa/xtensa.c:2185
+#: config/xtensa/xtensa.c:2186
 #, gcc-internal-format
 msgid "boolean registers required for the floating-point option"
 msgstr "浮点选项需要布尔寄存器"
 
-#: config/xtensa/xtensa.c:2220
+#: config/xtensa/xtensa.c:2221
 #, gcc-internal-format, gfc-internal-format
 msgid "-f%s is not supported with CONST16 instructions"
 msgstr "CONST16 指令不支持 -f%s"
 
-#: config/xtensa/xtensa.c:2227
+#: config/xtensa/xtensa.c:2228
 #, gcc-internal-format
 msgid "PIC is required but not supported with CONST16 instructions"
 msgstr "需要 PIC，但 CONST16 指令不支持"
 
-#: config/xtensa/xtensa.c:3543
+#: config/xtensa/xtensa.c:3544
 #, gcc-internal-format
 msgid "only uninitialized variables can be placed in a .bss section"
 msgstr "只有未初始化的变量才能放在 .bss 节中"
@@ -34715,7 +34771,7 @@
 msgid "could not read the BRIG file"
 msgstr "无法写入响应文件 %s"
 
-#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8205
+#: c/c-array-notation.c:217 c/c-array-notation.c:246 cp/call.c:8210
 #: cp/cp-array-notation.c:250
 #, fuzzy, gcc-internal-format
 msgid "Invalid builtin arguments"
@@ -35121,9 +35177,9 @@
 msgstr "标号%qD在此定义"
 
 #: c/c-decl.c:3601 c/c-decl.c:3872 c/c-typeck.c:8091 cp/class.c:1480
-#: cp/class.c:3379 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
-#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3166 cp/parser.c:3259
-#: cp/parser.c:3290 cp/parser.c:6043 cp/parser.c:20681
+#: cp/class.c:3381 cp/decl.c:3907 cp/decl.c:10592 cp/decl.c:10999
+#: cp/friend.c:383 cp/friend.c:392 cp/parser.c:3168 cp/parser.c:3261
+#: cp/parser.c:3292 cp/parser.c:6048 cp/parser.c:20704
 #, gcc-internal-format
 msgid "%qD declared here"
 msgstr "%qD在此声明"
@@ -35256,7 +35312,7 @@
 msgid "%<[*]%> not allowed in other than function prototype scope"
 msgstr "%<[*]%>不能用于函数原型以外"
 
-#: c/c-decl.c:4606 cp/decl2.c:1408
+#: c/c-decl.c:4606 cp/decl2.c:1409
 #, gcc-internal-format
 msgid "%q+D in declare target directive does not have mappable type"
 msgstr ""
@@ -36307,7 +36363,7 @@
 msgid "two or more data types in declaration specifiers"
 msgstr "声明指定了两个以上的数据类型"
 
-#: c/c-decl.c:9853 cp/parser.c:27656
+#: c/c-decl.c:9853 cp/parser.c:27679
 #, gcc-internal-format
 msgid "%<long long long%> is too long for GCC"
 msgstr "%<long long long%>对 GCC 来说太长了"
@@ -36448,17 +36504,17 @@
 msgid "ISO C does not support plain %<complex%> meaning %<double complex%>"
 msgstr "ISO C 不支持单独用%<complex%>表示%<double complex%>"
 
-#: c/c-decl.c:10925 c/c-decl.c:10938 c/c-decl.c:10964
+#: c/c-decl.c:10925 c/c-decl.c:10941 c/c-decl.c:10967
 #, gcc-internal-format
 msgid "ISO C does not support complex integer types"
 msgstr "ISO C 不支持复整数"
 
-#: c/c-decl.c:11372 cp/semantics.c:5330
+#: c/c-decl.c:11375 cp/semantics.c:5343
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> combiner refers to variable %qD which is not %<omp_out%> nor %<omp_in%>"
 msgstr ""
 
-#: c/c-decl.c:11376 cp/semantics.c:5334
+#: c/c-decl.c:11379 cp/semantics.c:5347
 #, gcc-internal-format
 msgid "%<#pragma omp declare reduction%> initializer refers to variable %qD which is not %<omp_priv%> nor %<omp_orig%>"
 msgstr ""
@@ -36511,7 +36567,7 @@
 msgid "version control conflict marker in file"
 msgstr ""
 
-#: c/c-parser.c:1035 cp/parser.c:27863
+#: c/c-parser.c:1035 cp/parser.c:27886
 #, gcc-internal-format
 msgid "expected end of line"
 msgstr "需要行尾"
@@ -36553,7 +36609,7 @@
 msgstr "未知的类型名%qE"
 
 #: c/c-parser.c:1656 c/c-parser.c:10365 c/c-parser.c:15447 c/c-parser.c:15875
-#: c/c-parser.c:16351 cp/parser.c:35355 cp/parser.c:38379
+#: c/c-parser.c:16351 cp/parser.c:35378 cp/parser.c:38402
 #, gcc-internal-format
 msgid "expected declaration specifiers"
 msgstr "需要指定声明"
@@ -36568,7 +36624,7 @@
 msgid "expected %<;%>, identifier or %<(%>"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:1714 cp/parser.c:29516 cp/parser.c:29590
+#: c/c-parser.c:1714 cp/parser.c:29539 cp/parser.c:29613
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored for methods"
 msgstr "属性在未初始化类型上被忽略"
@@ -36583,8 +36639,8 @@
 msgid "unexpected attribute"
 msgstr "非预期的属性"
 
-#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10721
-#: cp/parser.c:10908
+#: c/c-parser.c:1780 c/c-parser.c:5035 c/c-parser.c:5376 cp/parser.c:10730
+#: cp/parser.c:10917
 #, fuzzy, gcc-internal-format
 #| msgid "section attribute not allowed for %q+D"
 msgid "%<fallthrough%> attribute not followed by %<;%>"
@@ -36623,7 +36679,7 @@
 msgid "%<__auto_type%> may only be used with a single declarator"
 msgstr "%<auto%> 只能被指定的用于变量或函数声明"
 
-#: c/c-parser.c:2028 cp/parser.c:12724 cp/parser.c:12881
+#: c/c-parser.c:2028 cp/parser.c:12733 cp/parser.c:12890
 #, gcc-internal-format
 msgid "expected %<,%> or %<;%>"
 msgstr "需要%<,%>或%<;%>"
@@ -36651,7 +36707,7 @@
 msgid "ISO C90 does not support %<_Static_assert%>"
 msgstr "ISO C90 不支持%<_Static_assert%>"
 
-#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38038
+#: c/c-parser.c:2234 c/c-parser.c:3925 c/c-parser.c:10423 cp/parser.c:38061
 #, gcc-internal-format
 msgid "expected string literal"
 msgstr "需要字面字符串"
@@ -36716,14 +36772,14 @@
 #: c/c-parser.c:10030 c/c-parser.c:10083 c/c-parser.c:10099 c/c-parser.c:10145
 #: c/c-parser.c:10737 c/c-parser.c:10778 c/c-parser.c:12750 c/c-parser.c:12984
 #: c/c-parser.c:14838 c/c-parser.c:17638 c/c-parser.c:17967
-#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27866
-#: cp/parser.c:30359 cp/parser.c:30389 cp/parser.c:30459 cp/parser.c:32558
-#: cp/parser.c:37752 cp/parser.c:38523
+#: c/gimple-parser.c:1008 c/gimple-parser.c:1046 cp/parser.c:27889
+#: cp/parser.c:30382 cp/parser.c:30412 cp/parser.c:30482 cp/parser.c:32581
+#: cp/parser.c:37775 cp/parser.c:38546
 #, gcc-internal-format
 msgid "expected identifier"
 msgstr "需要标识符"
 
-#: c/c-parser.c:2780 cp/parser.c:18016
+#: c/c-parser.c:2780 cp/parser.c:18039
 #, gcc-internal-format
 msgid "comma at end of enumerator list"
 msgstr "枚举表以逗号结尾"
@@ -36858,7 +36914,7 @@
 msgid "expected %<}%> before %<else%>"
 msgstr "%<else%>前需要%<}%>"
 
-#: c/c-parser.c:4908 cp/parser.c:11026
+#: c/c-parser.c:4908 cp/parser.c:11035
 #, gcc-internal-format
 msgid "%<else%> without a previous %<if%>"
 msgstr "%<else%>之前没有%<if%>"
@@ -36883,12 +36939,12 @@
 msgid "a label can only be part of a statement and a declaration is not a statement"
 msgstr "标号只能是语句的一部分，而声明并非语句"
 
-#: c/c-parser.c:5252 cp/parser.c:10573
+#: c/c-parser.c:5252 cp/parser.c:10582
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_for%>"
 msgstr ""
 
-#: c/c-parser.c:5262 cp/parser.c:10599
+#: c/c-parser.c:5262 cp/parser.c:10608
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_sync%>"
 msgstr ""
@@ -36902,17 +36958,17 @@
 #. c_parser_skip_until_found stops at a closing nesting
 #. delimiter without consuming it, but here we need to consume
 #. it to proceed further.
-#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10677
+#: c/c-parser.c:5397 c/gimple-parser.c:1391 cp/parser.c:10686
 #, gcc-internal-format
 msgid "expected statement"
 msgstr "需要语句"
 
-#: c/c-parser.c:5501 cp/parser.c:12259
+#: c/c-parser.c:5501 cp/parser.c:12268
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<if%> statement"
 msgstr "建议在空的%<if%>语句体周围加上花括号"
 
-#: c/c-parser.c:5535 cp/parser.c:12262
+#: c/c-parser.c:5535 cp/parser.c:12271
 #, gcc-internal-format
 msgid "suggest braces around empty body in an %<else%> statement"
 msgstr "建议在空的%<else%>语句体周围加上花括号"
@@ -36922,7 +36978,7 @@
 msgid "if statement cannot contain %<Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:5667 cp/parser.c:11261
+#: c/c-parser.c:5667 cp/parser.c:11270
 #, gcc-internal-format
 msgid "suggest explicit braces to avoid ambiguous %<else%>"
 msgstr "建议显式地使用花括号以避免出现有歧义的%<else%>"
@@ -36942,7 +36998,7 @@
 msgid "invalid iterating variable in fast enumeration"
 msgstr "此指令中寄存器无效"
 
-#: c/c-parser.c:6014 cp/parser.c:11462
+#: c/c-parser.c:6014 cp/parser.c:11471
 #, gcc-internal-format
 msgid "missing loop condition in loop with %<GCC ivdep%> pragma"
 msgstr ""
@@ -37119,17 +37175,17 @@
 msgid "%<__builtin_complex%> operands of different types"
 msgstr "?: 的操作数类型不一致，分别为%qT和%qT"
 
-#: c/c-parser.c:8121 cp/parser.c:6676
+#: c/c-parser.c:8121 cp/parser.c:6681
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_shuffle%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: c/c-parser.c:8202 cp/parser.c:6587
+#: c/c-parser.c:8202 cp/parser.c:6592
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<_Cilk_spawn%>"
 msgstr ""
 
-#: c/c-parser.c:8209 cp/parser.c:6593
+#: c/c-parser.c:8209 cp/parser.c:6598
 #, gcc-internal-format
 msgid "consecutive %<_Cilk_spawn%> keywords are not permitted"
 msgstr ""
@@ -37184,62 +37240,62 @@
 msgid "no type or storage class may be specified here,"
 msgstr "为%qs指定了存储类"
 
-#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30419
+#: c/c-parser.c:9946 c/c-parser.c:10003 cp/parser.c:30442
 #, fuzzy, gcc-internal-format
 msgid "unknown property attribute"
 msgstr "不能设置只读属性"
 
-#: c/c-parser.c:9967 cp/parser.c:30379
+#: c/c-parser.c:9967 cp/parser.c:30402
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<getter%> attribute)"
 msgstr "%qs后断言"
 
-#: c/c-parser.c:9970 cp/parser.c:30382
+#: c/c-parser.c:9970 cp/parser.c:30405
 #, fuzzy, gcc-internal-format
 msgid "missing %<=%> (after %<setter%> attribute)"
 msgstr "%<readonly%>属性与%<setter%>属性冲突"
 
-#: c/c-parser.c:9984 cp/parser.c:30397
+#: c/c-parser.c:9984 cp/parser.c:30420
 #, fuzzy, gcc-internal-format
 msgid "the %<setter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
 
-#: c/c-parser.c:9989 cp/parser.c:30403
+#: c/c-parser.c:9989 cp/parser.c:30426
 #, gcc-internal-format
 msgid "setter name must terminate with %<:%>"
 msgstr "setter 的名字必须以%<:%>结尾"
 
-#: c/c-parser.c:9996 cp/parser.c:30411
+#: c/c-parser.c:9996 cp/parser.c:30434
 #, fuzzy, gcc-internal-format
 msgid "the %<getter%> attribute may only be specified once"
 msgstr "不能为函数指定地址区域属性"
 
 #: c/c-parser.c:10191 c/c-parser.c:15872 c/c-parser.c:16130 c/c-parser.c:16189
-#: c/c-parser.c:16273 cp/parser.c:35352 cp/parser.c:35646 cp/parser.c:35734
-#: cp/parser.c:35805 cp/parser.c:38116 cp/parser.c:38131 cp/parser.c:38147
-#: cp/parser.c:38163 cp/parser.c:38179 cp/parser.c:38207 cp/parser.c:38220
-#: cp/parser.c:38243 cp/parser.c:38256
+#: c/c-parser.c:16273 cp/parser.c:35375 cp/parser.c:35669 cp/parser.c:35757
+#: cp/parser.c:35828 cp/parser.c:38139 cp/parser.c:38154 cp/parser.c:38170
+#: cp/parser.c:38186 cp/parser.c:38202 cp/parser.c:38230 cp/parser.c:38243
+#: cp/parser.c:38266 cp/parser.c:38279
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp flush%> may only be used in compound statements"
 msgid "%<#pragma %s%> may only be used in compound statements"
 msgstr "%<#pragma omp flush%>只能用在复合语句中"
 
-#: c/c-parser.c:10214 cp/parser.c:38233
+#: c/c-parser.c:10214 cp/parser.c:38256
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be at file scope"
 msgstr "Objective-C 声明只能出现在全局作用域中"
 
-#: c/c-parser.c:10292 cp/parser.c:38314
+#: c/c-parser.c:10292 cp/parser.c:38337
 #, gcc-internal-format
 msgid "%<#pragma omp section%> may only be used in %<#pragma omp sections%> construct"
 msgstr "%<#pragma omp section%>只能用在%<#pragma omp sections%>结构中"
 
-#: c/c-parser.c:10311 cp/parser.c:38333
+#: c/c-parser.c:10311 cp/parser.c:38356
 #, fuzzy, gcc-internal-format
 msgid "for, while or do statement expected"
 msgstr "需要语句"
 
-#: c/c-parser.c:10323 cp/parser.c:38106
+#: c/c-parser.c:10323 cp/parser.c:38129
 #, gcc-internal-format
 msgid "%<#pragma GCC pch_preprocess%> must be first"
 msgstr "%<#pragma GCC pch_preprocess%>必须是第一个"
@@ -37254,12 +37310,12 @@
 msgid "%<#pragma grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:10663 cp/parser.c:30809
+#: c/c-parser.c:10663 cp/parser.c:30832
 #, gcc-internal-format
 msgid "too many %qs clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:10684 cp/parser.c:31341
+#: c/c-parser.c:10684 cp/parser.c:31364
 #, fuzzy, gcc-internal-format
 msgid "expected integer expression before ')'"
 msgstr "需要整数表达式"
@@ -37274,58 +37330,58 @@
 msgid "%qD is not a variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:10986 cp/semantics.c:6815
+#: c/c-parser.c:10986 cp/semantics.c:6828
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a pointer variable"
 msgstr "%qD不是一个变量"
 
-#: c/c-parser.c:11027 cp/parser.c:31419
+#: c/c-parser.c:11027 cp/parser.c:31442
 #, gcc-internal-format
 msgid "collapse argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:11097 cp/parser.c:31476
+#: c/c-parser.c:11097 cp/parser.c:31499
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<new%>"
 msgid "expected %<none%>"
 msgstr "需要%<new%>"
 
-#: c/c-parser.c:11099 cp/parser.c:31478
+#: c/c-parser.c:11099 cp/parser.c:31501
 #, gcc-internal-format
 msgid "expected %<none%> or %<shared%>"
 msgstr "需要%<none%>或%<shared%>"
 
-#: c/c-parser.c:11199 cp/parser.c:31578
+#: c/c-parser.c:11199 cp/parser.c:31601
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<;%>, %<,%> or %<)%>"
 msgid "expected %<data%>, %<update%>, %<enter%> or %<exit%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31596
-#: cp/parser.c:35638 cp/parser.c:35726
+#: c/c-parser.c:11219 c/c-parser.c:16182 c/c-parser.c:16266 cp/parser.c:31619
+#: cp/parser.c:35661 cp/parser.c:35749
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<catch%>"
 msgid "expected %<data%>"
 msgstr "需要%<catch%>"
 
-#: c/c-parser.c:11266 cp/parser.c:31649
+#: c/c-parser.c:11266 cp/parser.c:31672
 #, gcc-internal-format
 msgid "too many %<if%> clauses with %qs modifier"
 msgstr ""
 
-#: c/c-parser.c:11273 cp/parser.c:31656
+#: c/c-parser.c:11273 cp/parser.c:31679
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:11275 cp/parser.c:31658
+#: c/c-parser.c:11275 cp/parser.c:31681
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "too many %<if%> clauses without modifier"
 msgstr "太多的%qs子句"
 
-#: c/c-parser.c:11281 cp/parser.c:31664
+#: c/c-parser.c:11281 cp/parser.c:31687
 #, gcc-internal-format
 msgid "if any %<if%> clause has modifier, then all %<if%> clauses have to use modifier"
 msgstr ""
@@ -37353,23 +37409,23 @@
 msgid "%<num_tasks%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:11502 cp/semantics.c:6999
+#: c/c-parser.c:11502 cp/semantics.c:7012
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:11548 cp/semantics.c:7028
+#: c/c-parser.c:11548 cp/semantics.c:7041
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> value must be non-negative"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31875 cp/parser.c:31882
+#: c/c-parser.c:11611 c/c-parser.c:11617 cp/parser.c:31898 cp/parser.c:31905
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<throw%>"
 msgid "expected %<tofrom%>"
 msgstr "需要%<throw%>"
 
-#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31891 cp/parser.c:31898
+#: c/c-parser.c:11625 c/c-parser.c:11631 cp/parser.c:31914 cp/parser.c:31921
 #, fuzzy, gcc-internal-format
 msgid "expected %<scalar%>"
 msgstr "需要%<;%>"
@@ -37379,59 +37435,59 @@
 msgid "%<num_workers%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:11762 cp/parser.c:31200
+#: c/c-parser.c:11762 cp/parser.c:31223
 #, gcc-internal-format
 msgid "too many %<static%> arguments"
 msgstr "太多 %<static%> 参数"
 
-#: c/c-parser.c:11796 cp/parser.c:31233
+#: c/c-parser.c:11796 cp/parser.c:31256
 #, gcc-internal-format
 msgid "unexpected argument"
 msgstr "非预期的参数"
 
-#: c/c-parser.c:11823 cp/semantics.c:6323
+#: c/c-parser.c:11823 cp/semantics.c:6336
 #, fuzzy, gcc-internal-format
 msgid "%qs value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:11962 cp/semantics.c:7128
+#: c/c-parser.c:11962 cp/semantics.c:7141
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute argument not an integer constant"
 msgid "%<tile%> argument needs positive integral constant"
 msgstr "%qE属性需要一个整常量作为实参"
 
-#: c/c-parser.c:12027 cp/parser.c:31955
+#: c/c-parser.c:12027 cp/parser.c:31978
 #, fuzzy, gcc-internal-format
 #| msgid "collapse argument needs positive constant integer expression"
 msgid "ordered argument needs positive constant integer expression"
 msgstr "折叠参数需要正整常量表达式"
 
-#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37047
+#: c/c-parser.c:12118 c/c-parser.c:16964 cp/parser.c:37070
 #, fuzzy, gcc-internal-format
 msgid "expected %<+%>, %<*%>, %<-%>, %<&%>, %<^%>, %<|%>, %<&&%>, %<||%> or identifier"
 msgstr "需要标识符或%<(%>"
 
-#: c/c-parser.c:12227 cp/parser.c:32168
+#: c/c-parser.c:12227 cp/parser.c:32191
 #, gcc-internal-format
 msgid "both %<monotonic%> and %<nonmonotonic%> modifiers specified"
 msgstr ""
 
-#: c/c-parser.c:12281 cp/parser.c:32184
+#: c/c-parser.c:12281 cp/parser.c:32207
 #, gcc-internal-format
 msgid "schedule %<runtime%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<runtime%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:12285 cp/parser.c:32187
+#: c/c-parser.c:12285 cp/parser.c:32210
 #, gcc-internal-format
 msgid "schedule %<auto%> does not take a %<chunk_size%> parameter"
 msgstr "调度%<auto%>不接受一个%<chunk_size%>参数"
 
-#: c/c-parser.c:12297 cp/semantics.c:6395
+#: c/c-parser.c:12297 cp/semantics.c:6408
 #, fuzzy, gcc-internal-format
 msgid "chunk size value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12320 cp/parser.c:32207
+#: c/c-parser.c:12320 cp/parser.c:32230
 #, gcc-internal-format
 msgid "invalid schedule kind"
 msgstr "无效的调度类型"
@@ -37446,17 +37502,17 @@
 msgid "%<num_teams%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12529 cp/semantics.c:6486
+#: c/c-parser.c:12529 cp/semantics.c:6499
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: c/c-parser.c:12573 cp/semantics.c:6596
+#: c/c-parser.c:12573 cp/semantics.c:6609
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:12636 cp/parser.c:32465
+#: c/c-parser.c:12636 cp/parser.c:32488
 #, fuzzy, gcc-internal-format
 msgid "using parameters for %<linear%> step is not supported yet"
 msgstr "尚未支持代码模式 %<large%>"
@@ -37476,17 +37532,17 @@
 msgid "%<simdlen%> clause expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: c/c-parser.c:12888 cp/parser.c:32701 cp/parser.c:32924
+#: c/c-parser.c:12888 cp/parser.c:32724 cp/parser.c:32947
 #, fuzzy, gcc-internal-format
 msgid "invalid depend kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:12972 cp/parser.c:32774
+#: c/c-parser.c:12972 cp/parser.c:32797
 #, fuzzy, gcc-internal-format
 msgid "invalid map kind"
 msgstr "无效的实型种别 %d，在%C处"
 
-#: c/c-parser.c:13068 cp/parser.c:32871
+#: c/c-parser.c:13068 cp/parser.c:32894
 #, fuzzy, gcc-internal-format
 msgid "invalid dist_schedule kind"
 msgstr "无效的调度类型"
@@ -37496,69 +37552,69 @@
 msgid "invalid proc_bind kind"
 msgstr "无效的调度类型"
 
-#: c/c-parser.c:13352 cp/parser.c:33149
+#: c/c-parser.c:13352 cp/parser.c:33172
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma acc%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33160 cp/parser.c:33476
+#: c/c-parser.c:13363 c/c-parser.c:13646 cp/parser.c:33183 cp/parser.c:33499
 #, gcc-internal-format
 msgid "%qs is not valid for %qs"
 msgstr "%qs对%qs而言无效"
 
-#: c/c-parser.c:13509 cp/parser.c:33336
+#: c/c-parser.c:13509 cp/parser.c:33359
 #, fuzzy, gcc-internal-format
 msgid "%qs must be the first clause of %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-parser.c:13635 cp/parser.c:33465
+#: c/c-parser.c:13635 cp/parser.c:33488
 #, gcc-internal-format
 msgid "expected %<#pragma omp%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:13773 cp/parser.c:36151
+#: c/c-parser.c:13773 cp/parser.c:36174
 #, gcc-internal-format
 msgid "no valid clauses specified in %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13783 cp/parser.c:36161
+#: c/c-parser.c:13783 cp/parser.c:36184
 #, fuzzy, gcc-internal-format
 msgid "array section in %<#pragma acc declare%>"
 msgstr "%qD的声明隐藏了一个全局声明"
 
-#: c/c-parser.c:13803 cp/parser.c:36181
+#: c/c-parser.c:13803 cp/parser.c:36204
 #, fuzzy, gcc-internal-format
 msgid "%qD must be a global variable in %<#pragma acc declare link%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:13814 cp/parser.c:36192
+#: c/c-parser.c:13814 cp/parser.c:36215
 #, fuzzy, gcc-internal-format
 #| msgid "variably modified field at file scope"
 msgid "invalid OpenACC clause at file scope"
 msgstr "文件域中的动态可变字段"
 
-#: c/c-parser.c:13821 cp/parser.c:36199
+#: c/c-parser.c:13821 cp/parser.c:36222
 #, fuzzy, gcc-internal-format
 #| msgid "declaration of %<extern%> variable %qD in %<for%> loop initial declaration"
 msgid "invalid use of %<extern%> variable %qD in %<#pragma acc declare%>"
 msgstr "在%<for%>循环初始声明中声明了%<extern%>变量%qD"
 
-#: c/c-parser.c:13829 cp/parser.c:36207
+#: c/c-parser.c:13829 cp/parser.c:36230
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<global%> variable %qD in %<#pragma acc declare%>"
 msgstr "指定链接时使用%qD无效"
 
-#: c/c-parser.c:13841 cp/parser.c:36219
+#: c/c-parser.c:13841 cp/parser.c:36242
 #, gcc-internal-format
 msgid "variable %qD used more than once with %<#pragma acc declare%>"
 msgstr ""
 
-#: c/c-parser.c:13933 cp/parser.c:36305
+#: c/c-parser.c:13933 cp/parser.c:36328
 #, fuzzy, gcc-internal-format
 msgid "expected %<data%> after %<#pragma acc %s%>"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: c/c-parser.c:13949 cp/parser.c:36322
+#: c/c-parser.c:13949 cp/parser.c:36345
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc %s data%> has no data movement clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -37574,7 +37630,7 @@
 msgid "expected function name"
 msgstr "需要函数"
 
-#: c/c-parser.c:14191 cp/parser.c:37466
+#: c/c-parser.c:14191 cp/parser.c:37489
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qD does not refer to a function"
@@ -37585,42 +37641,42 @@
 msgid "%<#pragma acc routine%> not immediately followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:14251 cp/parser.c:37520 cp/parser.c:37562
+#: c/c-parser.c:14251 cp/parser.c:37543 cp/parser.c:37585
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> not immediately followed by a single function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:14268 cp/parser.c:37576
+#: c/c-parser.c:14268 cp/parser.c:37599
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> already applied to %qD"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:14277 cp/parser.c:37585
+#: c/c-parser.c:14277 cp/parser.c:37608
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before use"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:14278 cp/parser.c:37586
+#: c/c-parser.c:14278 cp/parser.c:37609
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc routine%> must be applied before definition"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:14321 cp/parser.c:36497
+#: c/c-parser.c:14321 cp/parser.c:36520
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma acc update%> must contain at least one %<device%> or %<host%> or %<self%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:14729 cp/parser.c:33847 cp/parser.c:33873
+#: c/c-parser.c:14729 cp/parser.c:33870 cp/parser.c:33896
 #, fuzzy, gcc-internal-format
 msgid "invalid form of %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:14733 cp/parser.c:33904 cp/parser.c:33920
+#: c/c-parser.c:14733 cp/parser.c:33927 cp/parser.c:33943
 #, gcc-internal-format
 msgid "invalid operator for %<#pragma omp atomic%>"
 msgstr "%<#pragma omp atomic%>运算符无效"
 
-#: c/c-parser.c:14782 cp/semantics.c:8525 cp/semantics.c:8535
+#: c/c-parser.c:14782 cp/semantics.c:8538 cp/semantics.c:8548
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic capture%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 capture%>使用两不同的变量用于内存"
@@ -37630,27 +37686,27 @@
 msgid "expected %<(%> or end of line"
 msgstr "需要%<(%>或行尾"
 
-#: c/c-parser.c:14913 cp/parser.c:34451
+#: c/c-parser.c:14913 cp/parser.c:34474
 #, gcc-internal-format
 msgid "%<ordered%> clause parameter is less than %<collapse%>"
 msgstr ""
 
-#: c/c-parser.c:14924 cp/parser.c:34462
+#: c/c-parser.c:14924 cp/parser.c:34485
 #, gcc-internal-format
 msgid "%<linear%> clause may not be specified together with %<ordered%> clause with a parameter"
 msgstr ""
 
-#: c/c-parser.c:14943 cp/parser.c:34490 cp/parser.c:38700
+#: c/c-parser.c:14943 cp/parser.c:34513 cp/parser.c:38723
 #, gcc-internal-format
 msgid "for statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.c:14949 cp/parser.c:34497
+#: c/c-parser.c:14949 cp/parser.c:34520
 #, fuzzy, gcc-internal-format
 msgid "_Cilk_for statement expected"
 msgstr "需要 for 语句"
 
-#: c/c-parser.c:15018 cp/semantics.c:8074 cp/semantics.c:8161
+#: c/c-parser.c:15018 cp/semantics.c:8087 cp/semantics.c:8174
 #, gcc-internal-format
 msgid "expected iteration declaration or initialization"
 msgstr "需要迭代声明或初始化"
@@ -37660,74 +37716,74 @@
 msgid "not enough perfectly nested loops"
 msgstr "不够完美的嵌套循环"
 
-#: c/c-parser.c:15162 cp/parser.c:34723
+#: c/c-parser.c:15162 cp/parser.c:34746
 #, gcc-internal-format
 msgid "collapsed loops not perfectly nested"
 msgstr "折叠的循环没有完美的嵌套"
 
-#: c/c-parser.c:15209 cp/parser.c:34540 cp/parser.c:34582 cp/pt.c:15513
+#: c/c-parser.c:15209 cp/parser.c:34563 cp/parser.c:34605 cp/pt.c:15595
 #, gcc-internal-format
 msgid "iteration variable %qD should not be firstprivate"
 msgstr "迭代变量%qD不应当是 firstprivate"
 
-#: c/c-parser.c:15300 cp/parser.c:34796
+#: c/c-parser.c:15300 cp/parser.c:34819
 #, fuzzy, gcc-internal-format
 #| msgid "%<void%> as only parameter may not be qualified"
 msgid "%<ordered%> clause with parameter may not be specified on %qs construct"
 msgstr "%<void%>作为仅有的参数时不能被限定"
 
-#: c/c-parser.c:15461 cp/parser.c:34954
+#: c/c-parser.c:15461 cp/parser.c:34977
 #, fuzzy, gcc-internal-format
 #| msgid "%<#pragma omp barrier%> may only be used in compound statements"
 msgid "%<#pragma omp ordered%> with %<depend%> clause may only be used in compound statements"
 msgstr "%<#pragma omp barrier%>只能用在复合语句中"
 
-#: c/c-parser.c:15664 cp/parser.c:35147
+#: c/c-parser.c:15664 cp/parser.c:35170
 #, fuzzy, gcc-internal-format
 msgid "expected %<for%> after %qs"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: c/c-parser.c:15863 cp/parser.c:35343
+#: c/c-parser.c:15863 cp/parser.c:35366
 #, fuzzy, gcc-internal-format
 msgid "expected %<point%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:16083 cp/parser.c:35580
+#: c/c-parser.c:16083 cp/parser.c:35603
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16096 cp/parser.c:35593
+#: c/c-parser.c:16096 cp/parser.c:35616
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16143 cp/parser.c:35818
+#: c/c-parser.c:16143 cp/parser.c:35841
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target update%> must contain at least one %<from%> or %<to%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16215 cp/parser.c:35673
+#: c/c-parser.c:16215 cp/parser.c:35696
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> with map-type other than %<to%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16227 cp/parser.c:35685
+#: c/c-parser.c:16227 cp/parser.c:35708
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target enter data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16301 cp/parser.c:35762
+#: c/c-parser.c:16301 cp/parser.c:35785
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> with map-type other than %<from%>, %<release%> or %<delete%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16314 cp/parser.c:35775
+#: c/c-parser.c:16314 cp/parser.c:35798
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target exit data%> must contain at least one %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-parser.c:16528 cp/parser.c:36028
+#: c/c-parser.c:16528 cp/parser.c:36051
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp target%> with map-type other than %<to%>, %<from%>, %<tofrom%> or %<alloc%> on %<map%> clause"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -37742,7 +37798,7 @@
 msgid "%<#pragma omp declare simd%> must be followed by function declaration or definition"
 msgstr "%<#pragma align%>必须出现在 %D 的声明之前，忽略"
 
-#: c/c-parser.c:16675 cp/parser.c:36620
+#: c/c-parser.c:16675 cp/parser.c:36643
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> or %<simd%> attribute cannot be used in the same function marked as a Cilk Plus SIMD-enabled function"
 msgstr ""
@@ -37752,32 +37808,32 @@
 msgid "%<#pragma omp declare simd%> not immediately followed by a function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16697 cp/parser.c:36679
+#: c/c-parser.c:16697 cp/parser.c:36702
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by a single function declaration or definition"
 msgstr ""
 
-#: c/c-parser.c:16813 cp/parser.c:36749
+#: c/c-parser.c:16813 cp/parser.c:36772
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp declare target%> with clauses in between %<#pragma omp declare target%> without clauses and %<#pragma omp end declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
 
-#: c/c-parser.c:16832 cp/parser.c:36768
+#: c/c-parser.c:16832 cp/parser.c:36791
 #, gcc-internal-format
 msgid "%qD specified both in declare target %<link%> and %<to%> clauses"
 msgstr ""
 
-#: c/c-parser.c:16873 cp/parser.c:36815
+#: c/c-parser.c:16873 cp/parser.c:36838
 #, fuzzy, gcc-internal-format
 msgid "expected %<target%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:16880 cp/parser.c:36822
+#: c/c-parser.c:16880 cp/parser.c:36845
 #, fuzzy, gcc-internal-format
 msgid "expected %<declare%>"
 msgstr "需要%<;%>"
 
-#: c/c-parser.c:16886 cp/parser.c:36829
+#: c/c-parser.c:16886 cp/parser.c:36852
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp end declare target%> without corresponding %<#pragma omp declare target%>"
 msgstr "%<#pragma GCC pop_options%>缺少相应的%<#pragma GCC push_options%>"
@@ -37832,22 +37888,22 @@
 msgid "one of the initializer call arguments should be %<&omp_priv%>"
 msgstr ""
 
-#: c/c-parser.c:17286 cp/parser.c:37274
+#: c/c-parser.c:17286 cp/parser.c:37297
 #, fuzzy, gcc-internal-format
 msgid "expected %<simd%> or %<reduction%> or %<target%>"
 msgstr "需要%<#pragma omp section%>或%<}%>"
 
-#: c/c-parser.c:17501 cp/semantics.c:7539
+#: c/c-parser.c:17501 cp/semantics.c:7552
 #, gcc-internal-format
 msgid "%qE declared %<threadprivate%> after first use"
 msgstr "%qE在其首次使用后被声明为%<threadprivate%>"
 
-#: c/c-parser.c:17503 cp/semantics.c:7541
+#: c/c-parser.c:17503 cp/semantics.c:7554
 #, gcc-internal-format
 msgid "automatic variable %qE cannot be %<threadprivate%>"
 msgstr "自动变量%qE不能是%<threadprivate%>"
 
-#: c/c-parser.c:17507 cp/semantics.c:7543
+#: c/c-parser.c:17507 cp/semantics.c:7556
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE has incomplete type"
 msgstr "%<threadprivate%>%qE的类型不完全"
@@ -37862,52 +37918,52 @@
 msgid "pragma simd must be inside a function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: c/c-parser.c:17588 cp/parser.c:38471
+#: c/c-parser.c:17588 cp/parser.c:38494
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be an integer constant"
 msgstr "数组边界不是一个整数常量"
 
-#: c/c-parser.c:17590 cp/parser.c:38474
+#: c/c-parser.c:17590 cp/parser.c:38497
 #, fuzzy, gcc-internal-format
 msgid "vectorlength must be a power of 2"
 msgstr "栈大小必须刚好是 2 的某次方"
 
-#: c/c-parser.c:17673 cp/parser.c:38581
+#: c/c-parser.c:17673 cp/parser.c:38604
 #, fuzzy, gcc-internal-format
 msgid "step size must be an integer constant expression or an integer variable"
 msgstr "选择子必须是 0 到 %wi 间的整常量"
 
-#: c/c-parser.c:17772 cp/parser.c:38674
+#: c/c-parser.c:17772 cp/parser.c:38697
 #, fuzzy, gcc-internal-format
 msgid "expected %<#pragma simd%> clause"
 msgstr "需要%<#pragma omp%>子句"
 
-#: c/c-parser.c:17816 cp/parser.c:38077
+#: c/c-parser.c:17816 cp/parser.c:38100
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> is not followed by %<_Cilk_for%>"
 msgstr "在这里不允许使用%<#pragma%>"
 
-#: c/c-parser.c:18116 cp/parser.c:37969
+#: c/c-parser.c:18116 cp/parser.c:37992
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> without transactional memory support enabled"
 msgstr "%<__transaction_cancel%>而无需 transactional 内存支持已启用"
 
-#: c/c-parser.c:18122 cp/parser.c:37975
+#: c/c-parser.c:18122 cp/parser.c:37998
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> within a %<__transaction_relaxed%>"
 msgstr "%<__transaction_cancel%>在之内 %<__transaction_relaxed%>"
 
-#: c/c-parser.c:18131 cp/parser.c:37984
+#: c/c-parser.c:18131 cp/parser.c:38007
 #, fuzzy, gcc-internal-format
 msgid "outer %<__transaction_cancel%> not within outer %<__transaction_atomic%>"
 msgstr "外 %<__transaction_cancel%>无法在之内外 %<__transaction_atomic%>"
 
-#: c/c-parser.c:18133 cp/parser.c:37987
+#: c/c-parser.c:18133 cp/parser.c:38010
 #, fuzzy, gcc-internal-format
 msgid "  or a %<transaction_may_cancel_outer%> function"
 msgstr "  或 %<transaction_may_cancel_outer%> 函数"
 
-#: c/c-parser.c:18139 cp/parser.c:37993
+#: c/c-parser.c:18139 cp/parser.c:38016
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_cancel%> not within %<__transaction_atomic%>"
 msgstr "%<__transaction_cancel%>无法在之内 %<__transaction_atomic%>"
@@ -37917,7 +37973,7 @@
 msgid "base of array section must be pointer or array type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-parser.c:18216 cp/parser.c:7104
+#: c/c-parser.c:18216 cp/parser.c:7109
 #, fuzzy, gcc-internal-format
 msgid "expected %<:%> or numeral"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
@@ -38653,7 +38709,7 @@
 msgid "initialization left-hand side might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: c/c-typeck.c:6623 cp/typeck.c:8583
+#: c/c-typeck.c:6623 cp/typeck.c:8584
 #, gcc-internal-format
 msgid "return type might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
@@ -38981,7 +39037,7 @@
 msgid "ISO C forbids %<goto *expr;%>"
 msgstr "ISO C++ 不允许%<goto *expr;%>"
 
-#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8812
+#: c/c-typeck.c:9860 c/gimple-parser.c:1544 cp/typeck.c:8813
 #, gcc-internal-format
 msgid "function declared %<noreturn%> has a %<return%> statement"
 msgstr "被声明为%<noreturn%>的函数却有%<return%>语句"
@@ -38991,7 +39047,7 @@
 msgid "array notation expression cannot be used as a return value"
 msgstr "%qE 不能作为函数"
 
-#: c/c-typeck.c:9877 cp/typeck.c:8803
+#: c/c-typeck.c:9877 cp/typeck.c:8804
 #, fuzzy, gcc-internal-format
 msgid "use of %<_Cilk_spawn%> in a return statement is not allowed"
 msgstr "%L处 CASE 语句中的逻辑范围是不被允许的"
@@ -39016,7 +39072,7 @@
 msgid "function returns address of label"
 msgstr "函数返回局部变量的地址"
 
-#: c/c-typeck.c:10093 cp/semantics.c:1154
+#: c/c-typeck.c:10093 cp/semantics.c:1157
 #, gcc-internal-format
 msgid "switch quantity not an integer"
 msgstr "switch 语句中的值不是一个整数"
@@ -39031,7 +39087,7 @@
 msgid "case label is not an integer constant expression"
 msgstr "case 标号不是一个整数常量表达式"
 
-#: c/c-typeck.c:10170 cp/parser.c:10824
+#: c/c-typeck.c:10170 cp/parser.c:10833
 #, gcc-internal-format
 msgid "case label not within a switch statement"
 msgstr "case 标号出现在开关语句外"
@@ -39051,17 +39107,17 @@
 msgid "rank-mismatch between if-statement%'s condition and the else-block"
 msgstr ""
 
-#: c/c-typeck.c:10374 cp/parser.c:12094
+#: c/c-typeck.c:10374 cp/parser.c:12103
 #, gcc-internal-format
 msgid "break statement not within loop or switch"
 msgstr "break 语句不在循环或开关语句内"
 
-#: c/c-typeck.c:10376 cp/parser.c:12120
+#: c/c-typeck.c:10376 cp/parser.c:12129
 #, gcc-internal-format
 msgid "continue statement not within a loop"
 msgstr "continue 语句出现在循环以外"
 
-#: c/c-typeck.c:10381 cp/parser.c:12107
+#: c/c-typeck.c:10381 cp/parser.c:12116
 #, gcc-internal-format
 msgid "break statement used with OpenMP for loop"
 msgstr "OpenMP for 循环中使用了 break 语句"
@@ -39071,7 +39127,7 @@
 msgid "break statement within %<#pragma simd%> loop body"
 msgstr "break 语句不在循环或开关语句内"
 
-#: c/c-typeck.c:10388 cp/parser.c:12124
+#: c/c-typeck.c:10388 cp/parser.c:12133
 #, fuzzy, gcc-internal-format
 msgid "continue statement within %<#pragma simd%> loop body"
 msgstr "continue 语句出现在循环以外"
@@ -39177,12 +39233,12 @@
 msgid "used vector type where scalar is required"
 msgstr "需要标量时使用了联合类型"
 
-#: c/c-typeck.c:12108 cp/semantics.c:8632
+#: c/c-typeck.c:12108 cp/semantics.c:8645
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancel%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
 
-#: c/c-typeck.c:12147 cp/semantics.c:8669
+#: c/c-typeck.c:12147 cp/semantics.c:8682
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp cancellation point%> must specify one of %<parallel%>, %<for%>, %<sections%> or %<taskgroup%> clauses"
 msgstr "%<#pragma omp taskwait%>只能用在复合语句中"
@@ -39192,26 +39248,26 @@
 msgid "%<_Atomic%> %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4535
-#: cp/semantics.c:6724
+#: c/c-typeck.c:12204 c/c-typeck.c:13413 cp/semantics.c:4548
+#: cp/semantics.c:6737
 #, fuzzy, gcc-internal-format
 msgid "bit-field %qE in %qs clause"
 msgstr "字段%qE的类型不完全"
 
-#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4545
-#: cp/semantics.c:6742
+#: c/c-typeck.c:12213 c/c-typeck.c:13437 cp/semantics.c:4558
+#: cp/semantics.c:6755
 #, fuzzy, gcc-internal-format
 #| msgid "%qD is not a member template function"
 msgid "%qE is a member of a union"
 msgstr "%qD不是一个成员模板函数"
 
-#: c/c-typeck.c:12223 cp/semantics.c:4559 cp/semantics.c:6767
+#: c/c-typeck.c:12223 cp/semantics.c:4572 cp/semantics.c:6780
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4563
-#: cp/semantics.c:6770
+#: c/c-typeck.c:12227 c/c-typeck.c:13454 cp/semantics.c:4576
+#: cp/semantics.c:6783
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %qs clause"
 msgstr "%qE在子句%qs中不是一个变量"
@@ -39222,70 +39278,70 @@
 msgstr "字段%qE的类型不完全"
 
 #: c/c-typeck.c:12243 c/c-typeck.c:13461 c/c-typeck.c:13563
-#: cp/semantics.c:4580 cp/semantics.c:6776 cp/semantics.c:6938
+#: cp/semantics.c:4593 cp/semantics.c:6789 cp/semantics.c:6951
 #, fuzzy, gcc-internal-format
 msgid "%qD is threadprivate variable in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:12279 cp/semantics.c:4612
+#: c/c-typeck.c:12279 cp/semantics.c:4625
 #, fuzzy, gcc-internal-format
 msgid "low bound %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
-#: c/c-typeck.c:12286 cp/semantics.c:4619
+#: c/c-typeck.c:12286 cp/semantics.c:4632
 #, fuzzy, gcc-internal-format
 msgid "length %qE of array section does not have integral type"
 msgstr "数组 new 的大小必须有整数类型"
 
 #: c/c-typeck.c:12313 c/c-typeck.c:12377 c/c-typeck.c:12635
-#: cp/semantics.c:4655 cp/semantics.c:4719
+#: cp/semantics.c:4668 cp/semantics.c:4732
 #, fuzzy, gcc-internal-format
 msgid "zero length array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:12332 cp/semantics.c:4674
+#: c/c-typeck.c:12332 cp/semantics.c:4687
 #, gcc-internal-format
 msgid "for unknown bound array type length expression must be specified"
 msgstr ""
 
-#: c/c-typeck.c:12340 cp/semantics.c:4682
+#: c/c-typeck.c:12340 cp/semantics.c:4695
 #, gcc-internal-format
 msgid "negative low bound in array section in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4691
-#: cp/semantics.c:4801
+#: c/c-typeck.c:12349 c/c-typeck.c:12459 cp/semantics.c:4704
+#: cp/semantics.c:4814
 #, fuzzy, gcc-internal-format
 msgid "negative length in array section in %qs clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:12366 cp/semantics.c:4708
+#: c/c-typeck.c:12366 cp/semantics.c:4721
 #, gcc-internal-format
 msgid "low bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12403 cp/semantics.c:4745
+#: c/c-typeck.c:12403 cp/semantics.c:4758
 #, gcc-internal-format
 msgid "length %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12418 cp/semantics.c:4760
+#: c/c-typeck.c:12418 cp/semantics.c:4773
 #, gcc-internal-format
 msgid "high bound %qE above array section size in %qs clause"
 msgstr ""
 
-#: c/c-typeck.c:12451 cp/semantics.c:4793
+#: c/c-typeck.c:12451 cp/semantics.c:4806
 #, fuzzy, gcc-internal-format
 msgid "for pointer type length expression must be specified"
 msgstr "for 循环増量表达式不起作用"
 
-#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4811
-#: cp/semantics.c:4923
+#: c/c-typeck.c:12469 c/c-typeck.c:12578 cp/semantics.c:4824
+#: cp/semantics.c:4936
 #, fuzzy, gcc-internal-format
 msgid "array section is not contiguous in %qs clause"
 msgstr "在过程入口处将数组段复制到一个连续的块中"
 
-#: c/c-typeck.c:12477 cp/semantics.c:4819
+#: c/c-typeck.c:12477 cp/semantics.c:4832
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have pointer or array type"
 msgstr "%qE不是一个类"
@@ -39305,7 +39361,7 @@
 msgid "%qE has invalid type for %<reduction(%s)%>"
 msgstr "%qE的类型对%<reduction(%s)%>无效"
 
-#: c/c-typeck.c:12955 cp/semantics.c:5734
+#: c/c-typeck.c:12955 cp/semantics.c:5747
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction not found for %qE"
 msgstr "用户定义的%qD总是计算所有两个参数"
@@ -39315,17 +39371,17 @@
 msgid "variable length element type in array %<reduction%> clause"
 msgstr "使用了变长数组"
 
-#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7257
+#: c/c-typeck.c:13061 c/c-typeck.c:13621 cp/semantics.c:7270
 #, gcc-internal-format
 msgid "%<nowait%> clause must not be used together with %<copyprivate%>"
 msgstr ""
 
-#: c/c-typeck.c:13073 cp/semantics.c:7297
+#: c/c-typeck.c:13073 cp/semantics.c:7310
 #, gcc-internal-format
 msgid "%qE must be %<threadprivate%> for %<copyin%>"
 msgstr "%qE必须是%<threadprivate%>方可%<copyin%>"
 
-#: c/c-typeck.c:13087 cp/semantics.c:5908
+#: c/c-typeck.c:13087 cp/semantics.c:5921
 #, gcc-internal-format
 msgid "modifier should not be specified in %<linear%> clause on %<simd%> or %<for%> constructs"
 msgstr ""
@@ -39345,18 +39401,18 @@
 msgid "%<_Atomic%> %qD in %<linear%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13139 cp/semantics.c:5991
+#: c/c-typeck.c:13139 cp/semantics.c:6004
 #, fuzzy, gcc-internal-format
 msgid "%<linear%> clause step %qE is neither constant nor a parameter"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6075
-#: cp/semantics.c:6931
+#: c/c-typeck.c:13169 c/c-typeck.c:13556 cp/semantics.c:6088
+#: cp/semantics.c:6944
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13178 cp/semantics.c:6084
+#: c/c-typeck.c:13178 cp/semantics.c:6097
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in reduction clauses"
 msgstr "%qD在数据子句中多次出现"
@@ -39368,32 +39424,32 @@
 
 #: c/c-typeck.c:13196 c/c-typeck.c:13225 c/c-typeck.c:13385 c/c-typeck.c:13499
 #: c/c-typeck.c:13505 c/c-typeck.c:13518 c/c-typeck.c:13527
-#: cp/semantics.c:6094 cp/semantics.c:6101 cp/semantics.c:6152
-#: cp/semantics.c:6158 cp/semantics.c:6195 cp/semantics.c:6687
-#: cp/semantics.c:6824 cp/semantics.c:6830 cp/semantics.c:6843
-#: cp/semantics.c:6852
+#: cp/semantics.c:6107 cp/semantics.c:6114 cp/semantics.c:6165
+#: cp/semantics.c:6171 cp/semantics.c:6208 cp/semantics.c:6700
+#: cp/semantics.c:6837 cp/semantics.c:6843 cp/semantics.c:6856
+#: cp/semantics.c:6865
 #, gcc-internal-format
 msgid "%qD appears more than once in data clauses"
 msgstr "%qD在数据子句中多次出现"
 
 #: c/c-typeck.c:13198 c/c-typeck.c:13227 c/c-typeck.c:13507 c/c-typeck.c:13529
-#: cp/semantics.c:6103 cp/semantics.c:6160 cp/semantics.c:6832
-#: cp/semantics.c:6854
+#: cp/semantics.c:6116 cp/semantics.c:6173 cp/semantics.c:6845
+#: cp/semantics.c:6867
 #, fuzzy, gcc-internal-format
 msgid "%qD appears both in data and map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13212 cp/semantics.c:6146
+#: c/c-typeck.c:13212 cp/semantics.c:6159
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<firstprivate%>"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13241 cp/semantics.c:6189
+#: c/c-typeck.c:13241 cp/semantics.c:6202
 #, gcc-internal-format
 msgid "%qE is not a variable in clause %<lastprivate%>"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13260 cp/semantics.c:6552
+#: c/c-typeck.c:13260 cp/semantics.c:6565
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<aligned%> clause"
 msgstr "%qE在子句%<firstprivate%>中不是一个变量"
@@ -39413,56 +39469,56 @@
 msgid "%qE appears more than once in %<aligned%> clauses"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:13336 cp/semantics.c:6634
+#: c/c-typeck.c:13336 cp/semantics.c:6647
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a variable in %<depend%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
 
-#: c/c-typeck.c:13358 cp/semantics.c:6665
+#: c/c-typeck.c:13358 cp/semantics.c:6678
 #, fuzzy, gcc-internal-format
 msgid "array section does not have mappable type in %qs clause"
 msgstr "在 %L 处的推迟数组“%1$s”在初始化表达式中不被允许"
 
-#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6684
-#: cp/semantics.c:6841
+#: c/c-typeck.c:13382 c/c-typeck.c:13516 cp/semantics.c:6697
+#: cp/semantics.c:6854
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in motion clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6690
-#: cp/semantics.c:6845
+#: c/c-typeck.c:13388 c/c-typeck.c:13520 cp/semantics.c:6703
+#: cp/semantics.c:6858
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in map clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: c/c-typeck.c:13420 cp/semantics.c:6731
+#: c/c-typeck.c:13420 cp/semantics.c:6744
 #, fuzzy, gcc-internal-format
 msgid "%qE does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6806
-#: cp/semantics.c:6945
+#: c/c-typeck.c:13480 c/c-typeck.c:13570 cp/semantics.c:6819
+#: cp/semantics.c:6958
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have a mappable type in %qs clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13551 cp/semantics.c:6925
+#: c/c-typeck.c:13551 cp/semantics.c:6938
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a variable in clause %qs"
 msgid "%qE is neither a variable nor a function name in clause %qs"
 msgstr "%qE在子句%qs中不是一个变量"
 
-#: c/c-typeck.c:13579 cp/semantics.c:6954
+#: c/c-typeck.c:13579 cp/semantics.c:6967
 #, fuzzy, gcc-internal-format
 msgid "%qE appears more than once on the same %<declare target%> directive"
 msgstr "%qE在数据子句中多次出现"
 
-#: c/c-typeck.c:13593 cp/semantics.c:6969
+#: c/c-typeck.c:13593 cp/semantics.c:6982
 #, fuzzy, gcc-internal-format
 msgid "%qD is not an argument in %<uniform%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: c/c-typeck.c:13596 cp/semantics.c:6971
+#: c/c-typeck.c:13596 cp/semantics.c:6984
 #, fuzzy, gcc-internal-format
 msgid "%qE is not an argument in %<uniform%> clause"
 msgstr "%qE在子句%<lastprivate%>中不是一个变量"
@@ -39472,32 +39528,32 @@
 msgid "%qs variable is neither a pointer nor an array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: c/c-typeck.c:13686 cp/semantics.c:6351
+#: c/c-typeck.c:13686 cp/semantics.c:6364
 #, gcc-internal-format
 msgid "%<nonmonotonic%> modifier specified for %qs schedule kind"
 msgstr ""
 
-#: c/c-typeck.c:13717 cp/semantics.c:7149
+#: c/c-typeck.c:13717 cp/semantics.c:7162
 #, gcc-internal-format
 msgid "%<inbranch%> clause is incompatible with %<notinbranch%>"
 msgstr ""
 
-#: c/c-typeck.c:13767 cp/semantics.c:7340
+#: c/c-typeck.c:13767 cp/semantics.c:7353
 #, gcc-internal-format
 msgid "%qE is predetermined %qs for %qs"
 msgstr "%qE可被预先确定为%qs，为%qs"
 
-#: c/c-typeck.c:13787 cp/semantics.c:7231
+#: c/c-typeck.c:13787 cp/semantics.c:7244
 #, gcc-internal-format
 msgid "%<simdlen%> clause value is bigger than %<safelen%> clause value"
 msgstr ""
 
-#: c/c-typeck.c:13799 cp/semantics.c:7244
+#: c/c-typeck.c:13799 cp/semantics.c:7257
 #, gcc-internal-format
 msgid "%<nonmonotonic%> schedule modifier specified together with %<ordered%> clause"
 msgstr ""
 
-#: c/c-typeck.c:13817 cp/semantics.c:7211
+#: c/c-typeck.c:13817 cp/semantics.c:7224
 #, gcc-internal-format
 msgid "%<linear%> clause step is a parameter %qD not specified in %<uniform%> clause"
 msgstr ""
@@ -40056,155 +40112,155 @@
 msgid "use of multiversioned function without a default"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/call.c:7710
+#: cp/call.c:7713
 #, fuzzy, gcc-internal-format
 msgid "passing %qT as %<this%> argument discards qualifiers"
 msgstr "从%qT到%qT的转换丢失了限定信息"
 
-#: cp/call.c:7713 cp/call.c:7829 cp/call.c:9587 cp/name-lookup.c:5963
+#: cp/call.c:7716 cp/call.c:7832 cp/call.c:9592 cp/name-lookup.c:5962
 #, gcc-internal-format
 msgid "  in call to %qD"
 msgstr "在调用%qD时"
 
-#: cp/call.c:7743
+#: cp/call.c:7746
 #, gcc-internal-format
 msgid "%qT is not an accessible base of %qT"
 msgstr "%qT是%qT的一个不可访问的基类"
 
-#: cp/call.c:7825
+#: cp/call.c:7828
 #, gcc-internal-format
 msgid "deducing %qT as %qT"
 msgstr "演绎 %qT 为 %qT"
 
-#: cp/call.c:7831
+#: cp/call.c:7834
 #, gcc-internal-format
 msgid "  (you can disable this with -fno-deduce-init-list)"
 msgstr "(您可以用 -fno-deduce-init-lis 禁用它)"
 
-#: cp/call.c:7931
+#: cp/call.c:7934
 #, fuzzy, gcc-internal-format
 msgid "passing arguments to ellipsis of inherited constructor %qD"
 msgstr "给予函数 %s 的参数太多，于 %L"
 
-#: cp/call.c:8275
+#: cp/call.c:8280
 #, fuzzy, gcc-internal-format
 msgid "constructor delegates to itself"
 msgstr "inlined_to pointer 指向自身"
 
-#: cp/call.c:8525
+#: cp/call.c:8530
 #, gcc-internal-format
 msgid "call to non-function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/call.c:8571 cp/pt.c:14200 cp/typeck.c:2807
+#: cp/call.c:8576 cp/pt.c:14282 cp/typeck.c:2807
 #, gcc-internal-format
 msgid "cannot call constructor %<%T::%D%> directly"
 msgstr "不能直接调用构造函数%<%T::%D%>"
 
-#: cp/call.c:8573
+#: cp/call.c:8578
 #, fuzzy, gcc-internal-format
 msgid "for a function-style cast, remove the redundant %<::%D%>"
 msgstr "对于函数类型的类型转换，移除冗余的%<::%D%>"
 
-#: cp/call.c:8708
+#: cp/call.c:8713
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%T::operator %T(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:8724
+#: cp/call.c:8729
 #, fuzzy, gcc-internal-format
 #| msgid "no matching function for call to %<%T::%s(%A)%#V%>"
 msgid "no matching function for call to %<%T::%E(%A)%#V%>"
 msgstr "对%<%T::%s(%A)%#V%>的调用没有匹配的函数"
 
-#: cp/call.c:8748
+#: cp/call.c:8753
 #, fuzzy, gcc-internal-format
 msgid "no matching function for call to %<%s(%A)%>"
 msgstr "对%<%D(%A)%>的调用没有匹配的函数"
 
-#: cp/call.c:8751
+#: cp/call.c:8756
 #, gcc-internal-format
 msgid "call of overloaded %<%s(%A)%> is ambiguous"
 msgstr "对重载的%<%s(%A)%>的调用有歧义"
 
-#: cp/call.c:8772
+#: cp/call.c:8777
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from non-static data member initializer"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:8777
+#: cp/call.c:8782
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from constructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:8778
+#: cp/call.c:8783
 #, fuzzy, gcc-internal-format
 msgid "pure virtual %q#D called from destructor"
 msgstr "对非静态数据成员%q+D的无效使用"
 
-#: cp/call.c:8801
+#: cp/call.c:8806
 #, gcc-internal-format
 msgid "cannot call member function %qD without object"
 msgstr "没有对象无法调用成员函数%qD"
 
-#: cp/call.c:9585
+#: cp/call.c:9590
 #, gcc-internal-format
 msgid "passing %qT chooses %qT over %qT"
 msgstr "传递%qT时选择%qT而不是%qT"
 
-#: cp/call.c:9645
+#: cp/call.c:9650
 #, gcc-internal-format
 msgid "choosing %qD over %qD"
 msgstr "选择%qD而不是%qD"
 
-#: cp/call.c:9646
+#: cp/call.c:9651
 #, gcc-internal-format
 msgid "  for conversion from %qT to %qT"
 msgstr "以从%qT转换为%qT"
 
-#: cp/call.c:9649
+#: cp/call.c:9654
 #, gcc-internal-format
 msgid "  because conversion sequence for the argument is better"
 msgstr "因为前者的实参类型转换序列更好"
 
-#: cp/call.c:9873
+#: cp/call.c:9878
 #, gcc-internal-format
 msgid "default argument mismatch in overload resolution"
 msgstr "重载解决时默认参数不匹配"
 
-#: cp/call.c:9877
+#: cp/call.c:9882
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 1: %q+#F"
 msgid " candidate 1: %q#F"
 msgstr "备选 1: %q+#F"
 
-#: cp/call.c:9879
+#: cp/call.c:9884
 #, fuzzy, gcc-internal-format
 #| msgid " candidate 2: %q+#F"
 msgid " candidate 2: %q#F"
 msgstr "备选 2: %q+#F"
 
-#: cp/call.c:9924
+#: cp/call.c:9929
 #, gcc-internal-format
 msgid "ISO C++ says that these are ambiguous, even though the worst conversion for the first is better than the worst conversion for the second:"
 msgstr "ISO C++ 认为有歧义，尽管第一个备选的最差类型转换要好于第二个备选的最差类型转换"
 
-#: cp/call.c:10102
+#: cp/call.c:10107
 #, fuzzy, gcc-internal-format
 msgid "could not convert %qE from %qT to %qT"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/call.c:10296
+#: cp/call.c:10301
 #, fuzzy, gcc-internal-format
 msgid "a temporary bound to %qD only persists until the constructor exits"
 msgstr "暂时的约束到 %qD 只有持续直到建构子离开"
 
-#: cp/call.c:10419
+#: cp/call.c:10424
 #, gcc-internal-format
 msgid "invalid initialization of non-const reference of type %qT from an rvalue of type %qT"
 msgstr "用类型为%2$qT的右值初始化类型为%1$qT的非常量引用无效"
 
-#: cp/call.c:10423
+#: cp/call.c:10428
 #, gcc-internal-format
 msgid "invalid initialization of reference of type %qT from expression of type %qT"
 msgstr "将类型为%qT的引用初始化为类型为%qT的表达式无效"
@@ -40306,285 +40362,285 @@
 msgid "cannot derive from %<final%> base %qT in derived type %qT"
 msgstr "无法从基类%qT转换到派生类%qT，通过虚基类%qT"
 
-#: cp/class.c:2231
+#: cp/class.c:2233
 #, gcc-internal-format
 msgid "all member functions in class %qT are private"
 msgstr "类%qT中所有成员函数都是私有的"
 
-#: cp/class.c:2243
+#: cp/class.c:2245
 #, gcc-internal-format
 msgid "%q#T only defines a private destructor and has no friends"
 msgstr "%q#T仅定义了一个私有析构函数且没有友元"
 
-#: cp/class.c:2288
+#: cp/class.c:2290
 #, gcc-internal-format
 msgid "%q#T only defines private constructors and has no friends"
 msgstr "%q#T仅定义了一个私有构造函数且没有友元"
 
-#: cp/class.c:2681
+#: cp/class.c:2683
 #, gcc-internal-format
 msgid "no unique final overrider for %qD in %qT"
 msgstr "%qD的最终重载在%qT中不唯一"
 
-#: cp/class.c:3042
+#: cp/class.c:3044
 #, fuzzy, gcc-internal-format
 msgid "%qD can be marked override"
 msgstr "函数%q+D的定义被标记为 dllimport"
 
-#: cp/class.c:3054
+#: cp/class.c:3056
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<final%>, but is not virtual"
 msgstr "%q#D的定义被标记为 %<dllimport%>"
 
-#: cp/class.c:3056
+#: cp/class.c:3058
 #, fuzzy, gcc-internal-format
 msgid "%q+#D marked %<override%>, but does not override"
 msgstr "%q+D定义后未使用"
 
-#: cp/class.c:3126
+#: cp/class.c:3128
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D was hidden"
 msgid "%qD was hidden"
 msgstr "%q+D为"
 
-#: cp/class.c:3128
+#: cp/class.c:3130
 #, fuzzy, gcc-internal-format
 #| msgid "  by %q+D"
 msgid "  by %qD"
 msgstr "%q+D所隐藏"
 
-#: cp/class.c:3162 cp/decl2.c:1483
+#: cp/class.c:3164 cp/decl2.c:1484
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous union can only have non-static data members"
 msgid "%q#D invalid; an anonymous union can only have non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/class.c:3166
+#: cp/class.c:3168
 #, fuzzy, gcc-internal-format
 #| msgid "%q+#D invalid; an anonymous struct can only have non-static data members"
 msgid "%q#D invalid; an anonymous struct can only have non-static data members"
 msgstr "%q+#D无效；匿名联合只能有非静态的数据成员"
 
-#: cp/class.c:3178 cp/decl2.c:1490
+#: cp/class.c:3180 cp/decl2.c:1491
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous union"
 msgid "private member %q#D in anonymous union"
 msgstr "匿名联合中出现私有成员%q+#D"
 
-#: cp/class.c:3181
+#: cp/class.c:3183
 #, fuzzy, gcc-internal-format
 #| msgid "private member %q+#D in anonymous struct"
 msgid "private member %q#D in anonymous struct"
 msgstr "匿名联合中出现私有成员%q+#D"
 
-#: cp/class.c:3187 cp/decl2.c:1493
+#: cp/class.c:3189 cp/decl2.c:1494
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous union"
 msgid "protected member %q#D in anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/class.c:3190
+#: cp/class.c:3192
 #, fuzzy, gcc-internal-format
 #| msgid "protected member %q+#D in anonymous struct"
 msgid "protected member %q#D in anonymous struct"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/class.c:3378
+#: cp/class.c:3380
 #, fuzzy, gcc-internal-format
 msgid "the ellipsis in %qD is not inherited"
 msgstr "当继承来的方法未被实现时给出警告"
 
-#: cp/class.c:3547
+#: cp/class.c:3549
 #, gcc-internal-format
 msgid "bit-field %q+#D with non-integral type"
 msgstr "位段%q+#D有非整数的类型"
 
-#: cp/class.c:3563
+#: cp/class.c:3565
 #, gcc-internal-format
 msgid "bit-field %q+D width not an integer constant"
 msgstr "位段%q+D的宽度不是一个整数常量"
 
-#: cp/class.c:3568
+#: cp/class.c:3570
 #, gcc-internal-format
 msgid "negative width in bit-field %q+D"
 msgstr "位段%q+D宽度为负"
 
-#: cp/class.c:3573
+#: cp/class.c:3575
 #, gcc-internal-format
 msgid "zero width for bit-field %q+D"
 msgstr "位段%q+D宽度为 0"
 
-#: cp/class.c:3583
+#: cp/class.c:3585
 #, fuzzy, gcc-internal-format
 #| msgid "width of %q+D exceeds its type"
 msgid "width of %qD exceeds its type"
 msgstr "%q+D的宽度超过了它的类型"
 
-#: cp/class.c:3588
+#: cp/class.c:3590
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D is too small to hold all values of %q#T"
 msgid "%qD is too small to hold all values of %q#T"
 msgstr "%q+D太小而不能存放%q#T的所有可能值"
 
-#: cp/class.c:3648
+#: cp/class.c:3650
 #, gcc-internal-format
 msgid "member %q+#D with constructor not allowed in union"
 msgstr "有构造函数的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3651
+#: cp/class.c:3653
 #, gcc-internal-format
 msgid "member %q+#D with destructor not allowed in union"
 msgstr "有析构函数的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3653
+#: cp/class.c:3655
 #, gcc-internal-format
 msgid "member %q+#D with copy assignment operator not allowed in union"
 msgstr "有拷贝赋值运算符的成员%q+#D不能用在联合中"
 
-#: cp/class.c:3657
+#: cp/class.c:3659
 #, fuzzy, gcc-internal-format
 msgid "unrestricted unions only available with -std=c++11 or -std=gnu++11"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/class.c:3781
+#: cp/class.c:3783
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %q+D may not be static because it is a member of a union"
 msgstr "%q+D不能是静态的，因为它是联合的成员"
 
-#: cp/class.c:3788
+#: cp/class.c:3790
 #, fuzzy, gcc-internal-format
 msgid "non-static data member %q+D in a union may not have reference type %qT"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:3798
+#: cp/class.c:3800
 #, gcc-internal-format
 msgid "field %q+D invalidly declared function type"
 msgstr "字段%q+D无效地声明为函数类型"
 
-#: cp/class.c:3804
+#: cp/class.c:3806
 #, gcc-internal-format
 msgid "field %q+D invalidly declared method type"
 msgstr "字段%q+D无效地声明为方法类型"
 
-#: cp/class.c:3864
+#: cp/class.c:3866
 #, fuzzy, gcc-internal-format
 #| msgid "ignoring packed attribute because of unpacked non-POD field %q+#D"
 msgid "ignoring packed attribute because of unpacked non-POD field %q#D"
 msgstr "为非紧实的非简单旧数据字段%q+#D忽略 packed 属性"
 
-#: cp/class.c:3912
+#: cp/class.c:3914
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared both %<const%> and %<mutable%>"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/class.c:3918
+#: cp/class.c:3920
 #, fuzzy, gcc-internal-format
 msgid "member %q+D cannot be declared as a %<mutable%> reference"
 msgstr "非成员%qs不能被声明为%<mutable%>"
 
-#: cp/class.c:3944
+#: cp/class.c:3946
 #, gcc-internal-format
 msgid "multiple fields in union %qT initialized"
 msgstr "初始化了联合%qT中的多个字段"
 
-#: cp/class.c:3985
+#: cp/class.c:3987
 #, fuzzy, gcc-internal-format
 #| msgid "field %q+#D with same name as class"
 msgid "field %q#D with same name as class"
 msgstr "字段%q+#D与类重名"
 
-#: cp/class.c:4008
+#: cp/class.c:4010
 #, gcc-internal-format
 msgid "%q#T has pointer data members"
 msgstr "%q#T有指针数据成员"
 
-#: cp/class.c:4013
+#: cp/class.c:4015
 #, gcc-internal-format
 msgid "  but does not override %<%T(const %T&)%>"
 msgstr "但没有重载%<%T(const %T&)%>"
 
-#: cp/class.c:4015
+#: cp/class.c:4017
 #, gcc-internal-format
 msgid "  or %<operator=(const %T&)%>"
 msgstr "或者%<operator=(const %T&)%>"
 
-#: cp/class.c:4019
+#: cp/class.c:4021
 #, gcc-internal-format
 msgid "  but does not override %<operator=(const %T&)%>"
 msgstr "但没有重载%<operator=(const %T&)%>"
 
-#: cp/class.c:4424
+#: cp/class.c:4426
 #, gcc-internal-format
 msgid "alignment of %qD increased in -fabi-version=9 (GCC 5.2)"
 msgstr ""
 
-#: cp/class.c:4427
+#: cp/class.c:4429
 #, fuzzy, gcc-internal-format
 msgid "alignment of %qD will increase in -fabi-version=9"
 msgstr "%qD的对齐"
 
-#: cp/class.c:4698
+#: cp/class.c:4700
 #, gcc-internal-format
 msgid "initializer specified for non-virtual method %q+D"
 msgstr "为非虚方法%q+D指定了初始值设定项"
 
-#: cp/class.c:5155
+#: cp/class.c:5157
 #, fuzzy, gcc-internal-format
 msgid "method overrides both %<transaction_pure%> and %qE methods"
 msgstr "方法强制变更两者 %<transaction_pure%> 和 %qE 方法"
 
-#: cp/class.c:5176
+#: cp/class.c:5178
 #, fuzzy, gcc-internal-format
 msgid "method declared %qE overriding %qE method"
 msgstr "为不存在的方法%qE创建选择子"
 
-#: cp/class.c:5771 cp/constexpr.c:218
+#: cp/class.c:5775 cp/constexpr.c:220
 #, fuzzy, gcc-internal-format
 msgid "enclosing class of constexpr non-static member function %q+#D is not a literal type"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5796
+#: cp/class.c:5799
 #, fuzzy, gcc-internal-format
 msgid "%q+T is not literal because:"
 msgstr "在%q#T和%q#T间比较"
 
-#: cp/class.c:5798
+#: cp/class.c:5801
 #, fuzzy, gcc-internal-format
 msgid "  %q+T has a non-trivial destructor"
 msgstr "基类%q#T有一个非虚析构函数"
 
-#: cp/class.c:5803
+#: cp/class.c:5806
 #, fuzzy, gcc-internal-format
 msgid "  %q+T is not an aggregate, does not have a trivial default constructor, and has no constexpr constructor that is not a copy or move constructor"
 msgstr "  %q+T 不是汇总，没有 trivial 缺省构造函数，而没有任何 constexpr 建构子该并非复制或移动建构子"
 
-#: cp/class.c:5838
+#: cp/class.c:5841
 #, fuzzy, gcc-internal-format
 msgid "  base class %qT of %q+T is non-literal"
 msgstr "%3$L处 CLASS 变量‘%2$s’的类型‘%1$s’不能被扩展"
 
-#: cp/class.c:5853
+#: cp/class.c:5856
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has non-literal type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:5860
+#: cp/class.c:5863
 #, fuzzy, gcc-internal-format
 msgid "  non-static data member %qD has volatile type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
-#: cp/class.c:5978
+#: cp/class.c:5981
 #, fuzzy, gcc-internal-format
 msgid "base class %q#T has accessible non-virtual destructor"
 msgstr "%q#T有虚函数和可访问的非虚拟析构函数"
 
-#: cp/class.c:6007
+#: cp/class.c:6010
 #, fuzzy, gcc-internal-format
 #| msgid "non-static reference %q+#D in class without a constructor"
 msgid "non-static reference %q#D in class without a constructor"
 msgstr "类中有非静态引用%q+#D，却没有提供构造函数"
 
-#: cp/class.c:6013
+#: cp/class.c:6016
 #, fuzzy, gcc-internal-format
 #| msgid "non-static const member %q+#D in class without a constructor"
 msgid "non-static const member %q#D in class without a constructor"
@@ -40592,160 +40648,160 @@
 
 #. If the function is defaulted outside the class, we just
 #. give the synthesis error.
-#: cp/class.c:6039
+#: cp/class.c:6042
 #, gcc-internal-format
 msgid "%q+D declared to take const reference, but implicit declaration would take non-const"
 msgstr "%q+D被声明为取常量引用，但是隐式声明取非常量引用"
 
-#: cp/class.c:6316
+#: cp/class.c:6319
 #, gcc-internal-format
 msgid "direct base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，直接基类%qT在%qT中无法访问"
 
-#: cp/class.c:6328
+#: cp/class.c:6331
 #, gcc-internal-format
 msgid "virtual base %qT inaccessible in %qT due to ambiguity"
 msgstr "由于存在歧义，虚基类%qT在%qT中无法访问"
 
-#: cp/class.c:6556
+#: cp/class.c:6559
 #, fuzzy, gcc-internal-format
 #| msgid "offset of %q+D is not ABI-compliant and may change in a future version of GCC"
 msgid "offset of %qD is not ABI-compliant and may change in a future version of GCC"
 msgstr "%q+D的偏移量与 ABI 不兼容，并且在 GCC 的未来版本中可能会有变化"
 
-#: cp/class.c:6711
+#: cp/class.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "size of array %qE is too large"
 msgid "size of type %qT is too large (%qE bytes)"
 msgstr "数组%qE太大"
 
-#: cp/class.c:7009
+#: cp/class.c:7012
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %q#T with a zero-size array in %q#D"
 msgstr "对非左值数组的使用无效"
 
-#: cp/class.c:7011
+#: cp/class.c:7014
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of structure with flexible array member"
 msgid "invalid use of %q#T with a flexible array member in %q#T"
 msgstr "对包含可变数组成员的结构的无效使用"
 
-#: cp/class.c:7016
+#: cp/class.c:7019
 #, fuzzy, gcc-internal-format
 msgid "array member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:7043
+#: cp/class.c:7046
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "zero-size array member %qD not at end of %q#T"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/class.c:7045
+#: cp/class.c:7048
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "zero-size array member %qD in an otherwise empty %q#T"
 msgstr "可变数组是结构中的唯一成员"
 
-#: cp/class.c:7053 cp/class.c:7083
+#: cp/class.c:7056 cp/class.c:7086
 #, fuzzy, gcc-internal-format
 #| msgid "redefinition of %q#T"
 msgid "in the definition of %q#T"
 msgstr "%q#T重定义"
 
-#: cp/class.c:7061
+#: cp/class.c:7064
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member not at end of struct"
 msgid "flexible array member %qD not at end of %q#T"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/class.c:7063
+#: cp/class.c:7066
 #, fuzzy, gcc-internal-format
 #| msgid "flexible array member in otherwise empty struct"
 msgid "flexible array member %qD in an otherwise empty %q#T"
 msgstr "可变数组是结构中的唯一成员"
 
-#: cp/class.c:7081
+#: cp/class.c:7084
 #, fuzzy, gcc-internal-format
 msgid "next member %q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/class.c:7193 cp/parser.c:22773
+#: cp/class.c:7196 cp/parser.c:22796
 #, gcc-internal-format
 msgid "redefinition of %q#T"
 msgstr "%q#T重定义"
 
-#: cp/class.c:7337
+#: cp/class.c:7340
 #, gcc-internal-format
 msgid "%q#T has virtual functions and accessible non-virtual destructor"
 msgstr "%q#T有虚函数和可访问的非虚拟析构函数"
 
-#: cp/class.c:7365
+#: cp/class.c:7368
 #, fuzzy, gcc-internal-format
 msgid "type transparent %q#T does not have any fields"
 msgstr "类型%qT大小未知"
 
-#: cp/class.c:7371
+#: cp/class.c:7374
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has base classes"
 msgstr "类型透明类别 %qT 有基础类别"
 
-#: cp/class.c:7375
+#: cp/class.c:7378
 #, fuzzy, gcc-internal-format
 msgid "type transparent class %qT has virtual functions"
 msgstr "类型%qE有虚成员函数"
 
-#: cp/class.c:7381
+#: cp/class.c:7384
 #, gcc-internal-format
 msgid "type transparent %q#T cannot be made transparent because the type of the first field has a different ABI from the class overall"
 msgstr ""
 
-#: cp/class.c:7545
+#: cp/class.c:7548
 #, fuzzy, gcc-internal-format
 msgid "definition of std::initializer_list does not match #include <initializer_list>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/class.c:7556
+#: cp/class.c:7559
 #, gcc-internal-format
 msgid "trying to finish struct, but kicked out due to previous parse errors"
 msgstr "试图完成结构，但为先前的解析错误所中断"
 
-#: cp/class.c:8072
+#: cp/class.c:8075
 #, gcc-internal-format
 msgid "language string %<\"%E\"%> not recognized"
 msgstr "语言字符串%<\"%E\"%>不可识别"
 
-#: cp/class.c:8162
+#: cp/class.c:8165
 #, gcc-internal-format
 msgid "cannot resolve overloaded function %qD based on conversion to type %qT"
 msgstr "无法解析重载函数%qD，基于向类型%qT的转换"
 
-#: cp/class.c:8317
+#: cp/class.c:8320
 #, gcc-internal-format
 msgid "no matches converting function %qD to type %q#T"
 msgstr "没有可将函数%qD转换到类型%q#T的匹配项"
 
-#: cp/class.c:8345
+#: cp/class.c:8348
 #, gcc-internal-format
 msgid "converting overloaded function %qD to type %q#T is ambiguous"
 msgstr "将重载函数%qD转换为类型%q#T有歧义"
 
-#: cp/class.c:8372
+#: cp/class.c:8375
 #, gcc-internal-format
 msgid "assuming pointer to member %qD"
 msgstr "假定是成员指针%qD"
 
-#: cp/class.c:8375
+#: cp/class.c:8378
 #, gcc-internal-format
 msgid "(a pointer to member can only be formed with %<&%E%>)"
 msgstr "(成员指针只能用%<&%E%>构成)"
 
-#: cp/class.c:8450 cp/class.c:8487
+#: cp/class.c:8453 cp/class.c:8490
 #, gcc-internal-format
 msgid "not enough type information"
 msgstr "类型信息不充分"
 
-#: cp/class.c:8470 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
+#: cp/class.c:8473 cp/cvt.c:171 cp/cvt.c:198 cp/cvt.c:247
 #, gcc-internal-format
 msgid "cannot convert %qE from type %qT to type %qT"
 msgstr "无法将%qE从类型%qT转换到类型%qT"
@@ -40755,12 +40811,12 @@
 #. A name N used in a class S shall refer to the same declaration
 #. in its context and when re-evaluated in the completed scope of
 #. S.
-#: cp/class.c:8756
+#: cp/class.c:8759
 #, gcc-internal-format
 msgid "declaration of %q#D"
 msgstr "%q#D的声明"
 
-#: cp/class.c:8758
+#: cp/class.c:8761
 #, fuzzy, gcc-internal-format
 #| msgid "changes meaning of %qD from %q+#D"
 msgid "changes meaning of %qD from %q#D"
@@ -40791,336 +40847,336 @@
 msgid "invalid return type %qT of constexpr function %q+D"
 msgstr "函数%q+#D的抽象返回类型无效"
 
-#: cp/constexpr.c:228
+#: cp/constexpr.c:229
 #, fuzzy, gcc-internal-format
 msgid "%q#T has virtual base classes"
 msgstr "%q#T不是一个类"
 
-#: cp/constexpr.c:488
+#: cp/constexpr.c:489
 #, gcc-internal-format
 msgid "constexpr constructor does not have empty body"
 msgstr "广义常表达式构造函数体不为空"
 
-#: cp/constexpr.c:594
+#: cp/constexpr.c:595
 #, fuzzy, gcc-internal-format
 msgid "body of %<constexpr%> constructor cannot be a function-try-block"
 msgstr "不能从构造函数的异常处理中返回"
 
-#: cp/constexpr.c:723
+#: cp/constexpr.c:724
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> constructor for union %qT must initialize exactly one non-static data member"
 msgstr "类中对具有非整数类型%qT的静态数据成员的初始化无效"
 
-#: cp/constexpr.c:775
+#: cp/constexpr.c:776
 #, fuzzy, gcc-internal-format
 msgid "member %qD must be initialized by mem-initializer in %<constexpr%> constructor"
 msgstr "成员%qD在%<constexpr%>构造函数里未初始化"
 
-#: cp/constexpr.c:816
+#: cp/constexpr.c:817
 #, fuzzy, gcc-internal-format
 msgid "body of constexpr function %qD not a return-statement"
 msgstr "返回语句转换无效"
 
-#: cp/constexpr.c:876
+#: cp/constexpr.c:877
 #, fuzzy, gcc-internal-format
 msgid "%qD is not usable as a constexpr function because:"
 msgstr "%qD不是一个广义常函数"
 
-#: cp/constexpr.c:1176 cp/constexpr.c:1185 cp/constexpr.c:1750
+#: cp/constexpr.c:1177 cp/constexpr.c:1186 cp/constexpr.c:1766
 #, gcc-internal-format
 msgid "%q+E is not a constant expression"
 msgstr "%q+E不是一个常量表达式"
 
-#: cp/constexpr.c:1363 cp/constexpr.c:5115
+#: cp/constexpr.c:1364 cp/constexpr.c:5146
 #, fuzzy, gcc-internal-format
 msgid "call to internal function %qE"
 msgstr "内部函数"
 
-#: cp/constexpr.c:1426
+#: cp/constexpr.c:1442
 #, fuzzy, gcc-internal-format
 msgid "expression %qE does not designate a constexpr function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/constexpr.c:1444 cp/constexpr.c:5133
+#: cp/constexpr.c:1460 cp/constexpr.c:5164
 #, fuzzy, gcc-internal-format
 msgid "call to non-constexpr function %qD"
 msgstr "调用非函数的%qD"
 
-#: cp/constexpr.c:1516
+#: cp/constexpr.c:1532
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression before its definition is complete"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:1523
+#: cp/constexpr.c:1539
 #, fuzzy, gcc-internal-format
 msgid "%qD called in a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:1527
+#: cp/constexpr.c:1543
 #, fuzzy, gcc-internal-format
 msgid "%qD used before its definition"
 msgstr "使用%qD时先前既没有原型也没有定义"
 
-#: cp/constexpr.c:1567
+#: cp/constexpr.c:1583
 #, gcc-internal-format
 msgid "call has circular dependency"
 msgstr "调用存在循环依赖"
 
-#: cp/constexpr.c:1578
+#: cp/constexpr.c:1594
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "constexpr evaluation depth exceeds maximum of %d (use -fconstexpr-depth= to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:1661
+#: cp/constexpr.c:1677
 #, fuzzy, gcc-internal-format
 msgid "constexpr call flows off the end of the function"
 msgstr "调用这些函数时给出警告"
 
-#: cp/constexpr.c:1790
+#: cp/constexpr.c:1806
 #, fuzzy, gcc-internal-format
 msgid "right operand of shift expression %q+E is negative"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/constexpr.c:1797
+#: cp/constexpr.c:1813
 #, gcc-internal-format
 msgid "right operand of shift expression %q+E is >= than the precision of the left operand"
 msgstr ""
 
-#: cp/constexpr.c:1815
+#: cp/constexpr.c:1831
 #, fuzzy, gcc-internal-format
 msgid "left operand of shift expression %q+E is negative"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/constexpr.c:1834
+#: cp/constexpr.c:1850
 #, fuzzy, gcc-internal-format
 msgid "shift expression %q+E overflows"
 msgstr "%q+E不是一个常量表达式"
 
-#: cp/constexpr.c:1978
+#: cp/constexpr.c:1994
 #, gcc-internal-format
 msgid "arithmetic involving a null pointer in %qE"
 msgstr ""
 
-#: cp/constexpr.c:2172
+#: cp/constexpr.c:2188
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array %qD of type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:2177
+#: cp/constexpr.c:2193
 #, fuzzy, gcc-internal-format
 msgid "array subscript value %qE is outside the bounds of array type %qT"
 msgstr "枚举值 %E 对其类型%<%T%>而言太大了"
 
-#: cp/constexpr.c:2324
+#: cp/constexpr.c:2340
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized array element"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.c:2355
+#: cp/constexpr.c:2371
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer in %qE"
 msgstr "提领%<void *%>指针"
 
-#: cp/constexpr.c:2369 cp/constexpr.c:2459 cp/constexpr.c:4003
+#: cp/constexpr.c:2385 cp/constexpr.c:2475 cp/constexpr.c:4027
 #, gcc-internal-format
 msgid "%qE is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:2375
+#: cp/constexpr.c:2391
 #, fuzzy, gcc-internal-format
 msgid "mutable %qD is not usable in a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:2400
+#: cp/constexpr.c:2416
 #, fuzzy, gcc-internal-format
 msgid "accessing %qD member instead of initialized %qD member in constant expression"
 msgstr "初始值设定中数组索引不是整型常量表达式"
 
-#: cp/constexpr.c:2419
+#: cp/constexpr.c:2435
 #, fuzzy, gcc-internal-format
 msgid "accessing uninitialized member %qD"
 msgstr "成员%qD是未初始化的引用"
 
-#: cp/constexpr.c:3122 cp/constexpr.c:4412
+#: cp/constexpr.c:3146 cp/constexpr.c:4443
 #, fuzzy, gcc-internal-format
 #| msgid "dereferencing %<void *%> pointer"
 msgid "dereferencing a null pointer"
 msgstr "提领%<void *%>指针"
 
-#: cp/constexpr.c:3141
+#: cp/constexpr.c:3165
 #, fuzzy, gcc-internal-format
 msgid "accessing value of %qE through a %qT glvalue in a constant expression"
 msgstr "%qE的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:3180
+#: cp/constexpr.c:3204
 #, fuzzy, gcc-internal-format
 msgid "the value of %qD is not usable in a constant expression"
 msgstr "%qD的枚举值不是一个整数常量"
 
-#: cp/constexpr.c:3187
+#: cp/constexpr.c:3211
 #, gcc-internal-format
 msgid "%qD used in its own initializer"
 msgstr "%qD用在其自身的初始值设定中"
 
-#: cp/constexpr.c:3192
+#: cp/constexpr.c:3216
 #, gcc-internal-format
 msgid "%q#D is not const"
 msgstr "%q#D不是 const"
 
-#: cp/constexpr.c:3195
+#: cp/constexpr.c:3219
 #, gcc-internal-format
 msgid "%q#D is volatile"
 msgstr "%q#D是 volatile"
 
-#: cp/constexpr.c:3200 cp/constexpr.c:3207
+#: cp/constexpr.c:3224 cp/constexpr.c:3231
 #, fuzzy, gcc-internal-format
 msgid "%qD was not initialized with a constant expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/constexpr.c:3213
+#: cp/constexpr.c:3237
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared %<constexpr%>"
 msgstr "%qD在其类外被声明为%<constexpr%>"
 
-#: cp/constexpr.c:3216
+#: cp/constexpr.c:3240
 #, fuzzy, gcc-internal-format
 msgid "%qD does not have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/constexpr.c:3410
+#: cp/constexpr.c:3434
 #, fuzzy, gcc-internal-format
 msgid "modification of %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:3782
+#: cp/constexpr.c:3806
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "constexpr loop iteration count exceeds limit of %d (use -fconstexpr-loop-limit= to increase the limit)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/constexpr.c:3921
+#: cp/constexpr.c:3945
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "value %qE of type %qT is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:4049 cp/constexpr.c:5562
+#: cp/constexpr.c:4080 cp/constexpr.c:5593
 #, fuzzy, gcc-internal-format
 msgid "temporary of non-literal type %qT in a constant expression"
 msgstr "枚举和非枚举类型一起出现在条件表达式中"
 
-#: cp/constexpr.c:4398
+#: cp/constexpr.c:4429
 #, fuzzy, gcc-internal-format
 msgid "a reinterpret_cast is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:4424
+#: cp/constexpr.c:4455
 #, fuzzy, gcc-internal-format
 msgid "conversion of %qT null pointer to %qT is not a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.c:4439
+#: cp/constexpr.c:4470
 #, fuzzy, gcc-internal-format
 msgid "%<reinterpret_cast<%T>(%E)%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:4502 cp/constexpr.c:5423 cp/constexpr.c:5738
+#: cp/constexpr.c:4533 cp/constexpr.c:5454 cp/constexpr.c:5769
 #, fuzzy, gcc-internal-format
 msgid "expression %qE is not a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:4579
+#: cp/constexpr.c:4610
 #, fuzzy, gcc-internal-format
 msgid "statement is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:4582
+#: cp/constexpr.c:4613
 #, fuzzy, gcc-internal-format
 msgid "unexpected expression %qE of kind %s"
 msgstr "KIND 参数 %s 在%L处必须是初始化表达式"
 
-#: cp/constexpr.c:4652
+#: cp/constexpr.c:4683
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to mutable subobjects of %qT"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:4661
+#: cp/constexpr.c:4692
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a constant expression because it refers to an incompletely initialized variable"
 msgstr "%qT 无法类型的完成常数运算式因为它有可变的 sub-objects"
 
-#: cp/constexpr.c:4675
+#: cp/constexpr.c:4706
 #, fuzzy, gcc-internal-format
 msgid "conversion from pointer type %qT to arithmetic type %qT in a constant expression"
 msgstr "表达式%qE具有抽象类类型%qT，不能用于 throw 表达式中"
 
-#: cp/constexpr.c:5033
+#: cp/constexpr.c:5064
 #, gcc-internal-format
 msgid "expression %qE has side-effects"
 msgstr "表达式%qE有副作用"
 
-#: cp/constexpr.c:5227
+#: cp/constexpr.c:5258
 #, fuzzy, gcc-internal-format
 msgid "reinterpret_cast from integer to pointer"
 msgstr "赋值时将整数赋给指针，未作类型转换"
 
-#: cp/constexpr.c:5259
+#: cp/constexpr.c:5290
 #, fuzzy, gcc-internal-format
 msgid "address-of an object %qE with thread local or automatic storage is not a constant expression"
 msgstr "address-of 对象 %qE 与线程本地或自动贮藏体并非常数运算式"
 
-#: cp/constexpr.c:5293
+#: cp/constexpr.c:5324
 #, fuzzy, gcc-internal-format
 msgid "use of %<this%> in a constant expression"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/constexpr.c:5435
+#: cp/constexpr.c:5466
 #, fuzzy, gcc-internal-format
 msgid "typeid-expression is not a constant expression because %qE is of polymorphic type"
 msgstr "typeid-expression 并非常数运算式因为 %qE 是的 polymorphic 类型"
 
-#: cp/constexpr.c:5496
+#: cp/constexpr.c:5527
 #, fuzzy, gcc-internal-format
 msgid "cast to non-integral type %qT in a constant expression"
 msgstr "常量表达式中类型错误"
 
-#: cp/constexpr.c:5529 cp/decl.c:5163
+#: cp/constexpr.c:5560 cp/decl.c:5163
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<static%> in %<constexpr%> function"
 msgstr "非静态数据成员%qE被声明为%<constexpr%>"
 
-#: cp/constexpr.c:5536 cp/decl.c:5160
+#: cp/constexpr.c:5567 cp/decl.c:5160
 #, fuzzy, gcc-internal-format
 msgid "%qD declared %<thread_local%> in %<constexpr%> function"
 msgstr "函数%qs的存储类%<__thread%>无效"
 
-#: cp/constexpr.c:5543 cp/decl.c:5583
+#: cp/constexpr.c:5574 cp/decl.c:5583
 #, fuzzy, gcc-internal-format
 msgid "uninitialized variable %qD in %<constexpr%> function"
 msgstr "对广义常变量%qD的声明不同时是定义"
 
-#: cp/constexpr.c:5611
+#: cp/constexpr.c:5642
 #, fuzzy, gcc-internal-format
 msgid "division by zero is not a constant expression"
 msgstr "%L处被零除"
 
-#: cp/constexpr.c:5715
+#: cp/constexpr.c:5746
 #, fuzzy, gcc-internal-format
 msgid "%<delete[]%> is not a constant expression"
 msgstr "跳转至语句表达式中"
 
-#: cp/constexpr.c:5746
+#: cp/constexpr.c:5777
 #, fuzzy, gcc-internal-format
 msgid "non-constant array initialization"
 msgstr "%L处非常量初始化表达式"
 
-#: cp/constexpr.c:5767
+#: cp/constexpr.c:5798
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a constant expression"
 msgid "%<goto%> is not a constant expression"
 msgstr "%qE不是一个常量表达式"
 
-#: cp/constexpr.c:5779
+#: cp/constexpr.c:5810
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "unexpected AST of kind %s"
 msgstr "%2$L处 %1$s 种别无效"
@@ -41936,7 +41992,7 @@
 msgid "  skips initialization of %q#D"
 msgstr "跳过了%q+#D的初始化"
 
-#: cp/decl.c:3408 cp/parser.c:12104 cp/parser.c:12131
+#: cp/decl.c:3408 cp/parser.c:12113 cp/parser.c:12140
 #, gcc-internal-format
 msgid "invalid exit from OpenMP structured block"
 msgstr "OpenMP 结构块出口无效"
@@ -41951,7 +42007,7 @@
 msgid "%qD is not a type"
 msgstr "%qD不是一个类型"
 
-#: cp/decl.c:3766 cp/parser.c:6082
+#: cp/decl.c:3766 cp/parser.c:6087
 #, gcc-internal-format
 msgid "%qD used without template parameters"
 msgstr "%qD使用时未带模板参数"
@@ -43633,7 +43689,7 @@
 msgid "parameter declared %<auto%>"
 msgstr "形参声明为%<auto%>"
 
-#: cp/decl.c:11845 cp/parser.c:3161
+#: cp/decl.c:11845 cp/parser.c:3163
 #, gcc-internal-format
 msgid "invalid use of template-name %qE without an argument list"
 msgstr "使用模板名%qE时不带实参表无效"
@@ -44094,13 +44150,13 @@
 msgid "%qD has the same name as the class in which it is declared"
 msgstr "%qD与其声明所在的类重名"
 
-#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2987 cp/parser.c:6141
-#: cp/pt.c:8574
+#: cp/decl.c:13533 cp/friend.c:304 cp/parser.c:2989 cp/parser.c:6146
+#: cp/pt.c:8656
 #, gcc-internal-format
 msgid "%qT is not a template"
 msgstr "%qT不是一个模板"
 
-#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4036
+#: cp/decl.c:13534 cp/friend.c:305 cp/tree.c:4031
 #, fuzzy, gcc-internal-format
 msgid "previous declaration here"
 msgstr "%q+T先前在此处有过声明"
@@ -44110,8 +44166,8 @@
 msgid "perhaps you want to explicitly add %<%T::%>"
 msgstr ""
 
-#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3581
-#: cp/name-lookup.c:3626 cp/parser.c:6092 cp/parser.c:25696
+#: cp/decl.c:13547 cp/name-lookup.c:2741 cp/name-lookup.c:3580
+#: cp/name-lookup.c:3625 cp/parser.c:6097 cp/parser.c:25719
 #, gcc-internal-format
 msgid "reference to %qD is ambiguous"
 msgstr "对%qD的引用有歧义"
@@ -44162,7 +44218,7 @@
 msgid "scoped/unscoped mismatch in enum %q#T"
 msgstr "范围/unscoped 不匹配在中 enum %q#T"
 
-#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17916
+#: cp/decl.c:14058 cp/decl.c:14066 cp/decl.c:14078 cp/parser.c:17939
 #, gcc-internal-format
 msgid "previous definition here"
 msgstr "先前的定义在这里"
@@ -44227,7 +44283,7 @@
 msgid "return type %q#T is incomplete"
 msgstr "返回值类型%q#T不完全"
 
-#: cp/decl.c:14846 cp/typeck.c:8980
+#: cp/decl.c:14846 cp/typeck.c:8981
 #, gcc-internal-format
 msgid "%<operator=%> should return a reference to %<*this%>"
 msgstr "%<operator=%>应当返回一个对%<*this%>的引用"
@@ -44242,7 +44298,7 @@
 msgid "no return statements in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/decl.c:15615 cp/typeck.c:8861
+#: cp/decl.c:15615 cp/typeck.c:8862
 #, fuzzy, gcc-internal-format
 msgid "only plain %<auto%> return type can be deduced to %<void%>"
 msgstr "由于%<volatile%>，函数返回类型不兼容"
@@ -44400,27 +44456,27 @@
 msgid "width of bit-field %qD has non-integral type %qT"
 msgstr "位段%qD非整型"
 
-#: cp/decl2.c:1403
+#: cp/decl2.c:1404
 #, fuzzy, gcc-internal-format
 msgid "%q+D static data member inside of declare target directive"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/decl2.c:1467
+#: cp/decl2.c:1468
 #, gcc-internal-format
 msgid "anonymous struct not inside named type"
 msgstr "匿名结构不在有名类型内"
 
-#: cp/decl2.c:1558
+#: cp/decl2.c:1559
 #, gcc-internal-format
 msgid "namespace-scope anonymous aggregates must be static"
 msgstr "命名空间域的匿名聚合必须是静态的"
 
-#: cp/decl2.c:1567
+#: cp/decl2.c:1568
 #, gcc-internal-format
 msgid "anonymous union with no members"
 msgstr "匿名联合没有成员"
 
-#: cp/decl2.c:1600
+#: cp/decl2.c:1601
 #, gcc-internal-format
 msgid "%<operator new%> must return type %qT"
 msgstr "%<operator new%>必须返回%qT"
@@ -44429,71 +44485,71 @@
 #.
 #. The first parameter shall not have an associated default
 #. argument.
-#: cp/decl2.c:1611
+#: cp/decl2.c:1612
 #, gcc-internal-format
 msgid "the first parameter of %<operator new%> cannot have a default argument"
 msgstr "%<operator new%>的第一个形参不能有默认参数"
 
-#: cp/decl2.c:1627
+#: cp/decl2.c:1628
 #, gcc-internal-format
 msgid "%<operator new%> takes type %<size_t%> (%qT) as first parameter"
 msgstr "%<operator new%>的第一个形参类型为%<size_t%>(%qT)"
 
-#: cp/decl2.c:1656
+#: cp/decl2.c:1657
 #, gcc-internal-format
 msgid "%<operator delete%> must return type %qT"
 msgstr "%<operator delete%>必须返回%qT"
 
-#: cp/decl2.c:1665
+#: cp/decl2.c:1666
 #, gcc-internal-format
 msgid "%<operator delete%> takes type %qT as first parameter"
 msgstr "%<operator delete%>的第一个形参类型为%qT"
 
-#: cp/decl2.c:2527
+#: cp/decl2.c:2528
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type has no linkage"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2531
+#: cp/decl2.c:2532
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgid "%qT has a field %qD whose type depends on the type %qT which has no linkage"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2536
+#: cp/decl2.c:2537
 #, gcc-internal-format
 msgid "%qT has a field %qD whose type uses the anonymous namespace"
 msgstr "%qT有一个字段%qD使用匿名命名空间"
 
-#: cp/decl2.c:2544
+#: cp/decl2.c:2545
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than the type of its field %qD"
 msgstr "%qT被声明为比其字段%qD的类型有更高的可见性"
 
-#: cp/decl2.c:2562
+#: cp/decl2.c:2563
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type has no linkage"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2566
+#: cp/decl2.c:2567
 #, fuzzy, gcc-internal-format
 #| msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgid "%qT has a base %qT whose type depends on the type %qT which has no linkage"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2571
+#: cp/decl2.c:2572
 #, gcc-internal-format
 msgid "%qT has a base %qT whose type uses the anonymous namespace"
 msgstr "%qT有一个基类%qT使用匿名命名空间"
 
-#: cp/decl2.c:2578
+#: cp/decl2.c:2579
 #, gcc-internal-format
 msgid "%qT declared with greater visibility than its base %qT"
 msgstr "%qT被声明为比其基类%qT有更高的可见性"
 
-#: cp/decl2.c:4187
+#: cp/decl2.c:4188
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using unnamed type, is used but never defined"
 msgstr "%q+#D声明为具有匿名类型，在使用前未被定义"
@@ -44502,48 +44558,48 @@
 #. no linkage can only be used to declare extern "C"
 #. entities.  Since it's not always an error in the
 #. ISO C++ 90 Standard, we only issue a warning.
-#: cp/decl2.c:4196
+#: cp/decl2.c:4197
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare variable %q#D with linkage"
 msgstr "匿名类型不具任何链结用来声明变量 %q#D 与链结"
 
-#: cp/decl2.c:4200
+#: cp/decl2.c:4201
 #, fuzzy, gcc-internal-format
 msgid "unnamed type with no linkage used to declare function %q#D with linkage"
 msgstr "匿名类型不具任何链结用来声明函数 %q#D 与链结"
 
-#: cp/decl2.c:4204
+#: cp/decl2.c:4205
 #, fuzzy, gcc-internal-format
 msgid "%q#D does not refer to the unqualified type, so it is not used for linkage"
 msgstr "%q+#D未指明非限定类型，所以它不被用作外部链接"
 
-#: cp/decl2.c:4212
+#: cp/decl2.c:4213
 #, fuzzy, gcc-internal-format
 msgid "%q#D, declared using local type %qT, is used but never defined"
 msgstr "%q+#D声明为具有局部类型%qT，在使用前未被定义"
 
-#: cp/decl2.c:4216
+#: cp/decl2.c:4217
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare variable %q#D with linkage"
 msgstr "constexpr 变量%2$qD的类型%1$qT不是字面常量"
 
-#: cp/decl2.c:4219
+#: cp/decl2.c:4220
 #, fuzzy, gcc-internal-format
 msgid "type %qT with no linkage used to declare function %q#D with linkage"
 msgstr "%q+#D的早先声明有%qL链接"
 
-#: cp/decl2.c:4407 cp/decl2.c:4410
+#: cp/decl2.c:4408 cp/decl2.c:4411
 #, gcc-internal-format
 msgid "the program should also define %qD"
 msgstr ""
 
-#: cp/decl2.c:4775
+#: cp/decl2.c:4776
 #, fuzzy, gcc-internal-format
 #| msgid "inline function %q+D used but never defined"
 msgid "inline function %qD used but never defined"
 msgstr "使用了内联函数%q+D但从未定义过"
 
-#: cp/decl2.c:4963
+#: cp/decl2.c:4964
 #, gcc-internal-format
 msgid "default argument missing for parameter %P of %q+#D"
 msgstr "%2$q+#D的第 %1$P 个形参缺少默认实参"
@@ -44550,12 +44606,12 @@
 
 #. We mark a lambda conversion op as deleted if we can't
 #. generate it properly; see maybe_add_lambda_conv_op.
-#: cp/decl2.c:5063
+#: cp/decl2.c:5064
 #, gcc-internal-format
 msgid "converting lambda which uses %<...%> to function pointer"
 msgstr "将使用了%<...%>的 Lambda 转换为函数指针"
 
-#: cp/decl2.c:5070
+#: cp/decl2.c:5071
 #, gcc-internal-format
 msgid "use of deleted function %qD"
 msgstr "使用了被删除的函数%qD"
@@ -44864,18 +44920,18 @@
 msgid "invalid initializer for array member %q#D"
 msgstr "成员函数%q+#D的抽象返回类型无效"
 
-#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1345
+#: cp/init.c:797 cp/init.c:821 cp/init.c:2367 cp/method.c:1346
 #, fuzzy, gcc-internal-format
 msgid "uninitialized const member in %q#T"
 msgstr "%<new%>%q#T时常量未初始化"
 
 #: cp/init.c:799 cp/init.c:816 cp/init.c:823 cp/init.c:2352 cp/init.c:2380
-#: cp/method.c:1348 cp/method.c:1359
+#: cp/method.c:1349 cp/method.c:1360
 #, fuzzy, gcc-internal-format
 msgid "%q#D should be initialized"
 msgstr "%q+D将在"
 
-#: cp/init.c:814 cp/init.c:2339 cp/method.c:1356
+#: cp/init.c:814 cp/init.c:2339 cp/method.c:1357
 #, gcc-internal-format
 msgid "uninitialized reference member in %q#T"
 msgstr "%q#T中有未初始化的引用成员"
@@ -44977,7 +45033,7 @@
 msgid "array must be initialized with a brace-enclosed initializer"
 msgstr "数组必须为一个由花括号包围的初始值设定所初始化"
 
-#: cp/init.c:1980 cp/semantics.c:3192
+#: cp/init.c:1980 cp/semantics.c:3205
 #, gcc-internal-format
 msgid "%qT is not a class type"
 msgstr "%qT不是一个类"
@@ -44997,7 +45053,7 @@
 msgid "invalid use of non-static member function %qD"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/init.c:2143 cp/semantics.c:1763
+#: cp/init.c:2143 cp/semantics.c:1766
 #, gcc-internal-format
 msgid "invalid use of non-static data member %qD"
 msgstr "对非静态数据成员%qD的无效使用"
@@ -45194,22 +45250,22 @@
 msgid "because the array element type %qT has variable size"
 msgstr "复合字面量有可变的大小"
 
-#: cp/lambda.c:541
+#: cp/lambda.c:542
 #, gcc-internal-format
 msgid "cannot capture %qE by reference"
 msgstr "无法通过引用捕获%qE"
 
-#: cp/lambda.c:549
+#: cp/lambda.c:552
 #, fuzzy, gcc-internal-format
 msgid "capture by copy of incomplete type %qT"
 msgstr "向 void 的类型转换不会访问具有不完全类型%qT的对象"
 
-#: cp/lambda.c:573
+#: cp/lambda.c:576
 #, fuzzy, gcc-internal-format
 msgid "already captured %qD in lambda expression"
 msgstr "已经在 Lambda 表达式中捕获了%<this%>"
 
-#: cp/lambda.c:772
+#: cp/lambda.c:775
 #, gcc-internal-format
 msgid "%<this%> was not captured for this lambda function"
 msgstr "lambda 函数中无法捕获%<this%>"
@@ -45264,187 +45320,187 @@
 msgid "(if you use %<-fpermissive%>, G++ will accept your code, but allowing the use of an undeclared name is deprecated)"
 msgstr "(如果您使用%<-fpermissive%>，G++ 会接受您的代码，但是允许使用未定义的名称是已弃用的风格)"
 
-#: cp/mangle.c:2335
+#: cp/mangle.c:2340
 #, gcc-internal-format
 msgid "mangling typeof, use decltype instead"
 msgstr "修饰 typeof，请改用 decltype"
 
-#: cp/mangle.c:2339
+#: cp/mangle.c:2344
 #, fuzzy, gcc-internal-format
 msgid "mangling __underlying_type"
 msgstr "修饰未知的定点类型"
 
-#: cp/mangle.c:2622
+#: cp/mangle.c:2627
 #, gcc-internal-format
 msgid "mangling unknown fixed point type"
 msgstr "修饰未知的定点类型"
 
-#: cp/mangle.c:3233
+#: cp/mangle.c:3238
 #, gcc-internal-format
 msgid "use of built-in trait %qE in function signature; use library traits instead"
 msgstr ""
 
-#: cp/mangle.c:3238
+#: cp/mangle.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "mangling %C"
 msgstr "修饰 %C"
 
-#: cp/mangle.c:3315
+#: cp/mangle.c:3320
 #, gcc-internal-format
 msgid "omitted middle operand to %<?:%> operand cannot be mangled"
 msgstr "省略的%<?:%>中操作数不能被修饰"
 
-#: cp/mangle.c:3402
+#: cp/mangle.c:3407
 #, gcc-internal-format
 msgid "string literal in function template signature"
 msgstr "函数模板签名里有字面字符串"
 
-#: cp/mangle.c:3860
+#: cp/mangle.c:3865
 #, gcc-internal-format
 msgid "mangled name for %qD will change in C++17 because the exception specification is part of a function type"
 msgstr ""
 
-#: cp/mangle.c:3894
+#: cp/mangle.c:3899
 #, fuzzy, gcc-internal-format
 msgid "a later -fabi-version= (or =0) avoids this error with a change in mangling"
 msgstr "-fabi-version=4 (or =0) 可以改变向量修饰来避免这个错误"
 
-#: cp/mangle.c:3923
+#: cp/mangle.c:3928
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of %qD changed between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:3929
+#: cp/mangle.c:3934
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d (%D) and -fabi-version=%d (%D)"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4271
+#: cp/mangle.c:4276
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of a thunk for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4276
+#: cp/mangle.c:4281
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/mangle.c:4281
+#: cp/mangle.c:4286
 #, fuzzy, gcc-internal-format
 msgid "the mangled name of the initialization guard variable for %qD changes between -fabi-version=%d and -fabi-version=%d"
 msgstr "%qD修饰后的名字将在 GCC 的未来版本中有变化"
 
-#: cp/method.c:845 cp/method.c:1301
+#: cp/method.c:846 cp/method.c:1302
 #, fuzzy, gcc-internal-format
 msgid "non-static const member %q#D, can%'t use default assignment operator"
 msgstr "非静态的常量成员%q#D，不能使用默认的赋值运算符"
 
-#: cp/method.c:851 cp/method.c:1307
+#: cp/method.c:852 cp/method.c:1308
 #, fuzzy, gcc-internal-format
 msgid "non-static reference member %q#D, can%'t use default assignment operator"
 msgstr "非静态的引用成员%q#D，不能使用默认的赋值运算符"
 
-#: cp/method.c:969
+#: cp/method.c:970
 #, gcc-internal-format
 msgid "synthesized method %qD first required here "
 msgstr "在这里第一次需要生成的方法%qD"
 
-#: cp/method.c:1256
+#: cp/method.c:1257
 #, fuzzy, gcc-internal-format
 msgid "union member %q+D with non-trivial %qD"
 msgstr "未初始化的成员%qD具有%<const%>类型%qT"
 
-#: cp/method.c:1266
+#: cp/method.c:1267
 #, fuzzy, gcc-internal-format
 msgid "defaulted constructor calls non-constexpr %qD"
 msgstr "析构函数不能是%<constexpr%>"
 
-#: cp/method.c:1324
+#: cp/method.c:1325
 #, fuzzy, gcc-internal-format
 msgid "initializer for %q#D is invalid"
 msgstr "%q#D声明有缺少初始值设定"
 
-#: cp/method.c:1376
+#: cp/method.c:1377
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize %q#D"
 msgstr "缺席缺省构造函数不初始化 %q+#D"
 
-#: cp/method.c:1387
+#: cp/method.c:1388
 #, fuzzy, gcc-internal-format
 msgid "copying non-static data member %q#D of rvalue reference type"
 msgstr "非静态数据成员%qD具有 Java 类类型"
 
 #. A trivial constructor doesn't have any NSDMI.
-#: cp/method.c:1616
+#: cp/method.c:1617
 #, fuzzy, gcc-internal-format
 msgid "defaulted default constructor does not initialize any non-static data member"
 msgstr "缺席缺省构造函数不初始化任何非静态数据成员"
 
-#: cp/method.c:1657
+#: cp/method.c:1658
 #, gcc-internal-format
 msgid "defaulted move assignment for %qT calls a non-trivial move assignment operator for virtual base %qT"
 msgstr ""
 
-#: cp/method.c:1774
+#: cp/method.c:1775
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted default constructor"
 msgstr "lambda 闭合类型有删除的缺省构造函数"
 
-#: cp/method.c:1777
+#: cp/method.c:1778
 #, fuzzy, gcc-internal-format
 msgid "a lambda closure type has a deleted copy assignment operator"
 msgstr "lambda 闭合类型有删除的复制指派运算符"
 
-#: cp/method.c:1788
+#: cp/method.c:1789
 #, fuzzy, gcc-internal-format
 msgid "%q#D is implicitly declared as deleted because %qT declares a move constructor or move assignment operator"
 msgstr "%q+#D 是隐含地声明的作为删除的因为 %qT 声明移动建构子或移动指派运算符"
 
-#: cp/method.c:1799
+#: cp/method.c:1800
 #, gcc-internal-format
 msgid "%q#D inherits from multiple base subobjects"
 msgstr ""
 
-#: cp/method.c:1819
+#: cp/method.c:1820
 #, fuzzy, gcc-internal-format
 msgid "%q#D is implicitly deleted because the default definition would be ill-formed:"
 msgstr "%q+#D 是隐含地删除的因为缺省定义会被不当形式的："
 
-#: cp/method.c:1828
+#: cp/method.c:1829
 msgid "%q#F is implicitly deleted because its exception-specification does not match the implicit exception-specification %qX"
 msgstr ""
 
-#: cp/method.c:2148
+#: cp/method.c:2149
 #, gcc-internal-format
 msgid "defaulted declaration %q+D"
 msgstr "默认化声明%q+D"
 
-#: cp/method.c:2150
+#: cp/method.c:2151
 #, gcc-internal-format
 msgid "does not match expected signature %qD"
 msgstr "不匹配%qD预期的签名"
 
-#: cp/method.c:2182
+#: cp/method.c:2183
 #, fuzzy
 msgid "function %q+D defaulted on its redeclaration with an exception-specification that differs from the implicit exception-specification %qX"
 msgstr "首次声明时被默认化的函数%q+D不可以指定异常"
 
-#: cp/method.c:2204
+#: cp/method.c:2205
 #, fuzzy, gcc-internal-format
 msgid "explicitly defaulted function %q+D cannot be declared as constexpr because the implicit declaration is not constexpr:"
 msgstr "明确的缺席函数 %q+D 无法声明的作为 constexpr 因为蕴含声明不是 constexpr："
 
-#: cp/method.c:2250
+#: cp/method.c:2251
 #, fuzzy, gcc-internal-format
 msgid "a template cannot be defaulted"
 msgstr "%qD不能被默认化"
 
-#: cp/method.c:2278
+#: cp/method.c:2279
 #, gcc-internal-format
 msgid "%qD cannot be defaulted"
 msgstr "%qD不能被默认化"
 
-#: cp/method.c:2287
+#: cp/method.c:2288
 #, gcc-internal-format
 msgid "defaulted function %q+D with default argument"
 msgstr "默认化函数%q+D有默认参数"
@@ -45642,94 +45698,94 @@
 msgid "%<%T::%D%> names constructor in %qT"
 msgstr "%<%T::%D%>在%qT内指定了构造函数"
 
-#: cp/name-lookup.c:3459
+#: cp/name-lookup.c:3458
 #, gcc-internal-format
 msgid "cannot inherit constructors from indirect base %qT"
 msgstr ""
 
-#: cp/name-lookup.c:3467
+#: cp/name-lookup.c:3466
 #, gcc-internal-format
 msgid "no members matching %<%T::%D%> in %q#T"
 msgstr "没有与%<%T::%D%>匹配的成员，在%q#T中"
 
-#: cp/name-lookup.c:3559
+#: cp/name-lookup.c:3558
 #, gcc-internal-format
 msgid "declaration of %qD not in a namespace surrounding %qD"
 msgstr "%qD的声明不在包含%qD的命名空间中"
 
-#: cp/name-lookup.c:3567
+#: cp/name-lookup.c:3566
 #, gcc-internal-format
 msgid "explicit qualification in declaration of %qD"
 msgstr "%qD的声明中有显式的限定"
 
-#: cp/name-lookup.c:3640
+#: cp/name-lookup.c:3639
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has not been declared"
 msgid "%qD has not been declared within %D"
 msgstr "%qE未声明"
 
-#: cp/name-lookup.c:3641
+#: cp/name-lookup.c:3640
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D declared as a friend"
 msgid "only here as a friend"
 msgstr "%q+D声明为友元"
 
-#: cp/name-lookup.c:3657
+#: cp/name-lookup.c:3656
 #, gcc-internal-format
 msgid "%qD should have been declared inside %qD"
 msgstr "%qD应当先在%qD内声明"
 
-#: cp/name-lookup.c:3702
+#: cp/name-lookup.c:3701
 #, gcc-internal-format
 msgid "%qD attribute requires a single NTBS argument"
 msgstr "%qD属性需要一个 NTBS 作为实参"
 
-#: cp/name-lookup.c:3709
+#: cp/name-lookup.c:3708
 #, gcc-internal-format
 msgid "%qD attribute is meaningless since members of the anonymous namespace get local symbols"
 msgstr "%qD属性无意义，因为匿名命名空间的成员拥有局部符号"
 
-#: cp/name-lookup.c:3719
+#: cp/name-lookup.c:3718
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on non-inline namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.c:3725
+#: cp/name-lookup.c:3724
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qD attribute on anonymous namespace"
 msgstr "%qs(有%qT)的实参类型无效"
 
-#: cp/name-lookup.c:3744 cp/name-lookup.c:4165
+#: cp/name-lookup.c:3743 cp/name-lookup.c:4164
 #, gcc-internal-format
 msgid "%qD attribute directive ignored"
 msgstr "指定%qD属性被忽略"
 
-#: cp/name-lookup.c:3809
+#: cp/name-lookup.c:3808
 #, gcc-internal-format
 msgid "namespace alias %qD not allowed here, assuming %qD"
 msgstr "这里不允许命名空间别名%qD，假定为%qD"
 
-#: cp/name-lookup.c:4150
+#: cp/name-lookup.c:4149
 #, fuzzy, gcc-internal-format
 msgid "strong using is deprecated; use inline namespaces instead"
 msgstr "已弃用此开关；请改用 -Wextra"
 
-#: cp/name-lookup.c:4153
+#: cp/name-lookup.c:4152
 #, gcc-internal-format
 msgid "strong using only meaningful at namespace scope"
 msgstr "强 using 只在命名空间作用域有意义"
 
-#: cp/name-lookup.c:4157
+#: cp/name-lookup.c:4156
 #, gcc-internal-format
 msgid "current namespace %qD does not enclose strongly used namespace %qD"
 msgstr "当前命名空间%qD并不包含经常被作用的命名空间%qD"
 
-#: cp/name-lookup.c:4506
+#: cp/name-lookup.c:4505
 #, fuzzy, gcc-internal-format
 msgid "maximum limit of %d namespaces searched for %qE"
 msgstr "最大值限制的 %d 命名空间搜索的用于 %qE"
 
-#: cp/name-lookup.c:4522 cp/name-lookup.c:4563
+#: cp/name-lookup.c:4521 cp/name-lookup.c:4562
 #, fuzzy, gcc-internal-format
 #| msgid "suggested alternative:"
 #| msgid_plural "suggested alternatives:"
@@ -45736,33 +45792,33 @@
 msgid "suggested alternative: %qs"
 msgstr "建议的替代："
 
-#: cp/name-lookup.c:4530
+#: cp/name-lookup.c:4529
 #, gcc-internal-format
 msgid "suggested alternative:"
 msgid_plural "suggested alternatives:"
 msgstr[0] "建议的替代："
 
-#: cp/name-lookup.c:4534
+#: cp/name-lookup.c:4533
 #, gcc-internal-format
 msgid "  %qE"
 msgstr "  %qE"
 
-#: cp/name-lookup.c:5962
+#: cp/name-lookup.c:5961
 #, gcc-internal-format
 msgid "argument dependent lookup finds %q+D"
 msgstr "依赖参数的查找找到了%q+D"
 
-#: cp/name-lookup.c:6215
+#: cp/name-lookup.c:6214
 #, fuzzy, gcc-internal-format
 msgid "declaration of std::initializer_list does not match #include <initializer_list>, isn't a template"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/name-lookup.c:6526
+#: cp/name-lookup.c:6525
 #, gcc-internal-format
 msgid "XXX entering pop_everything ()\n"
 msgstr "XXX 进入 pop_everything ()\n"
 
-#: cp/name-lookup.c:6535
+#: cp/name-lookup.c:6534
 #, gcc-internal-format
 msgid "XXX leaving pop_everything ()\n"
 msgstr "XXX 离开 pop_everything ()\n"
@@ -45782,7 +45838,7 @@
 msgid "LEXER_DEBUGGING_ENABLED_P is not set to true"
 msgstr ""
 
-#: cp/parser.c:1359 cp/parser.c:36599
+#: cp/parser.c:1359 cp/parser.c:36622
 #, gcc-internal-format
 msgid "%<#pragma omp declare simd%> not immediately followed by function declaration or definition"
 msgstr ""
@@ -45807,7 +45863,7 @@
 msgid "request for member %qE in non-class type %qT"
 msgstr "在非类类型%2$qT中请求成员%1$qE"
 
-#: cp/parser.c:2842 cp/parser.c:17854
+#: cp/parser.c:2842 cp/parser.c:17877
 #, gcc-internal-format
 msgid "%<%T::%E%> has not been declared"
 msgstr "%<%T::%E%>尚未声明"
@@ -45867,735 +45923,741 @@
 msgid "(perhaps a semicolon is missing after the definition of %qT)"
 msgstr "(%qT的定义末尾可能缺少一个分号)"
 
-#: cp/parser.c:2991
+#: cp/parser.c:2993
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a class template"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/parser.c:2993
+#: cp/parser.c:2995
 #, gcc-internal-format
 msgid "%qE is not a template"
 msgstr "%qE不是一个模板"
 
-#: cp/parser.c:2996
+#: cp/parser.c:2998
 #, gcc-internal-format
 msgid "invalid template-id"
 msgstr "无效的模板 ID"
 
-#: cp/parser.c:3030
+#: cp/parser.c:3032
 #, fuzzy, gcc-internal-format
 #| msgid "floating-point literal cannot appear in a constant-expression"
 msgid "ISO C++ forbids using a floating-point literal in a constant-expression"
 msgstr "浮点字面量不能出现在常量表达式中"
 
-#: cp/parser.c:3034 cp/pt.c:16746
+#: cp/parser.c:3036 cp/pt.c:16828
 #, gcc-internal-format
 msgid "a cast to a type other than an integral or enumeration type cannot appear in a constant-expression"
 msgstr "常量表达式中不能出现目标不是整型或枚举型的类型转换"
 
-#: cp/parser.c:3039
+#: cp/parser.c:3041
 #, fuzzy, gcc-internal-format
 msgid "%<typeid%> operator cannot appear in a constant-expression"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:3043
+#: cp/parser.c:3045
 #, fuzzy, gcc-internal-format
 msgid "non-constant compound literals cannot appear in a constant-expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/parser.c:3047
+#: cp/parser.c:3049
 #, gcc-internal-format
 msgid "a function call cannot appear in a constant-expression"
 msgstr "函数调用不能出现在常量表达式中"
 
-#: cp/parser.c:3051
+#: cp/parser.c:3053
 #, gcc-internal-format
 msgid "an increment cannot appear in a constant-expression"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:3055
+#: cp/parser.c:3057
 #, gcc-internal-format
 msgid "an decrement cannot appear in a constant-expression"
 msgstr "自减不能出现在常量表达式中"
 
-#: cp/parser.c:3059
+#: cp/parser.c:3061
 #, fuzzy, gcc-internal-format
 msgid "an array reference cannot appear in a constant-expression"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:3063
+#: cp/parser.c:3065
 #, fuzzy, gcc-internal-format
 msgid "the address of a label cannot appear in a constant-expression"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:3067
+#: cp/parser.c:3069
 #, fuzzy, gcc-internal-format
 msgid "calls to overloaded operators cannot appear in a constant-expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/parser.c:3071
+#: cp/parser.c:3073
 #, fuzzy, gcc-internal-format
 msgid "an assignment cannot appear in a constant-expression"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:3074
+#: cp/parser.c:3076
 #, fuzzy, gcc-internal-format
 msgid "a comma operator cannot appear in a constant-expression"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:3078
+#: cp/parser.c:3080
 #, fuzzy, gcc-internal-format
 msgid "a call to a constructor cannot appear in a constant-expression"
 msgstr "函数调用不能出现在常量表达式中"
 
-#: cp/parser.c:3082
+#: cp/parser.c:3084
 #, fuzzy, gcc-internal-format
 msgid "a transaction expression cannot appear in a constant-expression"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:3128
+#: cp/parser.c:3130
 #, fuzzy, gcc-internal-format
 msgid "%qs cannot appear in a constant-expression"
 msgstr "自减不能出现在常量表达式中"
 
-#: cp/parser.c:3164
+#: cp/parser.c:3166
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction is only available with -std=c++1z or -std=gnu++1z"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:3169
+#: cp/parser.c:3171
 #, gcc-internal-format
 msgid "invalid use of destructor %qD as a type"
 msgstr "将析构函数%qD用作类型无效"
 
 #. Something like 'unsigned A a;'
-#: cp/parser.c:3172
+#: cp/parser.c:3174
 #, gcc-internal-format
 msgid "invalid combination of multiple type-specifiers"
 msgstr "无效的类型限定符组合"
 
-#: cp/parser.c:3184
+#: cp/parser.c:3186
 #, fuzzy, gcc-internal-format
 #| msgid "%qE does not name a type"
 msgid "%qE does not name a type; did you mean %qs?"
 msgstr "%qE不是一个类型名"
 
-#: cp/parser.c:3188
+#: cp/parser.c:3190
 #, gcc-internal-format
 msgid "%qE does not name a type"
 msgstr "%qE不是一个类型名"
 
-#: cp/parser.c:3197
+#: cp/parser.c:3199
 #, fuzzy, gcc-internal-format
 msgid "C++11 %<constexpr%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:3200
+#: cp/parser.c:3202
 #, fuzzy, gcc-internal-format
 msgid "C++11 %<noexcept%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:3205
+#: cp/parser.c:3207
 #, fuzzy, gcc-internal-format
 msgid "C++11 %<thread_local%> only available with -std=c++11 or -std=gnu++11"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:3208
+#: cp/parser.c:3210
 #, fuzzy, gcc-internal-format
 msgid "%<concept%> only available with -fconcepts"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:3234
+#: cp/parser.c:3236
 #, gcc-internal-format
 msgid "(perhaps %<typename %T::%E%> was intended)"
 msgstr "(也许您本意是想用%<typename %T::%E%>)"
 
-#: cp/parser.c:3252
+#: cp/parser.c:3254
 #, fuzzy, gcc-internal-format
 msgid "%qE in namespace %qE does not name a template type"
 msgstr "%qE不是命名空间%qE中的一个类型名"
 
-#: cp/parser.c:3256
+#: cp/parser.c:3258
 #, gcc-internal-format
 msgid "%qE in namespace %qE does not name a type"
 msgstr "%qE不是命名空间%qE中的一个类型名"
 
 #. A<T>::A<T>()
-#: cp/parser.c:3265
+#: cp/parser.c:3267
 #, gcc-internal-format
 msgid "%<%T::%E%> names the constructor, not the type"
 msgstr "%<%T::%E%>命名了一个构造函数而非类型"
 
-#: cp/parser.c:3268
+#: cp/parser.c:3270
 #, gcc-internal-format
 msgid "and %qT has no template constructors"
 msgstr "且%qT没有模板构造函数"
 
-#: cp/parser.c:3273
+#: cp/parser.c:3275
 #, gcc-internal-format
 msgid "need %<typename%> before %<%T::%E%> because %qT is a dependent scope"
 msgstr "%<%T::%E%>之前需要%<typename%>，因为%qT是一个有依赖的作用域"
 
-#: cp/parser.c:3283
+#: cp/parser.c:3285
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a template type"
 msgstr "%qE不是类%qT中的一个类型名"
 
-#: cp/parser.c:3287
+#: cp/parser.c:3289
 #, fuzzy, gcc-internal-format
 msgid "%qE in %q#T does not name a type"
 msgstr "%qE不是一个类型名"
 
-#: cp/parser.c:3890
+#: cp/parser.c:3892
 #, gcc-internal-format
 msgid "expected string-literal"
 msgstr "需要字面字符串"
 
-#: cp/parser.c:3955
+#: cp/parser.c:3957
 #, fuzzy, gcc-internal-format
 msgid "inconsistent user-defined literal suffixes %qD and %qD in string literal"
 msgstr "不一致用户定义的实字后缀 %qD 和 %qD 在中字串实字"
 
-#: cp/parser.c:4009
+#: cp/parser.c:4011
 #, gcc-internal-format
 msgid "a wide string is invalid in this context"
 msgstr "此上下文中宽字符串无效"
 
-#: cp/parser.c:4124
+#: cp/parser.c:4126
 #, fuzzy, gcc-internal-format
 msgid "unable to find character literal operator %qD with %qT argument"
 msgstr "无法找到字符实字运算符 %qD 与 %qT 参数"
 
-#: cp/parser.c:4225
+#: cp/parser.c:4227
 #, fuzzy, gcc-internal-format
 msgid "integer literal exceeds range of %qT type"
 msgstr "浮点常量超出%qT的范围"
 
-#: cp/parser.c:4232
+#: cp/parser.c:4234
 #, fuzzy, gcc-internal-format
 msgid "floating literal exceeds range of %qT type"
 msgstr "浮点常量超出%qT的范围"
 
-#: cp/parser.c:4236
+#: cp/parser.c:4238
 #, fuzzy, gcc-internal-format
 msgid "floating literal truncated to zero"
 msgstr "浮点常量向零截断"
 
-#: cp/parser.c:4276
+#: cp/parser.c:4278
 #, fuzzy, gcc-internal-format
 msgid "unable to find numeric literal operator %qD"
 msgstr "在类%qs中找不到可溢出的寄存器"
 
-#: cp/parser.c:4278
+#: cp/parser.c:4280
 #, gcc-internal-format
 msgid "use -std=gnu++11 or -fext-numeric-literals to enable more built-in suffixes"
 msgstr ""
 
-#: cp/parser.c:4330
+#: cp/parser.c:4332
 #, fuzzy, gcc-internal-format
 msgid "unable to find string literal operator %qD with %qT, %qT arguments"
 msgstr "无法找到字串实字运算符 %qD 与 %qT，%qT 参数"
 
-#: cp/parser.c:4390 cp/parser.c:12668
+#: cp/parser.c:4392 cp/parser.c:12677
 #, gcc-internal-format
 msgid "expected declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:4652 cp/parser.c:4667
+#: cp/parser.c:4654 cp/parser.c:4669
 #, fuzzy, gcc-internal-format
 #| msgid "expected operator"
 msgid "expected binary operator"
 msgstr "需要操作符"
 
-#: cp/parser.c:4673
+#: cp/parser.c:4675
 #, fuzzy, gcc-internal-format
 #| msgid "expected %<...%>"
 msgid "expected ..."
 msgstr "需要%<...%>"
 
-#: cp/parser.c:4685
+#: cp/parser.c:4687
 #, fuzzy, gcc-internal-format
 #| msgid "lambda-expression in a constant expression"
 msgid "binary expression in operand of fold-expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/parser.c:4688
+#: cp/parser.c:4690
 #, fuzzy, gcc-internal-format
 msgid "conditional expression in operand of fold-expression"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:4696
+#: cp/parser.c:4698
 #, fuzzy, gcc-internal-format
 msgid "mismatched operator in fold-expression"
 msgstr "移位表达式类型不匹配"
 
-#: cp/parser.c:4800
+#: cp/parser.c:4802
 #, gcc-internal-format
 msgid "fixed-point types not supported in C++"
 msgstr "C++ 不支持定点类型"
 
-#: cp/parser.c:4881
+#: cp/parser.c:4883
 #, gcc-internal-format
 msgid "ISO C++ forbids braced-groups within expressions"
 msgstr "ISO C++ 不允许在表达式中使用花括号组"
 
-#: cp/parser.c:4893
+#: cp/parser.c:4895
 #, gcc-internal-format
 msgid "statement-expressions are not allowed outside functions nor in template-argument lists"
 msgstr "语句表达式只能用于函数或模板实参列表内"
 
-#: cp/parser.c:4932
+#: cp/parser.c:4934
 #, fuzzy, gcc-internal-format
 msgid "fold-expressions only available with -std=c++1z or -std=gnu++1z"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:4990 cp/parser.c:5164 cp/parser.c:5342 cp/semantics.c:3530
+#: cp/parser.c:4992 cp/parser.c:5166 cp/parser.c:5344 cp/semantics.c:3543
 #, gcc-internal-format
 msgid "expected primary-expression"
 msgstr "需要元表达式"
 
-#: cp/parser.c:5020
+#: cp/parser.c:5022
 #, gcc-internal-format
 msgid "%<this%> may not be used in this context"
 msgstr "%<this%>不能用在此上下文中"
 
-#: cp/parser.c:5158
+#: cp/parser.c:5160
 #, fuzzy, gcc-internal-format
 msgid "a template declaration cannot appear at block scope"
 msgstr "Objective-C 声明只能出现在全局作用域中"
 
-#: cp/parser.c:5317
+#: cp/parser.c:5319
 #, gcc-internal-format
 msgid "local variable %qD may not appear in this context"
 msgstr "局部变量%qD不应出现在此上下文中"
 
-#: cp/parser.c:5494
+#: cp/parser.c:5501
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression"
 msgstr "? 预期于运算式中"
 
-#: cp/parser.c:5626
+#: cp/parser.c:5633
 #, gcc-internal-format
 msgid "scope %qT before %<~%> is not a class-name"
 msgstr "%<~%>前的作用域%qT不是一个类名"
 
-#: cp/parser.c:5655 cp/parser.c:7675
+#: cp/parser.c:5662 cp/parser.c:7680
 #, fuzzy, gcc-internal-format
 msgid "%<~auto%> only available with -std=c++14 or -std=gnu++14"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:5766
+#: cp/parser.c:5773
 #, gcc-internal-format
 msgid "declaration of %<~%T%> as member of %qT"
 msgstr "%<~%T%>声明为%qT的一个成员"
 
-#: cp/parser.c:5781
+#: cp/parser.c:5788
 #, gcc-internal-format
 msgid "typedef-name %qD used as destructor declarator"
 msgstr "typedef 名%qD用于析构函数声明"
 
-#: cp/parser.c:5817
+#: cp/parser.c:5824
 #, fuzzy, gcc-internal-format
 msgid "literal operator suffixes not preceded by %<_%> are reserved for future standardization"
 msgstr "实字运算符后缀无法前继的由 %<_%>被保留的用于未来标准化"
 
-#: cp/parser.c:5828 cp/parser.c:19884
+#: cp/parser.c:5835 cp/parser.c:19907
 #, fuzzy, gcc-internal-format
 msgid "expected unqualified-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:5935
+#: cp/parser.c:5942
 #, fuzzy, gcc-internal-format
 msgid "found %<:%> in nested-name-specifier, expected %<::%>"
 msgstr "嵌套名指定中使用了不完全的类型%qT"
 
-#: cp/parser.c:6004
+#: cp/parser.c:6009
 #, fuzzy, gcc-internal-format
 msgid "decltype evaluates to %qT, which is not a class or enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/parser.c:6030
+#: cp/parser.c:6035
 #, fuzzy, gcc-internal-format
 msgid "function template-id %qD in nested-name-specifier"
 msgstr "嵌套名指定中使用了不完全的类型%qT"
 
-#: cp/parser.c:6038
+#: cp/parser.c:6043
 #, fuzzy, gcc-internal-format
 msgid "variable template-id %qD in nested-name-specifier"
 msgstr "%C 期待访问指定符"
 
-#: cp/parser.c:6142 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
+#: cp/parser.c:6147 cp/typeck.c:2625 cp/typeck.c:2628 cp/typeck.c:2648
 #, gcc-internal-format
 msgid "%qD is not a template"
 msgstr "%qD不是一个模板"
 
-#: cp/parser.c:6220
+#: cp/parser.c:6225
 #, fuzzy, gcc-internal-format
 msgid "expected nested-name-specifier"
 msgstr "typedef 名不能是嵌套名指定"
 
-#: cp/parser.c:6421 cp/parser.c:8656
+#: cp/parser.c:6426 cp/parser.c:8661
 #, gcc-internal-format
 msgid "types may not be defined in casts"
 msgstr "类型不能定义在类型转换中"
 
-#: cp/parser.c:6505
+#: cp/parser.c:6510
 #, gcc-internal-format
 msgid "types may not be defined in a %<typeid%> expression"
 msgstr "类型不能定义在%<typeid%>表达式中"
 
-#: cp/parser.c:6563
+#: cp/parser.c:6568
 #, gcc-internal-format
 msgid "%<_Cilk_spawn%> must be followed by an expression"
 msgstr ""
 
-#: cp/parser.c:6647
+#: cp/parser.c:6652
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_addressof%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.c:6659 cp/pt.c:17319
+#: cp/parser.c:6664 cp/pt.c:17401
 #, fuzzy, gcc-internal-format
 msgid "wrong number of arguments to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
 
-#: cp/parser.c:6751
+#: cp/parser.c:6756
 #, gcc-internal-format
 msgid "ISO C++ forbids compound-literals"
 msgstr "ISO C++ 不允许复合字面量"
 
-#: cp/parser.c:6810
+#: cp/parser.c:6815
 #, gcc-internal-format
 msgid "two consecutive %<[%> shall only introduce an attribute"
 msgstr ""
 
-#: cp/parser.c:7210
+#: cp/parser.c:7215
 #, fuzzy, gcc-internal-format
 msgid "braced list index is not allowed with array notation"
 msgstr "-client_name 不能和 -dynamiclib 一起使用"
 
-#: cp/parser.c:7420 cp/typeck.c:2513
+#: cp/parser.c:7425 cp/typeck.c:2513
 #, gcc-internal-format
 msgid "invalid use of %qD"
 msgstr "错误地使用了%qD"
 
-#: cp/parser.c:7429
+#: cp/parser.c:7434
 #, fuzzy, gcc-internal-format
 msgid "%<%D::%D%> is not a class member"
 msgstr "%<%D::%D%>不是%qT的成员"
 
-#: cp/parser.c:7727
+#: cp/parser.c:7732
 #, gcc-internal-format
 msgid "non-scalar type"
 msgstr "非标准类型"
 
-#: cp/parser.c:7826
+#: cp/parser.c:7831
 #, gcc-internal-format
 msgid "ISO C++ does not allow %<alignof%> with a non-type"
 msgstr "ISO C++ 不允许对非类型使用%<alignof%>"
 
-#: cp/parser.c:7911
+#: cp/parser.c:7916
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in %<noexcept%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.c:8189
+#: cp/parser.c:8194
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a new-expression"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:8205
+#: cp/parser.c:8210
 #, gcc-internal-format
 msgid "array bound forbidden after parenthesized type-id"
 msgstr "括起的类型标识符后面不能出现数组边界"
 
-#: cp/parser.c:8207
+#: cp/parser.c:8212
 #, gcc-internal-format
 msgid "try removing the parentheses around the type-id"
 msgstr "请尝试删除类型标识符两边的括号"
 
-#: cp/parser.c:8239
+#: cp/parser.c:8244
 #, gcc-internal-format
 msgid "initialization of new-expression for type %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/parser.c:8287
+#: cp/parser.c:8292
 #, fuzzy, gcc-internal-format
 #| msgid "Expected expression type"
 msgid "expected expression-list or type-id"
 msgstr "需要表达式类型"
 
-#: cp/parser.c:8316
+#: cp/parser.c:8321
 #, gcc-internal-format
 msgid "types may not be defined in a new-type-id"
 msgstr "类型不能定义在 new-type-id 中"
 
-#: cp/parser.c:8444
+#: cp/parser.c:8449
 #, gcc-internal-format
 msgid "expression in new-declarator must have integral or enumeration type"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/parser.c:8752
+#: cp/parser.c:8757
 #, gcc-internal-format
 msgid "use of old-style cast"
 msgstr "使用旧式的类型转换"
 
-#: cp/parser.c:8899
+#: cp/parser.c:8904
 #, fuzzy, gcc-internal-format
 msgid "%<>>%> operator is treated as two right angle brackets in C++11"
 msgstr "%<>>%>运算符在 C++0x 中将被认为是两个右尖括号"
 
-#: cp/parser.c:8902
+#: cp/parser.c:8907
 #, gcc-internal-format
 msgid "suggest parentheses around %<>>%> expression"
 msgstr "建议%<>>%>表达式周围加上括号"
 
-#: cp/parser.c:9098
+#: cp/parser.c:9103
 #, gcc-internal-format
 msgid "ISO C++ does not allow ?: with omitted middle operand"
 msgstr "ISO C++ 不允许省略 ?: 的中间操作数"
 
-#: cp/parser.c:9813
+#: cp/parser.c:9822
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in unevaluated context"
 msgstr "已经在 Lambda 表达式中捕获了%<this%>"
 
-#: cp/parser.c:9822
+#: cp/parser.c:9831
 #, fuzzy, gcc-internal-format
 msgid "lambda-expression in template-argument"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/parser.c:9975
+#: cp/parser.c:9984
 #, gcc-internal-format
 msgid "expected end of capture-list"
 msgstr "捕获列表应在此结束"
 
-#: cp/parser.c:9989
+#: cp/parser.c:9998
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %<this%> redundant with by-copy capture default"
 msgstr "明确的 by-copy 截取的 %<this%> 冗余与 by-copy 截取缺省"
 
-#: cp/parser.c:10006
+#: cp/parser.c:10015
 #, fuzzy, gcc-internal-format
 msgid "%<*this%> capture only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10051
+#: cp/parser.c:10060
 #, fuzzy, gcc-internal-format
 msgid "lambda capture initializers only available with -std=c++14 or -std=gnu++14"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10058
+#: cp/parser.c:10067
 #, gcc-internal-format
 msgid "empty initializer for lambda init-capture"
 msgstr ""
 
-#: cp/parser.c:10081
+#: cp/parser.c:10090
 #, fuzzy, gcc-internal-format
 msgid "capture of non-variable %qD "
 msgstr "%qD不是一个变量"
 
-#: cp/parser.c:10084 cp/parser.c:10094 cp/semantics.c:3371 cp/semantics.c:3383
+#: cp/parser.c:10093 cp/parser.c:10103 cp/semantics.c:3384 cp/semantics.c:3396
 #, fuzzy, gcc-internal-format
 msgid "%q#D declared here"
 msgstr "%q+D已在此声明过"
 
-#: cp/parser.c:10090
+#: cp/parser.c:10099
 #, fuzzy, gcc-internal-format
 msgid "capture of variable %qD with non-automatic storage duration"
 msgstr "截取的变量 %qD 与 non-automatic 贮藏体持续时间"
 
-#: cp/parser.c:10128
+#: cp/parser.c:10137
 #, fuzzy, gcc-internal-format
 msgid "explicit by-copy capture of %qD redundant with by-copy capture default"
 msgstr "明确的 by-copy 截取的 %qD 冗余与 by-copy 截取缺省"
 
-#: cp/parser.c:10133
+#: cp/parser.c:10142
 #, fuzzy, gcc-internal-format
 msgid "explicit by-reference capture of %qD redundant with by-reference capture default"
 msgstr "明确的 by-reference 截取的 %qD 冗余与 by-reference 截取缺省"
 
-#: cp/parser.c:10182
+#: cp/parser.c:10191
 #, fuzzy, gcc-internal-format
 msgid "lambda templates are only available with -std=c++14 or -std=gnu++14"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10186
+#: cp/parser.c:10195
 #, fuzzy, gcc-internal-format
 #| msgid "ISO C90 does not support boolean types"
 msgid "ISO C++ does not support lambda templates"
 msgstr "ISO C90 不支持布尔类型"
 
-#: cp/parser.c:10216
+#: cp/parser.c:10225
 #, gcc-internal-format
 msgid "default argument specified for lambda parameter"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/parser.c:10234
+#: cp/parser.c:10243
 #, fuzzy, gcc-internal-format
 #| msgid "duplicate %<volatile%>"
 msgid "duplicate %<mutable%>"
 msgstr "重复的%<volatile%>"
 
-#: cp/parser.c:10282
+#: cp/parser.c:10291
 #, fuzzy, gcc-internal-format
 msgid "%<constexpr%> lambda only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:10734 cp/parser.c:10915
+#: cp/parser.c:10743 cp/parser.c:10924
 #, fuzzy, gcc-internal-format
 msgid "attributes at the beginning of statement are ignored"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:10762
+#: cp/parser.c:10771
 #, gcc-internal-format
 msgid "expected labeled-statement"
 msgstr "需要标号语句"
 
-#: cp/parser.c:10808
+#: cp/parser.c:10817
 #, gcc-internal-format
 msgid "case label %qE not within a switch statement"
 msgstr "case 标号%qE未出现在 switch 语句中"
 
-#: cp/parser.c:10922
+#: cp/parser.c:10931
 #, gcc-internal-format
 msgid "need %<typename%> before %qE because %qT is a dependent scope"
 msgstr "%qE之前需要%<typename%>，因为%qT是一个有依赖的作用域"
 
-#: cp/parser.c:10931
+#: cp/parser.c:10940
 #, gcc-internal-format
 msgid "%<%T::%D%> names the constructor, not the type"
 msgstr "%<%T::%D%>命名了一个构造函数而非类型"
 
-#: cp/parser.c:10978
+#: cp/parser.c:10987
 #, fuzzy, gcc-internal-format
 msgid "compound-statement in constexpr function"
 msgstr "标号位于复合语句末尾"
 
-#: cp/parser.c:11105
+#: cp/parser.c:11114
 #, fuzzy, gcc-internal-format
 msgid "%<if constexpr%> only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++0x %<constexpr%>只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11131
+#: cp/parser.c:11140
 #, fuzzy, gcc-internal-format
 msgid "init-statement in selection statements only available with -std=c++1z or -std=gnu++1z"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:11301 cp/parser.c:27869
+#: cp/parser.c:11310 cp/parser.c:27892
 #, gcc-internal-format
 msgid "expected selection-statement"
 msgstr "需要选择语句"
 
-#: cp/parser.c:11334
+#: cp/parser.c:11343
 #, gcc-internal-format
 msgid "types may not be defined in conditions"
 msgstr "类型不能定义在条件表达式中"
 
-#: cp/parser.c:11757
+#: cp/parser.c:11766
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has incomplete type"
 msgstr "表达式语句类型不完全"
 
-#: cp/parser.c:11795
+#: cp/parser.c:11804
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has an %<end%> member but not a %<begin%>"
 msgstr "range-based %<for%> 运算式的类型 %qT 有 %<end%>成员并不是 %<begin%>"
 
-#: cp/parser.c:11801
+#: cp/parser.c:11810
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> expression of type %qT has a %<begin%> member but not an %<end%>"
 msgstr "range-based %<for%> 运算式的类型 %qT 有 %<begin%>成员并不是 %<end%>"
 
-#: cp/parser.c:11853
+#: cp/parser.c:11862
 #, fuzzy, gcc-internal-format
 msgid "inconsistent begin/end types in range-based %<for%> statement: %qT and %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:11988 cp/parser.c:27872
+#: cp/parser.c:11997 cp/parser.c:27895
 #, gcc-internal-format
 msgid "expected iteration-statement"
 msgstr "需要循环语句"
 
-#: cp/parser.c:12036
+#: cp/parser.c:12045
 #, fuzzy, gcc-internal-format
 msgid "range-based %<for%> loops only available with -std=c++11 or -std=gnu++11"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:12110
+#: cp/parser.c:12119
 #, fuzzy, gcc-internal-format
 msgid "break statement used with Cilk Plus for loop"
 msgstr "OpenMP for 循环中使用了 break 语句"
 
-#: cp/parser.c:12170
+#: cp/parser.c:12179
 #, fuzzy, gcc-internal-format
 msgid "%<goto%> in %<constexpr%> function"
 msgstr "前往目录:"
 
 #. Issue a warning about this use of a GNU extension.
-#: cp/parser.c:12178
+#: cp/parser.c:12187
 #, gcc-internal-format
 msgid "ISO C++ forbids computed gotos"
 msgstr "ISO C++ 不允许计算转移"
 
-#: cp/parser.c:12191 cp/parser.c:27875
+#: cp/parser.c:12200 cp/parser.c:27898
 #, gcc-internal-format
 msgid "expected jump-statement"
 msgstr "需要跳转语句"
 
-#: cp/parser.c:12348 cp/parser.c:23115
+#: cp/parser.c:12357 cp/parser.c:23138
 #, gcc-internal-format
 msgid "extra %<;%>"
 msgstr "多余的%<;%>"
 
-#: cp/parser.c:12591
+#: cp/parser.c:12600
 #, gcc-internal-format
 msgid "%<__label__%> not at the beginning of a block"
 msgstr "%<__label__%>未出现在块起始"
 
-#: cp/parser.c:12805
+#: cp/parser.c:12814
 #, gcc-internal-format
 msgid "non-variable %qD in declaration with more than one declarator with placeholder type"
 msgstr ""
 
-#: cp/parser.c:12825
+#: cp/parser.c:12834
 #, gcc-internal-format
 msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/parser.c:12846
+#: cp/parser.c:12855
 #, gcc-internal-format
 msgid "mixing declarations and function-definitions is forbidden"
 msgstr "不能混合声明和函数定义"
 
-#: cp/parser.c:12870
+#: cp/parser.c:12879
 #, fuzzy, gcc-internal-format
 #| msgid "types may not be defined in exception-declarations"
 msgid "types may not be defined in a for-range-declaration"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:12925
+#: cp/parser.c:12934
 #, fuzzy, gcc-internal-format
 msgid "initializer in range-based %<for%> loop"
 msgstr "初始值设定项中索引范围为空"
 
-#: cp/parser.c:12928
+#: cp/parser.c:12937
 #, gcc-internal-format
 msgid "multiple declarations in range-based %<for%> loop"
 msgstr ""
 
-#: cp/parser.c:12979
+#: cp/parser.c:12988
 #, fuzzy, gcc-internal-format
 msgid "decomposition declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:13028
+#: cp/parser.c:13037
 #, fuzzy, gcc-internal-format
 #| msgid "empty declaration"
 msgid "empty decomposition declaration"
 msgstr "空声明"
 
-#: cp/parser.c:13201
+#: cp/parser.c:13054
+#, fuzzy, gcc-internal-format
+#| msgid "invalid initializer for member function %qD"
+msgid "invalid initializer for structured binding declaration"
+msgstr "成员函数%qD的初始值设定无效"
+
+#: cp/parser.c:13220
 #, gcc-internal-format
 msgid "%<friend%> used outside of class"
 msgstr "%<friend%>用在类外"
@@ -46602,483 +46664,483 @@
 
 #. Complain about `auto' as a storage specifier, if
 #. we're complaining about C++0x compatibility.
-#: cp/parser.c:13265
+#: cp/parser.c:13284
 #, fuzzy, gcc-internal-format
 msgid "%<auto%> changes meaning in C++11; please remove it"
 msgstr "%<auto%>的语义在 C++0x 中将被改变；请考虑删除它"
 
-#: cp/parser.c:13301
+#: cp/parser.c:13320
 #, fuzzy, gcc-internal-format
 msgid "decl-specifier invalid in condition"
 msgstr "%s：无效的新列指定符号“%s”\n"
 
-#: cp/parser.c:13307
+#: cp/parser.c:13326
 #, fuzzy, gcc-internal-format
 #| msgid "%q+D invalid in %q#T"
 msgid "%qD invalid in lambda"
 msgstr "%q+D无效，在%q#T中"
 
-#: cp/parser.c:13400
+#: cp/parser.c:13419
 #, gcc-internal-format
 msgid "class definition may not be declared a friend"
 msgstr "类定义不能被声明为友元"
 
-#: cp/parser.c:13470 cp/parser.c:23522
+#: cp/parser.c:13489 cp/parser.c:23545
 #, gcc-internal-format
 msgid "templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
 
-#: cp/parser.c:13510
+#: cp/parser.c:13529
 #, fuzzy, gcc-internal-format
 msgid "invalid linkage-specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:13597
+#: cp/parser.c:13616
 #, fuzzy, gcc-internal-format
 msgid "static_assert without a message only available with -std=c++1z or -std=gnu++1z"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:13791
+#: cp/parser.c:13810
 #, gcc-internal-format
 msgid "types may not be defined in %<decltype%> expressions"
 msgstr "类型不能定义在%<decltype%>中"
 
-#: cp/parser.c:13934
+#: cp/parser.c:13953
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in a conversion-type-id"
 msgstr "类型不能定义在 new-type-id 中"
 
-#: cp/parser.c:13961
+#: cp/parser.c:13980
 #, gcc-internal-format
 msgid "invalid use of %<auto%> in conversion operator"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:13965
+#: cp/parser.c:13984
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in member template conversion operator can never be deduced"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:14054
+#: cp/parser.c:14073
 #, fuzzy, gcc-internal-format
 msgid "only constructors take member initializers"
 msgstr "只有构造函数才能有基类初始值设定"
 
-#: cp/parser.c:14076
+#: cp/parser.c:14095
 #, gcc-internal-format
 msgid "cannot expand initializer for member %<%D%>"
 msgstr "无法从成员%<%D%>中扩展初始值"
 
-#: cp/parser.c:14088
+#: cp/parser.c:14107
 #, fuzzy, gcc-internal-format
 msgid "mem-initializer for %qD follows constructor delegation"
 msgstr "对%qD的静态声明出现在非静态声明之后"
 
-#: cp/parser.c:14100
+#: cp/parser.c:14119
 #, fuzzy, gcc-internal-format
 msgid "constructor delegation follows mem-initializer for %qD"
 msgstr "建构子 delegation 追随 mem-initializer 用于 %qD"
 
-#: cp/parser.c:14152
+#: cp/parser.c:14171
 #, gcc-internal-format
 msgid "anachronistic old-style base class initializer"
 msgstr "年代错误的旧式基类初始值设定"
 
-#: cp/parser.c:14222
+#: cp/parser.c:14241
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (a qualified member initializer is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(限定的初始值设定隐式地是一个类型)"
 
-#: cp/parser.c:14583
+#: cp/parser.c:14602
 #, fuzzy, gcc-internal-format
 msgid "unexpected keyword; remove space between quotes and suffix identifier"
 msgstr "缺少空格介于 %<“”%>和后缀识别码"
 
-#: cp/parser.c:14589
+#: cp/parser.c:14608
 #, fuzzy, gcc-internal-format
 msgid "expected suffix identifier"
 msgstr "需要标识符或%<(%>"
 
-#: cp/parser.c:14598
+#: cp/parser.c:14617
 #, fuzzy, gcc-internal-format
 msgid "expected empty string after %<operator%> keyword"
 msgstr "%<#pragma message%>后需要一个字符串"
 
-#: cp/parser.c:14604
+#: cp/parser.c:14623
 #, fuzzy, gcc-internal-format
 msgid "invalid encoding prefix in literal operator"
 msgstr "二元操作中中操作数无效"
 
-#: cp/parser.c:14627
+#: cp/parser.c:14646
 #, gcc-internal-format
 msgid "expected operator"
 msgstr "需要操作符"
 
 #. Warn that we do not support `export'.
-#: cp/parser.c:14672
+#: cp/parser.c:14691
 #, gcc-internal-format
 msgid "keyword %<export%> not implemented, and will be ignored"
 msgstr "关键字%<export%>未实现，将被忽略"
 
-#: cp/parser.c:14842
+#: cp/parser.c:14861
 #, fuzzy, gcc-internal-format
 msgid "invalid constrained type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:14850
+#: cp/parser.c:14869
 #, fuzzy, gcc-internal-format
 msgid "cv-qualified type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/parser.c:14935
+#: cp/parser.c:14954
 #, gcc-internal-format
 msgid "variadic constraint introduced without %<...%>"
 msgstr ""
 
-#: cp/parser.c:14999
+#: cp/parser.c:15018
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in default template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:15234 cp/parser.c:15320 cp/parser.c:21348
+#: cp/parser.c:15253 cp/parser.c:15339 cp/parser.c:21371
 #, gcc-internal-format
 msgid "template parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:15238 cp/parser.c:15324
+#: cp/parser.c:15257 cp/parser.c:15343
 #, gcc-internal-format
 msgid "template parameter packs cannot have default arguments"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:15390
+#: cp/parser.c:15409
 #, gcc-internal-format
 msgid "expected template-id"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:15450
+#: cp/parser.c:15469
 #, gcc-internal-format
 msgid "%<<::%> cannot begin a template-argument list"
 msgstr "不能以%<<::%>开始一个模板实参列表"
 
-#: cp/parser.c:15454
+#: cp/parser.c:15473
 #, gcc-internal-format
 msgid "%<<:%> is an alternate spelling for %<[%>. Insert whitespace between %<<%> and %<::%>"
 msgstr "%<<:%>是%<[%>的另一种拼法。请在%<<%>和%<::%>间加上空格"
 
-#: cp/parser.c:15458
+#: cp/parser.c:15477
 #, fuzzy, gcc-internal-format
 msgid "(if you use %<-fpermissive%> or %<-std=c++11%>, or %<-std=gnu++11%> G++ will accept your code)"
 msgstr "(如果您使用%<-fpermissive%>G++ 会接受您的代码)"
 
-#: cp/parser.c:15565
+#: cp/parser.c:15584
 #, gcc-internal-format
 msgid "parse error in template argument list"
 msgstr "模板实参表语法错误"
 
 #. The name does not name a template.
-#: cp/parser.c:15634 cp/parser.c:15761 cp/parser.c:15976
+#: cp/parser.c:15653 cp/parser.c:15784 cp/parser.c:15999
 #, gcc-internal-format
 msgid "expected template-name"
 msgstr "需要模板名"
 
 #. Explain what went wrong.
-#: cp/parser.c:15680
+#: cp/parser.c:15699
 #, gcc-internal-format
 msgid "non-template %qD used as template"
 msgstr "非模板%qD用作模板"
 
-#: cp/parser.c:15682
+#: cp/parser.c:15701
 #, gcc-internal-format
 msgid "use %<%T::template %D%> to indicate that it is a template"
 msgstr "使用%<%T::template %D%>来表示这是一个模板"
 
-#: cp/parser.c:15828
+#: cp/parser.c:15851
 #, gcc-internal-format
 msgid "expected parameter pack before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:15937 cp/parser.c:15955 cp/parser.c:16122
+#: cp/parser.c:15960 cp/parser.c:15978 cp/parser.c:16145
 #, gcc-internal-format
 msgid "expected template-argument"
 msgstr "需要模板实参"
 
-#: cp/parser.c:16097
+#: cp/parser.c:16120
 #, fuzzy, gcc-internal-format
 msgid "invalid non-type template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:16224
+#: cp/parser.c:16247
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<inline%> specifier"
 msgstr "显式实例化不应当使用%<inline%>限定符"
 
-#: cp/parser.c:16228
+#: cp/parser.c:16251
 #, gcc-internal-format
 msgid "explicit instantiation shall not use %<constexpr%> specifier"
 msgstr "显式实例化不应当使用%<constexpr%>限定符"
 
-#: cp/parser.c:16287
+#: cp/parser.c:16310
 #, gcc-internal-format
 msgid "template specialization with C linkage"
 msgstr "特例化模板有 C 链接"
 
-#: cp/parser.c:16507
+#: cp/parser.c:16530
 #, fuzzy, gcc-internal-format
 msgid "expected type specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:16691
+#: cp/parser.c:16714
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in lambda parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:16697
+#: cp/parser.c:16720
 #, fuzzy, gcc-internal-format
 msgid "use of %<auto%> in parameter declaration only available with -std=c++14 or -std=gnu++14"
 msgstr "默认化和被删除的函数只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:16702
+#: cp/parser.c:16725
 #, gcc-internal-format
 msgid "ISO C++ forbids use of %<auto%> in parameter declaration"
 msgstr "ISO C 不允许在参数声明中使用 %<auto%>"
 
-#: cp/parser.c:16847
+#: cp/parser.c:16870
 #, fuzzy, gcc-internal-format
 msgid "expected template-id for type"
 msgstr "需要模板 ID"
 
-#: cp/parser.c:16916
+#: cp/parser.c:16939
 #, gcc-internal-format
 msgid "expected type-name"
 msgstr "需要类型名"
 
-#: cp/parser.c:17265
+#: cp/parser.c:17288
 #, fuzzy, gcc-internal-format
 msgid "elaborated-type-specifier for a scoped enum must not use the %<%D%> keyword"
 msgstr "elaborated-type-specifier 用于范围的 enum 必须不使用 %<%D%>关键字"
 
-#: cp/parser.c:17488
+#: cp/parser.c:17511
 #, gcc-internal-format
 msgid "declaration %qD does not declare anything"
 msgstr "声明%qD没有声明任何东西"
 
-#: cp/parser.c:17575
+#: cp/parser.c:17598
 #, gcc-internal-format
 msgid "attributes ignored on uninstantiated type"
 msgstr "属性在未初始化类型上被忽略"
 
-#: cp/parser.c:17579
+#: cp/parser.c:17602
 #, gcc-internal-format
 msgid "attributes ignored on template instantiation"
 msgstr "属性在模板实例化上被忽略"
 
-#: cp/parser.c:17584
+#: cp/parser.c:17607
 #, gcc-internal-format
 msgid "attributes ignored on elaborated-type-specifier that is not a forward declaration"
 msgstr "类型在非前向声明的详尽类型限定符中被忽略"
 
-#: cp/parser.c:17718
+#: cp/parser.c:17741
 #, gcc-internal-format
 msgid "%qD is an enumeration template"
 msgstr "%qD不是一个枚举模板"
 
-#: cp/parser.c:17729
+#: cp/parser.c:17752
 #, fuzzy, gcc-internal-format
 msgid "%qD does not name an enumeration in %qT"
 msgstr "new 声明中的表达式必须具有整数或枚举类型"
 
-#: cp/parser.c:17744
+#: cp/parser.c:17767
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "unnamed scoped enum is not allowed"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:17799
+#: cp/parser.c:17822
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> or %<{%>"
 msgstr "需要 %<;%>、%<,%> 或 %<)%>"
 
-#: cp/parser.c:17848
+#: cp/parser.c:17871
 #, fuzzy, gcc-internal-format
 msgid "cannot add an enumerator list to a template instantiation"
 msgstr "启用模板自动实例化"
 
-#: cp/parser.c:17862
+#: cp/parser.c:17885
 #, fuzzy, gcc-internal-format
 #| msgid "friend declaration does not name a class or function"
 msgid "nested name specifier %qT for enum declaration does not name a class or namespace"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:17874 cp/parser.c:22605
+#: cp/parser.c:17897 cp/parser.c:22628
 #, gcc-internal-format
 msgid "declaration of %qD in namespace %qD which does not enclose %qD"
 msgstr "%qD声明出现在命名空间%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:17879 cp/parser.c:22610
+#: cp/parser.c:17902 cp/parser.c:22633
 #, gcc-internal-format
 msgid "declaration of %qD in %qD which does not enclose %qD"
 msgstr "%qD声明出现在%qD中，而后者并不包含%qD"
 
-#: cp/parser.c:17891 cp/parser.c:22624
+#: cp/parser.c:17914 cp/parser.c:22647
 #, gcc-internal-format
 msgid "extra qualification not allowed"
 msgstr "不允许有多余的限定"
 
-#: cp/parser.c:17914
+#: cp/parser.c:17937
 #, gcc-internal-format
 msgid "multiple definition of %q#T"
 msgstr "%q#T多次定义"
 
-#: cp/parser.c:17927
+#: cp/parser.c:17950
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ forbids empty unnamed enum"
 msgstr "ISO C++ 不允许枚举自减"
 
-#: cp/parser.c:17947
+#: cp/parser.c:17970
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier without name"
 msgstr "opaque-enum-specifier 而无需名称"
 
-#: cp/parser.c:17950
+#: cp/parser.c:17973
 #, fuzzy, gcc-internal-format
 msgid "opaque-enum-specifier must use a simple identifier"
 msgstr "opaque-enum-specifier 必须使用简单的识别码"
 
-#: cp/parser.c:18128
+#: cp/parser.c:18151
 #, gcc-internal-format
 msgid "%qD is not a namespace-name"
 msgstr "%qD不是一个命名空间名"
 
-#: cp/parser.c:18129
+#: cp/parser.c:18152
 #, gcc-internal-format
 msgid "expected namespace-name"
 msgstr "需要命名空间名"
 
-#: cp/parser.c:18207
+#: cp/parser.c:18230
 #, fuzzy, gcc-internal-format
 #| msgid "%<namespace%> definition is not allowed here"
 msgid "a nested namespace definition cannot have attributes"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:18210
+#: cp/parser.c:18233
 #, fuzzy, gcc-internal-format
 msgid "nested namespace definitions only available with -std=c++1z or -std=gnu++1z"
 msgstr "可变参数模板只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18213
+#: cp/parser.c:18236
 #, fuzzy, gcc-internal-format
 #| msgid "Warn when an inlined function cannot be inlined"
 msgid "a nested namespace definition cannot be inline"
 msgstr "当内联函数无法被内联时给出警告"
 
-#: cp/parser.c:18221
+#: cp/parser.c:18244
 #, fuzzy, gcc-internal-format
 #| msgid "expected identifier"
 msgid "nested identifier required"
 msgstr "需要标识符"
 
-#: cp/parser.c:18249
+#: cp/parser.c:18272
 #, fuzzy, gcc-internal-format
 #| msgid "use of namespace %qD as expression"
 msgid "namespace %qD entered"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/parser.c:18302
+#: cp/parser.c:18325
 #, gcc-internal-format
 msgid "%<namespace%> definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:18453
+#: cp/parser.c:18476
 #, fuzzy, gcc-internal-format
 msgid "pack expansion in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18468
+#: cp/parser.c:18491
 #, gcc-internal-format
 msgid "a template-id may not appear in a using-declaration"
 msgstr "模板标识符不允许出现在 using 声明中"
 
-#: cp/parser.c:18515
+#: cp/parser.c:18538
 #, fuzzy, gcc-internal-format
 msgid "comma-separated list in using-declaration only available with -std=c++1z or -std=gnu++1z"
 msgstr "Lambda 表达式只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:18525
+#: cp/parser.c:18548
 #, fuzzy, gcc-internal-format
 msgid "access declarations are deprecated in favour of using-declarations; suggestion: add the %<using%> keyword"
 msgstr "访问声明被不宜用在中 favour 的 using-declarations；建议：加入 %<using%> 关键字"
 
-#: cp/parser.c:18590
+#: cp/parser.c:18613
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in alias template declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:18743
+#: cp/parser.c:18766
 #, fuzzy, gcc-internal-format
 msgid "%<asm%> in %<constexpr%> function"
 msgstr "函数%qD用作%<asm%>的输出"
 
-#: cp/parser.c:19130
+#: cp/parser.c:19153
 #, fuzzy, gcc-internal-format
 msgid "a function-definition is not allowed here"
 msgstr "在这里不允许使用%<namespace%>定义"
 
-#: cp/parser.c:19141
+#: cp/parser.c:19164
 #, gcc-internal-format
 msgid "an asm-specification is not allowed on a function-definition"
 msgstr "函数定义中不允许出现 asm 指定"
 
-#: cp/parser.c:19145
+#: cp/parser.c:19168
 #, gcc-internal-format
 msgid "attributes are not allowed on a function-definition"
 msgstr "函数定义中不允许有属性"
 
-#: cp/parser.c:19196
+#: cp/parser.c:19219
 #, fuzzy, gcc-internal-format
 msgid "expected constructor, destructor, or type conversion"
 msgstr "预期的建构子、解构式，或类型转换"
 
 #. Anything else is an error.
-#: cp/parser.c:19235 cp/parser.c:21539
+#: cp/parser.c:19258 cp/parser.c:21562
 #, gcc-internal-format
 msgid "expected initializer"
 msgstr "需要初始值设定"
 
-#: cp/parser.c:19316
+#: cp/parser.c:19339
 #, gcc-internal-format
 msgid "initializer provided for function"
 msgstr "为函数提供了初始值设定"
 
-#: cp/parser.c:19350
+#: cp/parser.c:19373
 #, gcc-internal-format
 msgid "attributes after parenthesized initializer ignored"
 msgstr "括起的初始值设定后出现的属性被忽略"
 
-#: cp/parser.c:19355
+#: cp/parser.c:19378
 #, fuzzy, gcc-internal-format
 msgid "non-function %qD declared as implicit template"
 msgstr "函数%q+D重声明为内联的"
 
-#: cp/parser.c:19804
+#: cp/parser.c:19827
 #, gcc-internal-format
 msgid "array bound is not an integer constant"
 msgstr "数组边界不是一个整数常量"
 
-#: cp/parser.c:19930
+#: cp/parser.c:19953
 #, gcc-internal-format
 msgid "cannot define member of dependent typedef %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/parser.c:19934
+#: cp/parser.c:19957
 #, gcc-internal-format
 msgid "%<%T::%E%> is not a type"
 msgstr "%<%T::%E%>不是一个类型"
 
-#: cp/parser.c:19962
+#: cp/parser.c:19985
 #, gcc-internal-format
 msgid "invalid use of constructor as a template"
 msgstr "将构造函数用作模板无效"
 
-#: cp/parser.c:19964
+#: cp/parser.c:19987
 #, gcc-internal-format
 msgid "use %<%T::%D%> instead of %<%T::%D%> to name the constructor in a qualified name"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
@@ -47087,7 +47149,7 @@
 #. here because we do not have enough
 #. information about its original syntactic
 #. form.
-#: cp/parser.c:19981
+#: cp/parser.c:20004
 #, gcc-internal-format
 msgid "invalid declarator"
 msgstr "无效的声明"
@@ -47094,342 +47156,343 @@
 
 #. But declarations with qualified-ids can't appear in a
 #. function.
-#: cp/parser.c:20051
+#: cp/parser.c:20074
 #, fuzzy, gcc-internal-format
 msgid "qualified-id in declaration"
 msgstr "需要一个限定的标识符"
 
-#: cp/parser.c:20076
+#: cp/parser.c:20099
 #, gcc-internal-format
 msgid "expected declarator"
 msgstr "需要声明"
 
-#: cp/parser.c:20179
+#: cp/parser.c:20202
 #, gcc-internal-format
 msgid "%qD is a namespace"
 msgstr "%qD是一个命名空间"
 
-#: cp/parser.c:20181
+#: cp/parser.c:20204
 #, fuzzy, gcc-internal-format
 msgid "cannot form pointer to member of non-class %q#T"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/parser.c:20202
+#: cp/parser.c:20225
 #, fuzzy, gcc-internal-format
 msgid "expected ptr-operator"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:20261
+#: cp/parser.c:20284
 #, gcc-internal-format
 msgid "duplicate cv-qualifier"
 msgstr "重复的 cv 限定"
 
-#: cp/parser.c:20315
+#: cp/parser.c:20338
 #, fuzzy, gcc-internal-format
 msgid "multiple ref-qualifiers"
 msgstr "%q+D的类型限定冲突"
 
-#: cp/parser.c:20352
+#: cp/parser.c:20375
 #, fuzzy, gcc-internal-format
 #| msgid "%<-mfpxx%> requires %<-mlra%>"
 msgid "%E requires %<-fgnu-tm%>"
 msgstr "%<-mfpxx%> 需要 %<-mlra%>"
 
-#: cp/parser.c:20408
+#: cp/parser.c:20431
 #, fuzzy, gcc-internal-format
 msgid "duplicate virt-specifier"
 msgstr "%C处重复访问限定符"
 
-#: cp/parser.c:20679
+#: cp/parser.c:20702
 #, fuzzy, gcc-internal-format
 msgid "missing template arguments after %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
 
-#: cp/parser.c:20685 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
+#: cp/parser.c:20708 cp/typeck2.c:493 cp/typeck2.c:532 cp/typeck2.c:1976
 #, gcc-internal-format
 msgid "invalid use of %qT"
 msgstr "对%qT的使用非法"
 
-#: cp/parser.c:20706
+#: cp/parser.c:20729
 #, gcc-internal-format
 msgid "types may not be defined in template arguments"
 msgstr "不能在模板实参中定义类型"
 
-#: cp/parser.c:20711
+#: cp/parser.c:20734
 #, fuzzy, gcc-internal-format
 msgid "invalid use of %<auto%> in template argument"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/parser.c:20799
+#: cp/parser.c:20822
 #, gcc-internal-format
 msgid "expected type-specifier"
 msgstr "需要类型限定"
 
-#: cp/parser.c:21105
+#: cp/parser.c:21128
 #, gcc-internal-format
 msgid "expected %<,%> or %<...%>"
 msgstr "需要%<,%>或%<...%>"
 
-#: cp/parser.c:21180
+#: cp/parser.c:21203
 #, gcc-internal-format
 msgid "types may not be defined in parameter types"
 msgstr "类型不能定义在参数类型中"
 
-#: cp/parser.c:21332
+#: cp/parser.c:21355
 #, gcc-internal-format
 msgid "default arguments are only permitted for function parameters"
 msgstr "默认参数只允许出现在函数参数中"
 
-#: cp/parser.c:21350
+#: cp/parser.c:21373
 #, fuzzy, gcc-internal-format
 msgid "parameter pack %qD cannot have a default argument"
 msgstr "模板参数包%qD不能有默认参数"
 
-#: cp/parser.c:21356
+#: cp/parser.c:21379
 #, gcc-internal-format
 msgid "template parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:21358
+#: cp/parser.c:21381
 #, fuzzy, gcc-internal-format
 msgid "parameter pack cannot have a default argument"
 msgstr "模板参数包不能有默认参数"
 
-#: cp/parser.c:21745
+#: cp/parser.c:21768
 #, gcc-internal-format
 msgid "ISO C++ does not allow designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:21759
+#: cp/parser.c:21782
 #, fuzzy, gcc-internal-format
 msgid "ISO C++ does not allow C99 designated initializers"
 msgstr "ISO C++ 不允许指定元素初始值设定"
 
-#: cp/parser.c:21879 cp/parser.c:22005
+#: cp/parser.c:21902 cp/parser.c:22028
 #, gcc-internal-format
 msgid "expected class-name"
 msgstr "需要类名"
 
-#: cp/parser.c:22206
+#: cp/parser.c:22229
 #, gcc-internal-format
 msgid "expected %<;%> after class definition"
 msgstr "类定义后需要%<;%>"
 
-#: cp/parser.c:22209
+#: cp/parser.c:22232
 #, gcc-internal-format
 msgid "expected %<;%> after struct definition"
 msgstr "结构定义后需要%<;%>"
 
-#: cp/parser.c:22212
+#: cp/parser.c:22235
 #, gcc-internal-format
 msgid "expected %<;%> after union definition"
 msgstr "联合定义后需要%<;%>"
 
-#: cp/parser.c:22553
+#: cp/parser.c:22576
 #, gcc-internal-format
 msgid "expected %<{%> or %<:%>"
 msgstr "需要%<{%>或%<:%>"
 
-#: cp/parser.c:22564
+#: cp/parser.c:22587
 #, gcc-internal-format
 msgid "cannot specify %<override%> for a class"
 msgstr "不能为类指定 %<override%>"
 
-#: cp/parser.c:22572
+#: cp/parser.c:22595
 #, fuzzy, gcc-internal-format
 msgid "global qualification of class name is invalid"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:22579
+#: cp/parser.c:22602
 #, fuzzy, gcc-internal-format
 msgid "qualified name does not name a class"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:22591
+#: cp/parser.c:22614
 #, gcc-internal-format
 msgid "invalid class name in declaration of %qD"
 msgstr "%qD的声明中类名无效"
 
-#: cp/parser.c:22650
+#: cp/parser.c:22673
 #, gcc-internal-format
 msgid "an explicit specialization must be preceded by %<template <>%>"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:22680
+#: cp/parser.c:22703
 #, gcc-internal-format
 msgid "function template %qD redeclared as a class template"
 msgstr "函数模板%qD重声明为类模板"
 
-#: cp/parser.c:22716
+#: cp/parser.c:22739
 #, fuzzy, gcc-internal-format
 msgid "could not resolve typename type"
 msgstr "缺少用以解析%qE类型的上下文"
 
-#: cp/parser.c:22775
+#: cp/parser.c:22798
 #, fuzzy, gcc-internal-format
 #| msgid "previous definition of %q+#T"
 msgid "previous definition of %q#T"
 msgstr "%q+#T的前一个定义"
 
-#: cp/parser.c:22865 cp/parser.c:27878
+#: cp/parser.c:22888 cp/parser.c:27901
 #, fuzzy, gcc-internal-format
 msgid "expected class-key"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:22889
+#: cp/parser.c:22912
 #, gcc-internal-format
 msgid "ISO C++ forbids typename key in template template parameter; use -std=c++1z or -std=gnu++1z"
 msgstr ""
 
-#: cp/parser.c:22893
+#: cp/parser.c:22916
 #, fuzzy, gcc-internal-format
 msgid "expected %<class%> or %<typename%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:23135
+#: cp/parser.c:23158
 #, fuzzy, gcc-internal-format
 msgid "in C++03 a class-key must be used when declaring a friend"
 msgstr "声明友元时必须使用 class 关键字"
 
-#: cp/parser.c:23153
+#: cp/parser.c:23176
 #, gcc-internal-format
 msgid "friend declaration does not name a class or function"
 msgstr "友元声明没有指定类或函数名"
 
-#: cp/parser.c:23171
+#: cp/parser.c:23194
 #, gcc-internal-format
 msgid "a storage class on an anonymous aggregate in class scope is not allowed"
 msgstr ""
 
-#: cp/parser.c:23375
+#: cp/parser.c:23398
 #, gcc-internal-format
 msgid "pure-specifier on function-definition"
 msgstr "函数定义上有 pure 指定"
 
-#: cp/parser.c:23430
+#: cp/parser.c:23453
 #, fuzzy, gcc-internal-format
 msgid "stray %<,%> at end of member declaration"
 msgstr "可变数组成员没有出现在结构的末尾"
 
-#: cp/parser.c:23442
+#: cp/parser.c:23465
 #, fuzzy, gcc-internal-format
 msgid "expected %<;%> at end of member declaration"
 msgstr "需要声明"
 
-#: cp/parser.c:23516
+#: cp/parser.c:23539
 #, fuzzy, gcc-internal-format
 msgid "invalid pure specifier (only %<= 0%> is allowed)"
 msgstr "指定了无效的 AE 类型(%s)\n"
 
-#: cp/parser.c:23551
+#: cp/parser.c:23574
 #, fuzzy, gcc-internal-format
 msgid "a brace-enclosed initializer is not allowed here"
 msgstr "%qT的初始值设定必须在花括号内"
 
-#: cp/parser.c:23680
-#, gcc-internal-format
-msgid "%<virtual%> specified more than once in base-specified"
+#: cp/parser.c:23703
+#, fuzzy, gcc-internal-format
+#| msgid "%<virtual%> specified more than once in base-specified"
+msgid "%<virtual%> specified more than once in base-specifier"
 msgstr "在基类限定中指定了多于一次的%<virtual%>"
 
-#: cp/parser.c:23700
+#: cp/parser.c:23723
 #, fuzzy, gcc-internal-format
-msgid "more than one access specifier in base-specified"
+msgid "more than one access specifier in base-specifier"
 msgstr "超过一个访问说明符在中 base-specified"
 
-#: cp/parser.c:23724
+#: cp/parser.c:23747
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed outside of templates"
 msgstr "关键字%<typename%>不能在模板以外使用"
 
-#: cp/parser.c:23727
+#: cp/parser.c:23750
 #, gcc-internal-format
 msgid "keyword %<typename%> not allowed in this context (the base class is implicitly a type)"
 msgstr "关键字%<typename%>不允许用在此上下文中(基类隐式地是一个类型)"
 
-#: cp/parser.c:23820 cp/parser.c:23897
+#: cp/parser.c:23843 cp/parser.c:23920
 #, gcc-internal-format
 msgid "types may not be defined in an exception-specification"
 msgstr "类型不能定义在异常规范中"
 
-#: cp/parser.c:23905
+#: cp/parser.c:23928
 #, fuzzy, gcc-internal-format
 #| msgid "due to different exception specifications"
 msgid "ISO C++1z does not allow dynamic exception specifications"
 msgstr "因为异常规范不一致"
 
-#: cp/parser.c:23911
+#: cp/parser.c:23934
 #, fuzzy, gcc-internal-format
 msgid "dynamic exception specifications are deprecated in C++11"
 msgstr "动态异常规格被不宜用在中 C++0x; 使用 %<noexcept%> 作为替代"
 
-#: cp/parser.c:23955
+#: cp/parser.c:23978
 #, fuzzy, gcc-internal-format
 #| msgid "invalid use of %<auto%> in conversion operator"
 msgid "invalid use of %<auto%> in exception-specification"
 msgstr "在转换运算符中使用%<auto%>无效"
 
-#: cp/parser.c:23994
+#: cp/parser.c:24017
 #, fuzzy, gcc-internal-format
 msgid "%<try%> in %<constexpr%> function"
 msgstr "对%qD的重声明在%<constexpr%>方面"
 
-#: cp/parser.c:24107
+#: cp/parser.c:24130
 #, gcc-internal-format
 msgid "types may not be defined in exception-declarations"
 msgstr "类型不能定义在异常声明中"
 
-#: cp/parser.c:24711
+#: cp/parser.c:24734
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix used together with scoped attribute token"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:24725
+#: cp/parser.c:24748
 #, fuzzy, gcc-internal-format
 msgid "expected an identifier for the attribute name"
 msgstr "需要标识符"
 
-#: cp/parser.c:24806
+#: cp/parser.c:24829
 #, fuzzy, gcc-internal-format
 msgid "attribute %<noreturn%> can appear at most once in an attribute-list"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:24810
+#: cp/parser.c:24833
 #, fuzzy, gcc-internal-format
 msgid "attribute %<deprecated%> can appear at most once in an attribute-list"
 msgstr "%qE属性与 %s 属性冲突"
 
-#: cp/parser.c:24847
+#: cp/parser.c:24870
 #, fuzzy, gcc-internal-format
 #| msgid "expected parameter pack before %<...%>"
 msgid "expected attribute before %<...%>"
 msgstr "%<...%>前需要形参包"
 
-#: cp/parser.c:24908
+#: cp/parser.c:24931
 #, fuzzy, gcc-internal-format
 msgid "attribute using prefix only available with -std=c++1z or -std=gnu++1z"
 msgstr "C++0x auto 只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:25122
+#: cp/parser.c:25145
 #, fuzzy, gcc-internal-format
 msgid "%<requires%> only available with -fconcepts"
 msgstr "带作用域的枚举只在 -std=c++0x 或 -std=gnu++0x 下可用"
 
-#: cp/parser.c:25154
+#: cp/parser.c:25177
 #, fuzzy, gcc-internal-format
 msgid "a requires expression cannot appear outside a template"
 msgstr "自增不能出现在常量表达式中"
 
-#: cp/parser.c:25856
+#: cp/parser.c:25879
 #, gcc-internal-format
 msgid "specializing member %<%T::%E%> requires %<template<>%> syntax"
 msgstr "特例化成员%<%T::%E%>需要%<template<>%>语法"
 
-#: cp/parser.c:25861
+#: cp/parser.c:25884
 #, gcc-internal-format
 msgid "invalid declaration of %<%T::%E%>"
 msgstr "%<%T::%E%>声明无效"
 
-#: cp/parser.c:25865
+#: cp/parser.c:25888
 #, gcc-internal-format
 msgid "too few template-parameter-lists"
 msgstr "模板参数表太少"
@@ -47438,491 +47501,491 @@
 #. something like:
 #.
 #. template <class T> template <class U> void S::f();
-#: cp/parser.c:25872
+#: cp/parser.c:25895
 #, gcc-internal-format
 msgid "too many template-parameter-lists"
 msgstr "模板参数表太多"
 
-#: cp/parser.c:26222
+#: cp/parser.c:26245
 #, gcc-internal-format
 msgid "named return values are no longer supported"
 msgstr "有名返回值不再被支持"
 
-#: cp/parser.c:26388
+#: cp/parser.c:26411
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...> or <typename CharT, CharT...>"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:26393
+#: cp/parser.c:26416
 #, fuzzy, gcc-internal-format
 msgid "literal operator template %qD has invalid parameter list.  Expected non-type template argument pack <char...>"
 msgstr "实字运算符模板 %qD 有无效的参数清单。 预期 non-type 模板参数包装 <char...>"
 
-#: cp/parser.c:26462
+#: cp/parser.c:26485
 #, fuzzy, gcc-internal-format
 #| msgid "Enable multiply instructions"
 msgid "empty introduction-list"
 msgstr "启用乘法指令"
 
-#: cp/parser.c:26486
+#: cp/parser.c:26509
 #, fuzzy, gcc-internal-format
 #| msgid "no matching template for %qD found"
 msgid "no matching concept for template-introduction"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/parser.c:26508
+#: cp/parser.c:26531
 #, gcc-internal-format
 msgid "invalid declaration of member template in local class"
 msgstr "局部类中对成员模板的声明无效"
 
-#: cp/parser.c:26517
+#: cp/parser.c:26540
 #, gcc-internal-format
 msgid "template with C linkage"
 msgstr "模板有 C 链接"
 
-#: cp/parser.c:26536
+#: cp/parser.c:26559
 #, fuzzy, gcc-internal-format
 msgid "invalid explicit specialization"
 msgstr "显式特例化前必须有%<template <>%>"
 
-#: cp/parser.c:26640
+#: cp/parser.c:26663
 #, gcc-internal-format
 msgid "template declaration of %<typedef%>"
 msgstr "%<typedef%>的模板声明"
 
-#: cp/parser.c:26691
+#: cp/parser.c:26714
 #, fuzzy, gcc-internal-format
 #| msgid "declaration does not declare anything"
 msgid "a class template declaration must not declare anything else"
 msgstr "没有声明任何东西"
 
-#: cp/parser.c:26737
+#: cp/parser.c:26760
 #, gcc-internal-format
 msgid "explicit template specialization cannot have a storage class"
 msgstr "显式特例化不能有存储类型"
 
-#: cp/parser.c:27045
+#: cp/parser.c:27068
 #, gcc-internal-format
 msgid "%<>>%> should be %<> >%> within a nested template argument list"
 msgstr "在嵌套模板实参列表中应当使用%<> >%>而非%<>>%>"
 
-#: cp/parser.c:27058
+#: cp/parser.c:27081
 #, gcc-internal-format
 msgid "spurious %<>>%>, use %<>%> to terminate a template argument list"
 msgstr "可疑的%<>>%>，使用%<>%>来结束模板实参列表"
 
-#: cp/parser.c:27357
+#: cp/parser.c:27380
 #, gcc-internal-format
 msgid "%<sizeof...%> argument must be surrounded by parentheses"
 msgstr ""
 
-#: cp/parser.c:27513
+#: cp/parser.c:27536
 #, gcc-internal-format
 msgid "invalid use of %qD in linkage specification"
 msgstr "指定链接时使用%qD无效"
 
-#: cp/parser.c:27528
+#: cp/parser.c:27551
 #, gcc-internal-format
 msgid "%<__thread%> before %qD"
 msgstr "%<__thread%>出现在%qD之前"
 
-#: cp/parser.c:27662
+#: cp/parser.c:27685
 #, gcc-internal-format
 msgid "ISO C++ 1998 does not support %<long long%>"
 msgstr "ISO C++ 1998 不支持%<long long%>"
 
-#: cp/parser.c:27670
+#: cp/parser.c:27693
 #, fuzzy, gcc-internal-format
 msgid "both %<__thread%> and %<thread_local%> specified"
 msgstr "线程局部的 COMMON 数据没有实现"
 
-#: cp/parser.c:27672
+#: cp/parser.c:27695
 #, fuzzy, gcc-internal-format
 msgid "duplicate %qD"
 msgstr "重复的标号%qD"
 
-#: cp/parser.c:27694
+#: cp/parser.c:27717
 #, gcc-internal-format
 msgid "duplicate %qs"
 msgstr "重复的%qs"
 
-#: cp/parser.c:27736
+#: cp/parser.c:27759
 #, gcc-internal-format
 msgid "expected %<new%>"
 msgstr "需要%<new%>"
 
-#: cp/parser.c:27739
+#: cp/parser.c:27762
 #, gcc-internal-format
 msgid "expected %<delete%>"
 msgstr "需要%<delete%>"
 
-#: cp/parser.c:27742
+#: cp/parser.c:27765
 #, gcc-internal-format
 msgid "expected %<return%>"
 msgstr "需要%<return%>"
 
-#: cp/parser.c:27748
+#: cp/parser.c:27771
 #, gcc-internal-format
 msgid "expected %<extern%>"
 msgstr "需要%<extern%>"
 
-#: cp/parser.c:27751
+#: cp/parser.c:27774
 #, gcc-internal-format
 msgid "expected %<static_assert%>"
 msgstr "需要%<static_assert%>"
 
-#: cp/parser.c:27754
+#: cp/parser.c:27777
 #, gcc-internal-format
 msgid "expected %<decltype%>"
 msgstr "需要%<decltype%>"
 
-#: cp/parser.c:27757
+#: cp/parser.c:27780
 #, gcc-internal-format
 msgid "expected %<operator%>"
 msgstr "需要%<operator%>"
 
-#: cp/parser.c:27760
+#: cp/parser.c:27783
 #, gcc-internal-format
 msgid "expected %<class%>"
 msgstr "需要%<class%>"
 
-#: cp/parser.c:27763
+#: cp/parser.c:27786
 #, gcc-internal-format
 msgid "expected %<template%>"
 msgstr "需要%<template%>"
 
-#: cp/parser.c:27766
+#: cp/parser.c:27789
 #, gcc-internal-format
 msgid "expected %<namespace%>"
 msgstr "需要%<namespace%>"
 
-#: cp/parser.c:27769
+#: cp/parser.c:27792
 #, gcc-internal-format
 msgid "expected %<using%>"
 msgstr "需要%<using%>"
 
-#: cp/parser.c:27772
+#: cp/parser.c:27795
 #, gcc-internal-format
 msgid "expected %<asm%>"
 msgstr "需要%<asm%>"
 
-#: cp/parser.c:27775
+#: cp/parser.c:27798
 #, gcc-internal-format
 msgid "expected %<try%>"
 msgstr "需要%<try%>"
 
-#: cp/parser.c:27778
+#: cp/parser.c:27801
 #, gcc-internal-format
 msgid "expected %<catch%>"
 msgstr "需要%<catch%>"
 
-#: cp/parser.c:27781
+#: cp/parser.c:27804
 #, gcc-internal-format
 msgid "expected %<throw%>"
 msgstr "需要%<throw%>"
 
-#: cp/parser.c:27784
+#: cp/parser.c:27807
 #, gcc-internal-format
 msgid "expected %<__label__%>"
 msgstr "需要%<__label__%>"
 
-#: cp/parser.c:27787
+#: cp/parser.c:27810
 #, gcc-internal-format
 msgid "expected %<@try%>"
 msgstr "需要%<@try%>"
 
-#: cp/parser.c:27790
+#: cp/parser.c:27813
 #, gcc-internal-format
 msgid "expected %<@synchronized%>"
 msgstr "需要%<@synchronized%>"
 
-#: cp/parser.c:27793
+#: cp/parser.c:27816
 #, gcc-internal-format
 msgid "expected %<@throw%>"
 msgstr "需要%<@throw%>"
 
-#: cp/parser.c:27796
+#: cp/parser.c:27819
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_atomic%>"
 msgstr "对 rpmtxn 数据库异动作业进行除错"
 
-#: cp/parser.c:27799
+#: cp/parser.c:27822
 #, fuzzy, gcc-internal-format
 msgid "expected %<__transaction_relaxed%>"
 msgstr "于 %s 等待异动作业锁定\n"
 
-#: cp/parser.c:27830
+#: cp/parser.c:27853
 #, gcc-internal-format
 msgid "expected %<::%>"
 msgstr "需要%<::%>"
 
-#: cp/parser.c:27842
+#: cp/parser.c:27865
 #, gcc-internal-format
 msgid "expected %<...%>"
 msgstr "需要%<...%>"
 
-#: cp/parser.c:27845
+#: cp/parser.c:27868
 #, gcc-internal-format
 msgid "expected %<*%>"
 msgstr "需要%<*%>"
 
-#: cp/parser.c:27848
+#: cp/parser.c:27871
 #, gcc-internal-format
 msgid "expected %<~%>"
 msgstr "需要%<~%>"
 
-#: cp/parser.c:27854
+#: cp/parser.c:27877
 #, gcc-internal-format
 msgid "expected %<:%> or %<::%>"
 msgstr "需要%<:%>或%<::%>"
 
-#: cp/parser.c:27882
+#: cp/parser.c:27905
 #, gcc-internal-format
 msgid "expected %<class%>, %<typename%>, or %<template%>"
 msgstr "需要%<class%>、%<typename%>或%<template%>"
 
-#: cp/parser.c:28144
+#: cp/parser.c:28167
 #, gcc-internal-format
 msgid "%qs tag used in naming %q#T"
 msgstr "使用了%qs标记，在命名%q#T时"
 
-#: cp/parser.c:28149
+#: cp/parser.c:28172
 #, fuzzy, gcc-internal-format
 msgid "%q#T was previously declared here"
 msgstr "以前在此声明过"
 
-#: cp/parser.c:28170
+#: cp/parser.c:28193
 #, gcc-internal-format
 msgid "%qD redeclared with different access"
 msgstr "%qD重声明时有不同的可访问性"
 
-#: cp/parser.c:28191
+#: cp/parser.c:28214
 #, fuzzy, gcc-internal-format
 msgid "in C++98 %<template%> (as a disambiguator) is only allowed within templates"
 msgstr "用作消歧义的%<template%>只能用于模板内"
 
-#: cp/parser.c:28434
+#: cp/parser.c:28457
 #, gcc-internal-format
 msgid "file ends in default argument"
 msgstr "文件在默认参数处结束"
 
-#: cp/parser.c:28663 cp/parser.c:29972 cp/parser.c:30158
+#: cp/parser.c:28686 cp/parser.c:29995 cp/parser.c:30181
 #, gcc-internal-format
 msgid "misplaced %<@%D%> Objective-C++ construct"
 msgstr "位置错误的%<@%D%>Objective-C++ 构造"
 
-#: cp/parser.c:28732
+#: cp/parser.c:28755
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message receiver expected"
 msgstr "需要指定声明"
 
-#: cp/parser.c:28802
+#: cp/parser.c:28825
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ message argument(s) are expected"
 msgstr "objective-c++ 消息参数被预期"
 
-#: cp/parser.c:28832
+#: cp/parser.c:28855
 #, gcc-internal-format
 msgid "%<@encode%> must specify a type as an argument"
 msgstr "%<@encode%>必须指定一个类型作为实参"
 
-#: cp/parser.c:29238
+#: cp/parser.c:29261
 #, gcc-internal-format
 msgid "invalid Objective-C++ selector name"
 msgstr "无效的 Objective-C++ 选择子名"
 
-#: cp/parser.c:29313 cp/parser.c:29331
+#: cp/parser.c:29336 cp/parser.c:29354
 #, fuzzy, gcc-internal-format
 msgid "objective-c++ method declaration is expected"
 msgstr "%C处数组声明需要另外一维"
 
-#: cp/parser.c:29325 cp/parser.c:29390
+#: cp/parser.c:29348 cp/parser.c:29413
 #, fuzzy, gcc-internal-format
 msgid "method attributes must be specified at the end"
 msgstr "不能为局部变量指定节属性"
 
-#: cp/parser.c:29433
+#: cp/parser.c:29456
 #, fuzzy, gcc-internal-format
 msgid "stray %qs between Objective-C++ methods"
 msgstr "零星的 %qs 介于 Objective-C++ 方法"
 
-#: cp/parser.c:29639 cp/parser.c:29646 cp/parser.c:29653
+#: cp/parser.c:29662 cp/parser.c:29669 cp/parser.c:29676
 #, fuzzy, gcc-internal-format
 msgid "invalid type for instance variable"
 msgstr "不一致的实例变量指定"
 
-#: cp/parser.c:29766
+#: cp/parser.c:29789
 #, gcc-internal-format
 msgid "identifier expected after %<@protocol%>"
 msgstr "%<@protocol%>需要标识符"
 
-#: cp/parser.c:29937
+#: cp/parser.c:29960
 #, fuzzy, gcc-internal-format
 msgid "attributes may not be specified before the %<@%D%> Objective-C++ keyword"
 msgstr "属性可能无法被指定的之前 %<@%D%>Objective-C++ 关键字"
 
-#: cp/parser.c:29944
+#: cp/parser.c:29967
 #, fuzzy, gcc-internal-format
 msgid "prefix attributes are ignored before %<@%D%>"
 msgstr "%qE属性为%qE所忽略"
 
-#: cp/parser.c:30217 cp/parser.c:30224 cp/parser.c:30231
+#: cp/parser.c:30240 cp/parser.c:30247 cp/parser.c:30254
 #, fuzzy, gcc-internal-format
 msgid "invalid type for property"
 msgstr "不能设置只读属性"
 
-#: cp/parser.c:31358
+#: cp/parser.c:31381
 #, fuzzy, gcc-internal-format
 msgid "%<wait%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/parser.c:32053
+#: cp/parser.c:32076
 #, gcc-internal-format
 msgid "invalid reduction-identifier"
 msgstr "无效还原标识符"
 
-#: cp/parser.c:34252
+#: cp/parser.c:34275
 #, gcc-internal-format
 msgid "parenthesized initialization is not allowed in OpenMP %<for%> loop"
 msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
 
-#: cp/parser.c:34255
+#: cp/parser.c:34278
 #, fuzzy, gcc-internal-format
 msgid "parenthesized initialization is not allowed in for-loop"
 msgstr "括起的初始化不允许使用在 OpenMP %<for%>循环中"
 
-#: cp/parser.c:34351
+#: cp/parser.c:34374
 #, gcc-internal-format
 msgid "%<_Cilk_for%> allows expression instead of declaration only in C, not in C++"
 msgstr ""
 
-#: cp/parser.c:34587 cp/pt.c:15520
+#: cp/parser.c:34610 cp/pt.c:15602
 #, gcc-internal-format
 msgid "iteration variable %qD should not be reduction"
 msgstr "迭代变量%qD不应当是 reduction"
 
-#: cp/parser.c:34672
+#: cp/parser.c:34695
 #, fuzzy, gcc-internal-format
 msgid "not enough for loops to collapse"
 msgstr "%L处折叠的 !$OMP DO 没有足够的 DO 循环"
 
-#: cp/parser.c:36630
+#: cp/parser.c:36653
 #, fuzzy, gcc-internal-format
 msgid "vector attribute not immediately followed by a single function declaration or definition"
 msgstr "函数定义中不允许有属性"
 
-#: cp/parser.c:36926
+#: cp/parser.c:36949
 #, fuzzy, gcc-internal-format
 msgid "invalid initializer clause"
 msgstr "无效的初始值设定"
 
-#: cp/parser.c:36954
+#: cp/parser.c:36977
 #, fuzzy, gcc-internal-format
 msgid "expected id-expression (arguments)"
 msgstr "? 预期于运算式中"
 
-#: cp/parser.c:36966
+#: cp/parser.c:36989
 #, gcc-internal-format
 msgid "one of the initializer call arguments should be %<omp_priv%> or %<&omp_priv%>"
 msgstr ""
 
-#: cp/parser.c:37066
+#: cp/parser.c:37089
 #, fuzzy, gcc-internal-format
 msgid "types may not be defined in declare reduction type list"
 msgstr "不能在返回类型中定义新类型"
 
-#: cp/parser.c:37088 cp/semantics.c:5387
+#: cp/parser.c:37111 cp/semantics.c:5400
 #, gcc-internal-format
 msgid "predeclared arithmetic type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37093 cp/semantics.c:5396
+#: cp/parser.c:37116 cp/semantics.c:5409
 #, gcc-internal-format
 msgid "function or array type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37096 cp/pt.c:12313 cp/semantics.c:5402
+#: cp/parser.c:37119 cp/pt.c:12395 cp/semantics.c:5415
 #, gcc-internal-format
 msgid "reference type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37099 cp/semantics.c:5408
+#: cp/parser.c:37122 cp/semantics.c:5421
 #, gcc-internal-format
 msgid "const, volatile or __restrict qualified type %qT in %<#pragma omp declare reduction%>"
 msgstr ""
 
-#: cp/parser.c:37449
+#: cp/parser.c:37472
 #, gcc-internal-format
 msgid "%<#pragma acc routine%> names a set of overloads"
 msgstr ""
 
-#: cp/parser.c:37459
+#: cp/parser.c:37482
 #, fuzzy, gcc-internal-format
 msgid "%qD does not refer to a namespace scope function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
 #. cancel-and-throw is unimplemented.
-#: cp/parser.c:37794
+#: cp/parser.c:37817
 #, gcc-internal-format
 msgid "atomic_cancel"
 msgstr ""
 
-#: cp/parser.c:37837 cp/semantics.c:8699
+#: cp/parser.c:37860 cp/semantics.c:8712
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_relaxed%> without transactional memory support enabled"
 msgstr "%<__transaction_relaxed%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:37839 cp/semantics.c:8701
+#: cp/parser.c:37862 cp/semantics.c:8714
 #, fuzzy, gcc-internal-format
 msgid "%<__transaction_atomic%> without transactional memory support enabled"
 msgstr "%<__transaction_atomic%>而无需 transactional 内存支持已启用"
 
-#: cp/parser.c:38035
+#: cp/parser.c:38058
 #, gcc-internal-format
 msgid "junk at end of %<#pragma GCC pch_preprocess%>"
 msgstr "%<#pragma GCC pch_preprocess%>末尾有垃圾字符"
 
-#: cp/parser.c:38068
+#: cp/parser.c:38091
 #, fuzzy, gcc-internal-format
 msgid "invalid grainsize for _Cilk_for"
 msgstr "错误地使用了%<::%>"
 
-#: cp/parser.c:38323
+#: cp/parser.c:38346
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma GCC ivdep%> must be inside a function"
 msgstr "#pragma GCC memregs 必须出现在所有函数声明之前"
 
-#: cp/parser.c:38344
+#: cp/parser.c:38367
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma simd%> must be inside a function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: cp/parser.c:38356
+#: cp/parser.c:38379
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma cilk grainsize%> must be inside a function"
 msgstr "#pragma GCC optimize 不允许用在函数中"
 
-#: cp/parser.c:38368
+#: cp/parser.c:38391
 #, gcc-internal-format
 msgid "-fcilkplus must be enabled to use %<#pragma cilk grainsize%>"
 msgstr ""
 
-#: cp/parser.c:38425
+#: cp/parser.c:38448
 #, gcc-internal-format
 msgid "inter-module optimizations not implemented for C++"
 msgstr "模块间优化未为 C++ 实现"
 
-#: cp/parser.c:38535
+#: cp/parser.c:38558
 #, fuzzy, gcc-internal-format
 msgid "expected variable-name"
 msgstr "在%C处需要变量名"
 
-#: cp/parser.c:38599
+#: cp/parser.c:38622
 #, fuzzy, gcc-internal-format
 msgid "expected %<,%> or %<)%> after %qE"
 msgstr "{ 预期于运算式中 ? 之后"
 
-#: cp/parser.c:38998
+#: cp/parser.c:39021
 #, fuzzy, gcc-internal-format
 msgid "implicit templates may not be %<virtual%>"
 msgstr "模板不能是%<virtual%>的"
@@ -48015,7 +48078,7 @@
 msgid "candidate is: %#D"
 msgstr "备选为：%+#D"
 
-#: cp/pt.c:1953 cp/semantics.c:5256
+#: cp/pt.c:1953 cp/semantics.c:5269
 #, fuzzy, gcc-internal-format
 msgid "%s %#D"
 msgstr "%s%#D"
@@ -48599,125 +48662,141 @@
 msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
 
-#: cp/pt.c:6609
+#: cp/pt.c:6610
 #, fuzzy, gcc-internal-format
 msgid "%qE is not a valid template argument of type %qT because %qD has no linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6639
+#: cp/pt.c:6625
+#, fuzzy, gcc-internal-format
+msgid "the address of %qD is not a valid template argument"
+msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
+
+#: cp/pt.c:6634
+#, fuzzy, gcc-internal-format
+msgid "the address of the %qT subobject of %qD is not a valid template argument"
+msgstr "%qE不是类型%qT的有效模板实参，因为%qE不是一个变量"
+
+#: cp/pt.c:6641
+#, fuzzy, gcc-internal-format
+#| msgid "%qE is not a valid template argument of type %qT because %qD does not have external linkage"
+msgid "the address of %qD is not a valid template argument because it does not have static storage duration"
+msgstr "%qE不是类型%qT的有效模板实参，因为函数%qD没有外部链接"
+
+#: cp/pt.c:6672
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because of conflicts in cv-qualification"
 msgstr "%qE不是类型%qT的有效模板实参，因为 cv 限定冲突"
 
-#: cp/pt.c:6647
+#: cp/pt.c:6680
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is not an lvalue"
 msgstr "%qE不是类型%qT的有效模板实参，因为它不是一个左值"
 
-#: cp/pt.c:6665
+#: cp/pt.c:6698
 #, gcc-internal-format
 msgid "%q#D is not a valid template argument for type %qT because a reference variable does not have a constant address"
 msgstr "%q#D不是类型%qT的有效模板参数，因为一个引用变量没有常量地址"
 
-#: cp/pt.c:6677
+#: cp/pt.c:6714
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because it is not an object with external linkage"
 msgid "%qE is not a valid template argument for type %qT because it is not an object with linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为它没有外部链接"
 
-#: cp/pt.c:6688
+#: cp/pt.c:6725
 #, fuzzy, gcc-internal-format
 #| msgid "%qE is not a valid template argument for type %qT because object %qD has not external linkage"
 msgid "%qE is not a valid template argument for type %qT because object %qD does not have linkage"
 msgstr "%qE不是类型%qT的有效模板实参，因为对象%qD没有外部链接"
 
-#: cp/pt.c:6735
+#: cp/pt.c:6775
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is a pointer"
 msgstr "%qE不是类型%qT的有效模板实参，因为它是一个指针"
 
-#: cp/pt.c:6737
+#: cp/pt.c:6777
 #, gcc-internal-format
 msgid "try using %qE instead"
 msgstr "尝试使用%qE代替"
 
-#: cp/pt.c:6783 cp/pt.c:6815
+#: cp/pt.c:6823 cp/pt.c:6855
 #, gcc-internal-format
 msgid "%qE is not a valid template argument for type %qT because it is of type %qT"
 msgstr "%qE不是类型%qT的有效模板实参，因为它的类型是%qT"
 
-#: cp/pt.c:6789
+#: cp/pt.c:6829
 #, gcc-internal-format
 msgid "standard conversions are not allowed in this context"
 msgstr "此上下文中不允许标准转换"
 
-#: cp/pt.c:7335
+#: cp/pt.c:7417
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes on template argument %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:7351
+#: cp/pt.c:7433
 #, fuzzy, gcc-internal-format
 msgid "ignoring attributes in template argument %qE"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/pt.c:7461
+#: cp/pt.c:7543
 #, gcc-internal-format
 msgid "injected-class-name %qD used as template template argument"
 msgstr "注入的类名%qD被用作模板的模板参数"
 
-#: cp/pt.c:7490
+#: cp/pt.c:7572
 #, fuzzy, gcc-internal-format
 msgid "invalid use of destructor %qE as a type"
 msgstr "将析构函数%qD用作类型无效"
 
-#: cp/pt.c:7495
+#: cp/pt.c:7577
 #, gcc-internal-format
 msgid "to refer to a type member of a template parameter, use %<typename %E%>"
 msgstr "需要使用某个模板参数的类型成员时，请使用%<typename %E%>"
 
-#: cp/pt.c:7511 cp/pt.c:7533 cp/pt.c:7586
+#: cp/pt.c:7593 cp/pt.c:7615 cp/pt.c:7668
 #, gcc-internal-format
 msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:7516
+#: cp/pt.c:7598
 #, gcc-internal-format
 msgid "  expected a constant of type %qT, got %qT"
 msgstr "需要一个%qT类型的常量，却给出了%qT"
 
-#: cp/pt.c:7521
+#: cp/pt.c:7603
 #, gcc-internal-format
 msgid "  expected a class template, got %qE"
 msgstr "需要一个类模板，却给出了%qE"
 
-#: cp/pt.c:7524
+#: cp/pt.c:7606
 #, gcc-internal-format
 msgid "  expected a type, got %qE"
 msgstr "需要一个类型，却给出了%qE"
 
-#: cp/pt.c:7538
+#: cp/pt.c:7620
 #, gcc-internal-format
 msgid "  expected a type, got %qT"
 msgstr "需要一个类型，却给出了%qT"
 
-#: cp/pt.c:7541
+#: cp/pt.c:7623
 #, gcc-internal-format
 msgid "  expected a class template, got %qT"
 msgstr "需要一个类模板，却给出了%qT"
 
-#: cp/pt.c:7590
+#: cp/pt.c:7672
 #, gcc-internal-format
 msgid "  expected a template of type %qD, got %qT"
 msgstr "需要有%qD类型的模板，却得到了%qT"
 
-#: cp/pt.c:7604
+#: cp/pt.c:7686
 #, fuzzy, gcc-internal-format
 #| msgid "type/value mismatch at argument %d in template parameter list for %qD"
 msgid "constraint mismatch at argument %d in template parameter list for %qD"
 msgstr "实参 %d 的类型/值不匹配，在%qD的模板参数列表中"
 
-#: cp/pt.c:7607
+#: cp/pt.c:7689
 #, fuzzy, gcc-internal-format
 #| msgid "  expected a type, got %qE"
 msgid "  expected %qD but got %qD"
@@ -48725,105 +48804,105 @@
 
 #. Not sure if this is reachable, but it doesn't hurt
 #. to be robust.
-#: cp/pt.c:7652
+#: cp/pt.c:7734
 #, gcc-internal-format
 msgid "type mismatch in nontype parameter pack"
 msgstr "非类型参数包中类型不匹配"
 
-#: cp/pt.c:7675
+#: cp/pt.c:7757
 #, fuzzy, gcc-internal-format
 #| msgid "could not convert template argument %qE to %qT"
 msgid "could not convert template argument %qE from %qT to %qT"
 msgstr "不能将模板参数从%qE转换到%qT"
 
-#: cp/pt.c:7812 cp/pt.c:8118
+#: cp/pt.c:7894 cp/pt.c:8200
 #, gcc-internal-format, gfc-internal-format
 msgid "template argument %d is invalid"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:7827 cp/pt.c:7957 cp/pt.c:8143
+#: cp/pt.c:7909 cp/pt.c:8039 cp/pt.c:8225
 #, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:7953
+#: cp/pt.c:8035
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "wrong number of template arguments (%d, should be at least %d)"
 msgstr "模板参数数目不对(不应是 %d 个而应是 %d 个)"
 
-#: cp/pt.c:7962
+#: cp/pt.c:8044
 #, fuzzy, gcc-internal-format
 #| msgid "provided for %q+D"
 msgid "provided for %qD"
 msgstr "提供给%q+D"
 
-#: cp/pt.c:7987
+#: cp/pt.c:8069
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of alias template %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:7991
+#: cp/pt.c:8073
 #, fuzzy, gcc-internal-format
 msgid "pack expansion argument for non-pack parameter %qD of concept %qD"
 msgstr "包含%qD的类的模板参数有默认参数"
 
-#: cp/pt.c:8084
+#: cp/pt.c:8166
 #, gcc-internal-format
 msgid "so any instantiation with a non-empty parameter pack would be ill-formed"
 msgstr ""
 
-#: cp/pt.c:8146
+#: cp/pt.c:8228
 #, gcc-internal-format
 msgid "provided for %q+D"
 msgstr "提供给%q+D"
 
-#: cp/pt.c:8419
+#: cp/pt.c:8501
 #, fuzzy, gcc-internal-format
 msgid "%q#D is not a function template"
 msgstr "%q#D声明为模板"
 
-#: cp/pt.c:8586
+#: cp/pt.c:8668
 #, gcc-internal-format
 msgid "non-template type %qT used as a template"
 msgstr "非模板类型%qT用作模板"
 
-#: cp/pt.c:8588
+#: cp/pt.c:8670
 #, gcc-internal-format
 msgid "for template declaration %q+D"
 msgstr "对于模板声明%q+D"
 
-#: cp/pt.c:8711
+#: cp/pt.c:8793
 #, fuzzy, gcc-internal-format
 #| msgid "internal consistency failure"
 msgid "template constraint failure"
 msgstr "内部一致性错误"
 
-#: cp/pt.c:9056
+#: cp/pt.c:9138
 #, fuzzy, gcc-internal-format
 msgid "use of invalid variable template %qE"
 msgstr "%qD不是一个模板"
 
-#: cp/pt.c:9492
+#: cp/pt.c:9574
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "template instantiation depth exceeds maximum of %d (use -ftemplate-depth= to increase the maximum)"
 msgstr "在实例化%2$qD时模板实例化深度超过最大值 %1$d(使用 use -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:11093
+#: cp/pt.c:11175
 #, gcc-internal-format
 msgid "fold of empty expansion over %O"
 msgstr ""
 
-#: cp/pt.c:11412
+#: cp/pt.c:11494
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%T%>"
 msgstr "展开%<%T%>时参数包长度不匹配"
 
-#: cp/pt.c:11416
+#: cp/pt.c:11498
 #, gcc-internal-format
 msgid "mismatched argument pack lengths while expanding %<%E%>"
 msgstr "展开%<%E%>时参数包长度不匹配"
 
-#: cp/pt.c:11983
+#: cp/pt.c:12065
 #, fuzzy, gcc-internal-format
 msgid "  when instantiating default argument for call to %D"
 msgstr "重定义%q#D的默认参数"
@@ -48841,273 +48920,273 @@
 #.
 #. is an attempt to declare a variable with function
 #. type.
-#: cp/pt.c:12843
+#: cp/pt.c:12925
 #, gcc-internal-format
 msgid "variable %qD has function type"
 msgstr "变量%qD有函数类型"
 
-#: cp/pt.c:13015
+#: cp/pt.c:13097
 #, gcc-internal-format
 msgid "invalid parameter type %qT"
 msgstr "无效的参数类型%qT"
 
-#: cp/pt.c:13017
+#: cp/pt.c:13099
 #, gcc-internal-format
 msgid "in declaration %q+D"
 msgstr "在声明%q+D中"
 
-#: cp/pt.c:13128
+#: cp/pt.c:13210
 #, gcc-internal-format
 msgid "function returning an array"
 msgstr "函数返回了一个数组"
 
-#: cp/pt.c:13130
+#: cp/pt.c:13212
 #, gcc-internal-format
 msgid "function returning a function"
 msgstr "函数返回了一个函数"
 
-#: cp/pt.c:13170
+#: cp/pt.c:13252
 #, gcc-internal-format
 msgid "creating pointer to member function of non-class type %qT"
 msgstr "生成非类类型%qT的成员函数指针"
 
-#: cp/pt.c:13783
+#: cp/pt.c:13865
 #, gcc-internal-format
 msgid "forming reference to void"
 msgstr "形成对 void 的引用"
 
-#: cp/pt.c:13785
+#: cp/pt.c:13867
 #, gcc-internal-format
 msgid "forming pointer to reference type %qT"
 msgstr "生成指向引用类型%qT的指针"
 
-#: cp/pt.c:13787
+#: cp/pt.c:13869
 #, gcc-internal-format
 msgid "forming reference to reference type %qT"
 msgstr "生成指向引用类型%qT的引用"
 
-#: cp/pt.c:13800
+#: cp/pt.c:13882
 #, fuzzy, gcc-internal-format
 msgid "forming pointer to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的指针"
 
-#: cp/pt.c:13803
+#: cp/pt.c:13885
 #, fuzzy, gcc-internal-format
 msgid "forming reference to qualified function type %qT"
 msgstr "不能声明指向限定函数类型%qT的引用"
 
-#: cp/pt.c:13851
+#: cp/pt.c:13933
 #, gcc-internal-format
 msgid "creating pointer to member of non-class type %qT"
 msgstr "生成非类类型%qT的成员指针"
 
-#: cp/pt.c:13857
+#: cp/pt.c:13939
 #, gcc-internal-format
 msgid "creating pointer to member reference type %qT"
 msgstr "生成引用类型%qT的成员指针"
 
-#: cp/pt.c:13863
+#: cp/pt.c:13945
 #, gcc-internal-format
 msgid "creating pointer to member of type void"
 msgstr "创建指向 void 类型的成员指针"
 
-#: cp/pt.c:13929
+#: cp/pt.c:14011
 #, gcc-internal-format
 msgid "creating array of %qT"
 msgstr "生成%qT的数组"
 
-#: cp/pt.c:13962
+#: cp/pt.c:14044
 #, gcc-internal-format
 msgid "%qT is not a class, struct, or union type"
 msgstr "%qT不是类、结构或联合类型"
 
-#: cp/pt.c:13999
+#: cp/pt.c:14081
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is not an enumeration type"
 msgstr "%qT被解析到非枚举类型%qT"
 
-#: cp/pt.c:14007
+#: cp/pt.c:14089
 #, gcc-internal-format
 msgid "%qT resolves to %qT, which is is not a class type"
 msgstr "%qT被解析到非类类型%qT"
 
-#: cp/pt.c:14071
+#: cp/pt.c:14153
 #, gcc-internal-format
 msgid "empty initializer in lambda init-capture"
 msgstr ""
 
-#: cp/pt.c:14150
+#: cp/pt.c:14232
 #, gcc-internal-format
 msgid "use of %qs in template"
 msgstr "在模板中使用%qs"
 
-#: cp/pt.c:14314
+#: cp/pt.c:14396
 #, gcc-internal-format
 msgid "qualifying type %qT does not match destructor name ~%qT"
 msgstr "限定类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/pt.c:14329
+#: cp/pt.c:14411
 #, gcc-internal-format
 msgid "dependent-name %qE is parsed as a non-type, but instantiation yields a type"
 msgstr "依赖名%qE被解析为非类型，但实例化却产生了一个类型"
 
-#: cp/pt.c:14331
+#: cp/pt.c:14413
 #, gcc-internal-format
 msgid "say %<typename %E%> if a type is meant"
 msgstr "如果您想指定类型，请使用%<typename %E%>"
 
-#: cp/pt.c:14551
+#: cp/pt.c:14633
 #, gcc-internal-format
 msgid "using invalid field %qD"
 msgstr "使用无效字段%qD"
 
-#: cp/pt.c:15018 cp/pt.c:16437
+#: cp/pt.c:15100 cp/pt.c:16519
 #, gcc-internal-format
 msgid "invalid use of pack expansion expression"
 msgstr "对集展开表达式的无效使用"
 
-#: cp/pt.c:15022 cp/pt.c:16441
+#: cp/pt.c:15104 cp/pt.c:16523
 #, gcc-internal-format
 msgid "use %<...%> to expand argument pack"
 msgstr "使用%<...%>来展开实参集"
 
-#: cp/pt.c:17236
+#: cp/pt.c:17318
 #, fuzzy, gcc-internal-format
 msgid "%qD was not declared in this scope, and no declarations were found by argument-dependent lookup at the point of instantiation"
 msgstr "%qD 未被声明在中这个范围，而找不到任何声明是由 argument-dependent 查找于点的实体化"
 
-#: cp/pt.c:17265
+#: cp/pt.c:17347
 #, fuzzy, gcc-internal-format
 msgid "declarations in dependent base %qT are not found by unqualified lookup"
 msgstr "声明在中附属基底 %qT 找不到由资格不符的查找"
 
-#: cp/pt.c:17270
+#: cp/pt.c:17352
 #, fuzzy, gcc-internal-format
 msgid "use %<this->%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:17273
+#: cp/pt.c:17355
 #, fuzzy, gcc-internal-format
 msgid "use %<%T::%D%> instead"
 msgstr "使用%<%T::%D%>而不是%<%T::%D%>来以限定名指定构造函数"
 
-#: cp/pt.c:17278
+#: cp/pt.c:17360
 #, fuzzy, gcc-internal-format
 msgid "%qD declared here, later in the translation unit"
 msgstr "%qE未声明(不在函数内)"
 
-#: cp/pt.c:17611
+#: cp/pt.c:17693
 #, gcc-internal-format
 msgid "%qT is not a class or namespace"
 msgstr "%qT既不是类也不是命名空间"
 
-#: cp/pt.c:17614
+#: cp/pt.c:17696
 #, gcc-internal-format
 msgid "%qD is not a class or namespace"
 msgstr "%qD既不是类也不是命名空间"
 
-#: cp/pt.c:17981
+#: cp/pt.c:18063
 #, fuzzy, gcc-internal-format
 #| msgid "%qT is/uses anonymous type"
 msgid "%qT is/uses unnamed type"
 msgstr "%qT是/使用了匿名类型"
 
-#: cp/pt.c:17983
+#: cp/pt.c:18065
 #, gcc-internal-format
 msgid "template argument for %qD uses local type %qT"
 msgstr "%qD的模板实参使用了局部类型%qT"
 
-#: cp/pt.c:17993
+#: cp/pt.c:18075
 #, gcc-internal-format
 msgid "%qT is a variably modified type"
 msgstr "%qT是一个可变类型"
 
-#: cp/pt.c:18008
+#: cp/pt.c:18090
 #, gcc-internal-format
 msgid "integral expression %qE is not constant"
 msgstr "整型表达式%qE不是常量"
 
-#: cp/pt.c:18026
+#: cp/pt.c:18108
 #, gcc-internal-format
 msgid "  trying to instantiate %qD"
 msgstr "  试图实例化%qD"
 
-#: cp/pt.c:21892
+#: cp/pt.c:21981
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#T"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:21894
+#: cp/pt.c:21983
 #, fuzzy, gcc-internal-format
 msgid "ambiguous template instantiation for %q#D"
 msgstr "有歧义的模板特例化%qD(为%q+D)"
 
-#: cp/pt.c:21900
+#: cp/pt.c:21989
 #, fuzzy
 msgid "%s %#S"
 msgstr "张贴被搁置的文章 [%%s]？(%s/%s/%s/%s/%s)："
 
-#: cp/pt.c:21924 cp/pt.c:22011
+#: cp/pt.c:22013 cp/pt.c:22100
 #, gcc-internal-format
 msgid "explicit instantiation of non-template %q#D"
 msgstr "对非模板%q#D的显式实例化"
 
-#: cp/pt.c:21943
+#: cp/pt.c:22032
 #, gcc-internal-format
 msgid "%qD is not a static data member of a class template"
 msgstr "%qD不是类模板的非静态数据成员"
 
-#: cp/pt.c:21949 cp/pt.c:22006
+#: cp/pt.c:22038 cp/pt.c:22095
 #, gcc-internal-format
 msgid "no matching template for %qD found"
 msgstr "没有找到与%qD匹配的模板"
 
-#: cp/pt.c:21954
+#: cp/pt.c:22043
 #, gcc-internal-format
 msgid "type %qT for explicit instantiation %qD does not match declared type %qT"
 msgstr "类型%qT用于显式实例化%qD时不匹配声明的类型%qT"
 
-#: cp/pt.c:21962
+#: cp/pt.c:22051
 #, gcc-internal-format
 msgid "explicit instantiation of %q#D"
 msgstr "对%q#D的显式实例化"
 
-#: cp/pt.c:21998
+#: cp/pt.c:22087
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#D"
 msgstr "对%q#D重复的显式实例化"
 
-#: cp/pt.c:22021 cp/pt.c:22118
+#: cp/pt.c:22110 cp/pt.c:22207
 #, gcc-internal-format
 msgid "ISO C++ 1998 forbids the use of %<extern%> on explicit instantiations"
 msgstr "ISO C++ 1998 不允许在显式实例化时使用%<extern%>"
 
-#: cp/pt.c:22026 cp/pt.c:22135
+#: cp/pt.c:22115 cp/pt.c:22224
 #, gcc-internal-format
 msgid "storage class %qD applied to template instantiation"
 msgstr "为模板实例化化应用了存储类型%qD"
 
-#: cp/pt.c:22094
+#: cp/pt.c:22183
 #, fuzzy, gcc-internal-format
 msgid "explicit instantiation of non-class template %qD"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:22096
+#: cp/pt.c:22185
 #, gcc-internal-format
 msgid "explicit instantiation of non-template type %qT"
 msgstr "显式实例化非模板类型%qT"
 
-#: cp/pt.c:22105
+#: cp/pt.c:22194
 #, gcc-internal-format
 msgid "explicit instantiation of %q#T before definition of template"
 msgstr "%q#T的显式实例化出现在模板定义之前"
 
-#: cp/pt.c:22123
+#: cp/pt.c:22212
 #, gcc-internal-format
 msgid "ISO C++ forbids the use of %qE on explicit instantiations"
 msgstr "ISO C++ 不允许在显式实例化时使用%qE"
 
-#: cp/pt.c:22169
+#: cp/pt.c:22258
 #, gcc-internal-format
 msgid "duplicate explicit instantiation of %q#T"
 msgstr "对%q#T重复的显式实例化"
@@ -49119,96 +49198,96 @@
 #. member function or static data member of a class template
 #. shall be present in every translation unit in which it is
 #. explicitly instantiated.
-#: cp/pt.c:22719
+#: cp/pt.c:22808
 #, gcc-internal-format
 msgid "explicit instantiation of %qD but no definition available"
 msgstr "显式实例化%qD时没有可用的定义"
 
-#: cp/pt.c:22971
+#: cp/pt.c:23060
 #, gcc-internal-format
 msgid "template instantiation depth exceeds maximum of %d instantiating %q+D, possibly from virtual table generation (use -ftemplate-depth= to increase the maximum)"
 msgstr "在实例化%2$q+D时模板实例化深度超过了最大值 %1$d，可能是由于生成虚函数表所致(使用 -ftemplate-depth= 来增大最大值)"
 
-#: cp/pt.c:23313
+#: cp/pt.c:23402
 #, fuzzy, gcc-internal-format
 msgid "invalid template non-type parameter"
 msgstr "对模板类型参数%qT的使用无效"
 
-#: cp/pt.c:23315
+#: cp/pt.c:23404
 #, fuzzy, gcc-internal-format
 msgid "%q#T is not a valid type for a template non-type parameter"
 msgstr "%q#T不是一个有效的模板常量参数类型"
 
-#: cp/pt.c:24740
+#: cp/pt.c:24862
 #, gcc-internal-format
 msgid "deducing from brace-enclosed initializer list requires #include <initializer_list>"
 msgstr "从花括号中的初始化列表演绎需要 #include <initializer_list>"
 
-#: cp/pt.c:25197
+#: cp/pt.c:25317
 #, fuzzy, gcc-internal-format
 #| msgid "non-template %qD used as template"
 msgid "non-class template %qT used without template arguments"
 msgstr "非模板%qD用作模板"
 
-#: cp/pt.c:25273
+#: cp/pt.c:25393
 #, gcc-internal-format
 msgid "cannot deduce template arguments for copy-initialization of %qT, as it has no non-explicit deduction guides or user-declared constructors"
 msgstr ""
 
-#: cp/pt.c:25287
+#: cp/pt.c:25407
 #, fuzzy, gcc-internal-format
 msgid "class template argument deduction failed:"
 msgstr "模板第 %d 个参数无效"
 
-#: cp/pt.c:25291
+#: cp/pt.c:25411
 #, fuzzy, gcc-internal-format
 #| msgid "function not considered for inlining"
 msgid "explicit deduction guides not considered for copy-initialization"
 msgstr "不考虑内联函数"
 
-#: cp/pt.c:25361
+#: cp/pt.c:25481
 #, gcc-internal-format
 msgid "direct-list-initialization of %<auto%> requires exactly one element"
 msgstr ""
 
-#: cp/pt.c:25364
+#: cp/pt.c:25484
 #, gcc-internal-format
 msgid "for deduction to %<std::initializer_list%>, use copy-list-initialization (i.e. add %<=%> before the %<{%>)"
 msgstr ""
 
-#: cp/pt.c:25396
+#: cp/pt.c:25516
 #, gcc-internal-format
 msgid "%qT as type rather than plain %<decltype(auto)%>"
 msgstr ""
 
-#: cp/pt.c:25431
+#: cp/pt.c:25551
 #, fuzzy, gcc-internal-format
 msgid "unable to deduce lambda return type from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:25433
+#: cp/pt.c:25553
 #, gcc-internal-format
 msgid "unable to deduce %qT from %qE"
 msgstr "无法从%2$qE推导出%1$qT"
 
-#: cp/pt.c:25466
+#: cp/pt.c:25586
 #, gcc-internal-format
 msgid "placeholder constraints not satisfied"
 msgstr ""
 
-#: cp/pt.c:25470
+#: cp/pt.c:25590
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced initializer does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:25474
+#: cp/pt.c:25594
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced return type does not satisfy placeholder constraints"
 msgstr "指令不满足其约束："
 
-#: cp/pt.c:25478
+#: cp/pt.c:25598
 #, fuzzy, gcc-internal-format
 #| msgid "insn does not satisfy its constraints:"
 msgid "deduced expression type does not satisfy placeholder constraints"
@@ -49368,471 +49447,471 @@
 msgid "  since %q+#D declared in base class"
 msgstr "因为%q+#D已在基类中声明过"
 
-#: cp/semantics.c:848
+#: cp/semantics.c:851
 #, gcc-internal-format
 msgid "suggest explicit braces around empty body in %<do%> statement"
 msgstr "建议在%<do%>的空语句体周围显式地加上花括号"
 
-#: cp/semantics.c:1516
+#: cp/semantics.c:1519
 #, gcc-internal-format
 msgid "type of asm operand %qE could not be determined"
 msgstr "无法确定 asm 操作数%qE的类型"
 
-#: cp/semantics.c:1581
+#: cp/semantics.c:1584
 #, gcc-internal-format
 msgid "__label__ declarations are only allowed in function scopes"
 msgstr "__label__ 声明只能出现在函数作用域中"
 
-#: cp/semantics.c:1761
+#: cp/semantics.c:1764
 #, fuzzy, gcc-internal-format
 msgid "invalid use of member %qD in static member function"
 msgstr "对非静态成员函数%qD的使用无效"
 
-#: cp/semantics.c:2447
+#: cp/semantics.c:2460
 #, gcc-internal-format
 msgid "arguments to destructor are not allowed"
 msgstr "析构函数不能有参数"
 
-#: cp/semantics.c:2544
+#: cp/semantics.c:2557
 #, gcc-internal-format
 msgid "%<this%> is unavailable for static member functions"
 msgstr "静态成员函数中不能使用%<this%>"
 
-#: cp/semantics.c:2546
+#: cp/semantics.c:2559
 #, gcc-internal-format
 msgid "invalid use of %<this%> in non-member function"
 msgstr "在非成员函数中使用%<this%>无效"
 
-#: cp/semantics.c:2548
+#: cp/semantics.c:2561
 #, gcc-internal-format
 msgid "invalid use of %<this%> at top level"
 msgstr "在文件作用域使用%<this%>无效"
 
-#: cp/semantics.c:2570
+#: cp/semantics.c:2583
 #, gcc-internal-format
 msgid "invalid qualifying scope in pseudo-destructor name"
 msgstr "伪析构函数名的限定作用域无效"
 
-#: cp/semantics.c:2578 cp/typeck.c:2545
+#: cp/semantics.c:2591 cp/typeck.c:2545
 #, gcc-internal-format
 msgid "qualified type %qT does not match destructor name ~%qT"
 msgstr "限定的类型%qT不匹配析构函数名 ~%qT"
 
-#: cp/semantics.c:2600
+#: cp/semantics.c:2613
 #, gcc-internal-format
 msgid "%qE is not of type %qT"
 msgstr "%qE的类型不是%qT"
 
-#: cp/semantics.c:2671
+#: cp/semantics.c:2684
 #, gcc-internal-format
 msgid "compound literal of non-object type %qT"
 msgstr "非对象类型%qT的复合字面常量"
 
-#: cp/semantics.c:2799
+#: cp/semantics.c:2812
 #, gcc-internal-format
 msgid "template type parameters must use the keyword %<class%> or %<typename%>"
 msgstr "模板形参必须使用%<class%>或%<typename%>关键字"
 
-#: cp/semantics.c:2849
+#: cp/semantics.c:2862
 #, gcc-internal-format
 msgid "invalid use of type %qT as a default value for a template template-parameter"
 msgstr "将类型%qT用作模板的模板参数的默认值无效"
 
-#: cp/semantics.c:2852
+#: cp/semantics.c:2865
 #, gcc-internal-format
 msgid "invalid default argument for a template template parameter"
 msgstr "模板的模板形参的默认实参无效"
 
-#: cp/semantics.c:2869
+#: cp/semantics.c:2882
 #, gcc-internal-format
 msgid "definition of %q#T inside template parameter list"
 msgstr "在模板参数列表中定义了%q#T"
 
-#: cp/semantics.c:2900
+#: cp/semantics.c:2913
 #, gcc-internal-format
 msgid "invalid definition of qualified type %qT"
 msgstr "对限定类型%qT的定义无效"
 
-#: cp/semantics.c:3187
+#: cp/semantics.c:3200
 #, gcc-internal-format
 msgid "invalid base-class specification"
 msgstr "无效的基类"
 
-#: cp/semantics.c:3348
+#: cp/semantics.c:3361
 #, fuzzy, gcc-internal-format
 msgid "cannot capture member %qD of anonymous union"
 msgstr "匿名联合中出现保护成员%q+#D"
 
-#: cp/semantics.c:3361 cp/semantics.c:9407
+#: cp/semantics.c:3374 cp/semantics.c:9420
 #, gcc-internal-format
 msgid "%qD is not captured"
 msgstr "%qD未被捕获"
 
-#: cp/semantics.c:3366
+#: cp/semantics.c:3379
 #, fuzzy, gcc-internal-format
 msgid "the lambda has no capture-default"
 msgstr "为 lambda 形参指定了默认参数"
 
-#: cp/semantics.c:3368
+#: cp/semantics.c:3381
 #, gcc-internal-format
 msgid "lambda in local class %q+T cannot capture variables from the enclosing context"
 msgstr ""
 
-#: cp/semantics.c:3380
+#: cp/semantics.c:3393
 #, fuzzy, gcc-internal-format
 msgid "use of local variable with automatic storage from containing function"
 msgstr "在包含函数中使用%<auto%>变量"
 
-#: cp/semantics.c:3382
+#: cp/semantics.c:3395
 #, fuzzy, gcc-internal-format
 msgid "use of parameter from containing function"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/semantics.c:3514
+#: cp/semantics.c:3527
 #, fuzzy, gcc-internal-format
 msgid "use of parameter outside function body"
 msgstr "已弃用为非函数指定默认参数"
 
-#: cp/semantics.c:3524
+#: cp/semantics.c:3537
 #, fuzzy, gcc-internal-format
 #| msgid "mismatched arguments"
 msgid "missing template arguments"
 msgstr "参数不匹配"
 
-#: cp/semantics.c:3551
+#: cp/semantics.c:3564
 #, gcc-internal-format
 msgid "template parameter %qD of type %qT is not allowed in an integral constant expression because it is not of integral or enumeration type"
 msgstr "模板参数%qD(类型为%qT)不允许出现在整数表达式中，因为它的类型不是整数或枚举"
 
-#: cp/semantics.c:3648
+#: cp/semantics.c:3661
 #, gcc-internal-format
 msgid "use of namespace %qD as expression"
 msgstr "命名空间%qD被用作表达式"
 
-#: cp/semantics.c:3653
+#: cp/semantics.c:3666
 #, gcc-internal-format
 msgid "use of class template %qT as expression"
 msgstr "将类模板%qT用作表达式"
 
 #. Ambiguous reference to base members.
-#: cp/semantics.c:3659
+#: cp/semantics.c:3672
 #, gcc-internal-format
 msgid "request for member %qD is ambiguous in multiple inheritance lattice"
 msgstr "在多继承网格中对%qD的访问有歧义"
 
-#: cp/semantics.c:3685
+#: cp/semantics.c:3698
 #, gcc-internal-format
 msgid "%qD cannot appear in a constant-expression"
 msgstr "%qD不能出现在常量表达式中"
 
-#: cp/semantics.c:3818
+#: cp/semantics.c:3831
 #, gcc-internal-format
 msgid "type of %qE is unknown"
 msgstr "%qE的类型未知"
 
-#: cp/semantics.c:3847
+#: cp/semantics.c:3860
 #, fuzzy, gcc-internal-format
 msgid "%qT is not an enumeration type"
 msgstr "%qD不是一个枚举名"
 
 #. Parameter packs can only be used in templates
-#: cp/semantics.c:4002
+#: cp/semantics.c:4015
 #, fuzzy, gcc-internal-format
 msgid "Parameter pack __bases only valid in template declaration"
 msgstr "为形参声明指定了无效的存储类"
 
-#: cp/semantics.c:4031
+#: cp/semantics.c:4044
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to destructor %<~%T%>"
 msgstr "不能为析构函数%<~%T%>使用%<offsetof%>"
 
-#: cp/semantics.c:4040
+#: cp/semantics.c:4053
 #, gcc-internal-format
 msgid "second operand of %<offsetof%> is neither a single identifier nor a sequence of member accesses and array references"
 msgstr ""
 
-#: cp/semantics.c:4048
+#: cp/semantics.c:4061
 #, gcc-internal-format
 msgid "cannot apply %<offsetof%> to member function %qD"
 msgstr "不能为成员函数%qD应用%<offsetof%>"
 
-#: cp/semantics.c:4061
+#: cp/semantics.c:4074
 #, gcc-internal-format
 msgid "offsetof within non-standard-layout type %qT is undefined"
 msgstr ""
 
-#: cp/semantics.c:4572 cp/semantics.c:6061 cp/semantics.c:6132
-#: cp/semantics.c:6175 cp/semantics.c:6540 cp/semantics.c:6639
-#: cp/semantics.c:6782
+#: cp/semantics.c:4585 cp/semantics.c:6074 cp/semantics.c:6145
+#: cp/semantics.c:6188 cp/semantics.c:6553 cp/semantics.c:6652
+#: cp/semantics.c:6795
 #, gcc-internal-format
 msgid "%<this%> allowed in OpenMP only in %<declare simd%> clauses"
 msgstr ""
 
-#: cp/semantics.c:5253
+#: cp/semantics.c:5266
 #, fuzzy, gcc-internal-format
 msgid "user defined reduction lookup is ambiguous"
 msgstr "对%qD的引用有歧义"
 
-#: cp/semantics.c:5526
+#: cp/semantics.c:5539
 #, fuzzy, gcc-internal-format
 msgid "%qE in %<reduction%> clause is a zero size array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:5574
+#: cp/semantics.c:5587
 #, fuzzy, gcc-internal-format
 #| msgid "%qE has invalid type for %<reduction%>"
 msgid "%qE has const type for %<reduction%>"
 msgstr "%qE的类型对%<reduction%>无效"
 
-#: cp/semantics.c:5686
+#: cp/semantics.c:5699
 #, gcc-internal-format
 msgid "user defined reduction with constructor initializer for base class %qT"
 msgstr ""
 
-#: cp/semantics.c:5920
+#: cp/semantics.c:5933
 #, gcc-internal-format
 msgid "linear clause with %qs modifier applied to non-reference variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5935
+#: cp/semantics.c:5948
 #, gcc-internal-format
 msgid "linear clause applied to non-integral, non-floating, non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5947
+#: cp/semantics.c:5960
 #, gcc-internal-format
 msgid "linear clause applied to non-integral non-pointer variable with %qT type"
 msgstr ""
 
-#: cp/semantics.c:5969
+#: cp/semantics.c:5982
 #, fuzzy, gcc-internal-format
 msgid "linear step expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6072
+#: cp/semantics.c:6085
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %qs"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:6144
+#: cp/semantics.c:6157
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<firstprivate%>"
 msgstr "%qD在%<firstprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6187
+#: cp/semantics.c:6200
 #, gcc-internal-format
 msgid "%qD is not a variable in clause %<lastprivate%>"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6232
+#: cp/semantics.c:6245
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6246
+#: cp/semantics.c:6259
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> static value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6280
+#: cp/semantics.c:6293
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6283
+#: cp/semantics.c:6296
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6287
+#: cp/semantics.c:6300
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6291
+#: cp/semantics.c:6304
 #, fuzzy, gcc-internal-format
 msgid "%qs expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6309
+#: cp/semantics.c:6322
 #, fuzzy, gcc-internal-format
 msgid "%<gang%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6313
+#: cp/semantics.c:6326
 #, fuzzy, gcc-internal-format
 msgid "%<vector%> length value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6318
+#: cp/semantics.c:6331
 #, fuzzy, gcc-internal-format
 msgid "%<worker%> num value must be positive"
 msgstr "%<num_threads%>值必须为正"
 
-#: cp/semantics.c:6370
+#: cp/semantics.c:6383
 #, gcc-internal-format
 msgid "schedule chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6413
+#: cp/semantics.c:6426
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6426
+#: cp/semantics.c:6439
 #, fuzzy, gcc-internal-format
 msgid "%qs length expression must be positive constant integer expression"
 msgstr "%H折叠变量需要正整常数表达式"
 
-#: cp/semantics.c:6445
+#: cp/semantics.c:6458
 #, fuzzy, gcc-internal-format
 msgid "%<async%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6473
+#: cp/semantics.c:6486
 #, fuzzy, gcc-internal-format
 msgid "%<thread_limit%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:6502
+#: cp/semantics.c:6515
 #, fuzzy, gcc-internal-format
 msgid "%<device%> id must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6523
+#: cp/semantics.c:6536
 #, fuzzy, gcc-internal-format
 msgid "%<dist_schedule%> chunk size expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6550
+#: cp/semantics.c:6563
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<aligned%> clause"
 msgstr "%qD在%<lastprivate%>子句中不是一个变量"
 
-#: cp/semantics.c:6564
+#: cp/semantics.c:6577
 #, gcc-internal-format
 msgid "%qE in %<aligned%> clause is neither a pointer nor an array nor a reference to pointer or array"
 msgstr ""
 
-#: cp/semantics.c:6570
+#: cp/semantics.c:6583
 #, fuzzy, gcc-internal-format
 msgid "%qD appears more than once in %<aligned%> clauses"
 msgstr "%qD在数据子句中多次出现"
 
-#: cp/semantics.c:6583
+#: cp/semantics.c:6596
 #, fuzzy, gcc-internal-format
 msgid "%<aligned%> clause alignment expression must be integral"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:6632
+#: cp/semantics.c:6645
 #, fuzzy, gcc-internal-format
 msgid "%qD is not a variable in %<depend%> clause"
 msgstr "%qD在子句%qs中不是一个变量"
 
-#: cp/semantics.c:6917
+#: cp/semantics.c:6930
 #, gcc-internal-format
 msgid "overloaded function name %qE in clause %qs"
 msgstr ""
 
-#: cp/semantics.c:6921
+#: cp/semantics.c:6934
 #, fuzzy, gcc-internal-format
 #| msgid "too many %qs clauses"
 msgid "template %qE in clause %qs"
 msgstr "太多的%qs子句"
 
-#: cp/semantics.c:6986
+#: cp/semantics.c:6999
 #, fuzzy, gcc-internal-format
 msgid "%<grainsize%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7015
+#: cp/semantics.c:7028
 #, fuzzy, gcc-internal-format
 msgid "%<priority%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7044
+#: cp/semantics.c:7057
 #, fuzzy, gcc-internal-format
 msgid "%<num_tasks%> expression must be integral"
 msgstr "num_threads 表达式必须是整型的"
 
-#: cp/semantics.c:7073
+#: cp/semantics.c:7086
 #, fuzzy, gcc-internal-format
 msgid "%qs variable is neither a pointer, nor an array nor reference to pointer or array"
 msgstr "向量 delete 的实参类型既非指针也非数组"
 
-#: cp/semantics.c:7113
+#: cp/semantics.c:7126
 #, fuzzy, gcc-internal-format
 msgid "%<tile%> argument needs integral type"
 msgstr "调度块大小表达式必须为整型"
 
-#: cp/semantics.c:7532
+#: cp/semantics.c:7545
 #, gcc-internal-format
 msgid "%<threadprivate%> %qD is not file, namespace or block scope variable"
 msgstr "%<threadprivate%>%qD不是一个文件、命名空间或块作用域变量"
 
-#: cp/semantics.c:7546
+#: cp/semantics.c:7559
 #, gcc-internal-format
 msgid "%<threadprivate%> %qE directive not in %qT definition"
 msgstr "%<threadprivate%>%qE指示不在%qT定义中"
 
-#: cp/semantics.c:7751
+#: cp/semantics.c:7764
 #, gcc-internal-format
 msgid "difference between %qE and %qD does not have integer type"
 msgstr "%qE和%qD之间的差不具有整数类型"
 
-#: cp/semantics.c:8179
+#: cp/semantics.c:8192
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp simd%> used with class iteration variable %qE"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:8522 cp/semantics.c:8532
+#: cp/semantics.c:8535 cp/semantics.c:8545
 #, fuzzy, gcc-internal-format
 msgid "%<#pragma omp atomic update%> uses two different expressions for memory"
 msgstr "%<# pragma omp 基元的 update%>使用两不同的变量用于内存"
 
-#: cp/semantics.c:8825
+#: cp/semantics.c:8838
 #, fuzzy, gcc-internal-format
 #| msgid "static assertion failed: %E"
 msgid "static assertion failed"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.c:8827
+#: cp/semantics.c:8840
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "static assertion failed: %s"
 msgstr "静态断言错误：%E"
 
-#: cp/semantics.c:8832
+#: cp/semantics.c:8845
 #, gcc-internal-format
 msgid "non-constant condition for static assertion"
 msgstr "静态断言中出现非常量条件"
 
-#: cp/semantics.c:8862
+#: cp/semantics.c:8875
 #, gcc-internal-format
 msgid "argument to decltype must be an expression"
 msgstr "decltype 的实参必须是一个表达式"
 
-#: cp/semantics.c:8890
+#: cp/semantics.c:8903
 #, fuzzy, gcc-internal-format
 msgid "decltype cannot resolve address of overloaded function"
 msgstr "%s 无法解析重载的函数地址"
 
-#: cp/semantics.c:9446
+#: cp/semantics.c:9459
 #, fuzzy, gcc-internal-format
 msgid "operand of fold expression has no unexpanded parameter packs"
 msgstr "逗号表达式的左操作数不起作用"
 
-#: cp/semantics.c:9499
+#: cp/semantics.c:9512
 #, fuzzy, gcc-internal-format
 #| msgid "template argument %qE involves template parameter(s)"
 msgid "both arguments in binary fold have unexpanded parameter packs"
 msgstr "模板实参%qE混杂了模板形参"
 
-#: cp/semantics.c:9501
+#: cp/semantics.c:9514
 #, gcc-internal-format
 msgid "no unexpanded parameter packs in binary fold"
 msgstr ""
 
-#: cp/semantics.c:9519
+#: cp/semantics.c:9532
 #, fuzzy, gcc-internal-format
 msgid "non-pointer argument to %<__builtin_launder%>"
 msgstr "给函数%<__builtin_next_arg%>的参数数目不对"
@@ -49847,108 +49926,108 @@
 msgid "lambda-expression in a constant expression"
 msgstr "常量表达式中的 Lambda 表达式"
 
-#: cp/tree.c:3893
+#: cp/tree.c:3888
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qD with void return type"
 msgstr "%qE属性在类型上被忽略"
 
-#: cp/tree.c:3900
+#: cp/tree.c:3895
 #, fuzzy, gcc-internal-format
 #| msgid "%qE attribute can only be applied to class definitions"
 msgid "%qE attribute can only be applied to functions or to class or enumeration types"
 msgstr "只能为类定义应用%qE属性"
 
-#: cp/tree.c:3952
+#: cp/tree.c:3947
 #, gcc-internal-format
 msgid "requested init_priority is not an integer constant"
 msgstr "请求的 init_priority 不是一个整数常数"
 
-#: cp/tree.c:3974
+#: cp/tree.c:3969
 #, gcc-internal-format
 msgid "can only use %qE attribute on file-scope definitions of objects of class type"
 msgstr "只能将%qE属性用于某个类的对象的文件作用域定义"
 
-#: cp/tree.c:3982
+#: cp/tree.c:3977
 #, gcc-internal-format
 msgid "requested init_priority is out of range"
 msgstr "请求的 init_priority 越界"
 
-#: cp/tree.c:3992
+#: cp/tree.c:3987
 #, gcc-internal-format
 msgid "requested init_priority is reserved for internal use"
 msgstr "请求的 init_priority 保留为内部使用"
 
-#: cp/tree.c:4003
+#: cp/tree.c:3998
 #, gcc-internal-format
 msgid "%qE attribute is not supported on this platform"
 msgstr "%qE属性在此平台上不受支持"
 
-#: cp/tree.c:4030
+#: cp/tree.c:4025
 #, fuzzy, gcc-internal-format
 msgid "redeclaration of %qD adds abi tag %E"
 msgstr "%qD声明为%qT的一个成员"
 
-#: cp/tree.c:4050
+#: cp/tree.c:4045
 #, fuzzy, gcc-internal-format
 msgid "the %qE attribute requires arguments"
 msgstr "%qE属性需要带有名实参的原型"
 
-#: cp/tree.c:4061
+#: cp/tree.c:4056
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must be narrow string literals"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.c:4074 cp/tree.c:4087
+#: cp/tree.c:4069 cp/tree.c:4082
 #, fuzzy, gcc-internal-format
 msgid "arguments to the %qE attribute must contain valid identifiers"
 msgstr "%qE属性的实参不是一个字符串常量"
 
-#: cp/tree.c:4076
+#: cp/tree.c:4071
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid first character for an identifier"
 msgstr "%<%T::%D%>不是一个有效的声明"
 
-#: cp/tree.c:4089
+#: cp/tree.c:4084
 #, fuzzy, gcc-internal-format
 msgid "%<%c%> is not a valid character in an identifier"
 msgstr "请输入有效字符"
 
-#: cp/tree.c:4113
+#: cp/tree.c:4108
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-class, non-enum type %qT"
 msgstr "%qE属性在不是类的类型上被忽略"
 
-#: cp/tree.c:4119
+#: cp/tree.c:4114
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to %qT after its definition"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:4126
+#: cp/tree.c:4121
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template instantiation %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:4133
+#: cp/tree.c:4128
 #, fuzzy, gcc-internal-format
 msgid "ignoring %qE attribute applied to template specialization %qT"
 msgstr "忽略在其定义之后为%qT应用的属性"
 
-#: cp/tree.c:4155
+#: cp/tree.c:4150
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to non-function, non-variable %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.c:4161
+#: cp/tree.c:4156
 #, fuzzy, gcc-internal-format
 msgid "%qE attribute applied to extern \"C\" declaration %qD"
 msgstr "%qE属性只能用于函数"
 
-#: cp/tree.c:4889
+#: cp/tree.c:4884
 #, fuzzy, gcc-internal-format
 msgid "zero as null pointer constant"
 msgstr "PRINT_OPERAND 空指针"
 
-#: cp/tree.c:4902
+#: cp/tree.c:4897
 #, gcc-internal-format, gfc-internal-format
 msgid "lang_* check: failed in %s, at %s:%d"
 msgstr "lang_* check：在 %s 中失败，于 %s:%d"
@@ -50635,105 +50714,105 @@
 msgid "invalid conversion to type %qT from type %qT"
 msgstr "到类型%qT的转换无效，从类型%qT"
 
-#: cp/typeck.c:8507
+#: cp/typeck.c:8508
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT for argument %qP to %qD"
 msgstr "不能将%4$qD的实参%3$qP从%1$qT转换到%2$qT"
 
-#: cp/typeck.c:8513
+#: cp/typeck.c:8514
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in default argument"
 msgstr "不能在参数默认时将%qT转换为%qT"
 
-#: cp/typeck.c:8517
+#: cp/typeck.c:8518
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in argument passing"
 msgstr "不能在传参时将%qT转换为%qT"
 
-#: cp/typeck.c:8521
+#: cp/typeck.c:8522
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT"
 msgstr "不能将%qT转换为%qT"
 
-#: cp/typeck.c:8525
+#: cp/typeck.c:8526
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in initialization"
 msgstr "不能在初始化时将%qT转换为%qT"
 
-#: cp/typeck.c:8529
+#: cp/typeck.c:8530
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in return"
 msgstr "不能在返回时将%qT转换为%qT"
 
-#: cp/typeck.c:8533
+#: cp/typeck.c:8534
 #, gcc-internal-format
 msgid "cannot convert %qT to %qT in assignment"
 msgstr "不能在赋值时将%qT转换为%qT"
 
-#: cp/typeck.c:8546
+#: cp/typeck.c:8547
 #, fuzzy, gcc-internal-format
 msgid "class type %qT is incomplete"
 msgstr "源有不完全的类类型"
 
-#: cp/typeck.c:8564
+#: cp/typeck.c:8565
 #, fuzzy, gcc-internal-format
 msgid "parameter %qP of %qD might be a candidate for a format attribute"
 msgstr "%2$qE的第 %1$d 个实参可能是 format 属性的备选"
 
-#: cp/typeck.c:8568
+#: cp/typeck.c:8569
 #, fuzzy, gcc-internal-format
 msgid "parameter might be a candidate for a format attribute"
 msgstr "返回类型可能是 format 属性的备选"
 
-#: cp/typeck.c:8573
+#: cp/typeck.c:8574
 #, fuzzy, gcc-internal-format
 msgid "target of conversion might be a candidate for a format attribute"
 msgstr "函数的实参可能是 format 属性的备选"
 
-#: cp/typeck.c:8578
+#: cp/typeck.c:8579
 #, fuzzy, gcc-internal-format
 msgid "target of initialization might be a candidate for a format attribute"
 msgstr "初始化的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:8588
+#: cp/typeck.c:8589
 #, fuzzy, gcc-internal-format
 msgid "left-hand side of assignment might be a candidate for a format attribute"
 msgstr "赋值的左手边可能是 format 属性的备选时"
 
-#: cp/typeck.c:8683
+#: cp/typeck.c:8684
 #, fuzzy, gcc-internal-format
 #| msgid "in passing argument %P of %q+D"
 msgid "in passing argument %P of %qD"
 msgstr "在传递%2$q+D的第 %1$P 个实参时"
 
-#: cp/typeck.c:8742
+#: cp/typeck.c:8743
 #, gcc-internal-format
 msgid "returning reference to temporary"
 msgstr "返回临时变量的引用"
 
-#: cp/typeck.c:8749
+#: cp/typeck.c:8750
 #, gcc-internal-format
 msgid "reference to non-lvalue returned"
 msgstr "返回了一个非左值的引用"
 
-#: cp/typeck.c:8764
+#: cp/typeck.c:8765
 #, fuzzy, gcc-internal-format
 #| msgid "reference to local variable %q+D returned"
 msgid "reference to local variable %qD returned"
 msgstr "返回了对局部变量的%q+D的引用"
 
-#: cp/typeck.c:8768
+#: cp/typeck.c:8769
 #, fuzzy, gcc-internal-format
 msgid "address of label %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:8772
+#: cp/typeck.c:8773
 #, fuzzy, gcc-internal-format
 #| msgid "address of local variable %q+D returned"
 msgid "address of local variable %qD returned"
 msgstr "返回了局部变量的%q+D的地址"
 
-#: cp/typeck.c:8818
+#: cp/typeck.c:8819
 #, gcc-internal-format
 msgid "returning a value from a destructor"
 msgstr "析构函数返回值"
@@ -50740,56 +50819,56 @@
 
 #. If a return statement appears in a handler of the
 #. function-try-block of a constructor, the program is ill-formed.
-#: cp/typeck.c:8826
+#: cp/typeck.c:8827
 #, gcc-internal-format
 msgid "cannot return from a handler of a function-try-block of a constructor"
 msgstr "不能从构造函数的异常处理中返回"
 
 #. You can't return a value from a constructor.
-#: cp/typeck.c:8829
+#: cp/typeck.c:8830
 #, gcc-internal-format
 msgid "returning a value from a constructor"
 msgstr "构造函数返回值"
 
 #. Give a helpful error message.
-#: cp/typeck.c:8859 cp/typeck.c:8905
+#: cp/typeck.c:8860 cp/typeck.c:8906
 #, gcc-internal-format
 msgid "return-statement with no value, in function returning %qT"
 msgstr "在返回%qT的函数中，返回语句不带返回值"
 
-#: cp/typeck.c:8867
+#: cp/typeck.c:8868
 #, fuzzy, gcc-internal-format
 msgid "returning initializer list"
 msgstr "<花括号内的初始值列表>"
 
-#: cp/typeck.c:8886
+#: cp/typeck.c:8887
 #, gcc-internal-format
 msgid "inconsistent types %qT and %qT deduced for lambda return type"
 msgstr "Lambda 返回类型演绎得到不一致的类型%qT和%qT"
 
-#: cp/typeck.c:8889
+#: cp/typeck.c:8890
 #, fuzzy, gcc-internal-format
 #| msgid "inconsistent deduction for %qT: %qT and then %qT"
 msgid "inconsistent deduction for auto return type: %qT and then %qT"
 msgstr "对%qT不一致的演绎：先是%qT然后是%qT"
 
-#: cp/typeck.c:8924
+#: cp/typeck.c:8925
 #, gcc-internal-format
 msgid "return-statement with a value, in function returning 'void'"
 msgstr "在返回‘void’的函数中，返回语句带返回值"
 
-#: cp/typeck.c:8954
+#: cp/typeck.c:8955
 #, gcc-internal-format
 msgid "%<operator new%> must not return NULL unless it is declared %<throw()%> (or -fcheck-new is in effect)"
 msgstr "%<operator new%>不能返回 NULL，除非它被声明为%<throw()%>(或 -fcheck-new 起作用)"
 
 #. Make this a permerror because we used to accept it.
-#: cp/typeck.c:9556
+#: cp/typeck.c:9557
 #, fuzzy, gcc-internal-format
 msgid "using temporary as lvalue"
 msgstr "右值的引用用作左值"
 
-#: cp/typeck.c:9558
+#: cp/typeck.c:9559
 #, gcc-internal-format
 msgid "using xvalue (rvalue reference) as lvalue"
 msgstr "右值的引用用作左值"
@@ -54774,87 +54853,87 @@
 msgid "Procedure pointer initialization target at %L may not be a procedure pointer"
 msgstr "%L处 PURE 过程中指针赋值目标错误"
 
-#: fortran/expr.c:5234
+#: fortran/expr.c:5239
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Fortran 2008: Pointer functions in variable definition context (%s) at %L"
 msgstr "Fortran 2003：%L处初始化表达式中非整数指数"
 
-#: fortran/expr.c:5242
+#: fortran/expr.c:5247
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-variable expression in variable definition context (%s) at %L"
 msgstr "Non-variable 运算式在中变量定义语境 (%s) 于 %L"
 
-#: fortran/expr.c:5250
+#: fortran/expr.c:5255
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5259
+#: fortran/expr.c:5264
 #, fuzzy, gcc-internal-format
 msgid "%qs in variable definition context (%s) at %L is not a variable"
 msgstr "%L处的属性不允许出现在 TYPE 定义中"
 
-#: fortran/expr.c:5270
+#: fortran/expr.c:5275
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-POINTER in pointer association context (%s) at %L"
 msgstr "Non-POINTER 在中指标关联语境 (%s) 于 %L"
 
-#: fortran/expr.c:5279
+#: fortran/expr.c:5284
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Type inaccessible in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5292
+#: fortran/expr.c:5297
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_TYPE in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5305
+#: fortran/expr.c:5310
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "LOCK_EVENT in variable definition context (%s) at %L"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5335
+#: fortran/expr.c:5340
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in pointer association context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5343
+#: fortran/expr.c:5348
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs with INTENT(IN) in variable definition context (%s) at %L"
 msgstr "虚参‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5356
+#: fortran/expr.c:5361
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a pointer association context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5364
+#: fortran/expr.c:5369
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs is PROTECTED and can not appear in a variable definition context (%s) at %L"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5376
+#: fortran/expr.c:5381
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs can not appear in a variable definition context (%s) at %L in PURE procedure"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5435
+#: fortran/expr.c:5440
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to vector-indexed target can not be used in a variable definition context (%s)"
 msgstr "变量‘%s’在%L处上下文中必须是常量"
 
-#: fortran/expr.c:5439
+#: fortran/expr.c:5444
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L associated to expression can not be used in a variable definition context (%s)"
 msgstr "变量‘%s’不能出现在%L处的表达式中"
 
-#: fortran/expr.c:5450
+#: fortran/expr.c:5455
 #, fuzzy, gcc-internal-format
 msgid "Associate-name %qs can not appear in a variable definition context (%s) at %L because its target at %L can not, either"
 msgstr "Associate-name‘%s’无法出现在中变量定义语境 (%s) 于 %L 因为它的目标于 %L 无法，还是"
 
-#: fortran/expr.c:5492
+#: fortran/expr.c:5497
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Elements with the same value at %L and %L in vector subscript in a variable definition context (%s)"
 msgstr "‘%s’于 %L 关联的到运算式无法已用于变量定义语境 (%s)"
@@ -55043,12 +55122,12 @@
 msgid "Second argument of defined assignment at %L must be INTENT(IN)"
 msgstr "%L处定义赋值的第二个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:965 fortran/resolve.c:15914
+#: fortran/interface.c:965 fortran/resolve.c:15882
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第一个参数必须是 INTENT(IN)"
 
-#: fortran/interface.c:972 fortran/resolve.c:15932
+#: fortran/interface.c:972 fortran/resolve.c:15900
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L must be INTENT(IN)"
 msgstr "%L处运算符接口的第二个参数必须是 INTENT(IN)"
@@ -55828,512 +55907,527 @@
 msgid "Fortran 2003: DT format specifier not allowed at %C"
 msgstr "不能为%C处的 NEWUNIT 指定 UNIT"
 
-#: fortran/io.c:685
+#: fortran/io.c:695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "X descriptor requires leading space count at %L"
 msgstr "扩展：X 描述符在%L需要前导空格数量"
 
-#: fortran/io.c:762
+#: fortran/io.c:724
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "$ descriptor at %L"
 msgstr "扩展：%L处的 L 描述符后缺少正的宽度"
 
-#: fortran/io.c:766
+#: fortran/io.c:728
 #, gcc-internal-format, gfc-internal-format
 msgid "$ should be the last specifier in format at %L"
 msgstr "$ 必须是%L处最后一个格式限定符"
 
-#: fortran/io.c:865 fortran/io.c:869
+#: fortran/io.c:828 fortran/io.c:832
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %L"
 msgid "Extension: Zero width after L descriptor at %L"
 msgstr "扩展：%L处的 L 描述符后缺少正的宽度"
 
-#: fortran/io.c:881
+#: fortran/io.c:844
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Extension: Missing positive width after L descriptor at %L"
 msgid "Missing positive width after L descriptor at %L"
 msgstr "扩展：%L处的 L 描述符后缺少正的宽度"
 
-#: fortran/io.c:912
+#: fortran/io.c:875
 #, fuzzy, gcc-internal-format
 msgid "%<G0%> in format at %L"
 msgstr "g0 描述符不允许有 E 限定符"
 
-#: fortran/io.c:940
+#: fortran/io.c:903
 #, gcc-internal-format, gfc-internal-format
 msgid "Positive width required in format specifier %s at %L"
 msgstr "%2$L处的格式指定 %1$s 需要正的宽度"
 
-#: fortran/io.c:956 fortran/io.c:963
+#: fortran/io.c:919 fortran/io.c:926
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier %s at %L"
 msgstr "%2$L处的格式限定符%1$s中需要句号"
 
-#: fortran/io.c:1035
+#: fortran/io.c:1045
 #, gcc-internal-format, gfc-internal-format
 msgid "Period required in format specifier at %L"
 msgstr "%L处的格式限定符需要句号"
 
-#: fortran/io.c:1057
+#: fortran/io.c:1067
 #, gcc-internal-format, gfc-internal-format
 msgid "The H format specifier at %L is a Fortran 95 deleted feature"
 msgstr "%L处的 H 格式限定符已在 Fortran 95 中被删除"
 
-#: fortran/io.c:1145 fortran/io.c:1207
+#: fortran/io.c:1155 fortran/io.c:1217
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Missing comma at %L"
 msgstr "%C处缺少右括号或逗号"
 
-#: fortran/io.c:1225
+#: fortran/io.c:1235
 #, gcc-internal-format, gfc-internal-format
 msgid "%s in format string at %L"
 msgstr "%s 出现在%L处的格式字符串中"
 
-#: fortran/io.c:1263
+#: fortran/io.c:1273
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Extraneous characters in format at %L"
 msgstr "%s 出现在%L处的格式字符串中"
 
-#: fortran/io.c:1285
+#: fortran/io.c:1295
 #, gcc-internal-format, gfc-internal-format
 msgid "Format statement in module main block at %C"
 msgstr "%C处模块主块中的格式语句"
 
-#: fortran/io.c:1294
+#: fortran/io.c:1304
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within an INTERFACE"
 msgid "FORMAT statement at %C cannot appear within an INTERFACE"
 msgstr "%C处的 ENTRY 语句不能出现在 INTERFACE 中"
 
-#: fortran/io.c:1300
+#: fortran/io.c:1310
 #, gcc-internal-format, gfc-internal-format
 msgid "Missing format label at %C"
 msgstr "%C处缺少格式标号"
 
-#: fortran/io.c:1348
+#: fortran/io.c:1358
 #, gcc-internal-format, gfc-internal-format
 msgid "IOMSG must be a scalar-default-char-variable at %L"
 msgstr ""
 
-#: fortran/io.c:1362
+#: fortran/io.c:1372
 #, gcc-internal-format, gfc-internal-format
 msgid "%s requires a scalar-default-char-expr at %L"
 msgstr ""
 
-#: fortran/io.c:1385 fortran/io.c:1416 fortran/io.c:1482
+#: fortran/io.c:1395 fortran/io.c:1426 fortran/io.c:1492
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid value for %s specification at %C"
 msgstr "%2$C处‘%1$s’规格无效"
 
-#: fortran/io.c:1391 fortran/io.c:1422 fortran/io.c:1564 fortran/io.c:1577
+#: fortran/io.c:1401 fortran/io.c:1432 fortran/io.c:1574 fortran/io.c:1587
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s specification at %C"
 msgstr "%2$C处重复的 %1$s 规格"
 
-#: fortran/io.c:1429
+#: fortran/io.c:1439
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be INTENT(IN) at %C"
 msgstr "%2$C处的变量 %1$s 不能是 INTENT(IN)"
 
-#: fortran/io.c:1437
+#: fortran/io.c:1447
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s cannot be assigned in PURE procedure at %C"
 msgstr "变量 %s 在%C处的 PURE 过程中不能被赋值"
 
-#: fortran/io.c:1488
+#: fortran/io.c:1498
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate %s label specification at %C"
 msgstr "%2$C处重复的 %1$s 标号规格"
 
-#: fortran/io.c:1508 fortran/io.c:1525 fortran/io.c:1546
+#: fortran/io.c:1518 fortran/io.c:1535 fortran/io.c:1556
 #, gcc-internal-format, gfc-internal-format
 msgid "%s is a DEC extension at %C, re-compile with -fdec to enable"
 msgstr ""
 
-#: fortran/io.c:1599
+#: fortran/io.c:1609
 #, gcc-internal-format, gfc-internal-format
 msgid "Constant expression in FORMAT tag at %L must be of type default CHARACTER"
 msgstr "%L处 FORMAT 标记中的常量表达式默认类型必须为 CHARACTER"
 
-#: fortran/io.c:1617
+#: fortran/io.c:1627
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "FORMAT tag at %L must be of type default-kind CHARACTER or of INTEGER"
 msgstr "%L处 FORMAT 标记中的常量表达式默认类型必须为 CHARACTER"
 
-#: fortran/io.c:1623
+#: fortran/io.c:1633
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ASSIGNED variable in FORMAT tag at %L"
 msgstr "ASSIGNED GOTO 语句在%L处需要一个 INTEGER 变量"
 
-#: fortran/io.c:1628
+#: fortran/io.c:1638
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L has not been assigned a format label"
 msgstr "变量‘%s’在 %L 尚未分配到格式标号"
 
-#: fortran/io.c:1635
+#: fortran/io.c:1645
 #, fuzzy, gcc-internal-format
 msgid "Scalar %qs in FORMAT tag at %L is not an ASSIGNED variable"
 msgstr "%2$L处的 FORMAT 标记中的标量‘%1$s’不是一个 ASSIGNED 变量"
 
-#: fortran/io.c:1647
+#: fortran/io.c:1657
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-character in FORMAT tag at %L"
 msgstr "扩展：%L处的 FORMAT 标记中有非字符"
 
-#: fortran/io.c:1653
+#: fortran/io.c:1663
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed shape array element in FORMAT tag at %L"
 msgstr "%L处的 FORMAT 标记中假定外形数组中有非字符元素"
 
-#: fortran/io.c:1660
+#: fortran/io.c:1670
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character assumed size array element in FORMAT tag at %L"
 msgstr "%L处的 FORMAT 标记中假定大小数组中有非字符元素"
 
-#: fortran/io.c:1667
+#: fortran/io.c:1677
 #, gcc-internal-format, gfc-internal-format
 msgid "Non-character pointer array element in FORMAT tag at %L"
 msgstr "%L处的 FORMAT 标记中有非字符指针数组元素"
 
-#: fortran/io.c:1693
+#: fortran/io.c:1703
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be of type %s"
 msgstr "%s 标记在%L处必须具有类型 %s"
 
-#: fortran/io.c:1700
+#: fortran/io.c:1710
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be a character string of default kind"
 msgstr "%L处的毗连运算符必须毗连同一种别的字符串"
 
-#: fortran/io.c:1707
+#: fortran/io.c:1717
 #, gcc-internal-format, gfc-internal-format
 msgid "%s tag at %L must be scalar"
 msgstr "%s 标记在%L处必须是标量"
 
-#: fortran/io.c:1713
+#: fortran/io.c:1723
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IOMSG tag at %L"
 msgstr "%s 标记在%L处必须是标量"
 
-#: fortran/io.c:1721
+#: fortran/io.c:1731
 #, gcc-internal-format, gfc-internal-format
 msgid "Fortran 95 requires default INTEGER in %s tag at %L"
 msgstr "Fortran 95 在%2$L处的 %1$s 标记中需要默认的 INTEGER"
 
-#: fortran/io.c:1730
+#: fortran/io.c:1740
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Non-default LOGICAL kind in %s tag at %L"
 msgstr "Fortran 95 在%2$L处的 %1$s 标记中需要默认的 INTEGER"
 
-#: fortran/io.c:1737
+#: fortran/io.c:1747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier at %L"
 msgstr "不能为%C处的 NEWUNIT 指定 UNIT"
 
-#: fortran/io.c:1755
+#: fortran/io.c:1765
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "CONVERT tag at %L"
 msgstr "%s 标记在%L处必须是标量"
 
-#: fortran/io.c:1965
+#: fortran/io.c:1975
 #, fuzzy, gcc-internal-format
 msgid "Fortran 2003: %s specifier in %s statement at %C has value %qs"
 msgstr "Fortran 2003：%3$C 处 %2$s 语句中的 %1$s 限定符值为‘%4$s’"
 
-#: fortran/io.c:1973 fortran/io.c:2000
+#: fortran/io.c:1983 fortran/io.c:2010
 #, fuzzy, gcc-internal-format
 msgid "%s specifier in %s statement at %C has value %qs"
 msgstr "为%3$C处 %2$s 语句中 %1$s 指定了非法的值‘%4$s’"
 
-#: fortran/io.c:1992
+#: fortran/io.c:2002
 #, fuzzy, gcc-internal-format
 msgid "Extension: %s specifier in %s statement at %C has value %qs"
 msgstr "扩展：为%3$C处 %2$s 语句中的 %1$s 指定了值‘%4$s’"
 
-#: fortran/io.c:2014 fortran/io.c:2022
+#: fortran/io.c:2024 fortran/io.c:2032
 #, fuzzy, gcc-internal-format
 msgid "%s specifier in %s statement at %C has invalid value %qs"
 msgstr "为%3$C处 %2$s 语句中 %1$s 指定了非法的值‘%4$s’"
 
-#: fortran/io.c:2075
+#: fortran/io.c:2085
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement not allowed in PURE procedure at %C"
 msgstr "OPEN 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/io.c:2088
+#: fortran/io.c:2098
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specifier not allowed with NEWUNIT at %C"
 msgstr "不能为%C处的 NEWUNIT 指定 UNIT"
 
-#: fortran/io.c:2098
+#: fortran/io.c:2108
 #, gcc-internal-format, gfc-internal-format
 msgid "NEWUNIT specifier must have FILE= or STATUS='scratch' at %C"
 msgstr "%C处的 NEWUNIT 限定符必须有 FILE= 或 STATUS='scratch'"
 
-#: fortran/io.c:2106
+#: fortran/io.c:2116
 #, gcc-internal-format, gfc-internal-format
 msgid "OPEN statement at %C must have UNIT or NEWUNIT specified"
 msgstr "%C处的 OPEN 语句需要指定 UNIT 或 NEWUNIT"
 
-#: fortran/io.c:2144
+#: fortran/io.c:2154
 #, gcc-internal-format, gfc-internal-format
 msgid "ACTION type conflicts with READONLY specifier at %C"
 msgstr ""
 
-#: fortran/io.c:2158
+#: fortran/io.c:2168
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= at %C not allowed in Fortran 95"
 msgstr "%C处的 ASYNCHRONOUS= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2179 fortran/io.c:3712
+#: fortran/io.c:2189 fortran/io.c:3779
 #, gcc-internal-format, gfc-internal-format
 msgid "BLANK= at %C not allowed in Fortran 95"
 msgstr "%C处的 BLANK= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2216 fortran/io.c:3688
+#: fortran/io.c:2226 fortran/io.c:3755
 #, gcc-internal-format, gfc-internal-format
 msgid "DECIMAL= at %C not allowed in Fortran 95"
 msgstr "%C处的 DECIMAL= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2254
+#: fortran/io.c:2264
 #, gcc-internal-format, gfc-internal-format
 msgid "ENCODING= at %C not allowed in Fortran 95"
 msgstr "%C处的 ENCODING= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2317 fortran/io.c:3761
+#: fortran/io.c:2327 fortran/io.c:3828
 #, gcc-internal-format, gfc-internal-format
 msgid "ROUND= at %C not allowed in Fortran 95"
 msgstr "%C处的 ROUND= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2356
+#: fortran/io.c:2366
 #, gcc-internal-format, gfc-internal-format
 msgid "SIGN= at %C not allowed in Fortran 95"
 msgstr "%C处的 SIGN= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:2577
+#: fortran/io.c:2587
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement not allowed in PURE procedure at %C"
 msgstr "CLOSE 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/io.c:2639
+#: fortran/io.c:2649
 #, gcc-internal-format, gfc-internal-format
 msgid "CLOSE statement at %L requires a UNIT number"
 msgstr "%L处的 CLOSE 语句需要一个 UNIT 数"
 
-#: fortran/io.c:2647
+#: fortran/io.c:2657
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in CLOSE statement at %L must be non-negative"
 msgstr "%L处 CLOSE 语句中的 UNIT 数必须是非负的"
 
-#: fortran/io.c:2745 fortran/match.c:2937
+#: fortran/io.c:2755 fortran/match.c:2937
 #, gcc-internal-format, gfc-internal-format
 msgid "%s statement not allowed in PURE procedure at %C"
 msgstr "%s 语句不允许出现在%C处的 PURE 程序中"
 
-#: fortran/io.c:2779
+#: fortran/io.c:2789
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number missing in statement at %L"
 msgstr "%L处的语句中 UNIT 数必须为非负的数"
 
-#: fortran/io.c:2787 fortran/io.c:3230
+#: fortran/io.c:2797 fortran/io.c:3264
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in statement at %L must be non-negative"
 msgstr "%L处的语句中 UNIT 数必须为非负的数"
 
-#: fortran/io.c:2820
+#: fortran/io.c:2830
 #, gcc-internal-format, gfc-internal-format
 msgid "FLUSH statement at %C"
 msgstr "%C处 FLUSH 语句"
 
-#: fortran/io.c:2861
+#: fortran/io.c:2871
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Missing format label at %C"
 msgid "Missing format with default unit at %C"
 msgstr "%C处缺少格式标号"
 
-#: fortran/io.c:2881
+#: fortran/io.c:2891
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate UNIT specification at %C"
 msgstr "%C处重复的 UNIT 规格"
 
-#: fortran/io.c:2955
+#: fortran/io.c:2965
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate format specification at %C"
 msgstr "%C处重复的格式规格"
 
-#: fortran/io.c:2972
+#: fortran/io.c:3006
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs in namelist %qs is INTENT(IN) at %C"
 msgstr "符号‘%s’在名字列表‘%s’是 INTENT(IN)，位于 %C"
 
-#: fortran/io.c:3008
+#: fortran/io.c:3042
 #, gcc-internal-format, gfc-internal-format
 msgid "Duplicate NML specification at %C"
 msgstr "%C处重复的 NML 规格"
 
-#: fortran/io.c:3017
+#: fortran/io.c:3051
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C must be a NAMELIST group name"
 msgstr "%2$C处的符号‘%1$s’必须是个 NAMELIST 组名"
 
-#: fortran/io.c:3087
+#: fortran/io.c:3121
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag at %C not allowed in output statement"
 msgstr "%C处的 END 标记不允许出现在输出语句中"
 
-#: fortran/io.c:3164
+#: fortran/io.c:3198
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT not specified at %L"
 msgstr "%L没有指定 UNIT"
 
-#: fortran/io.c:3176
+#: fortran/io.c:3210
 #, gcc-internal-format, gfc-internal-format
 msgid "UNIT specification at %L must be an INTEGER expression or a CHARACTER variable"
 msgstr "%L处的 UNIT 规格必须是 INTEGER 表达式或一个 CHARACTER 变量"
 
-#: fortran/io.c:3198
+#: fortran/io.c:3232
 #, gcc-internal-format, gfc-internal-format
 msgid "Invalid form of WRITE statement at %L, UNIT required"
 msgstr "%L处 WRITE 语句形式无效，需要 UNIT"
 
-#: fortran/io.c:3209
+#: fortran/io.c:3243
 #, gcc-internal-format, gfc-internal-format
 msgid "Internal unit with vector subscript at %L"
 msgstr "%L处内部单位带向量下标"
 
-#: fortran/io.c:3223
+#: fortran/io.c:3257
 #, gcc-internal-format, gfc-internal-format
 msgid "External IO UNIT cannot be an array at %L"
 msgstr "%L处的外部 IO UNIT 不能是数组"
 
-#: fortran/io.c:3251
+#: fortran/io.c:3287
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST %qs in READ statement at %L contains the symbol %qs which may not appear in a variable definition context"
 msgstr "名称表列‘%s’在中读取叙述于 %L 含有符号‘%s’该项可能无法出现在中变量定义语境"
 
-#: fortran/io.c:3261
+#: fortran/io.c:3299
+#, fuzzy, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
+msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有 POINTER 组件"
+
+#: fortran/io.c:3309 fortran/resolve.c:13913
+#, fuzzy, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
+msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
+
+#: fortran/io.c:3317
+#, fuzzy, gcc-internal-format
+msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
+msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
+
+#: fortran/io.c:3328
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Comma before i/o item list at %L"
 msgstr "扩展：%L处 i/o 项目列表前的逗号"
 
-#: fortran/io.c:3271
+#: fortran/io.c:3338
 #, gcc-internal-format, gfc-internal-format
 msgid "ERR tag label %d at %L not defined"
 msgstr "ERR 标号 %d 在%L处未定义"
 
-#: fortran/io.c:3283
+#: fortran/io.c:3350
 #, gcc-internal-format, gfc-internal-format
 msgid "END tag label %d at %L not defined"
 msgstr "END 标号 %d 在%L处未定义"
 
-#: fortran/io.c:3295
+#: fortran/io.c:3362
 #, gcc-internal-format, gfc-internal-format
 msgid "EOR tag label %d at %L not defined"
 msgstr "EOR 标号 %d 在%L处未定义"
 
-#: fortran/io.c:3305
+#: fortran/io.c:3372
 #, gcc-internal-format, gfc-internal-format
 msgid "FORMAT label %d at %L not defined"
 msgstr "FORMAT 标号 %d 在%L处未定义"
 
-#: fortran/io.c:3336
+#: fortran/io.c:3403
 #, gcc-internal-format
 msgid "io_kind_name(): bad I/O-kind"
 msgstr ""
 
-#: fortran/io.c:3425
+#: fortran/io.c:3492
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in I/O iterator at %C"
 msgstr "%C处 I/O 游标语法错误"
 
-#: fortran/io.c:3456
+#: fortran/io.c:3523
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected variable in READ statement at %C"
 msgstr "%C READ 语句需要变量"
 
-#: fortran/io.c:3462
+#: fortran/io.c:3529
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected expression in %s statement at %C"
 msgstr "%2$C处需要 %1$s 语句"
 
 #. A general purpose syntax error.
-#: fortran/io.c:3519 fortran/io.c:4179 fortran/gfortran.h:2813
+#: fortran/io.c:3586 fortran/io.c:4246 fortran/gfortran.h:2813
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in %s statement at %C"
 msgstr "%s 语句在%C处语法错误"
 
-#: fortran/io.c:3603
+#: fortran/io.c:3670
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Internal file at %L with namelist"
 msgstr "不允许按位置传递%L处的内部过程"
 
-#: fortran/io.c:3659
+#: fortran/io.c:3726
 #, gcc-internal-format, gfc-internal-format
 msgid "ASYNCHRONOUS= specifier at %L must be an initialization expression"
 msgstr "必须为%L处的 ASYNCHRONOUS= 指定一个初始化表达式"
 
-#: fortran/io.c:3737
+#: fortran/io.c:3804
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PAD= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 PAD= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:3813
+#: fortran/io.c:3880
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "DELIM= at %C not allowed in Fortran 95"
 msgstr "Fortran 2003：%C处的 DELIM= 不允许用在 Fortran 95 中"
 
-#: fortran/io.c:3965
+#: fortran/io.c:4032
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT namelist at %C is an extension"
 msgstr "%C处的 PRINT 名字列表是一个扩展"
 
-#: fortran/io.c:4146
+#: fortran/io.c:4213
 #, gcc-internal-format, gfc-internal-format
 msgid "Expected comma in I/O list at %C"
 msgstr "%C处 I/O 列表中需要逗号"
 
-#: fortran/io.c:4213
+#: fortran/io.c:4280
 #, gcc-internal-format, gfc-internal-format
 msgid "PRINT statement at %C not allowed within PURE procedure"
 msgstr "PRINT 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/io.c:4380 fortran/io.c:4442
+#: fortran/io.c:4447 fortran/io.c:4509
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement not allowed in PURE procedure at %C"
 msgstr "INQUIRE 语句不允许出现在%C处的 PURE 过程中"
 
-#: fortran/io.c:4408
+#: fortran/io.c:4475
 #, gcc-internal-format, gfc-internal-format
 msgid "IOLENGTH tag invalid in INQUIRE statement at %C"
 msgstr "%C处的 INQUIRE 语句中 IOLENGTH 标记无效"
 
-#: fortran/io.c:4418 fortran/trans-io.c:1333
+#: fortran/io.c:4485 fortran/trans-io.c:1333
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L cannot contain both FILE and UNIT specifiers"
 msgstr "%L处的 INQUIRE 语句不能包含 FILE 和 UNIT 限定符"
 
-#: fortran/io.c:4425
+#: fortran/io.c:4492
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires either FILE or UNIT specifier"
 msgstr "%L处的 INQUIRE 语句需要 FILE 或 UNIT 限定符"
 
-#: fortran/io.c:4435
+#: fortran/io.c:4502
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "UNIT number in INQUIRE statement at %L can not be %d"
 msgstr "%L处的语句中 UNIT 数必须为非负的数"
 
-#: fortran/io.c:4450
+#: fortran/io.c:4517
 #, gcc-internal-format, gfc-internal-format
 msgid "INQUIRE statement at %L requires a PENDING= specifier with the ID= specifier"
 msgstr "%L处的 INQUIRE 语句需要带有 ID= 指定的 PENDING="
 
-#: fortran/io.c:4628
+#: fortran/io.c:4695
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "WAIT at %C not allowed in Fortran 95"
 msgstr "%C处的 PURE 过程中不允许 WAIT 语句"
 
-#: fortran/io.c:4634
+#: fortran/io.c:4701
 #, gcc-internal-format, gfc-internal-format
 msgid "WAIT statement not allowed in PURE procedure at %C"
 msgstr "%C处的 PURE 过程中不允许 WAIT 语句"
@@ -57239,254 +57333,254 @@
 msgid "Missing generic specification in USE statement at %C"
 msgstr "%C处的 USE 语句缺少泛型规格"
 
-#: fortran/module.c:637
+#: fortran/module.c:638
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Renaming operators in USE statements at %C"
 msgstr "Fortran 2003：%C处的 USE 语句中更名运算符"
 
-#: fortran/module.c:678
+#: fortran/module.c:679
 #, fuzzy, gcc-internal-format
 msgid "The name %qs at %C has already been used as an external module name"
 msgstr "%2$C处的名字‘%1$s’已经被用作外部模块名。"
 
-#: fortran/module.c:741
+#: fortran/module.c:742
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "SUBMODULE declaration at %C"
 msgstr "%C处 CHARACTER 声明语法错误"
 
-#: fortran/module.c:746
+#: fortran/module.c:747
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "ENTRY statement at %C cannot appear within a contained subprogram"
 msgid "SUBMODULE declaration at %C cannot appear within another scoping unit"
 msgstr "%C处的 ENTRY 语句不能出现在嵌套的子程序中"
 
-#: fortran/module.c:821
+#: fortran/module.c:822
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Syntax error in SAVE statement at %C"
 msgid "Syntax error in SUBMODULE statement at %C"
 msgstr "%C SAVE 语句语法错误"
 
-#: fortran/module.c:1166
+#: fortran/module.c:1167
 #, fuzzy, gcc-internal-format
 msgid "Reading module %qs at line %d column %d: %s"
 msgstr "读出模块 %s，于行 %d 列 %d：%s"
 
-#: fortran/module.c:1170
+#: fortran/module.c:1171
 #, fuzzy, gcc-internal-format
 msgid "Writing module %qs at line %d column %d: %s"
 msgstr "读入模块 %s，于行 %d 列 %d：%s"
 
-#: fortran/module.c:1174
+#: fortran/module.c:1175
 #, fuzzy, gcc-internal-format
 msgid "Module %qs at line %d column %d: %s"
 msgstr "模块 %s 位于行 %d 列 %d：%s"
 
-#: fortran/module.c:1569
+#: fortran/module.c:1570
 #, gcc-internal-format
 msgid "require_atom(): bad atom type required"
 msgstr ""
 
-#: fortran/module.c:1618
+#: fortran/module.c:1619
 #, gcc-internal-format, gfc-internal-format
 msgid "Error writing modules file: %s"
 msgstr "写入模块文件时出错：%s"
 
-#: fortran/module.c:1662
+#: fortran/module.c:1663
 #, gcc-internal-format
 msgid "write_atom(): Writing negative integer"
 msgstr ""
 
-#: fortran/module.c:1669
+#: fortran/module.c:1670
 #, gcc-internal-format
 msgid "write_atom(): Trying to write dab atom"
 msgstr ""
 
-#: fortran/module.c:1875
+#: fortran/module.c:1876
 #, fuzzy, gcc-internal-format
 msgid "unquote_string(): got bad string"
 msgstr "错误的字符串常量"
 
-#: fortran/module.c:2674
+#: fortran/module.c:2675
 #, gcc-internal-format
 msgid "mio_array_ref(): Unknown array ref"
 msgstr ""
 
-#: fortran/module.c:3650
+#: fortran/module.c:3651
 #, gcc-internal-format, gfc-internal-format
 msgid "Namelist %s cannot be renamed by USE association to %s"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/module.c:4746
+#: fortran/module.c:4747
 #, gcc-internal-format, gfc-internal-format
 msgid "Ambiguous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4749
+#: fortran/module.c:4750
 #, gcc-internal-format, gfc-internal-format
 msgid "Previous !$OMP DECLARE REDUCTION from module %s at %L"
 msgstr ""
 
-#: fortran/module.c:4943
+#: fortran/module.c:4944
 #, fuzzy, gcc-internal-format
 msgid "%qs of module %qs, imported at %C, is also the name of the current program unit"
 msgstr "%2$C处的名字‘%1$s’是从当前程序单元对‘%3$s’有歧义的引用"
 
-#: fortran/module.c:5295
+#: fortran/module.c:5296
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in module %qs"
 msgstr "%2$L处引用的符号‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:5302
+#: fortran/module.c:5303
 #, fuzzy, gcc-internal-format
 msgid "User operator %qs referenced at %L not found in module %qs"
 msgstr "%2$L处引用的用户运算符‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:5307
+#: fortran/module.c:5308
 #, fuzzy, gcc-internal-format
 msgid "Intrinsic operator %qs referenced at %L not found in module %qs"
 msgstr "%2$L处引用的内建运算符‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:5542
+#: fortran/module.c:5543
 #, gcc-internal-format
 msgid "write_symbol(): bad module symbol %qs"
 msgstr ""
 
-#: fortran/module.c:5875
+#: fortran/module.c:5876
 #, gcc-internal-format
 msgid "write_symtree(): Symbol not written"
 msgstr ""
 
-#: fortran/module.c:6062
+#: fortran/module.c:6063
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for writing at %C: %s"
 msgstr "不能打开模块文件‘%s’写入，在%C处：%s"
 
-#: fortran/module.c:6081
+#: fortran/module.c:6082
 #, fuzzy, gcc-internal-format
 msgid "Error writing module file %qs for writing: %s"
 msgstr "写入到输出文件 '%s' 时出错\n"
 
-#: fortran/module.c:6092
+#: fortran/module.c:6093
 #, fuzzy, gcc-internal-format
 msgid "Can't delete module file %qs: %s"
 msgstr "%s：无法找到模块文件 %s\n"
 
-#: fortran/module.c:6095
+#: fortran/module.c:6096
 #, fuzzy, gcc-internal-format
 msgid "Can't rename module file %qs to %qs: %s"
 msgstr "无法将模块文件‘%s’重命名为‘%s’：%s"
 
-#: fortran/module.c:6101
+#: fortran/module.c:6102
 #, fuzzy, gcc-internal-format
 msgid "Can't delete temporary module file %qs: %s"
 msgstr "无法删除临时模块文件‘%s’：%s"
 
-#: fortran/module.c:6158
+#: fortran/module.c:6159
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs at %C already declared"
 msgstr "`%.*s' 已被定义为对照符号"
 
-#: fortran/module.c:6229
+#: fortran/module.c:6230
 #, gcc-internal-format, gfc-internal-format
 msgid "import_iso_c_binding_module(): Unable to create symbol for %s"
 msgstr ""
 
-#: fortran/module.c:6337 fortran/module.c:6681
+#: fortran/module.c:6338 fortran/module.c:6682
 #, fuzzy, gcc-internal-format
 msgid "The symbol %qs, referenced at %L, is not in the selected standard"
 msgstr "%2$L处引用的符号‘%1$s’在模块‘%3$s’中找不到"
 
-#: fortran/module.c:6465
+#: fortran/module.c:6466
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_C_BINDING"
 msgstr "%2$L处引用的符号‘%1$s’在内建模块 ISO_C_BINDING 中找不到"
 
-#: fortran/module.c:6486 fortran/module.c:6519 fortran/module.c:6561
+#: fortran/module.c:6487 fortran/module.c:6520 fortran/module.c:6562
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs already declared"
 msgstr "`%.*s' 已被定义为对照符号"
 
-#: fortran/module.c:6666
+#: fortran/module.c:6667
 #, fuzzy, gcc-internal-format
 msgid "Use of intrinsic module %qs at %C conflicts with non-intrinsic module name used previously"
 msgstr "%2$C处对内建模块‘%1$s’的使用与以前使用的非内建模块名字冲突"
 
-#: fortran/module.c:6688
+#: fortran/module.c:6689
 #, fuzzy, gcc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %L is incompatible with option %qs"
 msgstr "%C处在内建模块 ISO_FORTRAN_ENV 中对 NUMERIC_STORAGE_SIZE 命名常数的使用与选项 %s 不兼容"
 
-#: fortran/module.c:6756
+#: fortran/module.c:6757
 #, gcc-internal-format, gfc-internal-format
 msgid "Use of the NUMERIC_STORAGE_SIZE named constant from intrinsic module ISO_FORTRAN_ENV at %C is incompatible with option %s"
 msgstr "%C处在内建模块 ISO_FORTRAN_ENV 中对 NUMERIC_STORAGE_SIZE 命名常数的使用与选项 %s 不兼容"
 
-#: fortran/module.c:6810
+#: fortran/module.c:6811
 #, fuzzy, gcc-internal-format
 msgid "Symbol %qs referenced at %L not found in intrinsic module ISO_FORTRAN_ENV"
 msgstr "%2$L处引用的符号‘%1$s’在内建模块 ISO_FORTRAN_ENV 中找不到"
 
-#: fortran/module.c:6836
+#: fortran/module.c:6837
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "USE statement at %C has no ONLY qualifier"
 msgstr "%C处非预期的 CASE 语句"
 
-#: fortran/module.c:6865
+#: fortran/module.c:6866
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_FORTRAN_ENV intrinsic module at %C"
 msgstr "Fortran 2003：%C 处的 ISO_FORTRAN_ENV 内建模块"
 
-#: fortran/module.c:6877
+#: fortran/module.c:6878
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "ISO_C_BINDING module at %C"
 msgstr "%C处需要绑定名"
 
-#: fortran/module.c:6890
+#: fortran/module.c:6891
 #, fuzzy, gcc-internal-format
 msgid "Can't find an intrinsic module named %qs at %C"
 msgstr "%2$C处无法找到名为‘%1$s’的内建模块"
 
-#: fortran/module.c:6896
+#: fortran/module.c:6897
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_FEATURES module at %C"
 msgstr "使用了传统 C 不支持的特性时给出警告"
 
-#: fortran/module.c:6902
+#: fortran/module.c:6903
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_EXCEPTIONS module at %C"
 msgstr "模块间优化未为 C++ 实现"
 
-#: fortran/module.c:6908
+#: fortran/module.c:6909
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "IEEE_ARITHMETIC module at %C"
 msgstr "模块间优化未为 C++ 实现"
 
-#: fortran/module.c:6918
+#: fortran/module.c:6919
 #, fuzzy, gcc-internal-format
 msgid "Can't open module file %qs for reading at %C: %s"
 msgstr "无法打开模块文件‘%s’读取，在%C处：%s"
 
-#: fortran/module.c:6921
+#: fortran/module.c:6922
 #, gcc-internal-format
 msgid "Module file %qs has not been generated, either because the module does not contain a MODULE PROCEDURE or there is an error in the module."
 msgstr ""
 
-#: fortran/module.c:6932
+#: fortran/module.c:6933
 #, fuzzy, gcc-internal-format
 msgid "Use of non-intrinsic module %qs at %C conflicts with intrinsic module name used previously"
 msgstr "%2$C处对非内建模块‘%1$s’的使用与之前对内建模块名字的使用相冲突"
 
-#: fortran/module.c:6955
+#: fortran/module.c:6956
 #, fuzzy, gcc-internal-format
 msgid "File %qs opened at %C is not a GNU Fortran module file"
 msgstr "%2$C处打开的文件的‘%1$s’并非一个 GFORTRAN 模块文件"
 
-#: fortran/module.c:6963
+#: fortran/module.c:6964
 #, gcc-internal-format
 msgid "Cannot read module file %qs opened at %C, because it was created by a different version of GNU Fortran"
 msgstr ""
 
-#: fortran/module.c:6978
+#: fortran/module.c:6979
 #, fuzzy, gcc-internal-format, gfc-internal-format
 #| msgid "Can't USE the same module we're building!"
 msgid "Can't USE the same %smodule we're building!"
@@ -59878,7 +59972,7 @@
 msgid "Unable to resolve the specific function %qs at %L"
 msgstr "不能解析 %2$L处的函数‘%1$s’"
 
-#: fortran/resolve.c:2751 fortran/resolve.c:15846
+#: fortran/resolve.c:2751 fortran/resolve.c:15814
 #, fuzzy, gcc-internal-format
 msgid "Function %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的函数‘%1$s’没有隐式类型"
@@ -61378,448 +61472,438 @@
 msgid "Generic name %qs of function %qs at %L being the same name as derived type at %L"
 msgstr "%3$L处‘%2$s’的组件‘%1$s’与一个继承的类型限定过程同名"
 
-#: fortran/resolve.c:13884
+#: fortran/resolve.c:13866
 #, fuzzy, gcc-internal-format
 msgid "Assumed size array %qs in namelist %qs at %L is not allowed"
 msgstr "不允许 %3$L 处 %2$s 名字列表中假定大小的数组“%1$s”"
 
-#: fortran/resolve.c:13890
+#: fortran/resolve.c:13872
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with assumed shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有假定外形"
 
-#: fortran/resolve.c:13896
+#: fortran/resolve.c:13878
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST array object %qs with nonconstant shape in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:13904
+#: fortran/resolve.c:13886
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs with nonconstant character length in namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有常外形"
 
-#: fortran/resolve.c:13914
+#: fortran/resolve.c:13903
 #, fuzzy, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L is polymorphic and requires a defined input/output procedure"
-msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’不能有 POINTER 组件"
-
-#: fortran/resolve.c:13924
-#, fuzzy, gcc-internal-format
-msgid "NAMELIST object %qs in namelist %qs at %L with ALLOCATABLE or POINTER components"
-msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
-
-#: fortran/resolve.c:13942
-#, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs was declared PRIVATE and cannot be member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’声明为 PRIVATE 因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:13957
+#: fortran/resolve.c:13925
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has use-associated PRIVATE components and cannot be member of namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有使用相关的 PRIVATE 组件因此不能是 NAMELIST‘%2$s’的成员"
 
-#: fortran/resolve.c:13968
+#: fortran/resolve.c:13936
 #, fuzzy, gcc-internal-format
 msgid "NAMELIST object %qs has PRIVATE components and cannot be a member of PUBLIC namelist %qs at %L"
 msgstr "%3$L处 NAMELIST 对象‘%1$s’有 PRIVATE 组件因此不能是 PUBLIC 名字列表‘%2$s’的成员"
 
-#: fortran/resolve.c:13995
+#: fortran/resolve.c:13963
 #, fuzzy, gcc-internal-format
 msgid "PROCEDURE attribute conflicts with NAMELIST attribute in %qs at %L"
 msgstr "PROCEDURE 属性与%2$L处‘%1$s’中的 NAMELIST 属性冲突"
 
-#: fortran/resolve.c:14014
+#: fortran/resolve.c:13982
 #, fuzzy, gcc-internal-format
 msgid "Parameter array %qs at %L cannot be automatic or of deferred shape"
 msgstr "%2$L处的参数数组‘%1$s’不能是自动的或有延迟的外形"
 
-#: fortran/resolve.c:14030
+#: fortran/resolve.c:13998
 #, fuzzy, gcc-internal-format
 msgid "Implicitly typed PARAMETER %qs at %L doesn't match a later IMPLICIT type"
 msgstr "%2$L处隐式类型的 PARAMETER‘%1$s’与随后的 IMPLICIT 类型不匹配"
 
-#: fortran/resolve.c:14041
+#: fortran/resolve.c:14009
 #, gcc-internal-format, gfc-internal-format
 msgid "Incompatible derived type in PARAMETER at %L"
 msgstr "%L处 PARAMETER 中派生类型不兼容"
 
-#: fortran/resolve.c:14049
+#: fortran/resolve.c:14017
 #, fuzzy, gcc-internal-format
 msgid "CLASS variable %qs at %L cannot have the PARAMETER attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14091
+#: fortran/resolve.c:14059
 #, gcc-internal-format, gfc-internal-format
 msgid "Sorry, allocatable/pointer components in polymorphic (CLASS) type coarrays at %L are unsupported"
 msgstr ""
 
-#: fortran/resolve.c:14155
+#: fortran/resolve.c:14123
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROTECTED attribute conflicts with EXTERNAL attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:14158
+#: fortran/resolve.c:14126
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "PROCEDURE attribute conflicts with PROTECTED attribute at %L"
 msgstr "%s 属性与 %s 属性在%L处冲突"
 
-#: fortran/resolve.c:14254
+#: fortran/resolve.c:14222
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L has the CONTIGUOUS attribute but is not an array pointer or an assumed-shape or assumed-rank array"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:14272
+#: fortran/resolve.c:14240
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed size array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:14275
+#: fortran/resolve.c:14243
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed shape array at %L must be a dummy argument"
 msgstr "%L处假定外形的数组必须是一个虚参"
 
-#: fortran/resolve.c:14283
+#: fortran/resolve.c:14251
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L must be a dummy argument"
 msgstr "%L处假定大小的数组必须是一个虚参"
 
-#: fortran/resolve.c:14290
+#: fortran/resolve.c:14258
 #, gcc-internal-format, gfc-internal-format
 msgid "Assumed-rank array at %L may not have the VALUE or CODIMENSION attribute"
 msgstr ""
 
-#: fortran/resolve.c:14303
+#: fortran/resolve.c:14271
 #, gcc-internal-format, gfc-internal-format
 msgid "Symbol at %L is not a DUMMY variable"
 msgstr "%L处的符号不是一个 DUMMY 变量"
 
-#: fortran/resolve.c:14309
+#: fortran/resolve.c:14277
 #, fuzzy, gcc-internal-format
 msgid "%qs at %L cannot have the VALUE attribute because it is not a dummy argument"
 msgstr "%2$L 处的“%1$s”不能有 VALUE 属性，因为它不是个虚参"
 
-#: fortran/resolve.c:14319
+#: fortran/resolve.c:14287
 #, fuzzy, gcc-internal-format
 msgid "Character dummy variable %qs at %L with VALUE attribute must have constant length"
 msgstr "%2$L处带 VALUE 属性的字符哑元‘%1$s’必须具有常数长度"
 
-#: fortran/resolve.c:14328
+#: fortran/resolve.c:14296
 #, fuzzy, gcc-internal-format
 msgid "C interoperable character dummy variable %qs at %L with VALUE attribute must have length one"
 msgstr "%2$L处带 VALUE 属性与 C 可互操作的字符哑元‘%1$s’长度必须为 1"
 
-#: fortran/resolve.c:14341 fortran/resolve.c:14508
+#: fortran/resolve.c:14309 fortran/resolve.c:14476
 #, fuzzy, gcc-internal-format
 msgid "The derived type %qs at %L is of type %qs, which has not been defined"
 msgstr "%2$L处派生类型‘%1$s’的类型‘%3$s’尚未定义"
 
-#: fortran/resolve.c:14355
+#: fortran/resolve.c:14323
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be a dummy argument"
 msgstr ""
 
-#: fortran/resolve.c:14364
+#: fortran/resolve.c:14332
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall be of type TYPE(*) or of an numeric intrinsic type"
 msgstr ""
 
-#: fortran/resolve.c:14373
+#: fortran/resolve.c:14341
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14381
+#: fortran/resolve.c:14349
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14388
+#: fortran/resolve.c:14356
 #, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L with NO_ARG_CHECK attribute shall either be a scalar or an assumed-size array"
 msgstr ""
 
-#: fortran/resolve.c:14408
+#: fortran/resolve.c:14376
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed type of variable %s at %L is only permitted for dummy variables"
 msgstr "%2$L处假定外形数组‘%1$s’不能用在初始化表达式中"
 
-#: fortran/resolve.c:14415
+#: fortran/resolve.c:14383
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the ALLOCATABLE, CODIMENSION, POINTER or VALUE attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 ALLOCATABLE 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14422
+#: fortran/resolve.c:14390
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L may not have the INTENT(OUT) attribute"
 msgstr "%2$L处变量‘%1$s’不能既有 POINTER 又有 BIND(C) 属性"
 
-#: fortran/resolve.c:14429
+#: fortran/resolve.c:14397
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Assumed-type variable %s at %L shall not be an explicit-shape array"
 msgstr "%C处的循环变量不能是一个子组件"
 
-#: fortran/resolve.c:14454
+#: fortran/resolve.c:14422
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L cannot be BIND(C) because it is neither a COMMON block nor declared at the module level scope"
 msgstr "%2$L处变量‘%1$s’不能是 BIND(C) 因为它既不是一个 COMMON 块也不是于模块级作用域声明的"
 
-#: fortran/resolve.c:14534
+#: fortran/resolve.c:14502
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC %s %qs at %L of PRIVATE derived type %qs"
 msgstr "Fortran 2003：%3$L处 PUBLIC %1$s‘%2$s’具有 PRIVATE 派生类型‘%4$s’"
 
-#: fortran/resolve.c:14549
+#: fortran/resolve.c:14517
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type LOCK_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:14562
+#: fortran/resolve.c:14530
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "Variable %s at %L of type EVENT_TYPE or with subcomponent of type LOCK_TYPE must be a coarray"
 msgstr "变量 %s 于 %L 的类型 LOCK_TYPE 或与 subcomponent 的类型 LOCK_TYPE 必须是 coarray"
 
-#: fortran/resolve.c:14580
+#: fortran/resolve.c:14548
 #, fuzzy, gcc-internal-format
 msgid "The INTENT(OUT) dummy argument %qs at %L is ASSUMED SIZE and so cannot have a default initializer"
 msgstr "%2$L处INTENT(OUT) 虚参‘%1$s’是 ASSUMED SIZE，所以不能有一个默认初始值设定"
 
-#: fortran/resolve.c:14592
+#: fortran/resolve.c:14560
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of LOCK_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:14601
+#: fortran/resolve.c:14569
 #, fuzzy, gcc-internal-format
 msgid "Dummy argument %qs at %L of EVENT_TYPE shall not be INTENT(OUT)"
 msgstr "%2$L处的‘%1$s’虚参不能是 INTENT(OUT)"
 
-#: fortran/resolve.c:14613
+#: fortran/resolve.c:14581
 #, fuzzy, gcc-internal-format
 msgid "Function result %qs at %L shall not be a coarray or have a coarray component"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:14622
+#: fortran/resolve.c:14590
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L of TYPE(C_PTR) or TYPE(C_FUNPTR) shall not be a coarray"
 msgstr "变量‘%s’于 %L 的类型 (C_PTR) 或类型 (C_FUNPTR) 不应该是 coarray"
 
-#: fortran/resolve.c:14634
+#: fortran/resolve.c:14602
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L with coarray component shall be a nonpointer, nonallocatable scalar, which is not a coarray"
 msgstr "变量‘%s’于 %L 与 coarray 成分应该是 nonpointer，nonallocatable 纯量"
 
-#: fortran/resolve.c:14649
+#: fortran/resolve.c:14617
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is a coarray and is not ALLOCATABLE, SAVE nor a dummy argument"
 msgstr "变量‘%s’于 %L 是 coarray 和不是 ALLOCATABLE，保存 nor 虚参数"
 
-#: fortran/resolve.c:14657
+#: fortran/resolve.c:14625
 #, fuzzy, gcc-internal-format
 msgid "Coarray variable %qs at %L shall not have codimensions with deferred shape"
 msgstr "数组‘%s’在%L处不能有延迟的外形"
 
-#: fortran/resolve.c:14664
+#: fortran/resolve.c:14632
 #, fuzzy, gcc-internal-format
 msgid "Allocatable coarray variable %qs at %L must have deferred shape"
 msgstr "%C处可分配的组件必须有延迟的外形"
 
-#: fortran/resolve.c:14676
+#: fortran/resolve.c:14644
 #, fuzzy, gcc-internal-format
 msgid "Variable %qs at %L is INTENT(OUT) and can thus not be an allocatable coarray or have coarray components"
 msgstr "函数结果‘%s’在%L处不能有初始值设定"
 
-#: fortran/resolve.c:14685
+#: fortran/resolve.c:14653
 #, fuzzy, gcc-internal-format
 msgid "Coarray dummy variable %qs at %L not allowed in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:14701
+#: fortran/resolve.c:14669
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL dummy argument %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:14707
+#: fortran/resolve.c:14675
 #, fuzzy, gcc-internal-format
 msgid "LOGICAL result variable %qs at %L with non-C_Bool kind in BIND(C) procedure %qs"
 msgstr "%L处的哑过程不允许出现在 ELEMENTAL 过程中"
 
-#: fortran/resolve.c:14732
+#: fortran/resolve.c:14700
 #, fuzzy, gcc-internal-format
 #| msgid "Namelist %s cannot be renamed by USE association to %s"
 msgid "Namelist %qs can not be an argument to subroutine or function at %L"
 msgstr "名字列表 %s 不能为对 %s 的 USE 关联来更名"
 
-#: fortran/resolve.c:14802
+#: fortran/resolve.c:14770
 #, gcc-internal-format, gfc-internal-format
 msgid "Threadprivate at %L isn't SAVEd"
 msgstr "%L处的线程私有变量未被保存"
 
-#: fortran/resolve.c:14813
+#: fortran/resolve.c:14781
 #, gcc-internal-format
 msgid "!$OMP DECLARE TARGET variable %qs at %L isn't SAVEd"
 msgstr ""
 
-#: fortran/resolve.c:14909
+#: fortran/resolve.c:14877
 #, gcc-internal-format
 msgid "check_data_variable(): Bad expression"
 msgstr ""
 
-#: fortran/resolve.c:14915
+#: fortran/resolve.c:14883
 #, fuzzy, gcc-internal-format
 msgid "BLOCK DATA element %qs at %L must be in COMMON"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必须在 COMMON 中"
 
-#: fortran/resolve.c:14921
+#: fortran/resolve.c:14889
 #, fuzzy, gcc-internal-format
 msgid "DATA array %qs at %L must be specified in a previous declaration"
 msgstr "%2$L处 BLOCK DATA 元素‘%1$s’必在前一个声明中指定"
 
-#: fortran/resolve.c:14930
+#: fortran/resolve.c:14898
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L cannot have a coindex"
 msgstr "%L处数据传输元素不能有 PRIVATE 组件"
 
-#: fortran/resolve.c:14944
+#: fortran/resolve.c:14912
 #, fuzzy, gcc-internal-format
 msgid "DATA element %qs at %L is a pointer and so must be a full array"
 msgstr "%2$L处的 DATA 元素‘%1$s’是一个指针所以必须是一个完全的数组"
 
-#: fortran/resolve.c:14990
+#: fortran/resolve.c:14958
 #, gcc-internal-format, gfc-internal-format
 msgid "Nonconstant array section at %L in DATA statement"
 msgstr "%L处 DATA 语句中有非常量数组段"
 
-#: fortran/resolve.c:15003
+#: fortran/resolve.c:14971
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more variables than values"
 msgstr "%L处的 DATA 语名中变量比值多"
 
-#: fortran/resolve.c:15102
+#: fortran/resolve.c:15070
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "start of implied-do loop at %L could not be simplified to a constant value"
 msgstr "开始的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:15110
+#: fortran/resolve.c:15078
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "end of implied-do loop at %L could not be simplified to a constant value"
 msgstr "结束的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:15118
+#: fortran/resolve.c:15086
 #, fuzzy, gcc-internal-format, gfc-internal-format
 msgid "step of implied-do loop at %L could not be simplified to a constant value"
 msgstr "步骤的 implied-do 循环于 %L 无法被简化到常数"
 
-#: fortran/resolve.c:15243
+#: fortran/resolve.c:15211
 #, gcc-internal-format, gfc-internal-format
 msgid "DATA statement at %L has more values than variables"
 msgstr "%L处的 DATA 语句中值比变量多"
 
-#: fortran/resolve.c:15408
+#: fortran/resolve.c:15376
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but not used"
 msgstr "标号 %d 于 %L 经定义但未被使用"
 
-#: fortran/resolve.c:15414
+#: fortran/resolve.c:15382
 #, gcc-internal-format, gfc-internal-format
 msgid "Label %d at %L defined but cannot be used"
 msgstr "标号 %d 于 %L 经定义但无法被使用"
 
-#: fortran/resolve.c:15498
+#: fortran/resolve.c:15466
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L must have SEQUENCE attribute to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须有 SEQUENCE 属性方能成为 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15507
+#: fortran/resolve.c:15475
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L cannot have ALLOCATABLE components to be an EQUIVALENCE object"
 msgstr "%2$L处的派生类型变量‘%1$s’必须没有 ALLOCATABLE 组件方能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15515
+#: fortran/resolve.c:15483
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with default initialization cannot be in EQUIVALENCE with a variable in COMMON"
 msgstr "%2$L处的默认初始化的派生类型变量‘%1$s’不能成为 EQUIVALENCE 对象，因为它在 COMMON 中有变量"
 
-#: fortran/resolve.c:15531
+#: fortran/resolve.c:15499
 #, fuzzy, gcc-internal-format
 msgid "Derived type variable %qs at %L with pointer component(s) cannot be an EQUIVALENCE object"
 msgstr "%2$L处的带指针组件的派生类型变量‘%1$s’不能成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15634
+#: fortran/resolve.c:15602
 #, gcc-internal-format, gfc-internal-format
 msgid "Syntax error in EQUIVALENCE statement at %L"
 msgstr "%L处 EQUIVALENCE 语句语法错误"
 
-#: fortran/resolve.c:15649
+#: fortran/resolve.c:15617
 #, gcc-internal-format, gfc-internal-format
 msgid "Either all or none of the objects in the EQUIVALENCE set at %L shall have the PROTECTED attribute"
 msgstr "%L处 EQUIVALENCE 集中的对象必须都带有或者都不带有 PROTECTED 属性"
 
-#: fortran/resolve.c:15661
+#: fortran/resolve.c:15629
 #, fuzzy, gcc-internal-format
 msgid "Common block member %qs at %L cannot be an EQUIVALENCE object in the pure procedure %qs"
 msgstr "%2$L处的公共块成员‘%1$s’不能在纯过程‘%3$s’中成为一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15670
+#: fortran/resolve.c:15638
 #, fuzzy, gcc-internal-format
 msgid "Named constant %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处的有名常量‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15743
+#: fortran/resolve.c:15711
 #, fuzzy, gcc-internal-format
 msgid "Array %qs at %L with non-constant bounds cannot be an EQUIVALENCE object"
 msgstr "%2$L处有非常量界限的数组‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15754
+#: fortran/resolve.c:15722
 #, fuzzy, gcc-internal-format
 msgid "Structure component %qs at %L cannot be an EQUIVALENCE object"
 msgstr "%2$L处结构组件‘%1$s’不能是一个 EQUIVALENCE 对象"
 
-#: fortran/resolve.c:15765
+#: fortran/resolve.c:15733
 #, gcc-internal-format, gfc-internal-format
 msgid "Substring at %L has length zero"
 msgstr "%L 的子字符串长度为零"
 
-#: fortran/resolve.c:15856
+#: fortran/resolve.c:15824
 #, fuzzy, gcc-internal-format
 msgid "PUBLIC function %qs at %L of PRIVATE type %qs"
 msgstr "Fortran 2003：%2$L处 PRIVATE 类型‘%3$s’的 PUBLIC 函数‘%1$s’"
 
-#: fortran/resolve.c:15869
+#: fortran/resolve.c:15837
 #, fuzzy, gcc-internal-format
 msgid "ENTRY %qs at %L has no IMPLICIT type"
 msgstr "%2$L处的 ENTRY‘%1$s’没有隐式类型"
 
-#: fortran/resolve.c:15889
+#: fortran/resolve.c:15857
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must be a FUNCTION"
 msgstr "%2$L处的用户运算符‘%1$s’必须是一个 FUNCTION"
 
-#: fortran/resolve.c:15899
+#: fortran/resolve.c:15867
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L cannot be assumed character length"
 msgstr "%2$L处用户运算符过程‘%1$s’不能有假定字符长度"
 
-#: fortran/resolve.c:15907
+#: fortran/resolve.c:15875
 #, fuzzy, gcc-internal-format
 msgid "User operator procedure %qs at %L must have at least one argument"
 msgstr "%2$L处的用户运算符‘%1$s’必须至少有一个实参"
 
-#: fortran/resolve.c:15921
+#: fortran/resolve.c:15889
 #, gcc-internal-format, gfc-internal-format
 msgid "First argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第一个参数不能是可选的"
 
-#: fortran/resolve.c:15939
+#: fortran/resolve.c:15907
 #, gcc-internal-format, gfc-internal-format
 msgid "Second argument of operator interface at %L cannot be optional"
 msgstr "%L处运算符接口的第二个参数不能是可选的"
 
-#: fortran/resolve.c:15946
+#: fortran/resolve.c:15914
 #, gcc-internal-format, gfc-internal-format
 msgid "Operator interface at %L must have, at most, two arguments"
 msgstr "%L处的运算符接口必须有至多两个实参"
 
-#: fortran/resolve.c:16024
+#: fortran/resolve.c:15992
 #, fuzzy, gcc-internal-format
 msgid "Contained procedure %qs at %L of a PURE procedure must also be PURE"
 msgstr "%2$L处 PURE 过程中包含的过程‘%1$s’必须也是 PURE"
@@ -62916,12 +63000,12 @@
 msgid "The event variable at %L shall not be coindexed"
 msgstr "外部对象‘%s’在%L处不能有初始值设定"
 
-#: fortran/trans-io.c:1957
+#: fortran/trans-io.c:1968
 #, fuzzy, gcc-internal-format
 msgid "build_dt: format with namelist"
 msgstr "Fortran 2003：%L处内部文件有名字列表"
 
-#: fortran/trans-io.c:2464
+#: fortran/trans-io.c:2475
 #, gcc-internal-format, gfc-internal-format
 msgid "Bad IO basetype (%d)"
 msgstr "错误的 IO 基类型(%d)"
@@ -65262,10 +65346,6 @@
 #~ msgid "Assignment to an allocatable polymorphic variable at %L is not yet supported"
 #~ msgstr "不能在%2$C处的 PURE 过程中读取变量‘%1$s’"
 
-#, fuzzy
-#~ msgid "NAMELIST object %qs in namelist %qs at %L has ALLOCATABLE or POINTER components and thus requires a defined input/output procedure"
-#~ msgstr "%3$L处 NAMELIST 数组对象‘%1$s’在名字列表‘%2$s’必须有 ALLOCATABLE 组件"
-
 #~ msgid "bad method signature"
 #~ msgstr "错误的方法签名"
 
Index: gcc/tree-vect-patterns.c
===================================================================
--- gcc/tree-vect-patterns.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-vect-patterns.c	(.../branches/gcc-7-branch)
@@ -3641,7 +3641,7 @@
   rhs_code = gimple_assign_rhs_code (last_stmt);
   if (CONVERT_EXPR_CODE_P (rhs_code))
     {
-      if (TREE_CODE (TREE_TYPE (lhs)) != INTEGER_TYPE
+      if (! INTEGRAL_TYPE_P (TREE_TYPE (lhs))
 	  || TYPE_PRECISION (TREE_TYPE (lhs)) == 1)
 	return NULL;
       vectype = get_vectype_for_scalar_type (TREE_TYPE (lhs));
Index: gcc/ira.c
===================================================================
--- gcc/ira.c	(.../tags/gcc_7_2_0_release)
+++ gcc/ira.c	(.../branches/gcc-7-branch)
@@ -4406,6 +4406,12 @@
 	 for a reason.  */
       return false;
 
+    case ASM_OPERANDS:
+      /* The same is true for volatile asm: it has unknown side effects, it
+         cannot be moved at will.  */
+      if (MEM_VOLATILE_P (x))
+	return false;
+
     default:
       break;
     }
Index: gcc/tree-vect-stmts.c
===================================================================
--- gcc/tree-vect-stmts.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-vect-stmts.c	(.../branches/gcc-7-branch)
@@ -5702,6 +5702,12 @@
 
   op = gimple_assign_rhs1 (stmt);
 
+  /* In the case this is a store from a STRING_CST make sure
+     native_encode_expr can handle it.  */
+  if (TREE_CODE (op) == STRING_CST
+      && ! can_native_encode_string_p (op))
+    return false;
+
   if (!vect_is_simple_use (op, vinfo, &def_stmt, &dt, &rhs_vectype))
     {
       if (dump_enabled_p ())
@@ -7109,7 +7115,6 @@
     {
       first_stmt = GROUP_FIRST_ELEMENT (stmt_info);
       group_size = GROUP_SIZE (vinfo_for_stmt (first_stmt));
-      int group_gap = GROUP_GAP (vinfo_for_stmt (first_stmt));
       /* For SLP vectorization we directly vectorize a subchain
          without permutation.  */
       if (slp && ! SLP_TREE_LOAD_PERMUTATION (slp_node).exists ())
@@ -7152,7 +7157,8 @@
 	  else
 	    {
 	      vec_num = SLP_TREE_NUMBER_OF_VEC_STMTS (slp_node);
-	      group_gap_adj = group_gap;
+	      group_gap_adj
+		= group_size - SLP_INSTANCE_GROUP_SIZE (slp_node_instance);
 	    }
     	}
       else
Index: gcc/tree-inline.c
===================================================================
--- gcc/tree-inline.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-inline.c	(.../branches/gcc-7-branch)
@@ -4752,6 +4752,23 @@
 
   reset_debug_bindings (id, stmt_gsi);
 
+  if (flag_stack_reuse != SR_NONE
+      && (flag_sanitize & SANITIZE_KERNEL_ADDRESS) != 0)
+    for (tree p = DECL_ARGUMENTS (id->src_fn); p; p = DECL_CHAIN (p))
+      if (!TREE_THIS_VOLATILE (p))
+	{
+	  tree *varp = id->decl_map->get (p);
+	  if (varp && VAR_P (*varp) && !is_gimple_reg (*varp))
+	    {
+	      tree clobber = build_constructor (TREE_TYPE (*varp), NULL);
+	      gimple *clobber_stmt;
+	      TREE_THIS_VOLATILE (clobber) = 1;
+	      clobber_stmt = gimple_build_assign (*varp, clobber);
+	      gimple_set_location (clobber_stmt, gimple_location (stmt));
+	      gsi_insert_before (&stmt_gsi, clobber_stmt, GSI_SAME_STMT);
+	    }
+	}
+
   /* Reset the escaped solution.  */
   if (cfun->gimple_df)
     pt_solution_reset (&cfun->gimple_df->escaped);
@@ -4802,6 +4819,24 @@
       stmt = gimple_build_assign (gimple_call_lhs (stmt), use_retvar);
       gsi_replace (&stmt_gsi, stmt, false);
       maybe_clean_or_replace_eh_stmt (old_stmt, stmt);
+      /* Append a clobber for id->retvar if easily possible.  */
+      if (flag_stack_reuse != SR_NONE
+	  && (flag_sanitize & SANITIZE_KERNEL_ADDRESS) != 0
+	  && id->retvar
+	  && VAR_P (id->retvar)
+	  && id->retvar != return_slot
+	  && id->retvar != modify_dest
+	  && !TREE_THIS_VOLATILE (id->retvar)
+	  && !is_gimple_reg (id->retvar)
+	  && !stmt_ends_bb_p (stmt))
+	{
+	  tree clobber = build_constructor (TREE_TYPE (id->retvar), NULL);
+	  gimple *clobber_stmt;
+	  TREE_THIS_VOLATILE (clobber) = 1;
+	  clobber_stmt = gimple_build_assign (id->retvar, clobber);
+	  gimple_set_location (clobber_stmt, gimple_location (old_stmt));
+	  gsi_insert_after (&stmt_gsi, clobber_stmt, GSI_SAME_STMT);
+	}
 
       /* Copy bounds if we copy structure with bounds.  */
       if (chkp_function_instrumented_p (id->dst_fn)
@@ -4840,8 +4875,26 @@
 	      SSA_NAME_DEF_STMT (name) = gimple_build_nop ();
 	    }
 	}
+      /* Replace with a clobber for id->retvar.  */
+      else if (flag_stack_reuse != SR_NONE
+	       && (flag_sanitize & SANITIZE_KERNEL_ADDRESS) != 0
+	       && id->retvar
+	       && VAR_P (id->retvar)
+	       && id->retvar != return_slot
+	       && id->retvar != modify_dest
+	       && !TREE_THIS_VOLATILE (id->retvar)
+	       && !is_gimple_reg (id->retvar))
+	{
+	  tree clobber = build_constructor (TREE_TYPE (id->retvar), NULL);
+	  gimple *clobber_stmt;
+	  TREE_THIS_VOLATILE (clobber) = 1;
+	  clobber_stmt = gimple_build_assign (id->retvar, clobber);
+	  gimple_set_location (clobber_stmt, gimple_location (stmt));
+	  gsi_replace (&stmt_gsi, clobber_stmt, false);
+	  maybe_clean_or_replace_eh_stmt (stmt, clobber_stmt);
+	}
       else
-        gsi_remove (&stmt_gsi, true);
+	gsi_remove (&stmt_gsi, true);
     }
 
   /* Put returned bounds into the correct place if required.  */
@@ -4890,6 +4943,8 @@
   cg_edge->callee->remove ();
 
   id->block = NULL_TREE;
+  id->retvar = NULL_TREE;
+  id->retbnd = NULL_TREE;
   successfully_inlined = true;
 
  egress:
Index: gcc/combine.c
===================================================================
--- gcc/combine.c	(.../tags/gcc_7_2_0_release)
+++ gcc/combine.c	(.../branches/gcc-7-branch)
@@ -7397,7 +7397,14 @@
   if (pos_rtx && CONST_INT_P (pos_rtx))
     pos = INTVAL (pos_rtx), pos_rtx = 0;
 
-  if (GET_CODE (inner) == SUBREG && subreg_lowpart_p (inner))
+  if (GET_CODE (inner) == SUBREG
+      && subreg_lowpart_p (inner)
+      && (paradoxical_subreg_p (inner)
+	  /* If trying or potentionally trying to extract
+	     bits outside of is_mode, don't look through
+	     non-paradoxical SUBREGs.  See PR82192.  */
+	  || (pos_rtx == NULL_RTX
+	      && pos + len <= GET_MODE_PRECISION (is_mode))))
     {
       /* If going from (subreg:SI (mem:QI ...)) to (mem:QI ...),
 	 consider just the QI as the memory to extract from.
@@ -7423,7 +7430,12 @@
       if (new_rtx != 0)
 	return gen_rtx_ASHIFT (mode, new_rtx, XEXP (inner, 1));
     }
-  else if (GET_CODE (inner) == TRUNCATE)
+  else if (GET_CODE (inner) == TRUNCATE
+	   /* If trying or potentionally trying to extract
+	      bits outside of is_mode, don't look through
+	      TRUNCATE.  See PR82192.  */
+	   && pos_rtx == NULL_RTX
+	   && pos + len <= GET_MODE_PRECISION (is_mode))
     inner = XEXP (inner, 0);
 
   inner_mode = GET_MODE (inner);
@@ -14218,6 +14230,17 @@
 		  && CALL_P (from_insn)
 		  && find_reg_fusage (from_insn, USE, XEXP (note, 0)))
 		place = from_insn;
+	      else if (i2 && reg_set_p (XEXP (note, 0), PATTERN (i2)))
+		{
+		  /* If the new I2 sets the same register that is marked
+		     dead in the note, we do not in general know where to
+		     put the note.  One important case we _can_ handle is
+		     when the note comes from I3.  */
+		  if (from_insn == i3)
+		    place = i3;
+		  else
+		    break;
+		}
 	      else if (reg_referenced_p (XEXP (note, 0), PATTERN (i3)))
 		place = i3;
 	      else if (i2 != 0 && next_nonnote_nondebug_insn (i2) == i3
@@ -14231,11 +14254,6 @@
 		       || rtx_equal_p (XEXP (note, 0), elim_i0))
 		break;
 	      tem_insn = i3;
-	      /* If the new I2 sets the same register that is marked dead
-		 in the note, we do not know where to put the note.
-		 Give up.  */
-	      if (i2 != 0 && reg_set_p (XEXP (note, 0), PATTERN (i2)))
-		break;
 	    }
 
 	  if (place == 0)
Index: gcc/bb-reorder.c
===================================================================
--- gcc/bb-reorder.c	(.../tags/gcc_7_2_0_release)
+++ gcc/bb-reorder.c	(.../branches/gcc-7-branch)
@@ -2881,7 +2881,8 @@
 
   crossing_edges = find_rarely_executed_basic_blocks_and_crossing_edges ();
   if (!crossing_edges.exists ())
-    return 0;
+    /* Make sure to process deferred rescans and clear changeable df flags.  */
+    return TODO_df_finish;
 
   crtl->has_bb_partition = true;
 
@@ -2947,7 +2948,8 @@
       df_analyze ();
     }
 
-  return 0;
+  /* Make sure to process deferred rescans and clear changeable df flags.  */
+  return TODO_df_finish;
 }
 
 } // anon namespace
Index: gcc/config.gcc
===================================================================
--- gcc/config.gcc	(.../tags/gcc_7_2_0_release)
+++ gcc/config.gcc	(.../branches/gcc-7-branch)
@@ -775,7 +775,9 @@
   target_has_targetcm=yes
   ;;
 *-*-netbsd*)
-  tmake_file="t-slibgcc"
+  tm_p_file="${tm_p_file} netbsd-protos.h"
+  tmake_file="t-netbsd t-slibgcc"
+  extra_objs="${extra_objs} netbsd.o"
   gas=yes
   gnu_ld=yes
   use_gcc_stdint=wrap
@@ -1075,11 +1077,14 @@
 	case $target in
 	armv6*-*-freebsd*)
 	    target_cpu_cname="arm1176jzfs"
-	    tm_defines="${tm_defines} TARGET_FREEBSD_ARMv6=1"
             if test $fbsd_major -ge 11; then
                tm_defines="${tm_defines} TARGET_FREEBSD_ARM_HARD_FLOAT=1"
             fi
 	    ;;
+	armv7*-*-freebsd*)
+	    target_cpu_cname="genericv7a"
+	    tm_defines="${tm_defines} TARGET_FREEBSD_ARM_HARD_FLOAT=1"
+	    ;;
 	*)
 	    target_cpu_cname="arm9"
 	    ;;
@@ -2416,7 +2421,7 @@
 	;;
 powerpc-*-rtems*)
 	tm_file="rs6000/biarch64.h ${tm_file} dbxelf.h elfos.h freebsd-spec.h newlib-stdint.h rs6000/sysv4.h rs6000/e500.h rs6000/rtems.h rtems.h"
-	extra_options="${extra_options} rs6000/sysv4.opt"
+	extra_options="${extra_options} rs6000/sysv4.opt rs6000/linux64.opt"
 	tmake_file="${tmake_file} rs6000/t-fprules rs6000/t-rtems rs6000/t-ppccomm"
 	;;
 powerpc*-*-linux*)
Index: gcc/opts-global.c
===================================================================
--- gcc/opts-global.c	(.../tags/gcc_7_2_0_release)
+++ gcc/opts-global.c	(.../branches/gcc-7-branch)
@@ -167,7 +167,8 @@
 		    unsigned int lang_mask ATTRIBUTE_UNUSED, int kind,
 		    location_t loc,
 		    const struct cl_option_handlers *handlers,
-		    diagnostic_context *dc)
+		    diagnostic_context *dc,
+		    void (*) (void))
 {
   gcc_assert (opts == &global_options);
   gcc_assert (opts_set == &global_options_set);
@@ -267,10 +268,12 @@
 /* Set *HANDLERS to the default set of option handlers for use in the
    compilers proper (not the driver).  */
 void
-set_default_handlers (struct cl_option_handlers *handlers)
+set_default_handlers (struct cl_option_handlers *handlers,
+		      void (*target_option_override_hook) (void))
 {
   handlers->unknown_option_callback = unknown_option_callback;
   handlers->wrong_lang_callback = complain_wrong_lang;
+  handlers->target_option_override_hook = target_option_override_hook;
   handlers->num_handlers = 3;
   handlers->handlers[0].handler = lang_handle_option;
   handlers->handlers[0].mask = initial_lang_mask;
@@ -288,7 +291,8 @@
 decode_options (struct gcc_options *opts, struct gcc_options *opts_set,
 		struct cl_decoded_option *decoded_options,
 		unsigned int decoded_options_count,
-		location_t loc, diagnostic_context *dc)
+		location_t loc, diagnostic_context *dc,
+		void (*target_option_override_hook) (void))
 {
   struct cl_option_handlers handlers;
 
@@ -296,7 +300,7 @@
 
   lang_mask = initial_lang_mask;
 
-  set_default_handlers (&handlers);
+  set_default_handlers (&handlers, target_option_override_hook);
 
   default_options_optimization (opts, opts_set,
 				decoded_options, decoded_options_count,
Index: gcc/tree-cfg.c
===================================================================
--- gcc/tree-cfg.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-cfg.c	(.../branches/gcc-7-branch)
@@ -6667,7 +6667,15 @@
 		*tp = t = out->to;
 	    }
 
-	  DECL_CONTEXT (t) = p->to_context;
+	  /* For FORCED_LABELs we can end up with references from other
+	     functions if some SESE regions are outlined.  It is UB to
+	     jump in between them, but they could be used just for printing
+	     addresses etc.  In that case, DECL_CONTEXT on the label should
+	     be the function containing the glabel stmt with that LABEL_DECL,
+	     rather than whatever function a reference to the label was seen
+	     last time.  */
+	  if (!FORCED_LABEL (t) && !DECL_NONLOCAL (t))
+	    DECL_CONTEXT (t) = p->to_context;
 	}
       else if (p->remap_decls_p)
 	{
@@ -6785,6 +6793,21 @@
     case GIMPLE_OMP_RETURN:
     case GIMPLE_OMP_CONTINUE:
       break;
+
+    case GIMPLE_LABEL:
+      {
+	/* For FORCED_LABEL, move_stmt_op doesn't adjust DECL_CONTEXT,
+	   so that such labels can be referenced from other regions.
+	   Make sure to update it when seeing a GIMPLE_LABEL though,
+	   that is the owner of the label.  */
+	walk_gimple_op (stmt, move_stmt_op, wi);
+	*handled_ops_p = true;
+	tree label = gimple_label_label (as_a <glabel *> (stmt));
+	if (FORCED_LABEL (label) || DECL_NONLOCAL (label))
+	  DECL_CONTEXT (label) = p->to_context;
+      }
+      break;
+
     default:
       if (is_gimple_omp (stmt))
 	{
Index: gcc/config/t-netbsd
===================================================================
--- gcc/config/t-netbsd	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/config/t-netbsd	(.../branches/gcc-7-branch)
@@ -0,0 +1,21 @@
+# Copyright (C) 2017 Free Software Foundation, Inc.
+#
+# This file is part of GCC.
+#
+# GCC is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 3, or (at your option)
+# any later version.
+#
+# GCC is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with GCC; see the file COPYING3.  If not see
+# <http://www.gnu.org/licenses/>.
+
+netbsd.o: $(srcdir)/config/netbsd.c
+	$(COMPILE) $<
+	$(POSTCOMPILE)
Index: gcc/config/alpha/sync.md
===================================================================
--- gcc/config/alpha/sync.md	(.../tags/gcc_7_2_0_release)
+++ gcc/config/alpha/sync.md	(.../branches/gcc-7-branch)
@@ -24,7 +24,7 @@
   [(plus "add_operand") (minus "reg_or_8bit_operand")
    (ior "or_operand") (xor "or_operand") (and "and_operand")])
 (define_code_attr fetchop_constr
-  [(plus "rKL") (minus "rI") (ior "rIN") (xor "rIN") (and "riNM")])
+  [(plus "rKL") (minus "rI") (ior "rIN") (xor "rIN") (and "rINM")])
 
 
 (define_expand "memory_barrier"
Index: gcc/config/sparc/sparc.md
===================================================================
--- gcc/config/sparc/sparc.md	(.../tags/gcc_7_2_0_release)
+++ gcc/config/sparc/sparc.md	(.../branches/gcc-7-branch)
@@ -4518,7 +4518,14 @@
 ;; The 32-bit multiply/divide instructions are deprecated on v9, but at
 ;; least in UltraSPARC I, II and IIi it is a win tick-wise.
 
-(define_insn "mulsi3"
+(define_expand "mulsi3"
+  [(set (match_operand:SI 0 "register_operand" "")
+	(mult:SI (match_operand:SI 1 "arith_operand" "")
+		 (match_operand:SI 2 "arith_operand" "")))]
+  "TARGET_HARD_MUL || TARGET_ARCH64"
+  "")
+
+(define_insn "*mulsi3_sp32"
   [(set (match_operand:SI 0 "register_operand" "=r")
 	(mult:SI (match_operand:SI 1 "arith_operand" "%r")
 		 (match_operand:SI 2 "arith_operand" "rI")))]
@@ -4526,6 +4533,14 @@
   "smul\t%1, %2, %0"
   [(set_attr "type" "imul")])
 
+(define_insn "*mulsi3_sp64"
+  [(set (match_operand:SI 0 "register_operand" "=r")
+	(mult:SI (match_operand:SI 1 "arith_operand" "%r")
+		 (match_operand:SI 2 "arith_operand" "rI")))]
+  "TARGET_ARCH64"
+  "mulx\t%1, %2, %0"
+  [(set_attr "type" "imul")])
+
 (define_expand "muldi3"
   [(set (match_operand:DI 0 "register_operand" "")
 	(mult:DI (match_operand:DI 1 "arith_operand" "")
Index: gcc/config/i386/i386.md
===================================================================
--- gcc/config/i386/i386.md	(.../tags/gcc_7_2_0_release)
+++ gcc/config/i386/i386.md	(.../branches/gcc-7-branch)
@@ -6152,7 +6152,7 @@
    (set_attr "mode" "<MODE>")])
 
 (define_insn "addqi_ext_1"
-  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "=Q,Q")
+  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "+Q,Q")
 			 (const_int 8)
 			 (const_int 8))
 	(subreg:SI
@@ -6163,7 +6163,8 @@
 			       (const_int 8)) 0)
 	    (match_operand:QI 2 "general_operand" "QnBc,m")) 0))
    (clobber (reg:CC FLAGS_REG))]
-  ""
+  "/* FIXME: without this LRA can't reload this pattern, see PR82524.  */
+   rtx_equal_p (operands[0], operands[1])"
 {
   switch (get_attr_type (insn))
     {
@@ -6188,7 +6189,7 @@
    (set_attr "mode" "QI")])
 
 (define_insn "*addqi_ext_2"
-  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "=Q")
+  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "+Q")
 			 (const_int 8)
 			 (const_int 8))
 	(subreg:SI
@@ -6202,7 +6203,9 @@
 			       (const_int 8)
 			       (const_int 8)) 0)) 0))
   (clobber (reg:CC FLAGS_REG))]
-  ""
+  "/* FIXME: without this LRA can't reload this pattern, see PR82524.  */
+   rtx_equal_p (operands[0], operands[1])
+   || rtx_equal_p (operands[0], operands[2])"
   "add{b}\t{%h2, %h0|%h0, %h2}"
   [(set_attr "type" "alu")
    (set_attr "mode" "QI")])
@@ -8458,7 +8461,7 @@
    (set_attr "mode" "QI")])
 
 (define_insn "andqi_ext_1"
-  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "=Q,Q")
+  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "+Q,Q")
 			 (const_int 8)
 			 (const_int 8))
 	(subreg:SI
@@ -8469,7 +8472,8 @@
 			       (const_int 8)) 0)
 	    (match_operand:QI 2 "general_operand" "QnBc,m")) 0))
    (clobber (reg:CC FLAGS_REG))]
-  ""
+  "/* FIXME: without this LRA can't reload this pattern, see PR82524.  */
+   rtx_equal_p (operands[0], operands[1])"
   "and{b}\t{%2, %h0|%h0, %2}"
   [(set_attr "isa" "*,nox64")
    (set_attr "type" "alu")
@@ -8487,7 +8491,7 @@
 			       (const_int 8)) 0)
 	    (match_operand:QI 2 "general_operand" "QnBc,m"))
 	  (const_int 0)))
-   (set (zero_extract:SI (match_operand 0 "ext_register_operand" "=Q,Q")
+   (set (zero_extract:SI (match_operand 0 "ext_register_operand" "+Q,Q")
 			 (const_int 8)
 			 (const_int 8))
 	(subreg:SI
@@ -8497,7 +8501,9 @@
 			       (const_int 8)
 			       (const_int 8)) 0)
 	    (match_dup 2)) 0))]
-  "ix86_match_ccmode (insn, CCNOmode)"
+  "ix86_match_ccmode (insn, CCNOmode)
+   /* FIXME: without this LRA can't reload this pattern, see PR82524.  */
+   && rtx_equal_p (operands[0], operands[1])"
   "and{b}\t{%2, %h0|%h0, %2}"
   [(set_attr "isa" "*,nox64")
    (set_attr "type" "alu")
@@ -8504,7 +8510,7 @@
    (set_attr "mode" "QI")])
 
 (define_insn "*andqi_ext_2"
-  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "=Q")
+  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "+Q")
 			 (const_int 8)
 			 (const_int 8))
 	(subreg:SI
@@ -8518,7 +8524,9 @@
 			       (const_int 8)
 			       (const_int 8)) 0)) 0))
    (clobber (reg:CC FLAGS_REG))]
-  ""
+  "/* FIXME: without this LRA can't reload this pattern, see PR82524.  */
+   rtx_equal_p (operands[0], operands[1])
+   || rtx_equal_p (operands[0], operands[2])"
   "and{b}\t{%h2, %h0|%h0, %h2}"
   [(set_attr "type" "alu")
    (set_attr "mode" "QI")])
@@ -8845,7 +8853,7 @@
    (set_attr "mode" "<MODE>")])
 
 (define_insn "*<code>qi_ext_1"
-  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "=Q,Q")
+  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "+Q,Q")
 			 (const_int 8)
 			 (const_int 8))
 	(subreg:SI
@@ -8856,7 +8864,9 @@
 			       (const_int 8)) 0)
 	    (match_operand:QI 2 "general_operand" "QnBc,m")) 0))
    (clobber (reg:CC FLAGS_REG))]
-  "!TARGET_PARTIAL_REG_STALL || optimize_function_for_size_p (cfun)"
+  "(!TARGET_PARTIAL_REG_STALL || optimize_function_for_size_p (cfun))
+   /* FIXME: without this LRA can't reload this pattern, see PR82524.  */
+   && rtx_equal_p (operands[0], operands[1])"
   "<logic>{b}\t{%2, %h0|%h0, %2}"
   [(set_attr "isa" "*,nox64")
    (set_attr "type" "alu")
@@ -8863,7 +8873,7 @@
    (set_attr "mode" "QI")])
 
 (define_insn "*<code>qi_ext_2"
-  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "=Q")
+  [(set (zero_extract:SI (match_operand 0 "ext_register_operand" "+Q")
 			 (const_int 8)
 			 (const_int 8))
 	(subreg:SI
@@ -8877,7 +8887,10 @@
 			       (const_int 8)
 			       (const_int 8)) 0)) 0))
    (clobber (reg:CC FLAGS_REG))]
-  "!TARGET_PARTIAL_REG_STALL || optimize_function_for_size_p (cfun)"
+  "(!TARGET_PARTIAL_REG_STALL || optimize_function_for_size_p (cfun))
+   /* FIXME: without this LRA can't reload this pattern, see PR82524.  */
+   && (rtx_equal_p (operands[0], operands[1])
+       || rtx_equal_p (operands[0], operands[2]))"
   "<logic>{b}\t{%h2, %h0|%h0, %h2}"
   [(set_attr "type" "alu")
    (set_attr "mode" "QI")])
@@ -8966,7 +8979,7 @@
 			       (const_int 8)) 0)
 	    (match_operand:QI 2 "general_operand" "QnBc,m"))
 	  (const_int 0)))
-   (set (zero_extract:SI (match_operand 0 "ext_register_operand" "=Q,Q")
+   (set (zero_extract:SI (match_operand 0 "ext_register_operand" "+Q,Q")
 			 (const_int 8)
 			 (const_int 8))
 	(subreg:SI
@@ -8976,7 +8989,9 @@
 			       (const_int 8)
 			       (const_int 8)) 0)
 	  (match_dup 2)) 0))]
-  "ix86_match_ccmode (insn, CCNOmode)"
+  "ix86_match_ccmode (insn, CCNOmode)
+   /* FIXME: without this LRA can't reload this pattern, see PR82524.  */
+   && rtx_equal_p (operands[0], operands[1])"
   "xor{b}\t{%2, %h0|%h0, %2}"
   [(set_attr "isa" "*,nox64")
    (set_attr "type" "alu")
Index: gcc/config/i386/predicates.md
===================================================================
--- gcc/config/i386/predicates.md	(.../tags/gcc_7_2_0_release)
+++ gcc/config/i386/predicates.md	(.../branches/gcc-7-branch)
@@ -975,9 +975,9 @@
   (match_code "mem")
 {
   unsigned n_elts;
-  op = maybe_get_pool_constant (op);
+  op = avoid_constant_pool_reference (op);
 
-  if (!(op && GET_CODE (op) == CONST_VECTOR))
+  if (GET_CODE (op) != CONST_VECTOR)
     return false;
 
   n_elts = CONST_VECTOR_NUNITS (op);
Index: gcc/config/i386/i386-protos.h
===================================================================
--- gcc/config/i386/i386-protos.h	(.../tags/gcc_7_2_0_release)
+++ gcc/config/i386/i386-protos.h	(.../branches/gcc-7-branch)
@@ -282,8 +282,6 @@
 
 extern int i386_pe_reloc_rw_mask (void);
 
-extern rtx maybe_get_pool_constant (rtx);
-
 extern char internal_label_prefix[16];
 extern int internal_label_prefix_len;
 
Index: gcc/config/i386/i386.c
===================================================================
--- gcc/config/i386/i386.c	(.../tags/gcc_7_2_0_release)
+++ gcc/config/i386/i386.c	(.../branches/gcc-7-branch)
@@ -85,6 +85,9 @@
 #include "print-rtl.h"
 #include "intl.h"
 #include "ifcvt.h"
+#include "symbol-summary.h"
+#include "ipa-prop.h"
+#include "ipa-inline.h"
 
 /* This file should be included last.  */
 #include "target-def.h"
@@ -6288,12 +6291,6 @@
   gcc_assert ((opts->x_target_flags & MASK_LONG_DOUBLE_64) == 0
 	      || (opts->x_target_flags & MASK_LONG_DOUBLE_128) == 0);
 
-  /* Save the initial options in case the user does function specific
-     options.  */
-  if (main_args_p)
-    target_option_default_node = target_option_current_node
-      = build_target_option_node (opts);
-
   /* Handle stack protector */
   if (!opts_set->x_ix86_stack_protector_guard)
     opts->x_ix86_stack_protector_guard
@@ -6314,6 +6311,12 @@
       free (str);
     }
 
+  /* Save the initial options in case the user does function specific
+     options.  */
+  if (main_args_p)
+    target_option_default_node = target_option_current_node
+      = build_target_option_node (opts);
+
   return true;
 }
 
@@ -7114,7 +7117,14 @@
       else if (caller_opts->tune != callee_opts->tune)
 	ret = false;
 
-      else if (caller_opts->x_ix86_fpmath != callee_opts->x_ix86_fpmath)
+      else if (caller_opts->x_ix86_fpmath != callee_opts->x_ix86_fpmath
+	       /* If the calle doesn't use FP expressions differences in
+		  ix86_fpmath can be ignored.  We are called from FEs
+		  for multi-versioning call optimization, so beware of
+		  inline_summaries not available.  */
+	       && (! inline_summaries
+		   || inline_summaries->get
+			(cgraph_node::get (callee))->fp_expressions))
 	ret = false;
 
       else if (caller_opts->branch_cost != callee_opts->branch_cost)
@@ -19820,20 +19830,6 @@
   emit_insn (tmp);
 }
 
-/* X is an unchanging MEM.  If it is a constant pool reference, return
-   the constant pool rtx, else NULL.  */
-
-rtx
-maybe_get_pool_constant (rtx x)
-{
-  x = ix86_delegitimize_address (XEXP (x, 0));
-
-  if (GET_CODE (x) == SYMBOL_REF && CONSTANT_POOL_ADDRESS_P (x))
-    return get_pool_constant (x);
-
-  return NULL_RTX;
-}
-
 void
 ix86_expand_move (machine_mode mode, rtx operands[])
 {
@@ -20704,13 +20700,13 @@
 
   if (signed_p)
     {
-      div = gen_rtx_DIV (SImode, operands[2], operands[3]);
-      mod = gen_rtx_MOD (SImode, operands[2], operands[3]);
+      div = gen_rtx_DIV (mode, operands[2], operands[3]);
+      mod = gen_rtx_MOD (mode, operands[2], operands[3]);
     }
   else
     {
-      div = gen_rtx_UDIV (SImode, operands[2], operands[3]);
-      mod = gen_rtx_UMOD (SImode, operands[2], operands[3]);
+      div = gen_rtx_UDIV (mode, operands[2], operands[3]);
+      mod = gen_rtx_UMOD (mode, operands[2], operands[3]);
     }
 
   /* Extract remainder from AH.  */
@@ -25361,11 +25357,7 @@
   /* Optimize constant pool reference to immediates.  This is used by fp
      moves, that force all constants to memory to allow combining.  */
   if (MEM_P (operand) && MEM_READONLY_P (operand))
-    {
-      rtx tmp = maybe_get_pool_constant (operand);
-      if (tmp)
-	operand = tmp;
-    }
+    operand = avoid_constant_pool_reference (operand);
 
   if (MEM_P (operand) && !offsettable_memref_p (operand))
     {
@@ -32826,6 +32818,9 @@
     {
       const char *str = TREE_STRING_POINTER (TREE_VALUE (arg));
       size_t len = strlen (str);
+      /* Skip empty string.  */
+      if (len == 0)
+	continue;
       str_len_sum += len + 1;
       if (arg != arglist)
 	argnum++;
@@ -32840,11 +32835,21 @@
     {
       const char *str = TREE_STRING_POINTER (TREE_VALUE (arg));
       size_t len = strlen (str);
+      /* Skip empty string.  */
+      if (len == 0)
+	continue;
       memcpy (attr_str + str_len_sum, str, len);
       attr_str[str_len_sum + len] = TREE_CHAIN (arg) ? ',' : '\0';
       str_len_sum += len + 1;
     }
 
+  /* Strip ',' character at the end.  */
+  if (str_len_sum > 0 && attr_str[str_len_sum - 1] == ',')
+    {
+      attr_str[str_len_sum - 1] = '\0';
+      str_len_sum--;
+    }
+
   /* Replace "=,-" with "_".  */
   for (i = 0; i < strlen (attr_str); i++)
     if (attr_str[i] == '=' || attr_str[i]== '-')
@@ -33464,6 +33469,7 @@
     M_INTEL_KNL,
     M_AMD_BTVER1,
     M_AMD_BTVER2,    
+    M_AMDFAM17H,
     M_CPU_SUBTYPE_START,
     M_INTEL_COREI7_NEHALEM,
     M_INTEL_COREI7_WESTMERE,
@@ -33518,6 +33524,7 @@
       {"bdver3", M_AMDFAM15H_BDVER3},
       {"bdver4", M_AMDFAM15H_BDVER4},
       {"btver2", M_AMD_BTVER2},
+      {"amdfam17h", M_AMDFAM17H},
       {"znver1", M_AMDFAM17H_ZNVER1},
     };
 
Index: gcc/config/sol2.h
===================================================================
--- gcc/config/sol2.h	(.../tags/gcc_7_2_0_release)
+++ gcc/config/sol2.h	(.../branches/gcc-7-branch)
@@ -174,9 +174,9 @@
 			    %{!ansi:values-Xa.o%s}"
 
 #if defined(HAVE_LD_PIE) && defined(HAVE_SOLARIS_CRTS)
-#define STARTFILE_CRTBEGIN_SPEC "%{shared:crtbeginS.o%s} \
-				 %{" PIE_SPEC ":crtbeginS.o%s} \
-				 %{" NO_PIE_SPEC ":crtbegin.o%s}"
+#define STARTFILE_CRTBEGIN_SPEC "%{static:crtbegin.o%s; \
+				   shared|" PIE_SPEC ":crtbeginS.o%s; \
+				   :crtbegin.o%s}"
 #else
 #define STARTFILE_CRTBEGIN_SPEC	"crtbegin.o%s"
 #endif
@@ -224,9 +224,9 @@
 #endif
 
 #if defined(HAVE_LD_PIE) && defined(HAVE_SOLARIS_CRTS)
-#define ENDFILE_CRTEND_SPEC "%{shared:crtendS.o%s;: \
-			       %{" PIE_SPEC ":crtendS.o%s} \
-			       %{" NO_PIE_SPEC ":crtend.o%s}}"
+#define ENDFILE_CRTEND_SPEC "%{static:crtend.o%s; \
+			       shared|" PIE_SPEC ":crtendS.o%s; \
+			       :crtend.o%s}"
 #else
 #define ENDFILE_CRTEND_SPEC "crtend.o%s"
 #endif
Index: gcc/config/sh/sh-mem.cc
===================================================================
--- gcc/config/sh/sh-mem.cc	(.../tags/gcc_7_2_0_release)
+++ gcc/config/sh/sh-mem.cc	(.../branches/gcc-7-branch)
@@ -349,12 +349,13 @@
 
   rtx len = copy_to_mode_reg (SImode, operands[3]);
   int constp = CONST_INT_P (operands[3]);
+  HOST_WIDE_INT bytes = constp ? INTVAL (operands[3]) : 0;
 
   const unsigned int addr1_alignment = MEM_ALIGN (operands[1]) / BITS_PER_UNIT;
   const unsigned int addr2_alignment = MEM_ALIGN (operands[2]) / BITS_PER_UNIT;
 
   /* Loop on a register count.  */
-  if (constp)
+  if (constp && bytes >= 0 && bytes < 32)
     {
       rtx tmp0 = gen_reg_rtx (SImode);
       rtx tmp3 = gen_reg_rtx (SImode);
@@ -363,7 +364,6 @@
       rtx_code_label *L_loop_long = gen_label_rtx ();
       rtx_code_label *L_end_loop_long = gen_label_rtx ();
 
-      int bytes = INTVAL (operands[3]);
       int witers = bytes / 4;
 
       if (witers > 1)
Index: gcc/config/avr/avr.c
===================================================================
--- gcc/config/avr/avr.c	(.../tags/gcc_7_2_0_release)
+++ gcc/config/avr/avr.c	(.../branches/gcc-7-branch)
@@ -1095,7 +1095,7 @@
       || 0 == strcmp ("INTERRUPT", name)
       || 0 == strcmp ("SIGNAL", name))
     {
-      warning_at (loc, OPT_Wmisspelled_isr, "%qs is a reserved indentifier"
+      warning_at (loc, OPT_Wmisspelled_isr, "%qs is a reserved identifier"
                   " in AVR-LibC.  Consider %<#include <avr/interrupt.h>%>"
                   " before using the %qs macro", name, name);
     }
@@ -9549,10 +9549,12 @@
   bool io_p = (strncmp (IDENTIFIER_POINTER (name), "io", 2) == 0);
   location_t loc = DECL_SOURCE_LOCATION (*node);
 
-  if (TREE_CODE (*node) != VAR_DECL)
+  if (!VAR_P (*node))
     {
-      warning_at (loc, 0, "%qE attribute only applies to variables", name);
+      warning_at (loc, OPT_Wattributes, "%qE attribute only applies to "
+		  "variables", name);
       *no_add = true;
+      return NULL_TREE;
     }
 
   if (args != NULL_TREE)
@@ -9562,8 +9564,8 @@
       tree arg = TREE_VALUE (args);
       if (TREE_CODE (arg) != INTEGER_CST)
 	{
-	  warning (0, "%qE attribute allows only an integer constant argument",
-		   name);
+	  warning_at (loc, OPT_Wattributes, "%qE attribute allows only an "
+		      "integer constant argument", name);
 	  *no_add = true;
 	}
       else if (io_p
@@ -9572,19 +9574,20 @@
 			? low_io_address_operand : io_address_operand)
 			 (GEN_INT (TREE_INT_CST_LOW (arg)), QImode)))
 	{
-	  warning_at (loc, 0, "%qE attribute address out of range", name);
+	  warning_at (loc, OPT_Wattributes, "%qE attribute address "
+		      "out of range", name);
 	  *no_add = true;
 	}
       else
 	{
 	  tree attribs = DECL_ATTRIBUTES (*node);
-	  const char *names[] = { "io", "io_low", "address", NULL } ;
+	  const char *names[] = { "io", "io_low", "address", NULL };
 	  for (const char **p = names; *p; p++)
 	    {
 	      tree other = lookup_attribute (*p, attribs);
 	      if (other && TREE_VALUE (other))
 		{
-		  warning_at (loc, 0,
+		  warning_at (loc, OPT_Wattributes,
 			      "both %s and %qE attribute provide address",
 			      *p, name);
 		  *no_add = true;
@@ -9595,7 +9598,8 @@
     }
 
   if (*no_add == false && io_p && !TREE_THIS_VOLATILE (*node))
-    warning_at (loc, 0, "%qE attribute on non-volatile variable", name);
+    warning_at (loc, OPT_Wattributes, "%qE attribute on non-volatile variable",
+		name);
 
   return NULL_TREE;
 }
@@ -9643,11 +9647,11 @@
     false },
   { "OS_main",   0, 0, false, true,  true,   avr_handle_fntype_attribute,
     false },
-  { "io",        0, 1, false, false, false,  avr_handle_addr_attribute,
+  { "io",        0, 1, true, false, false,  avr_handle_addr_attribute,
     false },
-  { "io_low",    0, 1, false, false, false,  avr_handle_addr_attribute,
+  { "io_low",    0, 1, true, false, false,  avr_handle_addr_attribute,
     false },
-  { "address",   1, 1, false, false, false,  avr_handle_addr_attribute,
+  { "address",   1, 1, true, false, false,  avr_handle_addr_attribute,
     false },
   { "absdata",   0, 0, true, false, false,  avr_handle_absdata_attribute,
     false },
Index: gcc/config/xtensa/xtensa.c
===================================================================
--- gcc/config/xtensa/xtensa.c	(.../tags/gcc_7_2_0_release)
+++ gcc/config/xtensa/xtensa.c	(.../branches/gcc-7-branch)
@@ -605,6 +605,7 @@
     case HImode:
       return xtensa_uimm8x2 (v);
 
+    case DImode:
     case DFmode:
       return (xtensa_uimm8x4 (v) && xtensa_uimm8x4 (v + 4));
 
Index: gcc/config/netbsd.c
===================================================================
--- gcc/config/netbsd.c	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/config/netbsd.c	(.../branches/gcc-7-branch)
@@ -0,0 +1,54 @@
+/* Functions for generic NetBSD as target machine for GNU C compiler.
+   Copyright (C) 2017 Free Software Foundation, Inc.
+
+This file is part of GCC.
+
+GCC is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3, or (at your option)
+any later version.
+
+GCC is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GCC; see the file COPYING3.  If not see
+<http://www.gnu.org/licenses/>.  */
+
+#include "config.h"
+#include "system.h"
+#include "coretypes.h"
+#include "tm.h"
+#include "tree.h"
+#include "varasm.h"
+#include "netbsd-protos.h"
+
+static void
+netbsd_patch_builtin (enum built_in_function fncode)
+{
+  tree fn = builtin_decl_explicit (fncode);
+  tree sym;
+  char *newname;
+
+  if (!fn)
+    return;
+
+  sym = DECL_ASSEMBLER_NAME (fn);
+  newname = ACONCAT (("__c99_", IDENTIFIER_POINTER (sym), NULL));
+
+  set_user_assembler_name (fn, newname);
+
+  fn = builtin_decl_implicit (fncode);
+  if (fn)
+    set_user_assembler_name (fn, newname);
+}
+
+void
+netbsd_patch_builtins (void)
+{
+  netbsd_patch_builtin (BUILT_IN_CABSF);
+  netbsd_patch_builtin (BUILT_IN_CABS);
+  netbsd_patch_builtin (BUILT_IN_CABSL);
+}
Index: gcc/config/netbsd.h
===================================================================
--- gcc/config/netbsd.h	(.../tags/gcc_7_2_0_release)
+++ gcc/config/netbsd.h	(.../branches/gcc-7-branch)
@@ -96,6 +96,7 @@
        %{!pg:-lposix}}		\
      %{p:-lposix_p}		\
      %{pg:-lposix_p}}		\
+   %{shared:-lc}		\
    %{!shared:			\
      %{!symbolic:		\
        %{!p:			\
@@ -109,6 +110,7 @@
        %{!pg:-lposix}}		\
      %{p:-lposix_p}		\
      %{pg:-lposix_p}}		\
+   %{shared:-lc}		\
    %{!shared:			\
      %{!symbolic:		\
        %{!p:			\
@@ -120,8 +122,7 @@
 #undef LIB_SPEC
 #define LIB_SPEC NETBSD_LIB_SPEC
 
-/* Provide a LIBGCC_SPEC appropriate for NetBSD.  We also want to exclude
-   libgcc with -symbolic.  */
+/* Provide a LIBGCC_SPEC appropriate for NetBSD.  */
 
 #ifdef NETBSD_NATIVE
 #define NETBSD_LIBGCC_SPEC	\
@@ -133,7 +134,7 @@
      %{p: -lgcc_p}		\
      %{pg: -lgcc_p}}"
 #else
-#define NETBSD_LIBGCC_SPEC "%{!shared:%{!symbolic: -lgcc}}"
+#define NETBSD_LIBGCC_SPEC "-lgcc"
 #endif
 
 #undef LIBGCC_SPEC
@@ -179,3 +180,9 @@
 
 #undef WINT_TYPE
 #define WINT_TYPE "int"
+
+#undef  SUBTARGET_INIT_BUILTINS
+#define SUBTARGET_INIT_BUILTINS						\
+  do {									\
+    netbsd_patch_builtins ();						\
+  } while(0)
Index: gcc/config/netbsd-protos.h
===================================================================
--- gcc/config/netbsd-protos.h	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/config/netbsd-protos.h	(.../branches/gcc-7-branch)
@@ -0,0 +1,20 @@
+/* Prototypes.
+   Copyright (C) 2017 Free Software Foundation, Inc.
+
+This file is part of GCC.
+
+GCC is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 3, or (at your option)
+any later version.
+
+GCC is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with GCC; see the file COPYING3.  If not see
+<http://www.gnu.org/licenses/>.  */
+
+extern void netbsd_patch_builtins (void);
Index: gcc/config/gnu-user.h
===================================================================
--- gcc/config/gnu-user.h	(.../tags/gcc_7_2_0_release)
+++ gcc/config/gnu-user.h	(.../branches/gcc-7-branch)
@@ -50,11 +50,15 @@
 
 #if defined HAVE_LD_PIE
 #define GNU_USER_TARGET_STARTFILE_SPEC \
-  "%{!shared: %{pg|p|profile:gcrt1.o%s;: \
-    %{" PIE_SPEC ":Scrt1.o%s} %{" NO_PIE_SPEC ":crt1.o%s}}} \
-   crti.o%s %{static:crtbeginT.o%s;: %{shared:crtbeginS.o%s} \
-	      %{" PIE_SPEC ":crtbeginS.o%s} \
-	      %{" NO_PIE_SPEC ":crtbegin.o%s}} \
+  "%{shared:; \
+     pg|p|profile:gcrt1.o%s; \
+     static:crt1.o%s; \
+     " PIE_SPEC ":Scrt1.o%s; \
+     :crt1.o%s} \
+   crti.o%s \
+   %{static:crtbeginT.o%s; \
+     shared|" PIE_SPEC ":crtbeginS.o%s; \
+     :crtbegin.o%s} \
    %{fvtable-verify=none:%s; \
      fvtable-verify=preinit:vtv_start_preinit.o%s; \
      fvtable-verify=std:vtv_start.o%s} \
@@ -61,8 +65,13 @@
    " CRTOFFLOADBEGIN
 #else
 #define GNU_USER_TARGET_STARTFILE_SPEC \
-  "%{!shared: %{pg|p|profile:gcrt1.o%s;:crt1.o%s}} \
-   crti.o%s %{static:crtbeginT.o%s;shared|pie:crtbeginS.o%s;:crtbegin.o%s} \
+  "%{shared:; \
+     pg|p|profile:gcrt1.o%s; \
+     :crt1.o%s} \
+   crti.o%s \
+   %{static:crtbeginT.o%s; \
+     shared|pie:crtbeginS.o%s; \
+     :crtbegin.o%s} \
    %{fvtable-verify=none:%s; \
      fvtable-verify=preinit:vtv_start_preinit.o%s; \
      fvtable-verify=std:vtv_start.o%s} \
@@ -82,8 +91,10 @@
   "%{fvtable-verify=none:%s; \
      fvtable-verify=preinit:vtv_end_preinit.o%s; \
      fvtable-verify=std:vtv_end.o%s} \
-   %{shared:crtendS.o%s;: %{" PIE_SPEC ":crtendS.o%s} \
-   %{" NO_PIE_SPEC ":crtend.o%s}} crtn.o%s \
+   %{static:crtend.o%s; \
+     shared|" PIE_SPEC ":crtendS.o%s; \
+     :crtend.o%s} \
+   crtn.o%s \
    " CRTOFFLOADEND
 #else
 #define GNU_USER_TARGET_ENDFILE_SPEC \
@@ -90,7 +101,10 @@
   "%{fvtable-verify=none:%s; \
      fvtable-verify=preinit:vtv_end_preinit.o%s; \
      fvtable-verify=std:vtv_end.o%s} \
-   %{shared|pie:crtendS.o%s;:crtend.o%s} crtn.o%s \
+   %{static:crtend.o%s; \
+     shared|pie:crtendS.o%s; \
+     :crtend.o%s} \
+   crtn.o%s \
    " CRTOFFLOADEND
 #endif
 #undef  ENDFILE_SPEC
Index: gcc/config/riscv/rtems.h
===================================================================
--- gcc/config/riscv/rtems.h	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ gcc/config/riscv/rtems.h	(.../branches/gcc-7-branch)
@@ -0,0 +1,31 @@
+/* Definitions for RISC-V RTEMS systems with ELF format.
+   Copyright (C) 2017 Free Software Foundation, Inc.
+
+   This file is part of GCC.
+
+   GCC is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published
+   by the Free Software Foundation; either version 3, or (at your
+   option) any later version.
+
+   GCC is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
+   License for more details.
+
+   Under Section 7 of GPL version 3, you are granted additional
+   permissions described in the GCC Runtime Library Exception, version
+   3.1, as published by the Free Software Foundation.
+
+   You should have received a copy of the GNU General Public License and
+   a copy of the GCC Runtime Library Exception along with this program;
+   see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
+   <http://www.gnu.org/licenses/>.  */
+
+#undef TARGET_OS_CPP_BUILTINS
+#define TARGET_OS_CPP_BUILTINS()		\
+    do {					\
+	builtin_define ("__rtems__");		\
+	builtin_define ("__USE_INIT_FINI__");	\
+	builtin_assert ("system=rtems");	\
+    } while (0)
Index: gcc/config/aarch64/aarch64.c
===================================================================
--- gcc/config/aarch64/aarch64.c	(.../tags/gcc_7_2_0_release)
+++ gcc/config/aarch64/aarch64.c	(.../branches/gcc-7-branch)
@@ -2764,12 +2764,13 @@
 static bool
 aarch64_frame_pointer_required (void)
 {
-  /* In aarch64_override_options_after_change
-     flag_omit_leaf_frame_pointer turns off the frame pointer by
-     default.  Turn it back on now if we've not got a leaf
-     function.  */
-  if (flag_omit_leaf_frame_pointer
-      && (!crtl->is_leaf || df_regs_ever_live_p (LR_REGNUM)))
+  /* Use the frame pointer if enabled and it is not a leaf function, unless
+     leaf frame pointer omission is disabled.  If the frame pointer is enabled,
+     force the frame pointer in leaf functions which use LR.  */
+  if (flag_omit_frame_pointer == 2
+      && !(flag_omit_leaf_frame_pointer
+	   && crtl->is_leaf
+	   && !df_regs_ever_live_p (LR_REGNUM)))
     return true;
 
   /* Force a frame pointer for EH returns so the return address is at FP+8.  */
@@ -5623,6 +5624,7 @@
 	 LR in the function, then we'll want a frame pointer after all, so
 	 prevent this elimination to ensure a frame pointer is used.  */
       if (to == STACK_POINTER_REGNUM
+	  && flag_omit_frame_pointer == 2
 	  && flag_omit_leaf_frame_pointer
 	  && df_regs_ever_live_p (LR_REGNUM))
 	return false;
@@ -8573,24 +8575,16 @@
 static void
 aarch64_override_options_after_change_1 (struct gcc_options *opts)
 {
-  /* The logic here is that if we are disabling all frame pointer generation
-     then we do not need to disable leaf frame pointer generation as a
-     separate operation.  But if we are *only* disabling leaf frame pointer
-     generation then we set flag_omit_frame_pointer to true, but in
-     aarch64_frame_pointer_required we return false only for leaf functions.
+  /* PR 70044: We have to be careful about being called multiple times for the
+     same function.  This means all changes should be repeatable.  */
 
-     PR 70044: We have to be careful about being called multiple times for the
-     same function.  Once we have decided to set flag_omit_frame_pointer just
-     so that we can omit leaf frame pointers, we must then not interpret a
-     second call as meaning that all frame pointer generation should be
-     omitted.  We do this by setting flag_omit_frame_pointer to a special,
-     non-zero value.  */
-  if (opts->x_flag_omit_frame_pointer == 2)
-    opts->x_flag_omit_frame_pointer = 0;
-
-  if (opts->x_flag_omit_frame_pointer)
-    opts->x_flag_omit_leaf_frame_pointer = false;
-  else if (opts->x_flag_omit_leaf_frame_pointer)
+  /* If the frame pointer is enabled, set it to a special value that behaves
+     similar to frame pointer omission.  If we don't do this all leaf functions
+     will get a frame pointer even if flag_omit_leaf_frame_pointer is set.
+     If flag_omit_frame_pointer has this special value, we must force the
+     frame pointer if not in a leaf function.  We also need to force it in a
+     leaf function if flag_omit_frame_pointer is not set or if LR is used.  */
+  if (opts->x_flag_omit_frame_pointer == 0)
     opts->x_flag_omit_frame_pointer = 2;
 
   /* If not optimizing for size, set the default
@@ -11509,19 +11503,9 @@
       if (optab_handler (movmisalign_optab, mode) == CODE_FOR_nothing)
         return false;
 
+      /* Misalignment factor is unknown at compile time.  */
       if (misalignment == -1)
-	{
-	  /* Misalignment factor is unknown at compile time but we know
-	     it's word aligned.  */
-	  if (aarch64_simd_vector_alignment_reachable (type, is_packed))
-            {
-              int element_size = TREE_INT_CST_LOW (TYPE_SIZE (type));
-
-              if (element_size != 64)
-                return true;
-            }
-	  return false;
-	}
+	return false;
     }
   return default_builtin_support_vector_misalignment (mode, type, misalignment,
 						      is_packed);
Index: gcc/config/aarch64/aarch64.h
===================================================================
--- gcc/config/aarch64/aarch64.h	(.../tags/gcc_7_2_0_release)
+++ gcc/config/aarch64/aarch64.h	(.../branches/gcc-7-branch)
@@ -958,4 +958,12 @@
 extern tree aarch64_fp16_type_node;
 extern tree aarch64_fp16_ptr_type_node;
 
+/* The generic unwind code in libgcc does not initialize the frame pointer.
+   So in order to unwind a function using a frame pointer, the very first
+   function that is unwound must save the frame pointer.  That way the frame
+   pointer is restored and its value is now valid - otherwise _Unwind_GetGR
+   crashes.  Libgcc can now be safely built with -fomit-frame-pointer.  */
+#define LIBGCC2_UNWIND_ATTRIBUTE \
+  __attribute__((optimize ("no-omit-frame-pointer")))
+
 #endif /* GCC_AARCH64_H */
Index: gcc/config/rs6000/rtems.h
===================================================================
--- gcc/config/rs6000/rtems.h	(.../tags/gcc_7_2_0_release)
+++ gcc/config/rs6000/rtems.h	(.../branches/gcc-7-branch)
@@ -37,6 +37,15 @@
 #undef	TARGET_AIX
 #define	TARGET_AIX TARGET_64BIT
 
+/* Simplified copy and paste from linux64.h and freebsd64.h */
+#undef DOT_SYMBOLS
+#define DOT_SYMBOLS 0
+
+/* Copy and paste from linux64.h and freebsd64.h */
+#undef TARGET_CMODEL
+#define TARGET_CMODEL rs6000_current_cmodel
+#define SET_CMODEL(opt) rs6000_current_cmodel = opt
+
 #undef TARGET_OS_CPP_BUILTINS
 #define TARGET_OS_CPP_BUILTINS()			\
   do							\
@@ -64,6 +73,15 @@
   while (0)
 
 /* Copy and paste from linux64.h and freebsd64.h */
+#undef RELOCATABLE_NEEDS_FIXUP
+#define RELOCATABLE_NEEDS_FIXUP \
+  (rs6000_isa_flags & rs6000_isa_flags_explicit & OPTION_MASK_RELOCATABLE)
+
+/* Copy and paste from linux64.h */
+#undef	RS6000_ABI_NAME
+#define	RS6000_ABI_NAME "linux"
+
+/* Copy and paste from linux64.h and freebsd64.h */
 #define INVALID_64BIT "-m%s not supported in this configuration"
 
 /* A lot of copy and paste from linux64.h and freebsd64.h */
@@ -95,6 +113,24 @@
 	      rs6000_isa_flags |= OPTION_MASK_POWERPC64;	\
 	      error ("-m64 requires a PowerPC64 cpu");		\
 	    }							\
+	  if ((rs6000_isa_flags_explicit			\
+		& OPTION_MASK_MINIMAL_TOC) != 0)		\
+	    {							\
+	      if (global_options_set.x_rs6000_current_cmodel	\
+		  && rs6000_current_cmodel != CMODEL_SMALL)	\
+		error ("-mcmodel incompatible with other toc options"); \
+	      SET_CMODEL (CMODEL_SMALL);			\
+	    }							\
+	  else							\
+	    {							\
+	      if (!global_options_set.x_rs6000_current_cmodel)	\
+		SET_CMODEL (CMODEL_MEDIUM);			\
+	      if (rs6000_current_cmodel != CMODEL_SMALL)	\
+		{						\
+		  TARGET_NO_FP_IN_TOC = 0;			\
+		  TARGET_NO_SUM_IN_TOC = 0;			\
+		}						\
+	    }							\
 	}							\
     }								\
   while (0)
@@ -141,6 +177,30 @@
 #define RESTORE_FP_SUFFIX ""
 
 /* Copy and paste from linux64.h and freebsd64.h */
+#undef	ASM_PREFERRED_EH_DATA_FORMAT
+#define	ASM_PREFERRED_EH_DATA_FORMAT(CODE, GLOBAL) \
+  (TARGET_64BIT || flag_pic						\
+   ? (((GLOBAL) ? DW_EH_PE_indirect : 0) | DW_EH_PE_pcrel		\
+      | (TARGET_64BIT ? DW_EH_PE_udata8 : DW_EH_PE_sdata4))		\
+   : DW_EH_PE_absptr)
+
+/* Copy and paste from linux64.h and freebsd64.h */
+#undef  TOC_SECTION_ASM_OP
+#define TOC_SECTION_ASM_OP \
+  (TARGET_64BIT						\
+   ? "\t.section\t\".toc\",\"aw\""			\
+   : "\t.section\t\".got\",\"aw\"")
+
+/* Copy and paste from linux64.h and freebsd64.h */
+#undef  MINIMAL_TOC_SECTION_ASM_OP
+#define MINIMAL_TOC_SECTION_ASM_OP \
+  (TARGET_64BIT						\
+   ? "\t.section\t\".toc1\",\"aw\""			\
+   : (flag_pic						\
+      ? "\t.section\t\".got2\",\"aw\""			\
+      : "\t.section\t\".got1\",\"aw\""))
+
+/* Copy and paste from linux64.h and freebsd64.h */
 #undef	ASM_DECLARE_FUNCTION_SIZE
 #define	ASM_DECLARE_FUNCTION_SIZE(FILE, FNAME, DECL)			\
   do									\
Index: gcc/config/rs6000/rs6000-c.c
===================================================================
--- gcc/config/rs6000/rs6000-c.c	(.../tags/gcc_7_2_0_release)
+++ gcc/config/rs6000/rs6000-c.c	(.../branches/gcc-7-branch)
@@ -6218,7 +6218,13 @@
 
       /* Strip qualifiers like "const" from the pointer arg.  */
       tree arg1_type = TREE_TYPE (arg1);
-      if (!POINTER_TYPE_P (arg1_type) && TREE_CODE (arg1_type) != ARRAY_TYPE)
+      if (TREE_CODE (arg1_type) == ARRAY_TYPE && c_dialect_cxx ())
+	{
+	  /* Force array-to-pointer decay for C++.  */
+	  arg1 = default_conversion (arg1);
+	  arg1_type = TREE_TYPE (arg1);
+	}
+      if (!POINTER_TYPE_P (arg1_type))
 	goto bad;
 
       tree inner_type = TREE_TYPE (arg1_type);
@@ -6238,15 +6244,6 @@
 	  if (!ptrofftype_p (TREE_TYPE (arg0)))
 	    arg0 = build1 (NOP_EXPR, sizetype, arg0);
 
-	  tree arg1_type = TREE_TYPE (arg1);
-	  if (TREE_CODE (arg1_type) == ARRAY_TYPE)
-	    {
-	      arg1_type = TYPE_POINTER_TO (TREE_TYPE (arg1_type));
-	      tree const0 = build_int_cstu (sizetype, 0);
-	      tree arg1_elt0 = build_array_ref (loc, arg1, const0);
-	      arg1 = build1 (ADDR_EXPR, arg1_type, arg1_elt0);
-	    }
-
 	  tree addr = fold_build2_loc (loc, POINTER_PLUS_EXPR, arg1_type,
 				       arg1, arg0);
 	  tree aligned = fold_build2_loc (loc, BIT_AND_EXPR, arg1_type, addr,
@@ -6301,12 +6298,11 @@
 	    arg1 = build1 (NOP_EXPR, sizetype, arg1);
 
 	  tree arg2_type = TREE_TYPE (arg2);
-	  if (TREE_CODE (arg2_type) == ARRAY_TYPE)
+	  if (TREE_CODE (arg2_type) == ARRAY_TYPE && c_dialect_cxx ())
 	    {
-	      arg2_type = TYPE_POINTER_TO (TREE_TYPE (arg2_type));
-	      tree const0 = build_int_cstu (sizetype, 0);
-	      tree arg2_elt0 = build_array_ref (loc, arg2, const0);
-	      arg2 = build1 (ADDR_EXPR, arg2_type, arg2_elt0);
+	      /* Force array-to-pointer decay for C++.  */
+	      arg2 = default_conversion (arg2);
+	      arg2_type = TREE_TYPE (arg2);
 	    }
 
 	  /* Find the built-in to make sure a compatible one exists; if not
Index: gcc/config/rs6000/rs6000.c
===================================================================
--- gcc/config/rs6000/rs6000.c	(.../tags/gcc_7_2_0_release)
+++ gcc/config/rs6000/rs6000.c	(.../branches/gcc-7-branch)
@@ -5766,8 +5766,20 @@
 	if (SCALAR_FLOAT_TYPE_P (elem_type)
 	    && TYPE_PRECISION (elem_type) == 32)
 	  return 5;
+	/* On POWER9, integer vector types are built up in GPRs and then
+           use a direct move (2 cycles).  For POWER8 this is even worse,
+           as we need two direct moves and a merge, and the direct moves
+	   are five cycles.  */
+	else if (INTEGRAL_TYPE_P (elem_type))
+	  {
+	    if (TARGET_P9_VECTOR)
+	      return TYPE_VECTOR_SUBPARTS (vectype) - 1 + 2;
+	    else
+	      return TYPE_VECTOR_SUBPARTS (vectype) - 1 + 5;
+	  }
 	else
-	  return max (2, TYPE_VECTOR_SUBPARTS (vectype) - 1);
+	  /* V2DFmode doesn't need a direct move.  */
+	  return 2;
 
       default:
         gcc_unreachable ();
@@ -27718,24 +27730,23 @@
 rtx
 rs6000_return_addr (int count, rtx frame)
 {
-  /* Currently we don't optimize very well between prolog and body
-     code and for PIC code the code can be actually quite bad, so
-     don't try to be too clever here.  */
+  /* We can't use get_hard_reg_initial_val for LR when count == 0 if LR
+     is trashed by the prologue, as it is for PIC on ABI_V4 and Darwin.  */
   if (count != 0
       || ((DEFAULT_ABI == ABI_V4 || DEFAULT_ABI == ABI_DARWIN) && flag_pic))
     {
       cfun->machine->ra_needs_full_frame = 1;
 
-      return
-	gen_rtx_MEM
-	  (Pmode,
-	   memory_address
-	   (Pmode,
-	    plus_constant (Pmode,
-			   copy_to_reg
-			   (gen_rtx_MEM (Pmode,
-					 memory_address (Pmode, frame))),
-			   RETURN_ADDRESS_OFFSET)));
+      if (count == 0)
+	/* FRAME is set to frame_pointer_rtx by the generic code, but that
+	   is good for loading 0(r1) only when !FRAME_GROWS_DOWNWARD.  */
+	frame = stack_pointer_rtx;
+      rtx prev_frame_addr = memory_address (Pmode, frame);
+      rtx prev_frame = copy_to_reg (gen_rtx_MEM (Pmode, prev_frame_addr));
+      rtx lr_save_off = plus_constant (Pmode,
+				       prev_frame, RETURN_ADDRESS_OFFSET);
+      rtx lr_save_addr = memory_address (Pmode, lr_save_off);
+      return gen_rtx_MEM (Pmode, lr_save_addr);
     }
 
   cfun->machine->ra_need_lr = 1;
@@ -39555,6 +39566,22 @@
 /* Remember the last target of rs6000_set_current_function.  */
 static GTY(()) tree rs6000_previous_fndecl;
 
+/* Restore target's globals from NEW_TREE and invalidate the
+   rs6000_previous_fndecl cache.  */
+
+static void
+rs6000_activate_target_options (tree new_tree)
+{
+  cl_target_option_restore (&global_options, TREE_TARGET_OPTION (new_tree));
+  if (TREE_TARGET_GLOBALS (new_tree))
+    restore_target_globals (TREE_TARGET_GLOBALS (new_tree));
+  else if (new_tree == target_option_default_node)
+    restore_target_globals (&default_target_globals);
+  else
+    TREE_TARGET_GLOBALS (new_tree) = save_target_globals_default_opts ();
+  rs6000_previous_fndecl = NULL_TREE;
+}
+
 /* Establish appropriate back-end context for processing the function
    FNDECL.  The argument might be NULL to indicate processing at top
    level, outside of any function scope.  */
@@ -39561,17 +39588,8 @@
 static void
 rs6000_set_current_function (tree fndecl)
 {
-  tree old_tree = (rs6000_previous_fndecl
-		   ? DECL_FUNCTION_SPECIFIC_TARGET (rs6000_previous_fndecl)
-		   : NULL_TREE);
-
-  tree new_tree = (fndecl
-		   ? DECL_FUNCTION_SPECIFIC_TARGET (fndecl)
-		   : NULL_TREE);
-
   if (TARGET_DEBUG_TARGET)
     {
-      bool print_final = false;
       fprintf (stderr, "\n==================== rs6000_set_current_function");
 
       if (fndecl)
@@ -39584,11 +39602,43 @@
 	fprintf (stderr, ", prev_fndecl (%p)", (void *)rs6000_previous_fndecl);
 
       fprintf (stderr, "\n");
+    }
+
+  /* Only change the context if the function changes.  This hook is called
+     several times in the course of compiling a function, and we don't want to
+     slow things down too much or call target_reinit when it isn't safe.  */
+  if (fndecl == rs6000_previous_fndecl)
+    return;
+
+  tree old_tree;
+  if (rs6000_previous_fndecl == NULL_TREE)
+    old_tree = target_option_current_node;
+  else if (DECL_FUNCTION_SPECIFIC_TARGET (rs6000_previous_fndecl))
+    old_tree = DECL_FUNCTION_SPECIFIC_TARGET (rs6000_previous_fndecl);
+  else
+    old_tree = target_option_default_node;
+
+  tree new_tree;
+  if (fndecl == NULL_TREE)
+    {
+      if (old_tree != target_option_current_node)
+	new_tree = target_option_current_node;
+      else
+	new_tree = NULL_TREE;
+    }
+  else
+    {
+      new_tree = DECL_FUNCTION_SPECIFIC_TARGET (fndecl);
+      if (new_tree == NULL_TREE)
+	new_tree = target_option_default_node;
+    }
+
+  if (TARGET_DEBUG_TARGET)
+    {
       if (new_tree)
 	{
 	  fprintf (stderr, "\nnew fndecl target specific options:\n");
 	  debug_tree (new_tree);
-	  print_final = true;
 	}
 
       if (old_tree)
@@ -39595,47 +39645,17 @@
 	{
 	  fprintf (stderr, "\nold fndecl target specific options:\n");
 	  debug_tree (old_tree);
-	  print_final = true;
 	}
 
-      if (print_final)
+      if (old_tree != NULL_TREE || new_tree != NULL_TREE)
 	fprintf (stderr, "--------------------\n");
     }
 
-  /* Only change the context if the function changes.  This hook is called
-     several times in the course of compiling a function, and we don't want to
-     slow things down too much or call target_reinit when it isn't safe.  */
-  if (fndecl && fndecl != rs6000_previous_fndecl)
-    {
-      rs6000_previous_fndecl = fndecl;
-      if (old_tree == new_tree)
-	;
+  if (new_tree && old_tree != new_tree)
+    rs6000_activate_target_options (new_tree);
 
-      else if (new_tree && new_tree != target_option_default_node)
-	{
-	  cl_target_option_restore (&global_options,
-				    TREE_TARGET_OPTION (new_tree));
-	  if (TREE_TARGET_GLOBALS (new_tree))
-	    restore_target_globals (TREE_TARGET_GLOBALS (new_tree));
-	  else
-	    TREE_TARGET_GLOBALS (new_tree)
-	      = save_target_globals_default_opts ();
-	}
-
-      else if (old_tree && old_tree != target_option_default_node)
-	{
-	  new_tree = target_option_current_node;
-	  cl_target_option_restore (&global_options,
-				    TREE_TARGET_OPTION (new_tree));
-	  if (TREE_TARGET_GLOBALS (new_tree))
-	    restore_target_globals (TREE_TARGET_GLOBALS (new_tree));
-	  else if (new_tree == target_option_default_node)
-	    restore_target_globals (&default_target_globals);
-	  else
-	    TREE_TARGET_GLOBALS (new_tree)
-	      = save_target_globals_default_opts ();
-	}
-    }
+  if (fndecl)
+    rs6000_previous_fndecl = fndecl;
 }
 
 
@@ -42693,9 +42713,10 @@
 }
 
 /* Given INSN that's a load or store based at BASE_REG, look for a
-   feeding computation that aligns its address on a 16-byte boundary.  */
+   feeding computation that aligns its address on a 16-byte boundary.
+   Return the rtx and its containing AND_INSN.  */
 static rtx
-find_alignment_op (rtx_insn *insn, rtx base_reg)
+find_alignment_op (rtx_insn *insn, rtx base_reg, rtx_insn **and_insn)
 {
   df_ref base_use;
   struct df_insn_info *insn_info = DF_INSN_INFO_GET (insn);
@@ -42716,8 +42737,8 @@
       if (DF_REF_IS_ARTIFICIAL (base_def_link->ref))
 	break;
 
-      rtx_insn *and_insn = DF_REF_INSN (base_def_link->ref);
-      and_operation = alignment_mask (and_insn);
+      *and_insn = DF_REF_INSN (base_def_link->ref);
+      and_operation = alignment_mask (*and_insn);
       if (and_operation != 0)
 	break;
     }
@@ -42739,7 +42760,8 @@
   rtx mem = XEXP (SET_SRC (body), 0);
   rtx base_reg = XEXP (mem, 0);
 
-  rtx and_operation = find_alignment_op (insn, base_reg);
+  rtx_insn *and_insn;
+  rtx and_operation = find_alignment_op (insn, base_reg, &and_insn);
 
   if (and_operation != 0)
     {
@@ -42763,7 +42785,21 @@
 	  to_delete[INSN_UID (swap_insn)].replace = true;
 	  to_delete[INSN_UID (swap_insn)].replace_insn = swap_insn;
 
-	  XEXP (mem, 0) = and_operation;
+	  /* However, first we must be sure that we make the
+	     base register from the AND operation available
+	     in case the register has been overwritten.  Copy
+	     the base register to a new pseudo and use that
+	     as the base register of the AND operation in
+	     the new LVX instruction.  */
+	  rtx and_base = XEXP (and_operation, 0);
+	  rtx new_reg = gen_reg_rtx (GET_MODE (and_base));
+	  rtx copy = gen_rtx_SET (new_reg, and_base);
+	  rtx_insn *new_insn = emit_insn_after (copy, and_insn);
+	  set_block_for_insn (new_insn, BLOCK_FOR_INSN (and_insn));
+	  df_insn_rescan (new_insn);
+
+	  XEXP (mem, 0) = gen_rtx_AND (GET_MODE (and_base), new_reg,
+				       XEXP (and_operation, 1));
 	  SET_SRC (body) = mem;
 	  INSN_CODE (insn) = -1; /* Force re-recognition.  */
 	  df_insn_rescan (insn);
@@ -42786,7 +42822,8 @@
   rtx mem = SET_DEST (body);
   rtx base_reg = XEXP (mem, 0);
 
-  rtx and_operation = find_alignment_op (insn, base_reg);
+  rtx_insn *and_insn;
+  rtx and_operation = find_alignment_op (insn, base_reg, &and_insn);
 
   if (and_operation != 0)
     {
@@ -42814,7 +42851,21 @@
 	  to_delete[INSN_UID (swap_insn)].replace = true;
 	  to_delete[INSN_UID (swap_insn)].replace_insn = swap_insn;
 
-	  XEXP (mem, 0) = and_operation;
+	  /* However, first we must be sure that we make the
+	     base register from the AND operation available
+	     in case the register has been overwritten.  Copy
+	     the base register to a new pseudo and use that
+	     as the base register of the AND operation in
+	     the new STVX instruction.  */
+	  rtx and_base = XEXP (and_operation, 0);
+	  rtx new_reg = gen_reg_rtx (GET_MODE (and_base));
+	  rtx copy = gen_rtx_SET (new_reg, and_base);
+	  rtx_insn *new_insn = emit_insn_after (copy, and_insn);
+	  set_block_for_insn (new_insn, BLOCK_FOR_INSN (and_insn));
+	  df_insn_rescan (new_insn);
+
+	  XEXP (mem, 0) = gen_rtx_AND (GET_MODE (and_base), new_reg,
+				       XEXP (and_operation, 1));
 	  SET_SRC (body) = src_reg;
 	  INSN_CODE (insn) = -1; /* Force re-recognition.  */
 	  df_insn_rescan (insn);
Index: gcc/config/rs6000/vsx.md
===================================================================
--- gcc/config/rs6000/vsx.md	(.../tags/gcc_7_2_0_release)
+++ gcc/config/rs6000/vsx.md	(.../branches/gcc-7-branch)
@@ -736,17 +736,20 @@
 ;; special V1TI container class, which it is not appropriate to use vec_select
 ;; for the type.
 (define_insn "*vsx_le_permute_<mode>"
-  [(set (match_operand:VSX_LE_128 0 "nonimmediate_operand" "=<VSa>,<VSa>,Z")
+  [(set (match_operand:VSX_LE_128 0 "nonimmediate_operand" "=<VSa>,<VSa>,Z,&r,&r,Q")
 	(rotate:VSX_LE_128
-	 (match_operand:VSX_LE_128 1 "input_operand" "<VSa>,Z,<VSa>")
+	 (match_operand:VSX_LE_128 1 "input_operand" "<VSa>,Z,<VSa>,r,Q,r")
 	 (const_int 64)))]
   "!BYTES_BIG_ENDIAN && TARGET_VSX && !TARGET_P9_VECTOR"
   "@
    xxpermdi %x0,%x1,%x1,2
    lxvd2x %x0,%y1
-   stxvd2x %x1,%y0"
-  [(set_attr "length" "4")
-   (set_attr "type" "vecperm,vecload,vecstore")])
+   stxvd2x %x1,%y0
+   mr %0,%L1\;mr %L0,%1
+   ld%U1%X1 %0,%L1\;ld%U1%X1 %L0,%1
+   std%U0%X0 %L1,%0\;std%U0%X0 %1,%L0"
+  [(set_attr "length" "4,4,4,8,8,8")
+   (set_attr "type" "vecperm,vecload,vecstore,*,load,store")])
 
 (define_insn_and_split "*vsx_le_undo_permute_<mode>"
   [(set (match_operand:VSX_LE_128 0 "vsx_register_operand" "=<VSa>,<VSa>")
@@ -772,10 +775,12 @@
    (set_attr "type" "veclogical")])
 
 (define_insn_and_split "*vsx_le_perm_load_<mode>"
-  [(set (match_operand:VSX_LE_128 0 "vsx_register_operand" "=<VSa>")
-        (match_operand:VSX_LE_128 1 "memory_operand" "Z"))]
+  [(set (match_operand:VSX_LE_128 0 "vsx_register_operand" "=<VSa>,r")
+	(match_operand:VSX_LE_128 1 "memory_operand" "Z,Q"))]
   "!BYTES_BIG_ENDIAN && TARGET_VSX && !TARGET_P9_VECTOR"
-  "#"
+  "@
+   #
+   #"
   "!BYTES_BIG_ENDIAN && TARGET_VSX && !TARGET_P9_VECTOR"
   [(set (match_dup 2)
 	(rotate:VSX_LE_128 (match_dup 1)
@@ -789,16 +794,18 @@
                                        : operands[0];
 }
   "
-  [(set_attr "type" "vecload")
-   (set_attr "length" "8")])
+  [(set_attr "type" "vecload,load")
+   (set_attr "length" "8,8")])
 
 (define_insn "*vsx_le_perm_store_<mode>"
-  [(set (match_operand:VSX_LE_128 0 "memory_operand" "=Z")
-        (match_operand:VSX_LE_128 1 "vsx_register_operand" "+<VSa>"))]
+  [(set (match_operand:VSX_LE_128 0 "memory_operand" "=Z,Q")
+	(match_operand:VSX_LE_128 1 "vsx_register_operand" "+<VSa>,r"))]
   "!BYTES_BIG_ENDIAN && TARGET_VSX && !TARGET_P9_VECTOR"
-  "#"
-  [(set_attr "type" "vecstore")
-   (set_attr "length" "12")])
+  "@
+   #
+   #"
+  [(set_attr "type" "vecstore,store")
+   (set_attr "length" "12,8")])
 
 (define_split
   [(set (match_operand:VSX_LE_128 0 "memory_operand" "")
@@ -815,6 +822,31 @@
                                        : operands[0];
 })
 
+;; Peepholes to catch loads and stores for TImode if TImode landed in
+;; GPR registers on a little endian system.
+(define_peephole2
+  [(set (match_operand:VSX_LE_128 0 "int_reg_operand")
+	(rotate:VSX_LE_128 (match_operand:VSX_LE_128 1 "memory_operand")
+			   (const_int 64)))
+   (set (match_operand:VSX_LE_128 2 "int_reg_operand")
+	(rotate:VSX_LE_128 (match_dup 0)
+			   (const_int 64)))]
+  "!BYTES_BIG_ENDIAN && TARGET_VSX && TARGET_VSX_TIMODE && !TARGET_P9_VECTOR
+   && (rtx_equal_p (operands[0], operands[2])
+       || peep2_reg_dead_p (2, operands[0]))"
+   [(set (match_dup 2) (match_dup 1))])
+
+(define_peephole2
+  [(set (match_operand:VSX_LE_128 0 "int_reg_operand")
+	(rotate:VSX_LE_128 (match_operand:VSX_LE_128 1 "int_reg_operand")
+			   (const_int 64)))
+   (set (match_operand:VSX_LE_128 2 "memory_operand")
+	(rotate:VSX_LE_128 (match_dup 0)
+			   (const_int 64)))]
+  "!BYTES_BIG_ENDIAN && TARGET_VSX && TARGET_VSX_TIMODE && !TARGET_P9_VECTOR
+   && peep2_reg_dead_p (2, operands[0])"
+   [(set (match_dup 2) (match_dup 1))])
+
 ;; Peephole to catch memory to memory transfers for TImode if TImode landed in
 ;; VSX registers on a little endian system.  The vector types and IEEE 128-bit
 ;; floating point are handled by the more generic swap elimination pass.
@@ -2017,6 +2049,80 @@
 }
   [(set_attr "type" "vecperm")])
 
+;; Combiner patterns to allow creating XXPERMDI's to access either double
+;; word element in a vector register.
+(define_insn "*vsx_concat_<mode>_1"
+  [(set (match_operand:VSX_D 0 "vsx_register_operand" "=<VSa>")
+	(vec_concat:VSX_D
+	 (vec_select:<VS_scalar>
+	  (match_operand:VSX_D 1 "gpc_reg_operand" "<VSa>")
+	  (parallel [(match_operand:QI 2 "const_0_to_1_operand" "n")]))
+	 (match_operand:<VS_scalar> 3 "gpc_reg_operand" "<VSa>")))]
+  "VECTOR_MEM_VSX_P (<MODE>mode)"
+{
+  HOST_WIDE_INT dword = INTVAL (operands[2]);
+  if (BYTES_BIG_ENDIAN)
+    {
+      operands[4] = GEN_INT (2*dword);
+      return "xxpermdi %x0,%x1,%x3,%4";
+    }
+  else
+    {
+      operands[4] = GEN_INT (!dword);
+      return "xxpermdi %x0,%x3,%x1,%4";
+    }
+}
+  [(set_attr "type" "vecperm")])
+
+(define_insn "*vsx_concat_<mode>_2"
+  [(set (match_operand:VSX_D 0 "vsx_register_operand" "=<VSa>")
+	(vec_concat:VSX_D
+	 (match_operand:<VS_scalar> 1 "gpc_reg_operand" "<VSa>")
+	 (vec_select:<VS_scalar>
+	  (match_operand:VSX_D 2 "gpc_reg_operand" "<VSa>")
+	  (parallel [(match_operand:QI 3 "const_0_to_1_operand" "n")]))))]
+  "VECTOR_MEM_VSX_P (<MODE>mode)"
+{
+  HOST_WIDE_INT dword = INTVAL (operands[3]);
+  if (BYTES_BIG_ENDIAN)
+    {
+      operands[4] = GEN_INT (dword);
+      return "xxpermdi %x0,%x1,%x2,%4";
+    }
+  else
+    {
+      operands[4] = GEN_INT (2 * !dword);
+      return "xxpermdi %x0,%x2,%x1,%4";
+    }
+}
+  [(set_attr "type" "vecperm")])
+
+(define_insn "*vsx_concat_<mode>_3"
+  [(set (match_operand:VSX_D 0 "vsx_register_operand" "=<VSa>")
+	(vec_concat:VSX_D
+	 (vec_select:<VS_scalar>
+	  (match_operand:VSX_D 1 "gpc_reg_operand" "<VSa>")
+	  (parallel [(match_operand:QI 2 "const_0_to_1_operand" "n")]))
+	 (vec_select:<VS_scalar>
+	  (match_operand:VSX_D 3 "gpc_reg_operand" "<VSa>")
+	  (parallel [(match_operand:QI 4 "const_0_to_1_operand" "n")]))))]
+  "VECTOR_MEM_VSX_P (<MODE>mode)"
+{
+  HOST_WIDE_INT dword1 = INTVAL (operands[2]);
+  HOST_WIDE_INT dword2 = INTVAL (operands[4]);
+  if (BYTES_BIG_ENDIAN)
+    {
+      operands[5] = GEN_INT ((2 * dword1) + dword2);
+      return "xxpermdi %x0,%x1,%x3,%5";
+    }
+  else
+    {
+      operands[5] = GEN_INT ((2 * !dword2) + !dword1);
+      return "xxpermdi %x0,%x3,%x1,%5";
+    }
+}
+  [(set_attr "type" "vecperm")])
+
 ;; Special purpose concat using xxpermdi to glue two single precision values
 ;; together, relying on the fact that internally scalar floats are represented
 ;; as doubles.  This is used to initialize a V4SF vector with 4 floats
@@ -2217,25 +2323,35 @@
   DONE;
 })
 
-;; Set the element of a V2DI/VD2F mode
-(define_insn "vsx_set_<mode>"
-  [(set (match_operand:VSX_D 0 "vsx_register_operand" "=wd,?<VSa>")
-	(unspec:VSX_D
-	 [(match_operand:VSX_D 1 "vsx_register_operand" "wd,<VSa>")
-	  (match_operand:<VS_scalar> 2 "vsx_register_operand" "<VS_64reg>,<VSa>")
-	  (match_operand:QI 3 "u5bit_cint_operand" "i,i")]
-	 UNSPEC_VSX_SET))]
+;; Rewrite V2DF/V2DI set in terms of VEC_CONCAT
+(define_expand "vsx_set_<mode>"
+  [(use (match_operand:VSX_D 0 "vsx_register_operand"))
+   (use (match_operand:VSX_D 1 "vsx_register_operand"))
+   (use (match_operand:<VS_scalar> 2 "gpc_reg_operand"))
+   (use (match_operand:QI 3 "const_0_to_1_operand"))]
   "VECTOR_MEM_VSX_P (<MODE>mode)"
 {
-  int idx_first = BYTES_BIG_ENDIAN ? 0 : 1;
-  if (INTVAL (operands[3]) == idx_first)
-    return \"xxpermdi %x0,%x2,%x1,1\";
-  else if (INTVAL (operands[3]) == 1 - idx_first)
-    return \"xxpermdi %x0,%x1,%x2,0\";
+  rtx dest = operands[0];
+  rtx vec_reg = operands[1];
+  rtx value = operands[2];
+  rtx ele = operands[3];
+  rtx tmp = gen_reg_rtx (<VS_scalar>mode);
+
+  if (ele == const0_rtx)
+    {
+      emit_insn (gen_vsx_extract_<mode> (tmp, vec_reg, const1_rtx));
+      emit_insn (gen_vsx_concat_<mode> (dest, value, tmp));
+      DONE;
+    }
+  else if (ele == const1_rtx)
+    {
+      emit_insn (gen_vsx_extract_<mode> (tmp, vec_reg, const0_rtx));
+      emit_insn (gen_vsx_concat_<mode> (dest, tmp, value));
+      DONE;
+    }
   else
     gcc_unreachable ();
-}
-  [(set_attr "type" "vecperm")])
+})
 
 ;; Extract a DF/DI element from V2DF/V2DI
 ;; Optimize cases were we can do a simple or direct move.
Index: gcc/config/rs6000/altivec.md
===================================================================
--- gcc/config/rs6000/altivec.md	(.../tags/gcc_7_2_0_release)
+++ gcc/config/rs6000/altivec.md	(.../branches/gcc-7-branch)
@@ -1749,51 +1749,61 @@
   "vsum4s<VI_char>s %0,%1,%2"
   [(set_attr "type" "veccomplex")])
 
-;; FIXME: For the following two patterns, the scratch should only be
-;; allocated for !VECTOR_ELT_ORDER_BIG, and the instructions should
-;; be emitted separately.
-(define_insn "altivec_vsum2sws"
-  [(set (match_operand:V4SI 0 "register_operand" "=v")
-        (unspec:V4SI [(match_operand:V4SI 1 "register_operand" "v")
-                      (match_operand:V4SI 2 "register_operand" "v")]
-		     UNSPEC_VSUM2SWS))
-   (set (reg:SI VSCR_REGNO) (unspec:SI [(const_int 0)] UNSPEC_SET_VSCR))
-   (clobber (match_scratch:V4SI 3 "=v"))]
+(define_expand "altivec_vsum2sws"
+  [(use (match_operand:V4SI 0 "register_operand"))
+   (use (match_operand:V4SI 1 "register_operand"))
+   (use (match_operand:V4SI 2 "register_operand"))]
   "TARGET_ALTIVEC"
 {
   if (VECTOR_ELT_ORDER_BIG)
-    return "vsum2sws %0,%1,%2";
+    emit_insn (gen_altivec_vsum2sws_direct (operands[0], operands[1],
+                                            operands[2]));
   else
-    return "vsldoi %3,%2,%2,12\n\tvsum2sws %3,%1,%3\n\tvsldoi %0,%3,%3,4";
-}
-  [(set_attr "type" "veccomplex")
-   (set (attr "length")
-     (if_then_else
-       (match_test "VECTOR_ELT_ORDER_BIG")
-       (const_string "4")
-       (const_string "12")))])
+    {
+      rtx tmp1 = gen_reg_rtx (V4SImode);
+      rtx tmp2 = gen_reg_rtx (V4SImode);
+      emit_insn (gen_altivec_vsldoi_v4si (tmp1, operands[2],
+                                          operands[2], GEN_INT (12)));
+      emit_insn (gen_altivec_vsum2sws_direct (tmp2, operands[1], tmp1));
+      emit_insn (gen_altivec_vsldoi_v4si (operands[0], tmp2, tmp2,
+                                          GEN_INT (4)));
+    }
+  DONE;
+})
 
-(define_insn "altivec_vsumsws"
+; FIXME: This can probably be expressed without an UNSPEC.
+(define_insn "altivec_vsum2sws_direct"
   [(set (match_operand:V4SI 0 "register_operand" "=v")
         (unspec:V4SI [(match_operand:V4SI 1 "register_operand" "v")
-                      (match_operand:V4SI 2 "register_operand" "v")]
-		     UNSPEC_VSUMSWS))
-   (set (reg:SI VSCR_REGNO) (unspec:SI [(const_int 0)] UNSPEC_SET_VSCR))
-   (clobber (match_scratch:V4SI 3 "=v"))]
+	              (match_operand:V4SI 2 "register_operand" "v")]
+		     UNSPEC_VSUM2SWS))
+   (set (reg:SI VSCR_REGNO) (unspec:SI [(const_int 0)] UNSPEC_SET_VSCR))]
   "TARGET_ALTIVEC"
+  "vsum2sws %0,%1,%2"
+  [(set_attr "type" "veccomplex")])
+
+(define_expand "altivec_vsumsws"
+  [(use (match_operand:V4SI 0 "register_operand"))
+   (use (match_operand:V4SI 1 "register_operand"))
+   (use (match_operand:V4SI 2 "register_operand"))]
+  "TARGET_ALTIVEC"
 {
   if (VECTOR_ELT_ORDER_BIG)
-    return "vsumsws %0,%1,%2";
+    emit_insn (gen_altivec_vsumsws_direct (operands[0], operands[1],
+                                           operands[2]));
   else
-    return "vspltw %3,%2,0\n\tvsumsws %3,%1,%3\n\tvsldoi %0,%3,%3,12";
-}
-  [(set_attr "type" "veccomplex")
-   (set (attr "length")
-     (if_then_else
-       (match_test "(VECTOR_ELT_ORDER_BIG)")
-       (const_string "4")
-       (const_string "12")))])
+    {
+      rtx tmp1 = gen_reg_rtx (V4SImode);
+      rtx tmp2 = gen_reg_rtx (V4SImode);
+      emit_insn (gen_altivec_vspltw_direct (tmp1, operands[2], const0_rtx));
+      emit_insn (gen_altivec_vsumsws_direct (tmp2, operands[1], tmp1));
+      emit_insn (gen_altivec_vsldoi_v4si (operands[0], tmp2, tmp2,
+                                          GEN_INT (12)));
+    }
+  DONE;
+})
 
+; FIXME: This can probably be expressed without an UNSPEC.
 (define_insn "altivec_vsumsws_direct"
   [(set (match_operand:V4SI 0 "register_operand" "=v")
         (unspec:V4SI [(match_operand:V4SI 1 "register_operand" "v")
Index: gcc/config/rs6000/sysv4.h
===================================================================
--- gcc/config/rs6000/sysv4.h	(.../tags/gcc_7_2_0_release)
+++ gcc/config/rs6000/sysv4.h	(.../branches/gcc-7-branch)
@@ -757,24 +757,34 @@
 #define CRTOFFLOADEND ""
 #endif
 
-#ifdef HAVE_LD_PIE
-#define	STARTFILE_LINUX_SPEC "\
-%{!shared: %{pg|p|profile:gcrt1.o%s;pie:Scrt1.o%s;:crt1.o%s}} \
-%{mnewlib:ecrti.o%s;:crti.o%s} \
-%{static:crtbeginT.o%s;shared|pie:crtbeginS.o%s;:crtbegin.o%s} \
-" CRTOFFLOADBEGIN
-#else
-#define	STARTFILE_LINUX_SPEC "\
-%{!shared: %{pg|p|profile:gcrt1.o%s;:crt1.o%s}} \
-%{mnewlib:ecrti.o%s;:crti.o%s} \
-%{static:crtbeginT.o%s;shared|pie:crtbeginS.o%s;:crtbegin.o%s} \
-" CRTOFFLOADBEGIN
-#endif
+/* STARTFILE_LINUX_SPEC should be the same as GNU_USER_TARGET_STARTFILE_SPEC
+   but with the mnewlib ecrti.o%s selection substituted for crti.o%s.  */
+#define	STARTFILE_LINUX_SPEC \
+  "%{shared:; \
+     pg|p|profile:gcrt1.o%s; \
+     static:crt1.o%s; \
+     " PIE_SPEC ":Scrt1.o%s; \
+     :crt1.o%s} \
+   %{mnewlib:ecrti.o%s;:crti.o%s} \
+   %{static:crtbeginT.o%s; \
+     shared|" PIE_SPEC ":crtbeginS.o%s; \
+     :crtbegin.o%s} \
+   %{fvtable-verify=none:%s; \
+     fvtable-verify=preinit:vtv_start_preinit.o%s; \
+     fvtable-verify=std:vtv_start.o%s} \
+   " CRTOFFLOADBEGIN
 
-#define	ENDFILE_LINUX_SPEC "\
-%{shared|pie:crtendS.o%s;:crtend.o%s} \
-%{mnewlib:ecrtn.o%s;:crtn.o%s} \
-" CRTOFFLOADEND
+/* ENDFILE_LINUX_SPEC should be the same as GNU_USER_TARGET_ENDFILE_SPEC
+   but with the mnewlib ecrtn.o%s selection substituted for crtn.o%s.  */
+#define ENDFILE_LINUX_SPEC \
+  "%{fvtable-verify=none:%s; \
+     fvtable-verify=preinit:vtv_end_preinit.o%s; \
+     fvtable-verify=std:vtv_end.o%s} \
+   %{static:crtend.o%s; \
+     shared|" PIE_SPEC ":crtendS.o%s; \
+     :crtend.o%s} \
+   %{mnewlib:ecrtn.o%s;:crtn.o%s} \
+   " CRTOFFLOADEND
 
 #define LINK_START_LINUX_SPEC ""
 
Index: gcc/config/arm/arm.c
===================================================================
--- gcc/config/arm/arm.c	(.../tags/gcc_7_2_0_release)
+++ gcc/config/arm/arm.c	(.../branches/gcc-7-branch)
@@ -15199,12 +15199,23 @@
   return true;
 }
 
+/* Return true if a 64-bit access with alignment ALIGN and with a
+   constant offset OFFSET from the base pointer is permitted on this
+   architecture.  */
+static bool
+align_ok_ldrd_strd (HOST_WIDE_INT align, HOST_WIDE_INT offset)
+{
+  return (unaligned_access
+	  ? (align >= BITS_PER_WORD && (offset & 3) == 0)
+	  : (align >= 2 * BITS_PER_WORD && (offset & 7) == 0));
+}
+
 /* Helper for gen_operands_ldrd_strd.  Returns true iff the memory
    operand MEM's address contains an immediate offset from the base
-   register and has no side effects, in which case it sets BASE and
-   OFFSET accordingly.  */
+   register and has no side effects, in which case it sets BASE,
+   OFFSET and ALIGN accordingly.  */
 static bool
-mem_ok_for_ldrd_strd (rtx mem, rtx *base, rtx *offset)
+mem_ok_for_ldrd_strd (rtx mem, rtx *base, rtx *offset, HOST_WIDE_INT *align)
 {
   rtx addr;
 
@@ -15223,6 +15234,7 @@
   gcc_assert (MEM_P (mem));
 
   *offset = const0_rtx;
+  *align = MEM_ALIGN (mem);
 
   addr = XEXP (mem, 0);
 
@@ -15263,7 +15275,7 @@
                         bool const_store, bool commute)
 {
   int nops = 2;
-  HOST_WIDE_INT offsets[2], offset;
+  HOST_WIDE_INT offsets[2], offset, align[2];
   rtx base = NULL_RTX;
   rtx cur_base, cur_offset, tmp;
   int i, gap;
@@ -15275,7 +15287,8 @@
      registers, and the corresponding memory offsets.  */
   for (i = 0; i < nops; i++)
     {
-      if (!mem_ok_for_ldrd_strd (operands[nops+i], &cur_base, &cur_offset))
+      if (!mem_ok_for_ldrd_strd (operands[nops+i], &cur_base, &cur_offset,
+				 &align[i]))
         return false;
 
       if (i == 0)
@@ -15389,6 +15402,7 @@
       /* Swap the instructions such that lower memory is accessed first.  */
       std::swap (operands[0], operands[1]);
       std::swap (operands[2], operands[3]);
+      std::swap (align[0], align[1]);
       if (const_store)
         std::swap (operands[4], operands[5]);
     }
@@ -15402,6 +15416,9 @@
   if (gap != 4)
     return false;
 
+  if (!align_ok_ldrd_strd (align[0], offset))
+    return false;
+
   /* Make sure we generate legal instructions.  */
   if (operands_ok_ldrd_strd (operands[0], operands[1], base, offset,
                              false, load))
Index: gcc/tree-vect-slp.c
===================================================================
--- gcc/tree-vect-slp.c	(.../tags/gcc_7_2_0_release)
+++ gcc/tree-vect-slp.c	(.../branches/gcc-7-branch)
@@ -905,14 +905,51 @@
   return true;
 }
 
-/* Recursively build an SLP tree starting from NODE.
-   Fail (and return a value not equal to zero) if def-stmts are not
-   isomorphic, require data permutation or are of unsupported types of
-   operation.  Otherwise, return 0.
-   The value returned is the depth in the SLP tree where a mismatch
-   was found.  */
+/* Traits for the hash_set to record failed SLP builds for a stmt set.
+   Note we never remove apart from at destruction time so we do not
+   need a special value for deleted that differs from empty.  */
+struct bst_traits
+{
+  typedef vec <gimple *> value_type;
+  typedef vec <gimple *> compare_type;
+  static inline hashval_t hash (value_type);
+  static inline bool equal (value_type existing, value_type candidate);
+  static inline bool is_empty (value_type x) { return !x.exists (); }
+  static inline bool is_deleted (value_type x) { return !x.exists (); }
+  static inline void mark_empty (value_type &x) { x.release (); }
+  static inline void mark_deleted (value_type &x) { x.release (); }
+  static inline void remove (value_type &x) { x.release (); }
+};
+inline hashval_t
+bst_traits::hash (value_type x)
+{
+  inchash::hash h;
+  for (unsigned i = 0; i < x.length (); ++i)
+    h.add_int (gimple_uid (x[i]));
+  return h.end ();
+}
+inline bool
+bst_traits::equal (value_type existing, value_type candidate)
+{
+  if (existing.length () != candidate.length ())
+    return false;
+  for (unsigned i = 0; i < existing.length (); ++i)
+    if (existing[i] != candidate[i])
+      return false;
+  return true;
+}
 
+static hash_set <vec <gimple *>, bst_traits> *bst_fail;
+
 static slp_tree
+vect_build_slp_tree_2 (vec_info *vinfo,
+		       vec<gimple *> stmts, unsigned int group_size,
+		       unsigned int *max_nunits,
+		       vec<slp_tree> *loads,
+		       bool *matches, unsigned *npermutes, unsigned *tree_size,
+		       unsigned max_tree_size);
+
+static slp_tree
 vect_build_slp_tree (vec_info *vinfo,
                      vec<gimple *> stmts, unsigned int group_size,
                      unsigned int *max_nunits,
@@ -920,6 +957,39 @@
 		     bool *matches, unsigned *npermutes, unsigned *tree_size,
 		     unsigned max_tree_size)
 {
+  if (bst_fail->contains (stmts))
+    return NULL;
+  slp_tree res = vect_build_slp_tree_2 (vinfo, stmts, group_size, max_nunits,
+					loads, matches, npermutes, tree_size,
+					max_tree_size);
+  /* When SLP build fails for stmts record this, otherwise SLP build
+     can be exponential in time when we allow to construct parts from
+     scalars, see PR81723.  */
+  if (! res)
+    {
+      vec <gimple *> x;
+      x.create (stmts.length ());
+      x.splice (stmts);
+      bst_fail->add (x);
+    }
+  return res;
+}
+
+/* Recursively build an SLP tree starting from NODE.
+   Fail (and return a value not equal to zero) if def-stmts are not
+   isomorphic, require data permutation or are of unsupported types of
+   operation.  Otherwise, return 0.
+   The value returned is the depth in the SLP tree where a mismatch
+   was found.  */
+
+static slp_tree
+vect_build_slp_tree_2 (vec_info *vinfo,
+		       vec<gimple *> stmts, unsigned int group_size,
+		       unsigned int *max_nunits,
+		       vec<slp_tree> *loads,
+		       bool *matches, unsigned *npermutes, unsigned *tree_size,
+		       unsigned max_tree_size)
+{
   unsigned nops, i, this_tree_size = 0, this_max_nunits = *max_nunits;
   gimple *stmt;
   slp_tree node;
@@ -979,6 +1049,9 @@
 
   stmt = stmts[0];
 
+  if (tree_size)
+    max_tree_size -= *tree_size;
+
   /* Create SLP_TREE nodes for the definition node/s.  */
   FOR_EACH_VEC_ELT (oprnds_info, i, oprnd_info)
     {
@@ -1494,14 +1567,20 @@
       return true;
     }
 
-  /* For loop vectorization verify we can generate the permutation.  */
+  /* For loop vectorization verify we can generate the permutation.  Be
+     conservative about the vectorization factor, there are permutations
+     that will use three vector inputs only starting from a specific factor
+     and the vectorization factor is not yet final.
+     ???  The SLP instance unrolling factor might not be the maximum one.  */
   unsigned n_perms;
+  unsigned test_vf
+    = least_common_multiple (SLP_INSTANCE_UNROLLING_FACTOR (slp_instn),
+			     LOOP_VINFO_VECT_FACTOR
+			       (STMT_VINFO_LOOP_VINFO (vinfo_for_stmt (stmt))));
   FOR_EACH_VEC_ELT (SLP_INSTANCE_LOADS (slp_instn), i, node)
     if (node->load_permutation.exists ()
-	&& !vect_transform_slp_perm_load
-	      (node, vNULL, NULL,
-	       SLP_INSTANCE_UNROLLING_FACTOR (slp_instn), slp_instn, true,
-	       &n_perms))
+	&& !vect_transform_slp_perm_load (node, vNULL, NULL, test_vf,
+					  slp_instn, true, &n_perms))
       return false;
 
   return true;
@@ -1874,9 +1953,11 @@
   /* Build the tree for the SLP instance.  */
   bool *matches = XALLOCAVEC (bool, group_size);
   unsigned npermutes = 0;
+  bst_fail = new hash_set <vec <gimple *>, bst_traits> ();
   node = vect_build_slp_tree (vinfo, scalar_stmts, group_size,
 				   &max_nunits, &loads, matches, &npermutes,
 			      NULL, max_tree_size);
+  delete bst_fail;
   if (node != NULL)
     {
       /* Calculate the unrolling factor based on the smallest type.  */
@@ -3485,6 +3566,7 @@
 		  dump_gimple_stmt (MSG_MISSED_OPTIMIZATION, TDF_SLIM,
 				    stmt, 0);
 		}
+	      gcc_assert (analyze_only);
 	      return false;
 	    }
 
@@ -3508,6 +3590,7 @@
 			dump_printf (MSG_MISSED_OPTIMIZATION, "%d ", mask[i]);
 		      dump_printf (MSG_MISSED_OPTIMIZATION, "}\n");
 		    }
+		  gcc_assert (analyze_only);
 		  return false;
 		}
 
Index: gcc/langhooks-def.h
===================================================================
--- gcc/langhooks-def.h	(.../tags/gcc_7_2_0_release)
+++ gcc/langhooks-def.h	(.../branches/gcc-7-branch)
@@ -184,6 +184,7 @@
   lhd_omp_firstprivatize_type_sizes
 #define LANG_HOOKS_OMP_MAPPABLE_TYPE	lhd_omp_mappable_type
 #define LANG_HOOKS_TYPE_HASH_EQ		NULL
+#define LANG_HOOKS_COPY_LANG_QUALIFIERS NULL
 #define LANG_HOOKS_GET_ARRAY_DESCR_INFO	NULL
 #define LANG_HOOKS_GET_SUBRANGE_BOUNDS	NULL
 #define LANG_HOOKS_GET_TYPE_BIAS	NULL
@@ -209,6 +210,7 @@
   LANG_HOOKS_OMP_FIRSTPRIVATIZE_TYPE_SIZES, \
   LANG_HOOKS_OMP_MAPPABLE_TYPE, \
   LANG_HOOKS_TYPE_HASH_EQ, \
+  LANG_HOOKS_COPY_LANG_QUALIFIERS, \
   LANG_HOOKS_GET_ARRAY_DESCR_INFO, \
   LANG_HOOKS_GET_SUBRANGE_BOUNDS, \
   LANG_HOOKS_GET_TYPE_BIAS, \
Index: libgo/configure
===================================================================
--- libgo/configure	(.../tags/gcc_7_2_0_release)
+++ libgo/configure	(.../branches/gcc-7-branch)
@@ -13625,7 +13625,7 @@
 # supported by the gofrontend and all architectures supported by the
 # gc toolchain.
 # N.B. Keep in sync with gcc/testsuite/go.test/go-test.exp (go-set-goarch).
-ALLGOARCH="386 alpha amd64 amd64p32 arm armbe arm64 arm64be ia64 m68k mipso32 mipsn32 mipso64 mipsn64 mips mipsle mips64 mips64le mips64p32 mips64p32le ppc ppc64 ppc64le s390 s390x sparc sparc64"
+ALLGOARCH="386 alpha amd64 amd64p32 arm armbe arm64 arm64be ia64 m68k mips mipsle mips64 mips64le mips64p32 mips64p32le ppc ppc64 ppc64le s390 s390x sparc sparc64"
 
 # All known GOARCH_FAMILY values.
 ALLGOARCHFAMILY="I386 ALPHA AMD64 ARM ARM64 IA64 M68K MIPS MIPS64 PPC PPC64 S390 S390X SPARC SPARC64"
@@ -13728,16 +13728,6 @@
 if ac_fn_c_try_compile "$LINENO"; then :
   mips_abi="n64"
 else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-#if _MIPS_SIM != _ABIO64
-#error not o64
-#endif
-_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  mips_abi="o64"
-else
   as_fn_error "unknown MIPS ABI" "$LINENO" 5
 mips_abi="n32"
 fi
@@ -13746,13 +13736,10 @@
 rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 fi
 rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
     case "$mips_abi" in
-    "o32") GOARCH=mipso32 ;;
-    "n32") GOARCH=mipsn32 ;;
-    "n64") GOARCH=mipsn64 ;;
-    "o64") GOARCH=mipso64 ;;
+    "o32") GOARCH=mips ;;
+    "n32") GOARCH=mips64p32 ;;
+    "n64") GOARCH=mips64 ;;
     esac
     case "$mips_abi" in
     "o32" | "n32")
@@ -13759,13 +13746,14 @@
         GOARCH_FAMILY=MIPS
 	GOARCH_MINFRAMESIZE=4
         ;;
-    "n64" | "o64")
+    "n64")
         GOARCH_FAMILY=MIPS64
 	GOARCH_MINFRAMESIZE=8
         ;;
     esac
     case "${host}" in
-    mips*el)
+    mips*el-*-*)
+	GOARCH="${GOARCH}le"
         ;;
     *)
 	GOARCH_BIGENDIAN=1
@@ -14762,7 +14750,7 @@
   fi
 
 
-for ac_header in port.h sched.h semaphore.h sys/file.h sys/mman.h syscall.h sys/epoll.h sys/event.h sys/inotify.h sys/ptrace.h sys/syscall.h sys/user.h sys/utsname.h sys/select.h sys/socket.h net/if.h net/if_arp.h net/route.h netpacket/packet.h sys/prctl.h sys/mount.h sys/vfs.h sys/statfs.h sys/timex.h sys/sysinfo.h utime.h linux/ether.h linux/fs.h linux/reboot.h netinet/icmp6.h netinet/in_syst.h netinet/ip.h netinet/ip_mroute.h netinet/if_ether.h
+for ac_header in port.h sched.h semaphore.h sys/file.h sys/mman.h syscall.h sys/epoll.h sys/event.h sys/inotify.h sys/ptrace.h sys/syscall.h sys/user.h sys/utsname.h sys/select.h sys/socket.h net/if.h net/if_arp.h net/route.h netpacket/packet.h sys/prctl.h sys/mount.h sys/vfs.h sys/statfs.h sys/timex.h sys/sysinfo.h utime.h linux/ether.h linux/fs.h linux/ptrace.h linux/reboot.h netinet/icmp6.h netinet/in_syst.h netinet/ip.h netinet/ip_mroute.h netinet/if_ether.h
 do :
   as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
 ac_fn_c_check_header_mongrel "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default"
Index: libgo/VERSION
===================================================================
--- libgo/VERSION	(.../tags/gcc_7_2_0_release)
+++ libgo/VERSION	(.../branches/gcc-7-branch)
@@ -1 +1 @@
-go1.8.1
+go1.8.3
Index: libgo/testsuite/gotest
===================================================================
--- libgo/testsuite/gotest	(.../tags/gcc_7_2_0_release)
+++ libgo/testsuite/gotest	(.../branches/gcc-7-branch)
@@ -314,7 +314,7 @@
 	    android | darwin | dragonfly | freebsd | linux | nacl | netbsd | openbsd | plan9 | solaris | windows)
 		tag1=nonmatchingtag
 		;;
-	    386 | amd64 | amd64p32 | arm | armbe | arm64 | arm64be | alpha | ia64 | m68k | ppc64 | ppc64le | mips | mipsle | mips64 | mips64le | mips64p32 | mips64p32le | mipso32 | mipsn32 | mipsn64 | mipso64 | ppc | s390 | s390x | sparc | sparc64)
+	    386 | amd64 | amd64p32 | arm | armbe | arm64 | arm64be | alpha | ia64 | m68k | ppc64 | ppc64le | mips | mipsle | mips64 | mips64le | mips64p32 | mips64p32le | ppc | s390 | s390x | sparc | sparc64)
 		tag1=nonmatchingtag
 		;;
 	    esac
@@ -326,7 +326,7 @@
 	    android | darwin | dragonfly | freebsd | linux | nacl | netbsd | openbsd | plan9 | solaris | windows)
 		tag2=nonmatchingtag
 		;;
-	    386 | amd64 | amd64p32 | arm | armbe | arm64 | arm64be | alpha | ia64 | m68k | ppc64 | ppc64le | mips | mipsle | mips64 | mips64le | mips64p32 | mips64p32le | mipso32 | mipsn32 | mipsn64 | mipso64 | ppc | s390 | s390x | sparc | sparc64)
+	    386 | amd64 | amd64p32 | arm | armbe | arm64 | arm64be | alpha | ia64 | m68k | ppc64 | ppc64le | mips | mipsle | mips64 | mips64le | mips64p32 | mips64p32le | ppc | s390 | s390x | sparc | sparc64)
 		tag2=nonmatchingtag
 		;;
 	    esac
Index: libgo/mksysinfo.sh
===================================================================
--- libgo/mksysinfo.sh	(.../tags/gcc_7_2_0_release)
+++ libgo/mksysinfo.sh	(.../branches/gcc-7-branch)
@@ -295,16 +295,11 @@
 # _user_regs_struct.
 regs=`grep '^type _user_regs_struct struct' gen-sysinfo.go || true`
 if test "$regs" = ""; then
-  # s390
-  regs=`grep '^type __user_regs_struct struct' gen-sysinfo.go || true`
-  if test "$regs" != ""; then
-    # Substructures of __user_regs_struct on s390
-    upcase_fields "__user_psw_struct" "PtracePsw" >> ${OUT} || true
-    upcase_fields "__user_fpregs_struct" "PtraceFpregs" >> ${OUT} || true
-    upcase_fields "__user_per_struct" "PtracePer" >> ${OUT} || true
-  fi
+  # mips*
+  regs=`grep '^type _pt_regs struct' gen-sysinfo.go || true`
 fi
 if test "$regs" != ""; then
+  regs=`echo $regs | sed -e 's/type _pt_regs struct//'`
   regs=`echo $regs |
     sed -e 's/type __*user_regs_struct struct //' -e 's/[{}]//g'`
   regs=`echo $regs | sed -e s'/^ *//'`
Index: libgo/MERGE
===================================================================
--- libgo/MERGE	(.../tags/gcc_7_2_0_release)
+++ libgo/MERGE	(.../branches/gcc-7-branch)
@@ -1,4 +1,4 @@
-a4c18f063b6659079ca2848ca217a0587dabc001
+352996a381701cfa0c16e8de29cbde8f3922182f
 
 The first line of this file holds the git revision number of the
 last merge done from the master library sources.
Index: libgo/config.h.in
===================================================================
--- libgo/config.h.in	(.../tags/gcc_7_2_0_release)
+++ libgo/config.h.in	(.../branches/gcc-7-branch)
@@ -114,6 +114,9 @@
 /* Define to 1 if you have the <linux/netlink.h> header file. */
 #undef HAVE_LINUX_NETLINK_H
 
+/* Define to 1 if you have the <linux/ptrace.h> header file. */
+#undef HAVE_LINUX_PTRACE_H
+
 /* Define to 1 if you have the <linux/reboot.h> header file. */
 #undef HAVE_LINUX_REBOOT_H
 
Index: libgo/configure.ac
===================================================================
--- libgo/configure.ac	(.../tags/gcc_7_2_0_release)
+++ libgo/configure.ac	(.../branches/gcc-7-branch)
@@ -197,7 +197,7 @@
 # supported by the gofrontend and all architectures supported by the
 # gc toolchain.
 # N.B. Keep in sync with gcc/testsuite/go.test/go-test.exp (go-set-goarch).
-ALLGOARCH="386 alpha amd64 amd64p32 arm armbe arm64 arm64be ia64 m68k mipso32 mipsn32 mipso64 mipsn64 mips mipsle mips64 mips64le mips64p32 mips64p32le ppc ppc64 ppc64le s390 s390x sparc sparc64"
+ALLGOARCH="386 alpha amd64 amd64p32 arm armbe arm64 arm64be ia64 m68k mips mipsle mips64 mips64le mips64p32 mips64p32le ppc ppc64 ppc64le s390 s390x sparc sparc64"
 
 # All known GOARCH_FAMILY values.
 ALLGOARCHFAMILY="I386 ALPHA AMD64 ARM ARM64 IA64 M68K MIPS MIPS64 PPC PPC64 S390 S390X SPARC SPARC64"
@@ -280,18 +280,12 @@
 #error not n64
 #endif],
 [mips_abi="n64"],
-	[AC_COMPILE_IFELSE([
-#if _MIPS_SIM != _ABIO64
-#error not o64
-#endif],
-[mips_abi="o64"],
 	[AC_MSG_ERROR([unknown MIPS ABI])
-[mips_abi="n32"]])])])])
+[mips_abi="n32"]])])])
     case "$mips_abi" in
-    "o32") GOARCH=mipso32 ;;
-    "n32") GOARCH=mipsn32 ;;
-    "n64") GOARCH=mipsn64 ;;
-    "o64") GOARCH=mipso64 ;;
+    "o32") GOARCH=mips ;;
+    "n32") GOARCH=mips64p32 ;;
+    "n64") GOARCH=mips64 ;;
     esac
     case "$mips_abi" in
     "o32" | "n32")
@@ -298,13 +292,14 @@
         GOARCH_FAMILY=MIPS
 	GOARCH_MINFRAMESIZE=4
         ;;
-    "n64" | "o64")
+    "n64")
         GOARCH_FAMILY=MIPS64
 	GOARCH_MINFRAMESIZE=8
         ;;
     esac
     case "${host}" in
-    mips*el)
+    mips*el-*-*)
+        GOARCH="${GOARCH}le"
         ;;
     *)
 	GOARCH_BIGENDIAN=1
@@ -569,7 +564,7 @@
 
 GCC_CHECK_UNWIND_GETIPINFO
 
-AC_CHECK_HEADERS(port.h sched.h semaphore.h sys/file.h sys/mman.h syscall.h sys/epoll.h sys/event.h sys/inotify.h sys/ptrace.h sys/syscall.h sys/user.h sys/utsname.h sys/select.h sys/socket.h net/if.h net/if_arp.h net/route.h netpacket/packet.h sys/prctl.h sys/mount.h sys/vfs.h sys/statfs.h sys/timex.h sys/sysinfo.h utime.h linux/ether.h linux/fs.h linux/reboot.h netinet/icmp6.h netinet/in_syst.h netinet/ip.h netinet/ip_mroute.h netinet/if_ether.h)
+AC_CHECK_HEADERS(port.h sched.h semaphore.h sys/file.h sys/mman.h syscall.h sys/epoll.h sys/event.h sys/inotify.h sys/ptrace.h sys/syscall.h sys/user.h sys/utsname.h sys/select.h sys/socket.h net/if.h net/if_arp.h net/route.h netpacket/packet.h sys/prctl.h sys/mount.h sys/vfs.h sys/statfs.h sys/timex.h sys/sysinfo.h utime.h linux/ether.h linux/fs.h linux/ptrace.h linux/reboot.h netinet/icmp6.h netinet/in_syst.h netinet/ip.h netinet/ip_mroute.h netinet/if_ether.h)
 
 AC_CHECK_HEADERS([linux/filter.h linux/if_addr.h linux/if_ether.h linux/if_tun.h linux/netlink.h linux/rtnetlink.h], [], [],
 [#ifdef HAVE_SYS_SOCKET_H
Index: libgo/go/runtime/lfstack_32bit.go
===================================================================
--- libgo/go/runtime/lfstack_32bit.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/runtime/lfstack_32bit.go	(.../branches/gcc-7-branch)
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
-// +build 386 arm nacl armbe m68k mips mipsle mips64p32 mips64p32le mipso32 mipsn32 ppc s390 sparc
+// +build 386 arm nacl armbe m68k mips mipsle mips64p32 mips64p32le ppc s390 sparc
 
 package runtime
 
Index: libgo/go/runtime/hash64.go
===================================================================
--- libgo/go/runtime/hash64.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/runtime/hash64.go	(.../branches/gcc-7-branch)
@@ -6,7 +6,7 @@
 //   xxhash: https://code.google.com/p/xxhash/
 // cityhash: https://code.google.com/p/cityhash/
 
-// +build amd64 amd64p32 arm64 mips64 mips64le ppc64 ppc64le s390x alpha arm64be ia64 mipso64 mipsn64 mips64p32 mips64p32le sparc64
+// +build amd64 amd64p32 arm64 mips64 mips64le ppc64 ppc64le s390x alpha arm64be ia64 mips64p32 mips64p32le sparc64
 
 package runtime
 
Index: libgo/go/runtime/lfstack_64bit.go
===================================================================
--- libgo/go/runtime/lfstack_64bit.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/runtime/lfstack_64bit.go	(.../branches/gcc-7-branch)
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
-// +build amd64 arm64 mips64 mips64le ppc64 ppc64le s390x arm64be alpha mipsn64 sparc64
+// +build amd64 arm64 mips64 mips64le ppc64 ppc64le s390x arm64be alpha sparc64
 
 package runtime
 
Index: libgo/go/runtime/hash32.go
===================================================================
--- libgo/go/runtime/hash32.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/runtime/hash32.go	(.../branches/gcc-7-branch)
@@ -6,7 +6,7 @@
 //   xxhash: https://code.google.com/p/xxhash/
 // cityhash: https://code.google.com/p/cityhash/
 
-// +build 386 arm armbe m68k mipso32 mipsn32 mips mipsle ppc s390 sparc
+// +build 386 arm armbe m68k mips mipsle ppc s390 sparc
 
 package runtime
 
Index: libgo/go/runtime/unaligned2.go
===================================================================
--- libgo/go/runtime/unaligned2.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/runtime/unaligned2.go	(.../branches/gcc-7-branch)
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
-// +build arm mips mipsle mips64 mips64le armbe m68k mipso32 mipsn32 sparc alpha ia64 mipso64 mipsn64 mips64p32 mips64p32le sparc64
+// +build arm mips mipsle mips64 mips64le armbe m68k sparc alpha ia64 mips64p32 mips64p32le sparc64
 
 package runtime
 
Index: libgo/go/cmd/go/build.go
===================================================================
--- libgo/go/cmd/go/build.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/cmd/go/build.go	(.../branches/gcc-7-branch)
@@ -3133,6 +3133,26 @@
 	desc := p.ImportPath
 	output, err := b.runOut(p.Dir, desc, nil, compiler, flags, "-o", outfile, "-c", file)
 	if len(output) > 0 {
+		// On FreeBSD 11, when we pass -g to clang 3.8 it
+		// invokes its internal assembler with -dwarf-version=2.
+		// When it sees .section .note.GNU-stack, it warns
+		// "DWARF2 only supports one section per compilation unit".
+		// This warning makes no sense, since the section is empty,
+		// but it confuses people.
+		// We work around the problem by detecting the warning
+		// and dropping -g and trying again.
+		if bytes.Contains(output, []byte("DWARF2 only supports one section per compilation unit")) {
+			newFlags := make([]string, 0, len(flags))
+			for _, f := range flags {
+				if !strings.HasPrefix(f, "-g") {
+					newFlags = append(newFlags, f)
+				}
+			}
+			if len(newFlags) < len(flags) {
+				return b.ccompile(p, outfile, newFlags, file, compiler)
+			}
+		}
+
 		b.showOutput(p.Dir, desc, b.processOutput(output))
 		if err != nil {
 			err = errPrintedOutput
Index: libgo/go/cmd/cgo/main.go
===================================================================
--- libgo/go/cmd/cgo/main.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/cmd/cgo/main.go	(.../branches/gcc-7-branch)
@@ -139,51 +139,47 @@
 }
 
 var ptrSizeMap = map[string]int64{
-	"386":      4,
-	"alpha":    8,
-	"amd64":    8,
-	"arm":      4,
-	"arm64":    8,
-	"m68k":     4,
-	"mipso32":  4,
-	"mipsn32":  4,
-	"mipso64":  8,
-	"mipsn64":  8,
-	"mips":     4,
-	"mipsle":   4,
-	"mips64":   8,
-	"mips64le": 8,
-	"ppc":      4,
-	"ppc64":    8,
-	"ppc64le":  8,
-	"s390":     4,
-	"s390x":    8,
-	"sparc":    4,
-	"sparc64":  8,
+	"386":         4,
+	"alpha":       8,
+	"amd64":       8,
+	"arm":         4,
+	"arm64":       8,
+	"m68k":        4,
+	"mips":        4,
+	"mipsle":      4,
+	"mips64":      8,
+	"mips64le":    8,
+	"mips64p32":   4,
+	"mips64p32le": 4,
+	"ppc":         4,
+	"ppc64":       8,
+	"ppc64le":     8,
+	"s390":        4,
+	"s390x":       8,
+	"sparc":       4,
+	"sparc64":     8,
 }
 
 var intSizeMap = map[string]int64{
-	"386":      4,
-	"alpha":    8,
-	"amd64":    8,
-	"arm":      4,
-	"arm64":    8,
-	"m68k":     4,
-	"mipso32":  4,
-	"mipsn32":  4,
-	"mipso64":  8,
-	"mipsn64":  8,
-	"mips":     4,
-	"mipsle":   4,
-	"mips64":   8,
-	"mips64le": 8,
-	"ppc":      4,
-	"ppc64":    8,
-	"ppc64le":  8,
-	"s390":     4,
-	"s390x":    8,
-	"sparc":    4,
-	"sparc64":  8,
+	"386":         4,
+	"alpha":       8,
+	"amd64":       8,
+	"arm":         4,
+	"arm64":       8,
+	"m68k":        4,
+	"mips":        4,
+	"mipsle":      4,
+	"mips64":      8,
+	"mips64le":    8,
+	"mips64p32":   8,
+	"mips64p32le": 8,
+	"ppc":         4,
+	"ppc64":       8,
+	"ppc64le":     8,
+	"s390":        4,
+	"s390x":       8,
+	"sparc":       4,
+	"sparc64":     8,
 }
 
 var cPrefix string
Index: libgo/go/database/sql/sql_test.go
===================================================================
--- libgo/go/database/sql/sql_test.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/database/sql/sql_test.go	(.../branches/gcc-7-branch)
@@ -322,7 +322,7 @@
 	select {
 	case <-ctx.Done():
 		if err := ctx.Err(); err != context.Canceled {
-			t.Fatalf("context err = %v; want context.Canceled")
+			t.Fatalf("context err = %v; want context.Canceled", ctx.Err())
 		}
 	default:
 		t.Fatalf("context err = nil; want context.Canceled")
@@ -413,7 +413,8 @@
 	db := newTestDB(t, "people")
 	defer closeDB(t, db)
 
-	ctx, _ := context.WithTimeout(context.Background(), time.Millisecond*15)
+	ctx, cancel := context.WithTimeout(context.Background(), time.Millisecond*15)
+	defer cancel()
 
 	tx, err := db.BeginTx(ctx, nil)
 	if err != nil {
Index: libgo/go/database/sql/sql.go
===================================================================
--- libgo/go/database/sql/sql.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/database/sql/sql.go	(.../branches/gcc-7-branch)
@@ -1955,12 +1955,12 @@
 				rowsi: rowsi,
 				// releaseConn set below
 			}
-			rows.initContextClose(ctx)
 			s.db.addDep(s, rows)
 			rows.releaseConn = func(err error) {
 				releaseConn(err)
 				s.db.removeDep(s, rows)
 			}
+			rows.initContextClose(ctx)
 			return rows, nil
 		}
 
Index: libgo/go/internal/syscall/unix/getrandom_linux_mipso32.go
===================================================================
--- libgo/go/internal/syscall/unix/getrandom_linux_mipso32.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/internal/syscall/unix/getrandom_linux_mipso32.go	(.../branches/gcc-7-branch)	(nonexistent)
@@ -1,11 +0,0 @@
-// Copyright 2016 The Go Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style
-// license that can be found in the LICENSE file.
-
-// +build mipso32
-
-package unix
-
-// Linux getrandom system call number.
-// See GetRandom in getrandom_linux.go.
-const randomTrap uintptr = 4353
Index: libgo/go/internal/syscall/unix/getrandom_linux_mipsn32.go
===================================================================
--- libgo/go/internal/syscall/unix/getrandom_linux_mipsn32.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/internal/syscall/unix/getrandom_linux_mipsn32.go	(.../branches/gcc-7-branch)	(nonexistent)
@@ -1,11 +0,0 @@
-// Copyright 2016 The Go Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style
-// license that can be found in the LICENSE file.
-
-// +build mipsn32
-
-package unix
-
-// Linux getrandom system call number.
-// See GetRandom in getrandom_linux.go.
-const randomTrap uintptr = 6317
Index: libgo/go/internal/syscall/unix/getrandom_linux_mips64p32x.go
===================================================================
--- libgo/go/internal/syscall/unix/getrandom_linux_mips64p32x.go	(.../tags/gcc_7_2_0_release)	(nonexistent)
+++ libgo/go/internal/syscall/unix/getrandom_linux_mips64p32x.go	(.../branches/gcc-7-branch)
@@ -0,0 +1,11 @@
+// Copyright 2016 The Go Authors. All rights reserved.
+// Use of this source code is governed by a BSD-style
+// license that can be found in the LICENSE file.
+
+// +build mips64p32 mips64p32le
+
+package unix
+
+// Linux getrandom system call number.
+// See GetRandom in getrandom_linux.go.
+const randomTrap uintptr = 6317
Index: libgo/go/internal/syscall/unix/getrandom_linux_mips64x.go
===================================================================
--- libgo/go/internal/syscall/unix/getrandom_linux_mips64x.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/internal/syscall/unix/getrandom_linux_mips64x.go	(.../branches/gcc-7-branch)
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
-// +build mips64 mips64le mipsn64 mipso64
+// +build mips64 mips64le
 
 package unix
 
Index: libgo/go/crypto/elliptic/elliptic_test.go
===================================================================
--- libgo/go/crypto/elliptic/elliptic_test.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/crypto/elliptic/elliptic_test.go	(.../branches/gcc-7-branch)
@@ -300,6 +300,29 @@
 	},
 }
 
+type scalarMultTest struct {
+	k          string
+	xIn, yIn   string
+	xOut, yOut string
+}
+
+var p256MultTests = []scalarMultTest{
+	{
+		"2a265f8bcbdcaf94d58519141e578124cb40d64a501fba9c11847b28965bc737",
+		"023819813ac969847059028ea88a1f30dfbcde03fc791d3a252c6b41211882ea",
+		"f93e4ae433cc12cf2a43fc0ef26400c0e125508224cdb649380f25479148a4ad",
+		"4d4de80f1534850d261075997e3049321a0864082d24a917863366c0724f5ae3",
+		"a22d2b7f7818a3563e0f7a76c9bf0921ac55e06e2e4d11795b233824b1db8cc0",
+	},
+	{
+		"313f72ff9fe811bf573176231b286a3bdb6f1b14e05c40146590727a71c3bccd",
+		"cc11887b2d66cbae8f4d306627192522932146b42f01d3c6f92bd5c8ba739b06",
+		"a2f08a029cd06b46183085bae9248b0ed15b70280c7ef13a457f5af382426031",
+		"831c3f6b5f762d2f461901577af41354ac5f228c2591f84f8a6e51e2e3f17991",
+		"93f90934cd0ef2c698cc471c60a93524e87ab31ca2412252337f364513e43684",
+	},
+}
+
 func TestBaseMult(t *testing.T) {
 	p224 := P224()
 	for i, e := range p224BaseMultTests {
@@ -379,6 +402,19 @@
 			break
 		}
 	}
+
+	for i, e := range p256MultTests {
+		x, _ := new(big.Int).SetString(e.xIn, 16)
+		y, _ := new(big.Int).SetString(e.yIn, 16)
+		k, _ := new(big.Int).SetString(e.k, 16)
+		expectedX, _ := new(big.Int).SetString(e.xOut, 16)
+		expectedY, _ := new(big.Int).SetString(e.yOut, 16)
+
+		xx, yy := p256.ScalarMult(x, y, k.Bytes())
+		if xx.Cmp(expectedX) != 0 || yy.Cmp(expectedY) != 0 {
+			t.Errorf("#%d: got (%x, %x), want (%x, %x)", i, xx, yy, expectedX, expectedY)
+		}
+	}
 }
 
 func TestInfinity(t *testing.T) {
Index: libgo/go/net/http/h2_bundle.go
===================================================================
--- libgo/go/net/http/h2_bundle.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/net/http/h2_bundle.go	(.../branches/gcc-7-branch)
@@ -1,4 +1,4 @@
-// Code generated by golang.org/x/tools/cmd/bundle.
+// Code generated by golang.org/x/tools/cmd/bundle. DO NOT EDIT.
 //go:generate bundle -o h2_bundle.go -prefix http2 -underscore golang.org/x/net/http2
 
 // Package http2 implements the HTTP/2 protocol.
@@ -3536,9 +3536,13 @@
 		sc.idleTimerCh = sc.idleTimer.C
 	}
 
-	var gracefulShutdownCh <-chan struct{}
+	var gracefulShutdownCh chan struct{}
 	if sc.hs != nil {
-		gracefulShutdownCh = http2h1ServerShutdownChan(sc.hs)
+		ch := http2h1ServerShutdownChan(sc.hs)
+		if ch != nil {
+			gracefulShutdownCh = make(chan struct{})
+			go sc.awaitGracefulShutdown(ch, gracefulShutdownCh)
+		}
 	}
 
 	go sc.readFrames()
@@ -3587,6 +3591,14 @@
 	}
 }
 
+func (sc *http2serverConn) awaitGracefulShutdown(sharedCh <-chan struct{}, privateCh chan struct{}) {
+	select {
+	case <-sc.doneServing:
+	case <-sharedCh:
+		close(privateCh)
+	}
+}
+
 // readPreface reads the ClientPreface greeting from the peer
 // or returns an error on timeout or an invalid greeting.
 func (sc *http2serverConn) readPreface() error {
@@ -6003,7 +6015,6 @@
 	}
 	if len(keys) > 0 {
 		sort.Strings(keys)
-
 		return strings.Join(keys, ","), nil
 	}
 	return "", nil
Index: libgo/go/go/build/syslist.go
===================================================================
--- libgo/go/go/build/syslist.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/go/build/syslist.go	(.../branches/gcc-7-branch)
@@ -5,4 +5,4 @@
 package build
 
 const goosList = "android darwin dragonfly freebsd linux nacl netbsd openbsd plan9 solaris windows zos "
-const goarchList = "386 amd64 amd64p32 arm armbe arm64 arm64be alpha m68k ppc64 ppc64le mips mipsle mips64 mips64le mips64p32 mips64p32le mipso32 mipsn32 mipsn64 mipso64 ppc s390 s390x sparc sparc64 "
+const goarchList = "386 amd64 amd64p32 arm armbe arm64 arm64be alpha m68k ppc64 ppc64le mips mipsle mips64 mips64le mips64p32 mips64p32le ppc s390 s390x sparc sparc64 "
Index: libgo/go/syscall/syscall_linux_mips64x.go
===================================================================
--- libgo/go/syscall/syscall_linux_mips64x.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/syscall/syscall_linux_mips64x.go	(.../branches/gcc-7-branch)	(nonexistent)
@@ -1,20 +0,0 @@
-// Copyright 2009 The Go Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style
-// license that can be found in the LICENSE file.
-
-// +build linux
-// +build mips64 mips64le
-
-package syscall
-
-func (r *PtraceRegs) PC() uint64 { return r.Regs[64] }
-
-func (r *PtraceRegs) SetPC(pc uint64) { r.Regs[64] = pc }
-
-func PtraceGetRegs(pid int, regsout *PtraceRegs) (err error) {
-	return ptrace(PTRACE_GETREGS, pid, 0, uintptr(unsafe.Pointer(regsout)))
-}
-
-func PtraceSetRegs(pid int, regs *PtraceRegs) (err error) {
-	return ptrace(PTRACE_SETREGS, pid, 0, uintptr(unsafe.Pointer(regs)))
-}
Index: libgo/go/syscall/endian_big.go
===================================================================
--- libgo/go/syscall/endian_big.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/syscall/endian_big.go	(.../branches/gcc-7-branch)
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 //
-// +build ppc64 s390x mips mips64 armbe arm64be m68k ppc mipso32 mipsn32 mipso64 mipsn64 mips64p32 s390 sparc sparc64
+// +build ppc64 s390x mips mips64 armbe arm64be m68k ppc mips64p32 s390 sparc sparc64
 
 package syscall
 
Index: libgo/go/syscall/syscall_linux_alpha.go
===================================================================
--- libgo/go/syscall/syscall_linux_alpha.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/syscall/syscall_linux_alpha.go	(.../branches/gcc-7-branch)
@@ -8,38 +8,6 @@
 
 import "unsafe"
 
-type PtraceRegs struct {
-	R0      uint64
-	R1      uint64
-	R2      uint64
-	R3      uint64
-	R4      uint64
-	R5      uint64
-	R6      uint64
-	R7      uint64
-	R8      uint64
-	R19     uint64
-	R20     uint64
-	R21     uint64
-	R22     uint64
-	R23     uint64
-	R24     uint64
-	R25     uint64
-	R26     uint64
-	R27     uint64
-	R28     uint64
-	Hae     uint64
-	Trap_a0 uint64
-	Trap_a1 uint64
-	Trap_a2 uint64
-	Ps      uint64
-	Pc      uint64
-	Gp      uint64
-	R16     uint64
-	R17     uint64
-	R18     uint64
-}
-
 func (r *PtraceRegs) PC() uint64 {
 	return r.Pc
 }
Index: libgo/go/syscall/syscall_linux_mipsx.go
===================================================================
--- libgo/go/syscall/syscall_linux_mipsx.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/syscall/syscall_linux_mipsx.go	(.../branches/gcc-7-branch)
@@ -3,10 +3,24 @@
 // license that can be found in the LICENSE file.
 
 // +build linux
-// +build mips mipsle
+// +build mips mipsle mips64 mips64le mips64p32 mips64p32le
 
 package syscall
 
-func (r *PtraceRegs) PC() uint64 { return uint64(r.Regs[64]) }
+import "unsafe"
 
-func (r *PtraceRegs) SetPC(pc uint64) { r.Regs[64] = uint32(pc) }
+func (r *PtraceRegs) PC() uint64 {
+	return r.Cp0_epc
+}
+
+func (r *PtraceRegs) SetPC(pc uint64) {
+	r.Cp0_epc = pc
+}
+
+func PtraceGetRegs(pid int, regsout *PtraceRegs) (err error) {
+	return ptrace(PTRACE_GETREGS, pid, 0, uintptr(unsafe.Pointer(regsout)))
+}
+
+func PtraceSetRegs(pid int, regs *PtraceRegs) (err error) {
+	return ptrace(PTRACE_SETREGS, pid, 0, uintptr(unsafe.Pointer(regs)))
+}
Index: libgo/go/syscall/syscall_linux_s390x.go
===================================================================
--- libgo/go/syscall/syscall_linux_s390x.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/syscall/syscall_linux_s390x.go	(.../branches/gcc-7-branch)
@@ -8,9 +8,9 @@
 
 import "unsafe"
 
-func (r *PtraceRegs) PC() uint64 { return r.Psw.Addr }
+func (r *PtraceRegs) PC() uint64 { return r.Psw.addr }
 
-func (r *PtraceRegs) SetPC(pc uint64) { r.Psw.Addr = pc }
+func (r *PtraceRegs) SetPC(pc uint64) { r.Psw.addr = pc }
 
 const syscall_PTRACE_PEEKUSR_AREA = 0x5000
 const syscall_PTRACE_POKEUSR_AREA = 0x5001
Index: libgo/go/syscall/syscall_linux_s390.go
===================================================================
--- libgo/go/syscall/syscall_linux_s390.go	(.../tags/gcc_7_2_0_release)
+++ libgo/go/syscall/syscall_linux_s390.go	(.../branches/gcc-7-branch)
@@ -8,9 +8,9 @@
 
 import "unsafe"
 
-func (r *PtraceRegs) PC() uint64 { return uint64(r.Psw.Addr) }
+func (r *PtraceRegs) PC() uint64 { return uint64(r.Psw.addr) }
 
-func (r *PtraceRegs) SetPC(pc uint64) { r.Psw.Addr = uint32(pc) }
+func (r *PtraceRegs) SetPC(pc uint64) { r.Psw.addr = uint32(pc) }
 
 const syscall_PTRACE_PEEKUSR_AREA = 0x5000
 const syscall_PTRACE_POKEUSR_AREA = 0x5001
Index: libgo/match.sh
===================================================================
--- libgo/match.sh	(.../tags/gcc_7_2_0_release)
+++ libgo/match.sh	(.../branches/gcc-7-branch)
@@ -116,7 +116,7 @@
 	android | darwin | dragonfly | freebsd | linux | nacl | netbsd | openbsd | plan9 | solaris | windows)
 	    tag1=nonmatchingtag
 	    ;;
-	386 | amd64 | amd64p32 | arm | armbe | arm64 | arm64be | alpha | ia64 | m68k | ppc64 | ppc64le | mips | mipsle | mips64 | mips64le | mips64p32 | mips64p32le | mipso32 | mipsn32 | mipsn64 | mipso64 | ppc | s390 | s390x | sparc | sparc64)
+	386 | amd64 | amd64p32 | arm | armbe | arm64 | arm64be | alpha | ia64 | m68k | ppc64 | ppc64le | mips | mipsle | mips64 | mips64le | mips64p32 | mips64p32le | ppc | s390 | s390x | sparc | sparc64)
 	    tag1=nonmatchingtag
 	    ;;
     esac
@@ -128,7 +128,7 @@
 	android | darwin | dragonfly | freebsd | linux | nacl | netbsd | openbsd | plan9 | solaris | windows)
 	    tag2=nonmatchingtag
 	    ;;
-	386 | amd64 | amd64p32 | arm | armbe | arm64 | arm64be | alpha | ia64 | m68k | ppc64 | ppc64le | mips | mipsle | mips64 | mips64le | mips64p32 | mips64p32le | mipso32 | mipsn32 | mipsn64 | mipso64 | ppc | s390 | s390x | sparc | sparc64)
+	386 | amd64 | amd64p32 | arm | armbe | arm64 | arm64be | alpha | ia64 | m68k | ppc64 | ppc64le | mips | mipsle | mips64 | mips64le | mips64p32 | mips64p32le | ppc | s390 | s390x | sparc | sparc64)
 	    tag2=nonmatchingtag
 	    ;;
     esac
Index: libgo/sysinfo.c
===================================================================
--- libgo/sysinfo.c	(.../tags/gcc_7_2_0_release)
+++ libgo/sysinfo.c	(.../branches/gcc-7-branch)
@@ -102,6 +102,9 @@
 #if defined(HAVE_LINUX_NETLINK_H)
 #include <linux/netlink.h>
 #endif
+#if defined(HAVE_LINUX_PTRACE_H)
+#include <linux/ptrace.h>
+#endif
 #if defined(HAVE_LINUX_RTNETLINK_H)
 #include <linux/rtnetlink.h>
 #endif
Index: libgfortran/intrinsics/execute_command_line.c
===================================================================
--- libgfortran/intrinsics/execute_command_line.c	(.../tags/gcc_7_2_0_release)
+++ libgfortran/intrinsics/execute_command_line.c	(.../branches/gcc-7-branch)
@@ -125,15 +125,9 @@
   free (cmd);
 
   /* Now copy back to the Fortran string if needed.  */
-  if (cmdstat && *cmdstat > EXEC_NOERROR)
-    {
-      if (cmdmsg)
-	fstrcpy (cmdmsg, cmdmsg_len, cmdmsg_values[*cmdstat],
+  if (cmdstat && *cmdstat > EXEC_NOERROR && cmdmsg)
+    fstrcpy (cmdmsg, cmdmsg_len, cmdmsg_values[*cmdstat],
 		strlen (cmdmsg_values[*cmdstat]));
-      else
-	runtime_error ("Failure in EXECUTE_COMMAND_LINE: %s",
-		       cmdmsg_values[*cmdstat]);
-    }
 }
 
 
Index: libgfortran/ChangeLog
===================================================================
--- libgfortran/ChangeLog	(.../tags/gcc_7_2_0_release)
+++ libgfortran/ChangeLog	(.../branches/gcc-7-branch)
@@ -1,3 +1,30 @@
+2017-10-27  Jerry DeLisle  <jvdelisle@gcc.gnu.org>
+	    Rimvydas (RJ)
+
+	Backport from trunk
+	PR libgfortran/81938
+	io/format.c (free_format_data): Don't try to free vlist
+	descriptors past the end of the fnode array.
+
+2017-10-19  Thomas Koenig  <tkoenig@gcc.gnu.org>
+
+	Backport from trunk
+	PR libfortran/82233
+	* intrinsics/execute_command_line.c (execute_command_line):
+	No call to runtime_error if cmdstat is present.
+
+2017-09-19  Jerry DeLisle  <jvdelisle@gcc.gnu.org>
+
+	Backport from trunk
+	PR libgfortran/78387
+	* io/list_read.c (nml_read_obj): Remove use of stash.
+	* io/transfer.c (st_read_done, st_write_done): Likewise.
+	* io/unit.c (stash_internal_unit): Delete function.
+	(get_unit): Remove use of stash.
+	(init_units): Likewise.
+	(close_units): Likewise.
+	* io/write.c (nml_write_obj): Likewise:
+
 2017-08-14  Release Manager
 
 	* GCC 7.2.0 released.
Index: libgfortran/io/list_read.c
===================================================================
--- libgfortran/io/list_read.c	(.../tags/gcc_7_2_0_release)
+++ libgfortran/io/list_read.c	(.../branches/gcc-7-branch)
@@ -3019,11 +3019,6 @@
 		    child_iomsg_len = IOMSG_LEN;
 		  }
 
-		/* If reading from an internal unit, stash it to allow
-		   the child procedure to access it.  */
-		if (is_internal_unit (dtp))
-		  stash_internal_unit (dtp);
-
 		/* Call the user defined formatted READ procedure.  */
 		dtp->u.p.current_unit->child_dtio++;
 		dtio_ptr ((void *)&list_obj, &unit, iotype, &vlist,
Index: libgfortran/io/unit.c
===================================================================
--- libgfortran/io/unit.c	(.../tags/gcc_7_2_0_release)
+++ libgfortran/io/unit.c	(.../branches/gcc-7-branch)
@@ -94,16 +94,6 @@
 /* Unit numbers assigned with NEWUNIT start from here.  */
 #define NEWUNIT_START -10
 
-
-#define NEWUNIT_STACK_SIZE 16
-
-/* A stack to save previously used newunit-assigned unit numbers to
-   allow them to be reused without reallocating the gfc_unit structure
-   which is still in the treap.  */
-static gfc_saved_unit newunit_stack[NEWUNIT_STACK_SIZE];
-static int newunit_tos = 0; /* Index to Top of Stack.  */
-
-
 #define CACHE_SIZE 3
 static gfc_unit *unit_cache[CACHE_SIZE];
 gfc_offset max_offset;
@@ -538,22 +528,6 @@
 }
 
 
-/* stash_internal_unit()-- Push the internal unit number onto the
-   avaialble stack.  */
-void
-stash_internal_unit (st_parameter_dt *dtp)
-{
-  __gthread_mutex_lock (&unit_lock);
-  newunit_tos++;
-  if (newunit_tos >= NEWUNIT_STACK_SIZE)
-    internal_error (&dtp->common, "stash_internal_unit(): Stack Size Exceeded");
-  newunit_stack[newunit_tos].unit_number = dtp->common.unit;
-  newunit_stack[newunit_tos].unit = dtp->u.p.current_unit;
-  __gthread_mutex_unlock (&unit_lock);
-}
-
-
-
 /* get_unit()-- Returns the unit structure associated with the integer
    unit or the internal file.  */
 
@@ -572,49 +546,13 @@
       else
 	internal_error (&dtp->common, "get_unit(): Bad internal unit KIND");
 
-      if ((dtp->common.flags & IOPARM_DT_HAS_UDTIO) != 0)
-	{
-	  dtp->u.p.unit_is_internal = 1;
-	  dtp->common.unit = newunit_alloc ();
-	  unit = get_gfc_unit (dtp->common.unit, do_create);
-	  set_internal_unit (dtp, unit, kind);
-	  fbuf_init (unit, 128);
-	  return unit;
-	}
-      else
-	{
-	  __gthread_mutex_lock (&unit_lock);
-	  if (newunit_tos)
-	    {
-	      dtp->common.unit = newunit_stack[newunit_tos].unit_number;
-	      unit = newunit_stack[newunit_tos--].unit;
-	      __gthread_mutex_unlock (&unit_lock);
-	      unit->fbuf->act = unit->fbuf->pos = 0;
-	    }
-	  else
-	    {
-	      __gthread_mutex_unlock (&unit_lock);
-	      dtp->common.unit = newunit_alloc ();
-	      unit = xcalloc (1, sizeof (gfc_unit));
-	      fbuf_init (unit, 128);
-	    }
-	  set_internal_unit (dtp, unit, kind);
-	  return unit;
-	}
-    }
-
-  /* If an internal unit number is passed from the parent to the child
-     it should have been stashed on the newunit_stack ready to be used.
-     Check for it now and return the internal unit if found.  */
-  __gthread_mutex_lock (&unit_lock);
-  if (newunit_tos && (dtp->common.unit <= NEWUNIT_START)
-      && (dtp->common.unit == newunit_stack[newunit_tos].unit_number))
-    {
-      unit = newunit_stack[newunit_tos--].unit;
-      __gthread_mutex_unlock (&unit_lock);
+      dtp->u.p.unit_is_internal = 1;
+      dtp->common.unit = newunit_alloc ();
+      unit = get_gfc_unit (dtp->common.unit, do_create);
+      set_internal_unit (dtp, unit, kind);
+      fbuf_init (unit, 128);
       return unit;
     }
-  __gthread_mutex_unlock (&unit_lock);
 
   /* Has to be an external unit.  */
   dtp->u.p.unit_is_internal = 0;
@@ -752,10 +690,6 @@
   max_offset = 0;
   for (i = 0; i < sizeof (max_offset) * 8 - 1; i++)
     max_offset = max_offset + ((gfc_offset) 1 << i);
-
-  /* Initialize the newunit stack.  */
-  memset (newunit_stack, 0, NEWUNIT_STACK_SIZE * sizeof(gfc_saved_unit));
-  newunit_tos = 0;
 }
 
 
@@ -837,14 +771,6 @@
     close_unit_1 (unit_root, 1);
   __gthread_mutex_unlock (&unit_lock);
 
-  while (newunit_tos != 0)
-    if (newunit_stack[newunit_tos].unit)
-      {
-	fbuf_destroy (newunit_stack[newunit_tos].unit);
-	free (newunit_stack[newunit_tos].unit->s);
-	free (newunit_stack[newunit_tos--].unit);
-      }
-
   free (newunits);
 
 #ifdef HAVE_FREELOCALE
Index: libgfortran/io/transfer.c
===================================================================
--- libgfortran/io/transfer.c	(.../tags/gcc_7_2_0_release)
+++ libgfortran/io/transfer.c	(.../branches/gcc-7-branch)
@@ -4080,8 +4080,7 @@
   free_ionml (dtp);
 
   /* If this is a parent READ statement we do not need to retain the
-     internal unit structure for child use.  Free it and stash the unit
-     number for reuse.  */
+     internal unit structure for child use.  */
   if (dtp->u.p.current_unit != NULL
       && dtp->u.p.current_unit->child_dtio == 0)
     {
@@ -4095,7 +4094,6 @@
 	  if (dtp->u.p.current_unit->ls)
 	    free (dtp->u.p.current_unit->ls);
 	  dtp->u.p.current_unit->ls = NULL;
-	  stash_internal_unit (dtp);
 	}
       if (is_internal_unit (dtp) || dtp->u.p.format_not_saved)
 	{
@@ -4153,8 +4151,7 @@
       free_ionml (dtp);
 
       /* If this is a parent WRITE statement we do not need to retain the
-	 internal unit structure for child use.  Free it and stash the
-	 unit number for reuse.  */
+	 internal unit structure for child use.  */
       if (is_internal_unit (dtp) &&
 	  (dtp->common.flags & IOPARM_DT_HAS_UDTIO) == 0)
 	{
@@ -4165,7 +4162,6 @@
 	  if (dtp->u.p.current_unit->ls)
 	    free (dtp->u.p.current_unit->ls);
 	  dtp->u.p.current_unit->ls = NULL;
-	  stash_internal_unit (dtp);
 	}
       if (is_internal_unit (dtp) || dtp->u.p.format_not_saved)
 	{
Index: libgfortran/io/format.c
===================================================================
--- libgfortran/io/format.c	(.../tags/gcc_7_2_0_release)
+++ libgfortran/io/format.c	(.../branches/gcc-7-branch)
@@ -266,7 +266,8 @@
     return;
 
   /* Free vlist descriptors in the fnode_array if one was allocated.  */
-  for (fnp = fmt->array.array; fnp->format != FMT_NONE; fnp++)
+  for (fnp = fmt->array.array; fnp < &fmt->array.array[FARRAY_SIZE] &&
+       fnp->format != FMT_NONE; fnp++)
     if (fnp->format == FMT_DT)
 	{
 	  if (GFC_DESCRIPTOR_DATA(fnp->u.udf.vlist))
Index: libgfortran/io/write.c
===================================================================
--- libgfortran/io/write.c	(.../tags/gcc_7_2_0_release)
+++ libgfortran/io/write.c	(.../branches/gcc-7-branch)
@@ -2248,11 +2248,6 @@
 		      child_iomsg_len = IOMSG_LEN;
 		    }
 
-		  /* If writing to an internal unit, stash it to allow
-		     the child procedure to access it.  */
-		  if (is_internal_unit (dtp))
-		    stash_internal_unit (dtp);
-		      
 		  /* Call the user defined formatted WRITE procedure.  */
 		  dtp->u.p.current_unit->child_dtio++;
 		  if (obj->type == BT_DERIVED)
Index: .
===================================================================
--- .	(.../tags/gcc_7_2_0_release)
+++ .	(.../branches/gcc-7-branch)

Property changes on: .
___________________________________________________________________
Modified: svn:mergeinfo
## -0,0 +0,1 ##
   Merged /trunk:r253187,253451,254099
